#!/usr/bin/python
# coding = utf-8
import numpy as np
import pandas as pd
from WindPy import w
def convertInputSecurityType(func):
    def convertedFunc(*args):
        args = tuple((i.strftime("%Y-%m-%d") if hasattr(i,"strftime") else i for i in args))
        if type(args[0])==type(''):
            return func(*args)[1].fillna(np.nan)
        else:
            security = args[0]
            args = args[1:]
            return func(",".join(security),*args)[1].fillna(np.nan)
    return convertedFunc
@convertInputSecurityType
def getMmAvgPtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期末投资组合平均剩余期限时间序列
    return w.wsd(security,"mmavgptm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmAvgPtMMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内投资组合平均剩余期限最高值时间序列
    return w.wsd(security,"mmavgptm_max",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmAvgPtMMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内投资组合平均剩余期限最低值时间序列
    return w.wsd(security,"mmavgptm_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondByCreditRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取按信用评级的债券投资市值时间序列
    return w.wsd(security,"prt_bondbycreditrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtAbsByCreditRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取按信用评级的资产支持证券投资市值时间序列
    return w.wsd(security,"prt_absbycreditrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNcdByCreditRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取按信用评级的同业存单投资市值时间序列
    return w.wsd(security,"prt_ncdbycreditrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondByCreditRatingToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取按信用评级的债券投资占基金资产净值比时间序列
    return w.wsd(security,"prt_bondbycreditratingtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtAbsByCreditRatingToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取按信用评级的资产支持证券投资占基金资产净值比时间序列
    return w.wsd(security,"prt_absbycreditratingtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNcdByCreditRatingToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取按信用评级的同业存单投资占基金资产净值比时间序列
    return w.wsd(security,"prt_ncdbycreditratingtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInStYyBondValSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券估值(YY)时间序列
    return w.wsd(security,"inst_yybondval",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInStYyBondValHisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券估值历史(YY)时间序列
    return w.wsd(security,"inst_yybondvalhis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgBalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融资融券余额时间序列
    return w.wsd(security,"mrg_bal",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginGuaranteedStocksMarketValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融资融券担保股票市值时间序列
    return w.wsd(security,"margin_guaranteedstocksmarketvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否融资融券标的时间序列
    return w.wsd(security,"marginornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgBalIntAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融资融券余额均值时间序列
    return w.wsd(security,"mrg_bal_int_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1511Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入:融资融券业务时间序列
    return w.wsd(security,"stmnote_sec_1511",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1531Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息净收入:融资融券业务时间序列
    return w.wsd(security,"stmnote_sec_1531",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌_期货历史同月时间序列
    return w.wsd(security,"His_change",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisSwingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取振幅_期货历史同月时间序列
    return w.wsd(security,"His_swing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价_期货历史同月时间序列
    return w.wsd(security,"His_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisOpenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘价_期货历史同月时间序列
    return w.wsd(security,"His_open",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高价_期货历史同月时间序列
    return w.wsd(security,"His_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低价_期货历史同月时间序列
    return w.wsd(security,"His_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisSettleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取结算价_期货历史同月时间序列
    return w.wsd(security,"His_settle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅_期货历史同月时间序列
    return w.wsd(security,"His_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量_期货历史同月时间序列
    return w.wsd(security,"His_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisTurnoverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交额_期货历史同月时间序列
    return w.wsd(security,"His_turnover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量_期货历史同月时间序列
    return w.wsd(security,"His_oi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisPreSettleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前结算价_期货历史同月时间序列
    return w.wsd(security,"His_preSettle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisAvgPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交均价_期货历史同月时间序列
    return w.wsd(security,"His_avgprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisOiChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓变化_期货历史同月时间序列
    return w.wsd(security,"His_oichange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisCloseNightSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(夜盘)_期货历史同月时间序列
    return w.wsd(security,"His_close_night",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisChangeSettlementSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌(结算价)_期货历史同月时间序列
    return w.wsd(security,"His_change_settlement",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHisPctChangeSettlementSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅(结算价)_期货历史同月时间序列
    return w.wsd(security,"His_pctchange_settlement",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeAbstractSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩预告摘要时间序列
    return w.wsd(security,"profitnotice_abstract",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeReasonSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩预告变动原因时间序列
    return w.wsd(security,"profitnotice_reason",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩预告类型时间序列
    return w.wsd(security,"profitnotice_style",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩预告最新披露日期时间序列
    return w.wsd(security,"profitnotice_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeFirstDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩预告首次披露日期时间序列
    return w.wsd(security,"profitnotice_firstdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLastRpTDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新业绩预告报告期时间序列
    return w.wsd(security,"profitnotice_lastrptdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeAbstractSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.业绩预告摘要(海外)时间序列
    return w.wsd(security,"qprofitnotice_abstract",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.业绩预告类型(海外)时间序列
    return w.wsd(security,"qprofitnotice_style",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.业绩预告日期(海外)时间序列
    return w.wsd(security,"qprofitnotice_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressLastDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报最新披露日期时间序列
    return w.wsd(security,"performanceexpress_lastdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报首次披露日期时间序列
    return w.wsd(security,"performanceexpress_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.营业收入时间序列
    return w.wsd(security,"performanceexpress_perfexincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExprOfItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.营业利润时间序列
    return w.wsd(security,"performanceexpress_perfexprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExTotalProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.利润总额时间序列
    return w.wsd(security,"performanceexpress_perfextotalprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExNetProfitToShareholderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.归属母公司股东的净利润时间序列
    return w.wsd(security,"performanceexpress_perfexnetprofittoshareholder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressNpdEdToShareholderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.归属于上市公司股东的扣除非经常性损益的净利润时间序列
    return w.wsd(security,"performanceexpress_npdedtoshareholder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExEpsDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.每股收益EPS-基本时间序列
    return w.wsd(security,"performanceexpress_perfexepsdiluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExRoeDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.净资产收益率ROE-加权时间序列
    return w.wsd(security,"performanceexpress_perfexroediluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExTotalAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.总资产时间序列
    return w.wsd(security,"performanceexpress_perfextotalassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressPerFExNetAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.净资产时间序列
    return w.wsd(security,"performanceexpress_perfexnetassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressOrYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增长率:营业收入时间序列
    return w.wsd(security,"performanceexpress_or_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressOpYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增长率:营业利润时间序列
    return w.wsd(security,"performanceexpress_op_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressEBtYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增长率:利润总额时间序列
    return w.wsd(security,"performanceexpress_ebt_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressNpYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增长率:归属母公司股东的净利润时间序列
    return w.wsd(security,"performanceexpress_np_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressNpdEdYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增长率:归属于上市公司股东的扣除非经常性损益的净利润时间序列
    return w.wsd(security,"performanceexpress_npded_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressEpsYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增长率:基本每股收益时间序列
    return w.wsd(security,"performanceexpress_eps_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressRoeYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.同比增减:加权平均净资产收益率时间序列
    return w.wsd(security,"performanceexpress_roe_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressIncomeYaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.去年同期营业收入时间序列
    return w.wsd(security,"performanceexpress_income_ya",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressProfitYaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.去年同期营业利润时间序列
    return w.wsd(security,"performanceexpress_profit_ya",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressToTProfitYaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.去年同期利润总额时间序列
    return w.wsd(security,"performanceexpress_totprofit_ya",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressNetProfitYaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.去年同期净利润时间序列
    return w.wsd(security,"performanceexpress_netprofit_ya",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressNpdEdYaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.上年同期归属于上市公司股东的扣除非经常性损益的净利润时间序列
    return w.wsd(security,"performanceexpress_npded_ya",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressEpsYaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.去年同期每股收益时间序列
    return w.wsd(security,"performanceexpress_eps_ya",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.每股净资产时间序列
    return w.wsd(security,"performanceexpress_bps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressNetAssetsBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.期初净资产时间序列
    return w.wsd(security,"performanceexpress_netassets_b",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressBpSBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.期初每股净资产时间序列
    return w.wsd(security,"performanceexpress_bps_b",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressEqYGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.比年初增长率:归属母公司的股东权益时间序列
    return w.wsd(security,"performanceexpress_eqy_growth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressBpSGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.比年初增长率:归属于母公司股东的每股净资产时间序列
    return w.wsd(security,"performanceexpress_bps_growth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressToTAssetsGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩快报.比年初增长率:总资产时间序列
    return w.wsd(security,"performanceexpress_totassets_growth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceExpressLastRpTDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新业绩快报报告期时间序列
    return w.wsd(security,"performanceexpress_lastrptdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRelatedCbYearlyAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度可转债发行量时间序列
    return w.wsd(security,"relatedcb_yearlyamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueCoordinatorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金发行协调人时间序列
    return w.wsd(security,"issue_coordinator",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市基金发行价格时间序列
    return w.wsd(security,"issue_price",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs82Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金分红收益_FUND时间序列
    return w.wsd(security,"stm_is_82",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundScaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金规模时间序列
    return w.wsd(security,"fund_fundscale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetAssetTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金规模(合计)时间序列
    return w.wsd(security,"netasset_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属国民经济行业分类时间序列
    return w.wsd(security,"industry_nc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理层年度薪酬总额时间序列
    return w.wsd(security,"stmnote_mgmt_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPriceMhSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理层增持价格时间序列
    return w.wsd(security,"holder_price_mh",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareCnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中资中介机构持股数量时间序列
    return w.wsd(security,"share_CN",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国际中介机构持股数量时间序列
    return w.wsd(security,"share_OS",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctCnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中资中介机构持股占比时间序列
    return w.wsd(security,"share_pct_CN",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctOsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国际中介机构持股占比时间序列
    return w.wsd(security,"share_pct_OS",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取香港本地中介机构持股数量时间序列
    return w.wsd(security,"share_HK",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取香港本地中介机构持股占比时间序列
    return w.wsd(security,"share_pct_HK",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoIiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构调研家数时间序列
    return w.wsd(security,"ir_noii",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrIRfdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构调研首日时间序列
    return w.wsd(security,"ir_irfd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrIrlDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构调研最新日时间序列
    return w.wsd(security,"ir_irld",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoSoIiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资机构调研次数时间序列
    return w.wsd(security,"ir_nosoii",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoIiiiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资机构调研家数时间序列
    return w.wsd(security,"ir_noiiii",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNosOfISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外资机构调研次数时间序列
    return w.wsd(security,"ir_nosofi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoIiFiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外资机构调研家数时间序列
    return w.wsd(security,"ir_noiifi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareLiqAPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通A股占总股本比例时间序列
    return w.wsd(security,"share_liqa_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRestrictedAPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售A股占总股本比例时间序列
    return w.wsd(security,"share_restricteda_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTotalAPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取A股合计占总股本比例时间序列
    return w.wsd(security,"share_totala_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareLiqBPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通B股占总股本比例时间序列
    return w.wsd(security,"share_liqb_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRestrictedBPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售B股占总股本比例时间序列
    return w.wsd(security,"share_restrictedb_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTotalBPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取B股合计占总股本比例时间序列
    return w.wsd(security,"share_totalb_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcAPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取三板A股占总股本比例时间序列
    return w.wsd(security,"share_otca_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcBPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取三板B股占总股本比例时间序列
    return w.wsd(security,"share_otcb_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTotalOtcPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取三板合计占总股本比例时间序列
    return w.wsd(security,"share_totalotc_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareLiqHPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取香港上市股占总股本比例时间序列
    return w.wsd(security,"share_liqh_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOverSeaPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取海外上市股占总股本比例时间序列
    return w.wsd(security,"share_oversea_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTradablePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股合计占总股本比例时间序列
    return w.wsd(security,"share_tradable_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRestrictedPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股合计占总股本比例时间序列
    return w.wsd(security,"share_restricted_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareFreeFloatsHrPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自由流通股占总股本比例时间序列
    return w.wsd(security,"share_freefloatshr_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellShortIntRestPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未平仓卖空数占总股本比例时间序列
    return w.wsd(security,"shortsell_shortintrestpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareNonTradablePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股改前非流通股占总股本比例时间序列
    return w.wsd(security,"share_nontradable_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押股份数量合计时间序列
    return w.wsd(security,"share_pledgeda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额时间序列
    return w.wsd(security,"unit_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitFundShareTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额(合计)时间序列
    return w.wsd(security,"unit_fundshare_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额变化时间序列
    return w.wsd(security,"unit_change",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitChangeRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额变化率时间序列
    return w.wsd(security,"unit_changerate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额持有人户数时间序列
    return w.wsd(security,"holder_number",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderTotalNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额持有人户数(合计)时间序列
    return w.wsd(security,"fund_holder_totalnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitChangeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金份额变动日期时间序列
    return w.wsd(security,"unit_changedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期基金份额交易产生的基金净值变动数时间序列
    return w.wsd(security,"stm_navchange_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundShareTranslationDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF基金份额折算日时间序列
    return w.wsd(security,"fund_fundsharetranslationdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundShareTranslationRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF基金份额折算比例时间序列
    return w.wsd(security,"fund_fundsharetranslationratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期向基金份额持有人分配利润产生的基金净值变动数时间序列
    return w.wsd(security,"stm_navchange_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalNavReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.基金份额净值增长率时间序列
    return w.wsd(security,"qanal_navreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalStdNavReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.基金份额净值增长率标准差时间序列
    return w.wsd(security,"qanal_stdnavreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderAvgHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均每户持有基金份额时间序列
    return w.wsd(security,"holder_avgholding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalAccumulatedNavReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.累计基金份额净值增长率时间序列
    return w.wsd(security,"qanal_accumulatednavreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalAvgNetIncomePerUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.加权平均基金份额本期利润时间序列
    return w.wsd(security,"qanal_avgnetincomeperunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalAvgUnitIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.加权平均基金份额本期净收益时间序列
    return w.wsd(security,"qanal_avgunitincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalDIsTriButAblePerUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期末可供分配基金份额利润时间序列
    return w.wsd(security,"anal_distributableperunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.报告期期末基金份额净值时间序列
    return w.wsd(security,"qanal_nav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东户数时间序列
    return w.wsd(security,"holder_num",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构持股数量合计时间序列
    return w.wsd(security,"holder_totalbyinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构持股比例合计时间序列
    return w.wsd(security,"holder_pctbyinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSHClearL1TypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上清所债券分类时间序列
    return w.wsd(security,"shclearl1type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateOfStdBndSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标准券折算比例时间序列
    return w.wsd(security,"rateofstdbnd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2ToSharePriceAdjustItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股条款时间序列
    return w.wsd(security,"clause_conversion2_tosharepriceadjustitem",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedeemItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回条款时间序列
    return w.wsd(security,"clause_calloption_redeemitem",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedeemClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取时点赎回条款全文时间序列
    return w.wsd(security,"clause_calloption_redeemclause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMassRedemptionProvisionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取巨额赎回条款时间序列
    return w.wsd(security,"massredemptionprovision",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionIsWithTimeRedemptionClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否有时点赎回条款时间序列
    return w.wsd(security,"clause_calloption_iswithtimeredemptionclause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionSellBackItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取条件回售条款全文时间序列
    return w.wsd(security,"clause_putoption_sellbackitem",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionTimePutBackClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取时点回售条款全文时间序列
    return w.wsd(security,"clause_putoption_timeputbackclause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无条件回售条款时间序列
    return w.wsd(security,"clause_putoption_putbackclause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingLatestMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新评级月份时间序列
    return w.wsd(security,"rating_latestmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestIsSurerCreditRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新评级时间序列
    return w.wsd(security,"latestissurercreditrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingOutlooksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新评级展望时间序列
    return w.wsd(security,"ratingoutlooks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestIsSurerCreditRatingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新评级日期时间序列
    return w.wsd(security,"latestissurercreditratingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestRatingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新评级日期(指定机构)时间序列
    return w.wsd(security,"latestratingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLateIssuerChNgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新评级变动方向时间序列
    return w.wsd(security,"rate_lateissuerchng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestIsSurerCreditRatingTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新评级评级类型时间序列
    return w.wsd(security,"latestissurercreditratingtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestRatingOfGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人最新评级时间序列
    return w.wsd(security,"latestratingofguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLateGuarantorFwdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人最新评级展望时间序列
    return w.wsd(security,"rate_lateguarantorfwd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLateGuarantorDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人最新评级日期时间序列
    return w.wsd(security,"rate_lateguarantordate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLateGuaranTorchNgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人最新评级变动方向时间序列
    return w.wsd(security,"rate_lateguarantorchng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateBond2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券国际评级时间序列
    return w.wsd(security,"ratebond2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuer2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人国际评级时间序列
    return w.wsd(security,"issuer2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepoCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回购代码时间序列
    return w.wsd(security,"repo_code",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepoUBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的债券时间序列
    return w.wsd(security,"repo_ubond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmUbonDouStandingAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行时标的债券余额时间序列
    return w.wsd(security,"crm_ubondoustandingamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepoTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回购类型时间序列
    return w.wsd(security,"repo_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepoDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回购天数时间序列
    return w.wsd(security,"repo_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmCarryDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取凭证起始日时间序列
    return w.wsd(security,"crm_carrydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmSubjectCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的实体交易代码时间序列
    return w.wsd(security,"crm_subjectcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmPerformGuaranteeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取履约保障机制时间序列
    return w.wsd(security,"crm_performguarantee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmCreditEventSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用事件时间序列
    return w.wsd(security,"crm_creditevent",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditBondCreditStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券信用状态时间序列
    return w.wsd(security,"credit_bondcreditstatus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerFirstDefaultDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人首次违约日时间序列
    return w.wsd(security,"issuerfirstdefaultdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmRegisterAgencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取登记机构时间序列
    return w.wsd(security,"crm_registeragency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmSubjectSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的实体时间序列
    return w.wsd(security,"crm_subject",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发布机构时间序列
    return w.wsd(security,"crm_issuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmBookkeepingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取簿记建档日时间序列
    return w.wsd(security,"crm_bookkeepingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmPaymentTermsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取付费方式时间序列
    return w.wsd(security,"crm_paymentterms",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmStartingPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取创设价格时间序列
    return w.wsd(security,"crm_startingprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmPermissionNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取创设批准文件编号时间序列
    return w.wsd(security,"crm_permissionnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrmDateOfRecordSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取凭证登记日时间序列
    return w.wsd(security,"crm_dateofrecord",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundThirdPartyFundTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第三方基金分类时间序列
    return w.wsd(security,"fund_thirdpartyfundtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundProdTypeOcWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind封闭式开放式基金分类时间序列
    return w.wsd(security,"fund_prodtypeoc_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundManagerOfTradeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理时间序列
    return w.wsd(security,"fund_fundmanageroftradedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundManagerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理(现任)时间序列
    return w.wsd(security,"fund_fundmanager",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPRedFundManagerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理(历任)时间序列
    return w.wsd(security,"fund_predfundmanager",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInceptionFundManagerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理(成立)时间序列
    return w.wsd(security,"fund_inceptionfundmanager",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerManagerWorkingYearsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理年限时间序列
    return w.wsd(security,"fund_manager_managerworkingyears",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundAverageWorkingYearsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理平均年限时间序列
    return w.wsd(security,"fund_averageworkingyears",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMaxWorkingYearsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理最大年限时间序列
    return w.wsd(security,"fund_maxworkingyears",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数区间回报(算术平均)时间序列
    return w.wsd(security,"fund_managerindex_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexStDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数收益标准差(算术平均)时间序列
    return w.wsd(security,"fund_managerindex_stdev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexStDevYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数年化波动率(算术平均)时间序列
    return w.wsd(security,"fund_managerindex_stdevyearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexMaxDownsideSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数最大回撤(算术平均)时间序列
    return w.wsd(security,"fund_managerindex_maxdownside",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数区间回报(规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightStDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数收益标准差(规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_stdev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightStDevYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数年化波动率(规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_stdevyearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightMaxDownsideSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理指数最大回撤(规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_maxdownside",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFundManagersNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理数时间序列
    return w.wsd(security,"fund_corp_fundmanagersno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFundManagerMaturitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经理成熟度时间序列
    return w.wsd(security,"fund_corp_fundmanagermaturity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerProxyForManagerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代管基金经理说明时间序列
    return w.wsd(security,"fund_manager_proxyformanager",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexBetaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta(基金经理指数,算术平均)时间序列
    return w.wsd(security,"fund_managerindex_beta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightBetaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta(基金经理指数,规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_beta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexAlphaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha(基金经理指数,算术平均)时间序列
    return w.wsd(security,"fund_managerindex_alpha",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightAlphaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha(基金经理指数,规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_alpha",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe(基金经理指数,算术平均)时间序列
    return w.wsd(security,"fund_managerindex_sharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe(基金经理指数,规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_sharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexTreyNorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Treynor(基金经理指数,算术平均)时间序列
    return w.wsd(security,"fund_managerindex_treynor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerIndexWeightTreyNorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Treynor(基金经理指数,规模加权)时间序列
    return w.wsd(security,"fund_managerindex_weight_treynor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerLongestFundManagerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职期限最长的现任基金经理时间序列
    return w.wsd(security,"fund_manager_longestfundmanager",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrFcsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金公司调研次数时间序列
    return w.wsd(security,"ir_fcs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoFciSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金公司调研家数时间序列
    return w.wsd(security,"ir_nofci",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsFmSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下基金公司或其资管子公司配售数量时间序列
    return w.wsd(security,"fund__reitsfms",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsFMmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下基金公司或其资管子公司配售金额时间序列
    return w.wsd(security,"fund__reitsfmm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsFMrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下基金公司或其资管子公司配售份额占比时间序列
    return w.wsd(security,"fund__reitsfmr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsFmAsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下基金公司或其资管计划配售数量时间序列
    return w.wsd(security,"fund__reitsfmas",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsFmAmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下基金公司或其资管机构配售金额时间序列
    return w.wsd(security,"fund__reitsfmam",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsFMarSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下基金公司或其资管计划配售份额占比时间序列
    return w.wsd(security,"fund__reitsfmar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueHoldingIndustryMktValue2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属基金公司重仓行业市值时间序列
    return w.wsd(security,"prt_stockvalue_holdingindustrymktvalue2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrTmRfcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取调研最多的基金公司时间序列
    return w.wsd(security,"ir_tmrfc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFtDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开始交易日时间序列
    return w.wsd(security,"ftdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFtDateNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开始交易日(支持历史)时间序列
    return w.wsd(security,"ftdate_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastTradeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后交易日时间序列
    return w.wsd(security,"lasttrade_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtDateNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后交易日(支持历史)时间序列
    return w.wsd(security,"ltdate_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtDatedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后交易日说明时间序列
    return w.wsd(security,"ltdated",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastTradingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后交易日期时间序列
    return w.wsd(security,"lasttradingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivLastTrDDateShareBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取B股最后交易日时间序列
    return w.wsd(security,"div_lasttrddateshareb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastTradingDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)最后交易日时间序列
    return w.wsd(security,"lasttradingday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueRegDateShareBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权登记日(B股最后交易日)时间序列
    return w.wsd(security,"rightsissue_regdateshareb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastDeliveryDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后交割日时间序列
    return w.wsd(security,"lastdelivery_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLdDateNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后交割日(支持历史)时间序列
    return w.wsd(security,"lddate_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDlMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交割月份时间序列
    return w.wsd(security,"dlmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌基准价时间序列
    return w.wsd(security,"lprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTransactionFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期货交易手续费时间序列
    return w.wsd(security,"transactionfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeliveryFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期货交割手续费时间序列
    return w.wsd(security,"deliveryfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTodayPositionFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期货平今手续费时间序列
    return w.wsd(security,"todaypositionfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getScCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易品种时间序列
    return w.wsd(security,"sccode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易保证金时间序列
    return w.wsd(security,"margin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFtMarginsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最初交易保证金时间序列
    return w.wsd(security,"ftmargins",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1853Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益乘数(剔除客户交易保证金)时间序列
    return w.wsd(security,"stmnote_sec_1853",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期货多头保证金(支持历史)时间序列
    return w.wsd(security,"long_margin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期货空头保证金(支持历史)时间序列
    return w.wsd(security,"short_margin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPunItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价单位时间序列
    return w.wsd(security,"punit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChangeLtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅限制时间序列
    return w.wsd(security,"changelt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChangeLtNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅限制(支持历史)时间序列
    return w.wsd(security,"changelt_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最小变动价位时间序列
    return w.wsd(security,"mfprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfPrice1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最小变动价位(支持历史)时间序列
    return w.wsd(security,"mfprice1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getContractIssueDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标准合约上市日时间序列
    return w.wsd(security,"contract_issuedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合约乘数时间序列
    return w.wsd(security,"exe_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCdMonthsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合约月份说明时间序列
    return w.wsd(security,"cdmonths",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTHoursSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新交易时间说明时间序列
    return w.wsd(security,"thours",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交割日期说明时间序列
    return w.wsd(security,"ddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradeHisCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取月合约代码时间序列
    return w.wsd(security,"trade_hiscode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryFuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期货合约所属行业时间序列
    return w.wsd(security,"industry_fu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOptionsTradeCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期权代码(指定行权价)时间序列
    return w.wsd(security,"options_tradecode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAtmCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平值期权代码时间序列
    return w.wsd(security,"atmcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradeCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期权交易代码时间序列
    return w.wsd(security,"tradecode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的代码时间序列
    return w.wsd(security,"us_code",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的简称时间序列
    return w.wsd(security,"us_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基础资产/标的类型时间序列
    return w.wsd(security,"us_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExeModeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权方式时间序列
    return w.wsd(security,"exe_mode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExeTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权类型时间序列
    return w.wsd(security,"exe_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权价格时间序列
    return w.wsd(security,"exe_price",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPriceStockBasedCompensationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权激励行权价格时间序列
    return w.wsd(security,"holder_price_stockbasedcompensation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMainTMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期权维持保证金(支持历史)时间序列
    return w.wsd(security,"maint_margin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTotalTmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总存续期时间序列
    return w.wsd(security,"totaltm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取起始交易日期时间序列
    return w.wsd(security,"startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExeStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取起始行权日期时间序列
    return w.wsd(security,"exe_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExeEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最后行权日期时间序列
    return w.wsd(security,"exe_enddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSettlementMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交割方式时间序列
    return w.wsd(security,"settlementmethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前收盘价时间序列
    return w.wsd(security,"pre_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreClosePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间前收盘价时间序列
    return w.wsd(security,"pre_close_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsPreCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的前收盘价时间序列
    return w.wsd(security,"us_preclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockPreCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间前收盘价时间序列
    return w.wsd(security,"cb_pq_stockpreclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘价时间序列
    return w.wsd(security,"open",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpen3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘价(不前推)时间序列
    return w.wsd(security,"open3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpenPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间开盘价时间序列
    return w.wsd(security,"open_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsOpenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的开盘价时间序列
    return w.wsd(security,"us_open",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockOpenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间开盘价时间序列
    return w.wsd(security,"cb_pq_stockopen",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日开盘价时间序列
    return w.wsd(security,"ipo_open",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高价时间序列
    return w.wsd(security,"high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHigh3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高价(不前推)时间序列
    return w.wsd(security,"high3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHighPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高价时间序列
    return w.wsd(security,"high_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHighDatePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高价日时间序列
    return w.wsd(security,"high_date_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的最高价时间序列
    return w.wsd(security,"us_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgLowestPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间自最高价的最大跌幅时间序列
    return w.wsd(security,"pct_chg_lowest_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间最高价时间序列
    return w.wsd(security,"cb_pq_stockhigh",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日最高价时间序列
    return w.wsd(security,"ipo_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPohQeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取被剔除的最高价申报量占比时间序列
    return w.wsd(security,"pohqe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgLowPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新价较区间最高价跌幅(回撤)时间序列
    return w.wsd(security,"pct_chg_low_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechLnHighLow20DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取LN(最近一个月最高价/最近一个月最低价)_PIT时间序列
    return w.wsd(security,"tech_lnhighlow20d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低价时间序列
    return w.wsd(security,"low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLow3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低价(不前推)时间序列
    return w.wsd(security,"low3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLowPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低价时间序列
    return w.wsd(security,"low_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLowDatePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低价日时间序列
    return w.wsd(security,"low_date_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的最低价时间序列
    return w.wsd(security,"us_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgHighestPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间自最低价的最大涨幅时间序列
    return w.wsd(security,"pct_chg_highest_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间最低价时间序列
    return w.wsd(security,"cb_pq_stocklow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日最低价时间序列
    return w.wsd(security,"ipo_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测涨跌幅(评级日,最低价)时间序列
    return w.wsd(security,"est_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价时间序列
    return w.wsd(security,"close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClose2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(支持定点复权)时间序列
    return w.wsd(security,"close2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClose3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(不前推)时间序列
    return w.wsd(security,"close3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCloseFxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(23:30)时间序列
    return w.wsd(security,"close_FX",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCloseUsdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(美元)时间序列
    return w.wsd(security,"close_usd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCloseNightSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(夜盘)时间序列
    return w.wsd(security,"close_night",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskStDevCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价标准差时间序列
    return w.wsd(security,"risk_stdevclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirtyPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(全价)时间序列
    return w.wsd(security,"dirtyprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCleanPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价(净价)时间序列
    return w.wsd(security,"cleanprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价久期时间序列
    return w.wsd(security,"duration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getModifiedDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价修正久期时间序列
    return w.wsd(security,"modifiedduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConvexitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘价凸性时间序列
    return w.wsd(security,"convexity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClosePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间收盘价时间序列
    return w.wsd(security,"close_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def get1StQuartIleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日收盘价1/4分位数时间序列
    return w.wsd(security,"1stquartile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMedianSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日收盘价中位数时间序列
    return w.wsd(security,"median",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def get3RdQuartIleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日收盘价3/4分位数时间序列
    return w.wsd(security,"3rdquartile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的收盘价时间序列
    return w.wsd(security,"us_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTrix5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日收盘价三重指数平滑移动平均指标_PIT时间序列
    return w.wsd(security,"tech_trix5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNQOriginCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取推N日收盘价(债券)时间序列
    return w.wsd(security,"nq_originclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNQCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取推N日收盘价(当日结算价)时间序列
    return w.wsd(security,"nq_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTrix10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日收盘价三重指数平滑移动平均指标_PIT时间序列
    return w.wsd(security,"tech_trix10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChangeCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅(收盘价)时间序列
    return w.wsd(security,"pctchange_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间收盘价时间序列
    return w.wsd(security,"cb_pq_stockclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaxClosePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高收盘价时间序列
    return w.wsd(security,"max_close_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMinClosePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低收盘价时间序列
    return w.wsd(security,"min_close_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaxCloseDatePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高收盘价日时间序列
    return w.wsd(security,"max_close_date_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMinCloseDatePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低收盘价日时间序列
    return w.wsd(security,"min_close_date_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgClosePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日日均收盘价(算术平均)时间序列
    return w.wsd(security,"avgclose_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日收盘价时间序列
    return w.wsd(security,"ipo_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLimitUpOpenDateCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股开板日收盘价时间序列
    return w.wsd(security,"ipo_limitupopendate_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBBicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取BBI除以收盘价_PIT时间序列
    return w.wsd(security,"tech_bbic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCloseFixedIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上证固收平台收盘价时间序列
    return w.wsd(security,"close_fixedincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockHighCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间最高收盘价时间序列
    return w.wsd(security,"cb_pq_stockhighclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockLowCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间最低收盘价时间序列
    return w.wsd(security,"cb_pq_stocklowclose",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量时间序列
    return w.wsd(security,"volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolumEBTInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量(含大宗交易)时间序列
    return w.wsd(security,"volume_btin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiVolumeCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量比上交易日增减时间序列
    return w.wsd(security,"oi_volumec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiVNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量进榜会员名称时间序列
    return w.wsd(security,"oi_vname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolumeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量认沽认购比率时间序列
    return w.wsd(security,"volumeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVemA5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量的5日指数移动平均_PIT时间序列
    return w.wsd(security,"tech_vema5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVemA10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量的10日指数移动平均_PIT时间序列
    return w.wsd(security,"tech_vema10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVemA12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量的12日指数移动平均_PIT时间序列
    return w.wsd(security,"tech_vema12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVemA26Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量的26日指数移动平均_PIT时间序列
    return w.wsd(security,"tech_vema26",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVmaCdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量量指数平滑异同移动平均线_PIT时间序列
    return w.wsd(security,"tech_vmacd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量比率_PIT时间序列
    return w.wsd(security,"tech_vr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVosCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交量震荡_PIT时间序列
    return w.wsd(security,"tech_vosc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechPvISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正成交量指标_PIT时间序列
    return w.wsd(security,"tech_pvi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechNViSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负成交量指标_PIT时间序列
    return w.wsd(security,"tech_nvi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolumeAHtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取盘后成交量时间序列
    return w.wsd(security,"volume_aht",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交量时间序列
    return w.wsd(security,"vol_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqBlockTradeVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交量(含大宗交易)时间序列
    return w.wsd(security,"pq_blocktradevolume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日成交量时间序列
    return w.wsd(security,"vol_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的成交量时间序列
    return w.wsd(security,"us_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会员成交量时间序列
    return w.wsd(security,"oi_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOptionVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取品种成交量时间序列
    return w.wsd(security,"optionvolume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCallVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购成交量时间序列
    return w.wsd(security,"callvolume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPutVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认沽成交量时间序列
    return w.wsd(security,"putvolume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVsTd10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日成交量标准差_PIT时间序列
    return w.wsd(security,"tech_vstd10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVsTd20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日成交量标准差_PIT时间序列
    return w.wsd(security,"tech_vstd20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间成交量时间序列
    return w.wsd(security,"cb_pq_stockvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgVolPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均成交量时间序列
    return w.wsd(security,"avg_vol_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqVolumeAHtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间盘后成交量时间序列
    return w.wsd(security,"pq_volume_aht",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellVolumePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取卖空量占成交量比率时间序列
    return w.wsd(security,"shortsell_VolumePct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVsTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取VSTD成交量标准差时间序列
    return w.wsd(security,"VSTD",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoListDayVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日成交量时间序列
    return w.wsd(security,"ipo_listdayvolume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpenAuctionVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘集合竞价成交量时间序列
    return w.wsd(security,"open_auction_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolumeFixedIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上证固收平台成交量时间序列
    return w.wsd(security,"volume_fixedincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交额时间序列
    return w.wsd(security,"amt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmountBtInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交额(含大宗交易)时间序列
    return w.wsd(security,"amount_btin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAmount1M60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交额惯性_PIT时间序列
    return w.wsd(security,"tech_amount1m60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmountAHtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取盘后成交额时间序列
    return w.wsd(security,"amount_aht",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmtPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交额时间序列
    return w.wsd(security,"amt_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqBlockTradeAmountsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交额(含大宗交易)时间序列
    return w.wsd(security,"pq_blocktradeamounts",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmtNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日成交额时间序列
    return w.wsd(security,"amt_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的成交额时间序列
    return w.wsd(security,"us_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOptionAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取品种成交额时间序列
    return w.wsd(security,"optionamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCallAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购成交额时间序列
    return w.wsd(security,"callamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPutAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认沽成交额时间序列
    return w.wsd(security,"putamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间成交额时间序列
    return w.wsd(security,"cb_pq_stockamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgAmtPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均成交额时间序列
    return w.wsd(security,"avg_amt_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAmountAHtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间盘后成交额时间序列
    return w.wsd(security,"pq_amount_aht",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日成交额时间序列
    return w.wsd(security,"ipo_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpenAuctionAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘集合竞价成交额时间序列
    return w.wsd(security,"open_auction_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDealNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成交笔数时间序列
    return w.wsd(security,"dealnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDealNumFixedIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上证固收平台成交笔数时间序列
    return w.wsd(security,"dealnum_fixedincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌时间序列
    return w.wsd(security,"chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅时间序列
    return w.wsd(security,"pct_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅(债券)时间序列
    return w.wsd(security,"pct_chg_b",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChgSettlementSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌(结算价)时间序列
    return w.wsd(security,"chg_settlement",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgSettlementSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅(结算价)时间序列
    return w.wsd(security,"pct_chg_settlement",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaxUpOrDownSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌停状态时间序列
    return w.wsd(security,"maxupordown",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDQChangeCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌(中债)时间序列
    return w.wsd(security,"dq_change_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDQPctChangeCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨跌幅(中债)时间序列
    return w.wsd(security,"dq_pctchange_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChgPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间涨跌时间序列
    return w.wsd(security,"chg_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间涨跌幅时间序列
    return w.wsd(security,"pct_chg_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgPer2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间涨跌幅(包含上市首日涨跌幅)时间序列
    return w.wsd(security,"pct_chg_per2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日涨跌幅时间序列
    return w.wsd(security,"pct_chg_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFsPqChangeSettlementSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间涨跌(结算价)时间序列
    return w.wsd(security,"fs_pq_change_settlement",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFsPqPctChangeSettlementSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间涨跌幅(结算价)时间序列
    return w.wsd(security,"fs_pq_pctchange_settlement",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估算涨跌幅时间序列
    return w.wsd(security,"west_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestReturnErrorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估算涨跌幅误差时间序列
    return w.wsd(security,"west_return_error",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的涨跌时间序列
    return w.wsd(security,"us_change",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的涨跌幅时间序列
    return w.wsd(security,"us_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChg5DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近5日涨跌幅时间序列
    return w.wsd(security,"pct_chg_5d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1月涨跌幅时间序列
    return w.wsd(security,"pct_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近3月涨跌幅时间序列
    return w.wsd(security,"pct_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近6月涨跌幅时间序列
    return w.wsd(security,"pct_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChg1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1年涨跌幅时间序列
    return w.wsd(security,"pct_chg_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldStocksPerChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股涨跌幅时间序列
    return w.wsd(security,"prt_heavilyheldstocksperchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundAbnormalNavFluctuationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净值异常涨跌幅说明时间序列
    return w.wsd(security,"fund_abnormalnavfluctuation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间涨跌时间序列
    return w.wsd(security,"cb_pq_stockchg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockPctChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间涨跌幅时间序列
    return w.wsd(security,"cb_pq_stockpctchg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgPctChgNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日日均涨跌幅时间序列
    return w.wsd(security,"avg_pct_chg_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChg10DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近10日涨跌幅时间序列
    return w.wsd(security,"pct_chg_10d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日涨跌幅时间序列
    return w.wsd(security,"ipo_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldBondsPerChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券涨跌幅时间序列
    return w.wsd(security,"prt_heavilyheldbondsperchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldFundPerChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金涨跌幅时间序列
    return w.wsd(security,"prt_heavilyheldfundperchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRelIpoChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对发行价涨跌时间序列
    return w.wsd(security,"rel_ipo_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRelIpoPctChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对发行价涨跌幅时间序列
    return w.wsd(security,"rel_ipo_pct_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNpcTChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市后N日涨跌幅时间序列
    return w.wsd(security,"ipo_npctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLimitUpOpenDatePctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股开板日涨跌幅时间序列
    return w.wsd(security,"ipo_limitupopendate_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRelPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间相对指数涨跌幅时间序列
    return w.wsd(security,"relpctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对大盘区间涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNQRelPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对大盘N日涨跌幅时间序列
    return w.wsd(security,"nq_relpctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChangeYTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年迄今相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_ytd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChange5DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近5日相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_5d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChange1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1月相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChange3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近3月相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChange6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近6月相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChange1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1年相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChangeMTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本月至今相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_mtd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelRelPctChangeMTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取季度至今相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relrelpctchange_mtd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqRelPctChange10DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近10日相对指数涨跌幅时间序列
    return w.wsd(security,"pq_relpctchange_10d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSwingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取振幅时间序列
    return w.wsd(security,"swing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSwingPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间振幅时间序列
    return w.wsd(security,"swing_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSwingNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日振幅时间序列
    return w.wsd(security,"swing_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsSwingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的振幅时间序列
    return w.wsd(security,"us_swing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockSwingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间振幅时间序列
    return w.wsd(security,"cb_pq_stockswing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgSwingPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均振幅时间序列
    return w.wsd(security,"avg_swing_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVWapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取均价时间序列
    return w.wsd(security,"vwap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsAvgPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的均价时间序列
    return w.wsd(security,"us_avgprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPrePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行前均价时间序列
    return w.wsd(security,"ipo_preprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间均价时间序列
    return w.wsd(security,"cb_pq_stockavg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVWapPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交均价时间序列
    return w.wsd(security,"vwap_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAvgPrice2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交均价(可复权)时间序列
    return w.wsd(security,"pq_avgprice2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNQAvgPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日成交均价时间序列
    return w.wsd(security,"nq_avgprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetReferencePriceIsAnVerAgeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否为算术平均价时间序列
    return w.wsd(security,"clause_reset_referencepriceisanverage",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAvgPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日成交均价时间序列
    return w.wsd(security,"ipo_avgprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgPriceFixedIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上证固收平台平均价时间序列
    return w.wsd(security,"avgprice_fixedincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLimitUpOpenDateAvgPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股开板日成交均价时间序列
    return w.wsd(security,"ipo_limitupopendate_avgprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdjFactorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权因子时间序列
    return w.wsd(security,"adjfactor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjFactorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金净值复权因子时间序列
    return w.wsd(security,"NAV_adjfactor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取换手率时间序列
    return w.wsd(security,"turn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFreeTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取换手率(基准.自由流通股本)时间序列
    return w.wsd(security,"free_turn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRateVolatility20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取换手率相对波动率_PIT时间序列
    return w.wsd(security,"tech_turnoverratevolatility20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTurnPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间换手率时间序列
    return w.wsd(security,"turn_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTurnFreePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间换手率(基准.自由流通股本)时间序列
    return w.wsd(security,"turn_free_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTurnNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日换手率时间序列
    return w.wsd(security,"turn_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的换手率时间序列
    return w.wsd(security,"us_turn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechSToQSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月换手率对数平均_PIT时间序列
    return w.wsd(security,"tech_stoq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockTurnoverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间换手率时间序列
    return w.wsd(security,"cb_pq_stockturnover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAvgTurn2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均换手率时间序列
    return w.wsd(security,"pq_avgturn2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgTurnPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均换手率(剔除无成交日期)时间序列
    return w.wsd(security,"avg_turn_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgTurnFreePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均换手率(基准.自由流通股本)时间序列
    return w.wsd(security,"avg_turn_free_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgTurnNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取N日日均换手率时间序列
    return w.wsd(security,"avg_turn_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市首日换手率时间序列
    return w.wsd(security,"ipo_turn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRate5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turnoverrate5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechSToASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取12个月换手率对数平均_PIT时间序列
    return w.wsd(security,"tech_stoa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurn5DTurn120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日平均换手率/120日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turn5dturn120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市后N日换手率时间序列
    return w.wsd(security,"ipo_nturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRate10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turnoverrate10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRate20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turnoverrate20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRate60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turnoverrate60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurn10DTurn120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日平均换手率/120日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turn10dturn120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurn20DTurn120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日平均换手率/120日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turn20dturn120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbPqStockAveTurnoverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股区间平均换手率时间序列
    return w.wsd(security,"cb_pq_stockaveturnover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRate120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turnoverrate120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTurnoverRate240Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取240日平均换手率_PIT时间序列
    return w.wsd(security,"tech_turnoverrate240",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleRpTTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金报告期持仓换手率时间序列
    return w.wsd(security,"style_rpt_turn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量时间序列
    return w.wsd(security,"oi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量变化时间序列
    return w.wsd(security,"oi_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量(商品指数)时间序列
    return w.wsd(security,"oi_index",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量变化(商品指数)时间序列
    return w.wsd(security,"oichange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOi3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量(不前推)时间序列
    return w.wsd(security,"oi3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓量认沽认购比率时间序列
    return w.wsd(security,"oiratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间持仓量时间序列
    return w.wsd(security,"oi_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOptionOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取品种持仓量时间序列
    return w.wsd(security,"optionoi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCallOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购持仓量时间序列
    return w.wsd(security,"calloi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPutOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认沽持仓量时间序列
    return w.wsd(security,"putoi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgOiPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均持仓量时间序列
    return w.wsd(security,"avg_oi_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiAmountNoMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓额(不计保证金)时间序列
    return w.wsd(security,"oiamount_nomargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持仓额时间序列
    return w.wsd(security,"oiamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreSettleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前结算价时间序列
    return w.wsd(security,"pre_settle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreSettlePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间前结算价时间序列
    return w.wsd(security,"pre_settle_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSettleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取结算价时间序列
    return w.wsd(security,"settle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSettle3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取结算价(不前推)时间序列
    return w.wsd(security,"settle3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSettlePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间结算价时间序列
    return w.wsd(security,"settle_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightModiDuraSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价修正久期(中债)时间序列
    return w.wsd(security,"weight_modidura",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightSprDuraSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价利差久期(中债)时间序列
    return w.wsd(security,"weight_sprdura",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightInterestDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价利率久期(中债)时间序列
    return w.wsd(security,"weight_interestduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightVoBpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价基点价值(中债)时间序列
    return w.wsd(security,"weight_vobp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightCNvXTySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价凸性(中债)时间序列
    return w.wsd(security,"weight_cnvxty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightSPrcNxtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价利差凸性(中债)时间序列
    return w.wsd(security,"weight_sprcnxt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightInterestCNvXTySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算价利率凸性(中债)时间序列
    return w.wsd(security,"weight_interestcnvxty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLowSettlePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低结算价时间序列
    return w.wsd(security,"low_settle_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHighSettlePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高结算价时间序列
    return w.wsd(security,"high_settle_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFsPqHighSwingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高结算价日时间序列
    return w.wsd(security,"fs_pq_highswing_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFsPqLowSwingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低结算价日时间序列
    return w.wsd(security,"fs_pq_lowswing_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLasTradeDaySSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最近交易日期时间序列
    return w.wsd(security,"lastradeday_s",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFirsTradeDaySSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最早交易日期时间序列
    return w.wsd(security,"firstradeday_s",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastTradeDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场最近交易日时间序列
    return w.wsd(security,"last_trade_day",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradeStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易状态时间序列
    return w.wsd(security,"trade_status",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValMvArdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值时间序列
    return w.wsd(security,"val_mv_ARD",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值1时间序列
    return w.wsd(security,"ev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktCapArdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值2时间序列
    return w.wsd(security,"mkt_cap_ard",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEv3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值1(币种可选)时间序列
    return w.wsd(security,"ev3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktCapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值(不可回测)时间序列
    return w.wsd(security,"mkt_cap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktCapCsrCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值(证监会算法)时间序列
    return w.wsd(security,"mkt_cap_CSRC",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValMvToeBitDaTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值/EBITDA(TTM反推法)_PIT时间序列
    return w.wsd(security,"val_mvtoebitda_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeBitDaInDuSwTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总市值/息税折旧及摊销前利润TTM行业相对值_PIT时间序列
    return w.wsd(security,"val_pebitdaindu_sw_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMvRefSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取参考总市值时间序列
    return w.wsd(security,"mv_ref",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数总市值时间序列
    return w.wsd(security,"val_mv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMamVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取备考总市值(并购后)时间序列
    return w.wsd(security,"mamv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityToDebt2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取当日总市值/负债总计时间序列
    return w.wsd(security,"equitytodebt2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgMvPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均总市值时间序列
    return w.wsd(security,"avg_MV_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValAvgPeBitDaSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的总市值/息税折旧及摊销前利润TTM均值_PIT时间序列
    return w.wsd(security,"val_avgpebitda_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValStdPeBitDaSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的总市值/息税折旧及摊销前利润TTM标准差_PIT时间序列
    return w.wsd(security,"val_stdpebitda_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginMarketValueRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保证券市值占该证券总市值比重时间序列
    return w.wsd(security,"margin_marketvalueratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValMvCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通市值时间序列
    return w.wsd(security,"val_mvc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktCapFloatSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通市值(含限售股)时间序列
    return w.wsd(security,"mkt_cap_float",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktFreeSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自由流通市值时间序列
    return w.wsd(security,"mkt_freeshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValFloatMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自由流通市值_PIT时间序列
    return w.wsd(security,"val_floatmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValLnFloatMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对数流通市值_PIT时间序列
    return w.wsd(security,"val_lnfloatmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAvgMvNonRestrictedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间日均流通市值时间序列
    return w.wsd(security,"pq_avgmv_nonrestricted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSUspDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取连续停牌天数时间序列
    return w.wsd(security,"susp_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSUspReasonSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取停牌原因时间序列
    return w.wsd(security,"susp_reason",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaxUpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨停价时间序列
    return w.wsd(security,"maxup",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaxDownSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跌停价时间序列
    return w.wsd(security,"maxdown",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDiscountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贴水时间序列
    return w.wsd(security,"discount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDiscountRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贴水率时间序列
    return w.wsd(security,"discount_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgDiscountPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间均贴水时间序列
    return w.wsd(security,"avg_discount_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgDiscountRatioPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间均贴水率时间序列
    return w.wsd(security,"avg_discount_ratio_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexWeightSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属指数权重时间序列
    return w.wsd(security,"indexweight",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirectionGoldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交收方向(黄金现货)时间序列
    return w.wsd(security,"direction_gold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDQuantityGoldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交收量(黄金现货)时间序列
    return w.wsd(security,"dquantity_gold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpenAuctionPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘集合竞价成交价时间序列
    return w.wsd(security,"open_auction_price",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPctChgHighPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间收盘最大涨幅时间序列
    return w.wsd(security,"pct_chg_high_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradeDaysPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间交易天数时间序列
    return w.wsd(security,"trade_days_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLimitUpDaysPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间涨停天数时间序列
    return w.wsd(security,"limitupdays_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLimitDownDaysPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间跌停天数时间序列
    return w.wsd(security,"limitdowndays_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqUpDaysPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间上涨天数时间序列
    return w.wsd(security,"pq_updays_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqDownDaysPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间下跌天数时间序列
    return w.wsd(security,"pq_downdays_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQuoteDaysPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间报价天数时间序列
    return w.wsd(security,"quote_days_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiChgPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间持仓变化时间序列
    return w.wsd(security,"oi_chg_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtOpenPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间开盘净主动买入额时间序列
    return w.wsd(security,"mf_amt_open_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtClosePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间尾盘净主动买入额时间序列
    return w.wsd(security,"mf_amt_close_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfVolPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净主动买入量时间序列
    return w.wsd(security,"mf_vol_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfVolRatioPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净主动买入量占比时间序列
    return w.wsd(security,"mf_vol_ratio_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净主动买入额时间序列
    return w.wsd(security,"mf_amt_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtRatioPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净主动买入率(金额)时间序列
    return w.wsd(security,"mf_amt_ratio_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间主力净流入天数时间序列
    return w.wsd(security,"mfd_inflowdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfBuyAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间流入额时间序列
    return w.wsd(security,"mf_buy_amt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfBuyVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间流入量时间序列
    return w.wsd(security,"mf_buy_vol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfSellAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间流出额时间序列
    return w.wsd(security,"mf_sell_amt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfSellVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间流出量时间序列
    return w.wsd(security,"mf_sell_vol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqBlockTradeNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间大宗交易上榜次数时间序列
    return w.wsd(security,"pq_blocktradenum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqBlockTradeVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间大宗交易成交总量时间序列
    return w.wsd(security,"pq_blocktrade_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqBlockTradeAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间大宗交易成交总额时间序列
    return w.wsd(security,"pq_blocktradeamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAbnormalTradeNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间龙虎榜上榜次数时间序列
    return w.wsd(security,"pq_abnormaltradenum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAbnormalTradeLpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间龙虎榜买入额时间序列
    return w.wsd(security,"pq_abnormaltrade_lp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradeDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日相近交易日期时间序列
    return w.wsd(security,"tradeday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodMfNetInFlowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净流入额时间序列
    return w.wsd(security,"periodmf_netinflow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgLongAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融资买入额时间序列
    return w.wsd(security,"mrg_long_amt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgLongAmtIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融资买入额时间序列
    return w.wsd(security,"mrg_long_amt_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgLongRepaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融资偿还额时间序列
    return w.wsd(security,"mrg_long_repay",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgLongRepayIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融资偿还额时间序列
    return w.wsd(security,"mrg_long_repay_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgLongBalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融资余额时间序列
    return w.wsd(security,"mrg_long_bal",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgLongBalIntAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融资余额均值时间序列
    return w.wsd(security,"mrg_long_bal_int_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmRepurchase1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内债券回购融资余额时间序列
    return w.wsd(security,"mmrepurchase1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmRepurchase2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期末债券回购融资余额时间序列
    return w.wsd(security,"mmrepurchase2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmRepurchase1ToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内债券回购融资余额占基金资产净值比例时间序列
    return w.wsd(security,"mmrepurchase1tonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmRepurchase2ToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期末债券回购融资余额占基金资产净值比例时间序列
    return w.wsd(security,"mmrepurchase2tonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融券卖出量时间序列
    return w.wsd(security,"mrg_short_vol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortVolIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融券卖出量时间序列
    return w.wsd(security,"mrg_short_vol_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortVolRepaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融券偿还量时间序列
    return w.wsd(security,"mrg_short_vol_repay",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortVolRepayIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融券偿还量时间序列
    return w.wsd(security,"mrg_short_vol_repay_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginSaleTradingAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融券卖出额时间序列
    return w.wsd(security,"margin_saletradingamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginShortAmountIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融券卖出额时间序列
    return w.wsd(security,"margin_shortamountint",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginSaleRepayAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融券偿还额时间序列
    return w.wsd(security,"margin_salerepayamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginShortAmountRepayIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融券偿还额时间序列
    return w.wsd(security,"margin_shortamountrepayint",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortVolBalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融券余量时间序列
    return w.wsd(security,"mrg_short_vol_bal",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortVolBalIntAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融券余量均值时间序列
    return w.wsd(security,"mrg_short_vol_bal_int_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortBalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融券余额时间序列
    return w.wsd(security,"mrg_short_bal",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgShortBalIntAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间融券余额均值时间序列
    return w.wsd(security,"mrg_short_bal_int_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellTurnoverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全日卖空金额时间序列
    return w.wsd(security,"shortsell_Turnover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellTurnoverPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取卖空金额占市场卖空总额比率时间序列
    return w.wsd(security,"shortsell_TurnoverPct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全日卖空股数时间序列
    return w.wsd(security,"shortsell_Volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellVolumeToHSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取卖空量占香港流通股百分比时间序列
    return w.wsd(security,"shortsell_VolumeToHshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareShortSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未平仓卖空数时间序列
    return w.wsd(security,"share_shortshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareShortAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未平仓卖空金额时间序列
    return w.wsd(security,"share_shortamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShortSellDaysToCoverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取空头回补天数时间序列
    return w.wsd(security,"shortsell_daystocover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyAmtDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流入额时间序列
    return w.wsd(security,"mfd_buyamt_d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfNetInFlowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净流入额时间序列
    return w.wsd(security,"mf_netinflow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主力净流入额时间序列
    return w.wsd(security,"mfd_inflow_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowProportionMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主力净流入额占比时间序列
    return w.wsd(security,"mfd_inflowproportion_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowOpenMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘主力净流入额时间序列
    return w.wsd(security,"mfd_inflow_open_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowCloseMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘主力净流入额时间序列
    return w.wsd(security,"mfd_inflow_close_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowProportionOpenMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘主力净流入额占比时间序列
    return w.wsd(security,"mfd_inflowproportion_open_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowProportionCloseMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘主力净流入额占比时间序列
    return w.wsd(security,"mfd_inflowproportion_close_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSellAmtDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流出额时间序列
    return w.wsd(security,"mfd_sellamt_d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyVolDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流入量时间序列
    return w.wsd(security,"mfd_buyvol_d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyVolMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主力净流入量时间序列
    return w.wsd(security,"mfd_buyvol_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowProportionMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主力净流入量占比时间序列
    return w.wsd(security,"mfd_volinflowproportion_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyVolOpenMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘主力净流入量时间序列
    return w.wsd(security,"mfd_buyvol_open_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyVolCloseMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘主力净流入量时间序列
    return w.wsd(security,"mfd_buyvol_close_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowProportionOpenMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘主力净流入量占比时间序列
    return w.wsd(security,"mfd_volinflowproportion_open_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowProportionCloseMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘主力净流入量占比时间序列
    return w.wsd(security,"mfd_volinflowproportion_close_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSellVolDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流出量时间序列
    return w.wsd(security,"mfd_sellvol_d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdNetBuyAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净买入额时间序列
    return w.wsd(security,"mfd_netbuyamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfpSnInFlowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通区间净买入额时间序列
    return w.wsd(security,"mfp_sn_inflow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdNetBuyVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净买入量时间序列
    return w.wsd(security,"mfd_netbuyvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfpSnInFlowAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通区间净买入量时间序列
    return w.wsd(security,"mfp_sn_inflowamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfpSnInFlowAmt2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通区间净买入量(调整)时间序列
    return w.wsd(security,"mfp_sn_inflowamt2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyOrDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流入单数时间序列
    return w.wsd(security,"mfd_buyord",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSelLordSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流出单数时间序列
    return w.wsd(security,"mfd_sellord",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyAmtASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动买入额时间序列
    return w.wsd(security,"mfd_buyamt_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyAmtAtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动买入额(全单)时间序列
    return w.wsd(security,"mfd_buyamt_at",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdNetBuyAmtASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入额时间序列
    return w.wsd(security,"mfd_netbuyamt_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入额(全单)时间序列
    return w.wsd(security,"mf_amt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowProportionASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入额占比时间序列
    return w.wsd(security,"mfd_inflowproportion_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtOpenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘净主动买入额时间序列
    return w.wsd(security,"mf_amt_open",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtCloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘净主动买入额时间序列
    return w.wsd(security,"mf_amt_close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowProportionOpenASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘净主动买入额占比时间序列
    return w.wsd(security,"mfd_inflowproportion_open_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowProportionCloseASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘净主动买入额占比时间序列
    return w.wsd(security,"mfd_inflowproportion_close_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSellAmtASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动卖出额时间序列
    return w.wsd(security,"mfd_sellamt_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSellAmtAtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动卖出额(全单)时间序列
    return w.wsd(security,"mfd_sellamt_at",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyVolASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动买入量时间序列
    return w.wsd(security,"mfd_buyvol_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdBuyVolAtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动买入量(全单)时间序列
    return w.wsd(security,"mfd_buyvol_at",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdNetBuyVolASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入量时间序列
    return w.wsd(security,"mfd_netbuyvol_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入量(全单)时间序列
    return w.wsd(security,"mf_vol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfVolRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入量占比时间序列
    return w.wsd(security,"mf_vol_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowProportionOpenASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘净主动买入量占比时间序列
    return w.wsd(security,"mfd_volinflowproportion_open_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowProportionCloseASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘净主动买入量占比时间序列
    return w.wsd(security,"mfd_volinflowproportion_close_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowVolumeOpenASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘资金净主动买入量时间序列
    return w.wsd(security,"mfd_inflowvolume_open_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowVolumeCloseASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘资金净主动买入量时间序列
    return w.wsd(security,"mfd_inflowvolume_close_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSellVolASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动卖出量时间序列
    return w.wsd(security,"mfd_sellvol_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSellVolAtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主动卖出量(全单)时间序列
    return w.wsd(security,"mfd_sellvol_at",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfAmtRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入率(金额)时间序列
    return w.wsd(security,"mf_amt_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowRateOpenASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘净主动买入率(金额)时间序列
    return w.wsd(security,"mfd_inflowrate_open_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowRateCloseASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘净主动买入率(金额)时间序列
    return w.wsd(security,"mfd_inflowrate_close_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowRateASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净主动买入率(量)时间序列
    return w.wsd(security,"mfd_volinflowrate_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowRateOpenASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘净主动买入率(量)时间序列
    return w.wsd(security,"mfd_volinflowrate_open_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowRateCloseASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘净主动买入率(量)时间序列
    return w.wsd(security,"mfd_volinflowrate_close_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowRateMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主力净流入率(金额)时间序列
    return w.wsd(security,"mfd_inflowrate_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowRateOpenMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘主力净流入率(金额)时间序列
    return w.wsd(security,"mfd_inflowrate_open_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdInFlowRateCloseMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘主力净流入率(金额)时间序列
    return w.wsd(security,"mfd_inflowrate_close_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowRateMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主力净流入率(量)时间序列
    return w.wsd(security,"mfd_volinflowrate_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowRateOpenMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开盘主力净流入率(量)时间序列
    return w.wsd(security,"mfd_volinflowrate_open_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdVolInFlowRateCloseMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取尾盘主力净流入率(量)时间序列
    return w.wsd(security,"mfd_volinflowrate_close_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSnBuyAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通买入金额时间序列
    return w.wsd(security,"mfd_sn_buyamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSnSellAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通卖出金额时间序列
    return w.wsd(security,"mfd_sn_sellamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfdSnInFlowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通净买入金额时间序列
    return w.wsd(security,"mfd_sn_inflow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfpSnInFlowDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通区间净流入天数时间序列
    return w.wsd(security,"mfp_sn_inflowdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfpSnOutflowDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通区间净流出天数时间序列
    return w.wsd(security,"mfp_sn_outflowdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfnSnInFlowDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通持续净流入天数时间序列
    return w.wsd(security,"mfn_sn_inflowdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMfnSnOutflowDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪深港股通持续净卖出天数时间序列
    return w.wsd(security,"mfn_sn_outflowdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdQFIiExSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外资买卖超时间序列
    return w.wsd(security,"inshd_qfii_ex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdQFIiExMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外资买卖超市值时间序列
    return w.wsd(security,"inshd_qfii_exmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdFundExSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投信买卖超时间序列
    return w.wsd(security,"inshd_fund_ex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdFundExMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投信买卖超市值时间序列
    return w.wsd(security,"inshd_fund_exmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdDlrExSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营买卖超时间序列
    return w.wsd(security,"inshd_dlr_ex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdDlrExMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营买卖超市值时间序列
    return w.wsd(security,"inshd_dlr_exmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdTtlExSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合计买卖超时间序列
    return w.wsd(security,"inshd_ttl_ex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdTtlExMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合计买卖超市值时间序列
    return w.wsd(security,"inshd_ttl_exmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdQFIiBuySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外资买进数量时间序列
    return w.wsd(security,"inshd_qfii_buy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdQFIiSellSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外资卖出数量时间序列
    return w.wsd(security,"inshd_qfii_sell",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdFundBuySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投信买进数量时间序列
    return w.wsd(security,"inshd_fund_buy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdFundSellSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投信卖出数量时间序列
    return w.wsd(security,"inshd_fund_sell",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdDlrBuySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营商买进数量时间序列
    return w.wsd(security,"inshd_dlr_buy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSHdDlrSellSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营商卖出数量时间序列
    return w.wsd(security,"inshd_dlr_sell",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间回报时间序列
    return w.wsd(security,"return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundQSimilarProductSimilarRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取规模同类排名(券商集合理财)时间序列
    return w.wsd(security,"fund_qsimilarproductsimilarranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundScaleRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取规模同类排名时间序列
    return w.wsd(security,"fund_scaleranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskDownsideRiskRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下行风险同类排名时间序列
    return w.wsd(security,"risk_downsideriskranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTimeRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取选时能力同类排名时间序列
    return w.wsd(security,"risk_timeranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskStockRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取选股能力同类排名时间序列
    return w.wsd(security,"risk_stockranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskInfoRatioRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信息比率同类排名时间序列
    return w.wsd(security,"risk_inforatioranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTrackErrorRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪误差同类排名时间序列
    return w.wsd(security,"risk_trackerrorranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnnualVolRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化波动率同类排名时间序列
    return w.wsd(security,"risk_annualvolranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleAvgPositionTimeRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均持仓时间同类排名时间序列
    return w.wsd(security,"style_avgpositiontimeranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStStockSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取注册仓单数量时间序列
    return w.wsd(security,"st_stock",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEv1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业价值(含货币资金)时间序列
    return w.wsd(security,"ev1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEv2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业价值(剔除货币资金)时间序列
    return w.wsd(security,"ev2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValTaToEvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计/企业价值_PIT时间序列
    return w.wsd(security,"val_tatoev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValOrToEvTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(TTM)/企业价值_PIT时间序列
    return w.wsd(security,"val_ortoev_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcAccruedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应计利息(债券计算器)时间序列
    return w.wsd(security,"calc_accrued",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPtMTradeDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余存续期(交易日)时间序列
    return w.wsd(security,"ptmtradeday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPtMDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余存续期(日历日)时间序列
    return w.wsd(security,"ptmday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTheoryValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取理论价格时间序列
    return w.wsd(security,"theoryvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntrInCtValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内在价值时间序列
    return w.wsd(security,"intrinctvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTimeValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取时间价值时间序列
    return w.wsd(security,"timevalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingHisVol30DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的30日历史波动率时间序列
    return w.wsd(security,"underlyinghisvol_30d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsHisVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的60日历史波动率时间序列
    return w.wsd(security,"us_hisvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingHisVol90DSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的90日历史波动率时间序列
    return w.wsd(security,"underlyinghisvol_90d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsImpliedVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期权隐含波动率时间序列
    return w.wsd(security,"us_impliedvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolatilityRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史波动率时间序列
    return w.wsd(security,"volatilityratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M1300Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月130%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m1300",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M1200Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月120%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m1200",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M1100Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月110%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m1100",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M1050Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月105%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m1050",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M1025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月102.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m1025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M1000Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月100%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m1000",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M975Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月97.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m975",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M950Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月95%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m950",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M900Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月90%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m900",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M800Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月80%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m800",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1M600Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1个月60%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1m600",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M1300Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月130%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m1300",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M1200Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月120%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m1200",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M1100Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月110%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m1100",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M1050Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月105%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m1050",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M1025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月102.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m1025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M1000Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月100%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m1000",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M975Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月97.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m975",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M950Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月95%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m950",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M900Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月90%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m900",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M800Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月80%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m800",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv2M600Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取2个月60%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_2m600",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M1300Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月130%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m1300",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M1200Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月120%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m1200",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M1100Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月110%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m1100",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M1050Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月105%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m1050",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M1025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月102.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m1025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M1000Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月100%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m1000",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M975Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月97.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m975",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M950Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月95%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m950",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M900Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月90%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m900",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M800Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月80%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m800",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv3M600Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取3个月60%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_3m600",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M1300Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月130%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m1300",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M1200Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月120%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m1200",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M1100Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月110%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m1100",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M1050Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月105%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m1050",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M1025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月102.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m1025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M1000Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月100%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m1000",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M975Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月97.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m975",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M950Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月95%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m950",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M900Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月90%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m900",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M800Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月80%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m800",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv6M600Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6个月60%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_6m600",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M1300Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月130%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m1300",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M1200Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月120%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m1200",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M1100Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月110%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m1100",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M1050Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月105%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m1050",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M1025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月102.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m1025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M1000Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月100%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m1000",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M975Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月97.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m975",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M950Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月95%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m950",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M900Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月90%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m900",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M800Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月80%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m800",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv9M600Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取9个月60%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_9m600",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y1300Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年130%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y1300",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y1200Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年120%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y1200",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y1100Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年110%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y1100",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y1050Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年105%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y1050",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y1025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年102.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y1025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y1000Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年100%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y1000",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y975Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年97.5%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y975",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y950Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年95%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y950",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y900Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年90%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y900",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y800Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年80%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y800",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIv1Y600Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年60%价值状态隐含波动率时间序列
    return w.wsd(security,"iv_1y600",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)时间序列
    return w.wsd(security,"west_netprofit_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtmChg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)的变化_1M_PIT时间序列
    return w.wsd(security,"west_netprofit_ftm_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtmChg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)的变化_3M_PIT时间序列
    return w.wsd(security,"west_netprofit_ftm_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtmChg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)的变化_6M_PIT时间序列
    return w.wsd(security,"west_netprofit_ftm_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtm1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)的变化率_1M_PIT时间序列
    return w.wsd(security,"west_netprofit_ftm_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtm3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)的变化率_3M_PIT时间序列
    return w.wsd(security,"west_netprofit_ftm_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFtm6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)的变化率_6M_PIT时间序列
    return w.wsd(security,"west_netprofit_ftm_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitDiffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)与归属于母公司净利润(TTM)的差_PIT时间序列
    return w.wsd(security,"west_netprofitdiff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestRoeFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(未来12个月)/归属于母公司的股东权益_PIT时间序列
    return w.wsd(security,"west_roe_ftm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润同比时间序列
    return w.wsd(security,"west_netprofit_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgNpYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润同比(FY2比FY1)时间序列
    return w.wsd(security,"west_avgnp_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润2年复合增长率时间序列
    return w.wsd(security,"west_netprofit_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNProc1WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润1周变化率时间序列
    return w.wsd(security,"west_nproc_1w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNProc4WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润4周变化率时间序列
    return w.wsd(security,"west_nproc_4w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNProc13WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润13周变化率时间序列
    return w.wsd(security,"west_nproc_13w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNProc26WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润26周变化率时间序列
    return w.wsd(security,"west_nproc_26w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)时间序列
    return w.wsd(security,"west_eps_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtmChg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)的变化_1M_PIT时间序列
    return w.wsd(security,"west_eps_ftm_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtmChg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)的变化_3M_PIT时间序列
    return w.wsd(security,"west_eps_ftm_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtmChg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)的变化_6M_PIT时间序列
    return w.wsd(security,"west_eps_ftm_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtm1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)的变化率_1M_PIT时间序列
    return w.wsd(security,"west_eps_ftm_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtm3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)的变化率_3M_PIT时间序列
    return w.wsd(security,"west_eps_ftm_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtm6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)的变化率_6M_PIT时间序列
    return w.wsd(security,"west_eps_ftm_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFtmGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(未来12个月)与EPS(TTM)的变化率_PIT时间序列
    return w.wsd(security,"west_eps_ftmgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)时间序列
    return w.wsd(security,"west_sales_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtmChg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)的变化_1M_PIT时间序列
    return w.wsd(security,"west_sales_ftm_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtmChg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)的变化_3M_PIT时间序列
    return w.wsd(security,"west_sales_ftm_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtmChg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)的变化_6M_PIT时间序列
    return w.wsd(security,"west_sales_ftm_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtm1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)的变化率_1M_PIT时间序列
    return w.wsd(security,"west_sales_ftm_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtm3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)的变化率_3M_PIT时间序列
    return w.wsd(security,"west_sales_ftm_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFtm6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(未来12个月)的变化率_6M_PIT时间序列
    return w.wsd(security,"west_sales_ftm_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入同比时间序列
    return w.wsd(security,"west_sales_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入2年复合增长率时间序列
    return w.wsd(security,"west_sales_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgCpSFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股现金流(未来12个月)时间序列
    return w.wsd(security,"west_avgcps_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税前利润(未来12个月)时间序列
    return w.wsd(security,"west_avgebit_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税前利润同比时间序列
    return w.wsd(security,"west_avgebit_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税前利润年复合增长率时间序列
    return w.wsd(security,"west_avgebit_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税折旧摊销前利润(未来12个月)时间序列
    return w.wsd(security,"west_avgebitda_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税折旧摊销前利润同比时间序列
    return w.wsd(security,"west_avgebitda_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税折旧摊销前利润2年复合增长率时间序列
    return w.wsd(security,"west_avgebitda_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测利润总额(未来12个月)时间序列
    return w.wsd(security,"west_avgebt_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测利润总额同比时间序列
    return w.wsd(security,"west_avgebt_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测利润总额2年复合增长率时间序列
    return w.wsd(security,"west_avgebt_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业利润(未来12个月)时间序列
    return w.wsd(security,"west_avgoperatingprofit_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业利润同比时间序列
    return w.wsd(security,"west_avgoperatingprofit_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业利润2年复合增长率时间序列
    return w.wsd(security,"west_avgoperatingprofit_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcFtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业成本(未来12个月)时间序列
    return w.wsd(security,"west_avgoc_FTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业成本同比时间序列
    return w.wsd(security,"west_avgoc_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcCAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业成本2年复合增长率时间序列
    return w.wsd(security,"west_avgoc_CAGR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstInStNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股收益预测机构家数时间序列
    return w.wsd(security,"est_instnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股收益预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益平均值时间序列
    return w.wsd(security,"est_eps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益平均值(币种转换)时间序列
    return w.wsd(security,"est_eps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益平均值(可选类型)时间序列
    return w.wsd(security,"west_eps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_eps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最大值时间序列
    return w.wsd(security,"est_maxeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最大值(币种转换)时间序列
    return w.wsd(security,"est_maxeps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最大值(可选类型)时间序列
    return w.wsd(security,"west_maxeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxeps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinePsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最小值时间序列
    return w.wsd(security,"est_mineps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinePs1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最小值(币种转换)时间序列
    return w.wsd(security,"est_mineps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinePsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最小值(可选类型)时间序列
    return w.wsd(security,"west_mineps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinePs1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_mineps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益中值时间序列
    return w.wsd(security,"est_medianeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益中值(币种转换)时间序列
    return w.wsd(security,"est_medianeps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益中值(可选类型)时间序列
    return w.wsd(security,"west_medianeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_medianeps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益标准差时间序列
    return w.wsd(security,"est_stdeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益标准差(币种转换)时间序列
    return w.wsd(security,"est_stdeps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益标准差(可选类型)时间序列
    return w.wsd(security,"west_stdeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdEps1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股收益标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdeps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入平均值时间序列
    return w.wsd(security,"est_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入平均值(币种转换)时间序列
    return w.wsd(security,"est_sales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入平均值(可选类型)时间序列
    return w.wsd(security,"west_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_sales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最大值时间序列
    return w.wsd(security,"est_maxsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最大值(币种转换)时间序列
    return w.wsd(security,"est_maxsales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最大值(可选类型)时间序列
    return w.wsd(security,"west_maxsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxsales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最小值时间序列
    return w.wsd(security,"est_minsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最小值(币种转换)时间序列
    return w.wsd(security,"est_minsales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最小值(可选类型)时间序列
    return w.wsd(security,"west_minsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minsales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入中值时间序列
    return w.wsd(security,"est_mediansales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入中值(币种转换)时间序列
    return w.wsd(security,"est_mediansales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入中值(可选类型)时间序列
    return w.wsd(security,"west_mediansales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_mediansales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入标准差时间序列
    return w.wsd(security,"est_stdsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入标准差(币种转换)时间序列
    return w.wsd(security,"est_stdsales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入标准差(可选类型)时间序列
    return w.wsd(security,"west_stdsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdsales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润平均值时间序列
    return w.wsd(security,"est_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润平均值(币种转换)时间序列
    return w.wsd(security,"est_netprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润平均值(可选类型)时间序列
    return w.wsd(security,"west_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_netprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最大值时间序列
    return w.wsd(security,"est_maxnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最大值(币种转换)时间序列
    return w.wsd(security,"est_maxnetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最大值(可选类型)时间序列
    return w.wsd(security,"west_maxnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxnetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最小值时间序列
    return w.wsd(security,"est_minnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最小值(币种转换)时间序列
    return w.wsd(security,"est_minnetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最小值(可选类型)时间序列
    return w.wsd(security,"west_minnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minnetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润中值时间序列
    return w.wsd(security,"est_mediannetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润中值(币种转换)时间序列
    return w.wsd(security,"est_mediannetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润中值(可选类型)时间序列
    return w.wsd(security,"west_mediannetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_mediannetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润标准差时间序列
    return w.wsd(security,"est_stdnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润标准差(币种转换)时间序列
    return w.wsd(security,"est_stdnetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润标准差(可选类型)时间序列
    return w.wsd(security,"west_stdnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdNetProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdnetprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvGebTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额平均值时间序列
    return w.wsd(security,"est_avgebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvGebT1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额平均值(币种转换)时间序列
    return w.wsd(security,"est_avgebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额平均值(可选类型)时间序列
    return w.wsd(security,"west_avgebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebT1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_avgebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最大值时间序列
    return w.wsd(security,"est_maxebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEBt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最大值(币种转换)时间序列
    return w.wsd(security,"est_maxebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最大值(可选类型)时间序列
    return w.wsd(security,"west_maxebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEBt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最小值时间序列
    return w.wsd(security,"est_minebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinEBT1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最小值(币种转换)时间序列
    return w.wsd(security,"est_minebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最小值(可选类型)时间序列
    return w.wsd(security,"west_minebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinEBT1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额中值时间序列
    return w.wsd(security,"est_medianebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEBt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额中值(币种转换)时间序列
    return w.wsd(security,"est_medianebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额中值(可选类型)时间序列
    return w.wsd(security,"west_medianebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEBt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_medianebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额标准差时间序列
    return w.wsd(security,"est_stdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStDebt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额标准差(币种转换)时间序列
    return w.wsd(security,"est_stdebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额标准差(可选类型)时间序列
    return w.wsd(security,"west_stdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDebt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdebt1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvgOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润平均值时间序列
    return w.wsd(security,"est_avgoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvgOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润平均值(币种转换)时间序列
    return w.wsd(security,"est_avgoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润平均值(可选类型)时间序列
    return w.wsd(security,"west_avgoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_avgoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最大值时间序列
    return w.wsd(security,"est_maxoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最大值(币种转换)时间序列
    return w.wsd(security,"est_maxoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最大值(可选类型)时间序列
    return w.wsd(security,"west_maxoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最小值时间序列
    return w.wsd(security,"est_minoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最小值(币种转换)时间序列
    return w.wsd(security,"est_minoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最小值(可选类型)时间序列
    return w.wsd(security,"west_minoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润中值时间序列
    return w.wsd(security,"est_medianoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润中值(币种转换)时间序列
    return w.wsd(security,"est_medianoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润中值(可选类型)时间序列
    return w.wsd(security,"west_medianoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_medianoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润标准差时间序列
    return w.wsd(security,"est_stdoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润标准差(币种转换)时间序列
    return w.wsd(security,"est_stdoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdOperatingProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润标准差(可选类型)时间序列
    return w.wsd(security,"west_stdoperatingprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdOperatingProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdoperatingprofit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstSalesUpgradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入调高家数时间序列
    return w.wsd(security,"est_sales_upgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesUpgradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入调高家数(可选类型)时间序列
    return w.wsd(security,"west_sales_upgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstSalesDowngradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入调低家数时间序列
    return w.wsd(security,"est_sales_downgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesDowngradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入调低家数(可选类型)时间序列
    return w.wsd(security,"west_sales_downgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstSalesMaintainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入维持家数时间序列
    return w.wsd(security,"est_sales_maintain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesMaintainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入维持家数(可选类型)时间序列
    return w.wsd(security,"west_sales_maintain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNetProfitUpgradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润调高家数时间序列
    return w.wsd(security,"est_netprofit_upgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitUpgradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润调高家数(可选类型)时间序列
    return w.wsd(security,"west_netprofit_upgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNetProfitDowngradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润调低家数时间序列
    return w.wsd(security,"est_netprofit_downgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitDowngradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润调低家数(可选类型)时间序列
    return w.wsd(security,"west_netprofit_downgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNetProfitMaintainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润维持家数时间序列
    return w.wsd(security,"est_netprofit_maintain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitMaintainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润维持家数(可选类型)时间序列
    return w.wsd(security,"west_netprofit_maintain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstYoYNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润增长率时间序列
    return w.wsd(security,"est_yoynetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestYoYNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润增长率(可选类型)时间序列
    return w.wsd(security,"west_yoynetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstYoYSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入增长率时间序列
    return w.wsd(security,"est_yoysales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestYoYSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入增长率(可选类型)时间序列
    return w.wsd(security,"west_yoysales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合评级(数值)时间序列
    return w.wsd(security,"rating_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingAvgDataSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合评级(数值)(可选类型)时间序列
    return w.wsd(security,"wrating_avg_data",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingAvgChNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合评级(中文)时间序列
    return w.wsd(security,"rating_avgchn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingAvgCnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合评级(中文)(可选类型)时间序列
    return w.wsd(security,"wrating_avg_cn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingAvGengSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合评级(英文)时间序列
    return w.wsd(security,"rating_avgeng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingAvgEnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合评级(英文)(可选类型)时间序列
    return w.wsd(security,"wrating_avg_en",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingInStNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级机构家数时间序列
    return w.wsd(security,"rating_instnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingInStNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级机构家数(可选类型)时间序列
    return w.wsd(security,"wrating_instnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingUpgradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级调高家数时间序列
    return w.wsd(security,"rating_upgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingUpgradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级调高家数(可选类型)时间序列
    return w.wsd(security,"wrating_upgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingDowngradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级调低家数时间序列
    return w.wsd(security,"rating_downgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingDowngradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级调低家数(可选类型)时间序列
    return w.wsd(security,"wrating_downgrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingMaintainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级维持家数时间序列
    return w.wsd(security,"rating_maintain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingMaintainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级维持家数(可选类型)时间序列
    return w.wsd(security,"wrating_maintain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingNumOfBuySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级买入家数时间序列
    return w.wsd(security,"rating_numofbuy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingNumOfBuySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级买入家数(可选类型)时间序列
    return w.wsd(security,"wrating_numofbuy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingNumOfOutperformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级增持家数时间序列
    return w.wsd(security,"rating_numofoutperform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingNumOfOutperformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级增持家数(可选类型)时间序列
    return w.wsd(security,"wrating_numofoutperform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingNumOfHoldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级中性家数时间序列
    return w.wsd(security,"rating_numofhold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingNumOfHoldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级中性家数(可选类型)时间序列
    return w.wsd(security,"wrating_numofhold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingNumOfUnderPerformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级减持家数时间序列
    return w.wsd(security,"rating_numofunderperform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingNumOfUnderPerformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级减持家数(可选类型)时间序列
    return w.wsd(security,"wrating_numofunderperform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingNumOfSellSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级卖出家数时间序列
    return w.wsd(security,"rating_numofsell",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingNumOfSellSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级卖出家数(可选类型)时间序列
    return w.wsd(security,"wrating_numofsell",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWRatingTargetPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测目标价时间序列
    return w.wsd(security,"wrating_targetprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTargetPriceAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测目标价(可选类型)时间序列
    return w.wsd(security,"targetprice_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestFReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测目标价上升空间_PIT时间序列
    return w.wsd(security,"west_freturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstEventDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大事日期(大事后预测)时间序列
    return w.wsd(security,"est_event_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumNpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_np",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumCpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股现金流预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_cps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumDpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股利预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_dps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_ebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税折旧摊销前利润预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_ebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_bps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_ebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产收益率预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_roa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumOpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_op",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本平均值(可选类型)时间序列
    return w.wsd(security,"west_avgoc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxOcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本最大值(可选类型)时间序列
    return w.wsd(security,"west_maxoc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinoCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本最小值(可选类型)时间序列
    return w.wsd(security,"west_minoc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMediaOcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本中值(可选类型)时间序列
    return w.wsd(security,"west_mediaoc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSToCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本标准差(可选类型)时间序列
    return w.wsd(security,"west_stoc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测基准股本综合值(可选类型)时间序列
    return w.wsd(security,"west_avgshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getErrWiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取盈利修正比例(可选类型)时间序列
    return w.wsd(security,"err_wi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstCAgrNpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未来3年净利润复合年增长率时间序列
    return w.wsd(security,"est_cagr_np",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstCAgrSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未来3年营业总收入复合年增长率时间序列
    return w.wsd(security,"est_cagr_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumGmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_gm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOc1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_avgoc1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxOc1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxoc1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinoC1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minoc1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMediaOc1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_mediaoc1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSToC1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stoc1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstPreLowPriceInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前次最低目标价时间序列
    return w.wsd(security,"est_prelowprice_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstPreHighPriceInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前次最高目标价时间序列
    return w.wsd(security,"est_prehighprice_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstLowPriceInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本次最低目标价时间序列
    return w.wsd(security,"est_lowprice_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstHighPriceInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本次最高目标价时间序列
    return w.wsd(security,"est_highprice_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstOrGratingInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资评级(原始)时间序列
    return w.wsd(security,"est_orgrating_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstScoreRatingInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资评级(标准化得分)时间序列
    return w.wsd(security,"est_scorerating_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdRatingInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资评级(标准化评级)时间序列
    return w.wsd(security,"est_stdrating_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNewRatingTimeInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构最近评级时间时间序列
    return w.wsd(security,"est_newratingtime_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstEstNewTimeInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构最近预测时间时间序列
    return w.wsd(security,"est_estnewtime_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstSalesInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构预测营业收入时间序列
    return w.wsd(security,"est_sales_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstNetProfitInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构预测净利润时间序列
    return w.wsd(security,"est_netprofit_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstEpsInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构预测每股收益时间序列
    return w.wsd(security,"est_eps_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstFrStRatingTimeInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构首次评级时间时间序列
    return w.wsd(security,"est_frstratingtime_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstRatingAnalystSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取评级研究员时间序列
    return w.wsd(security,"est_ratinganalyst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstEstAnalystSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测研究员时间序列
    return w.wsd(security,"est_estanalyst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstRpTAbstractInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内容时间序列
    return w.wsd(security,"est_rptabstract_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstRpTTitleInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告标题时间序列
    return w.wsd(security,"est_rpttitle_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净利润变动幅度(%)时间序列
    return w.wsd(security,"profitnotice_change",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLaStepsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取去年同期每股收益时间序列
    return w.wsd(security,"profitnotice_lasteps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可分配利润时间序列
    return w.wsd(security,"stmnote_profitapr_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLastYearDeductedProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上年同期扣非净利润时间序列
    return w.wsd(security,"profitnotice_lastyeardeductedprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLastYearIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上年同期营业收入时间序列
    return w.wsd(security,"profitnotice_lastyearincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLastYearDeductedSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上年同期扣除后营业收入时间序列
    return w.wsd(security,"profitnotice_lastyeardeductedsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeBasicEarnMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告基本每股收益下限时间序列
    return w.wsd(security,"profitnotice_basicearnmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeBasicEarnMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告基本每股收益上限时间序列
    return w.wsd(security,"profitnotice_basicearnmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedEarnMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣非后基本每股收益下限时间序列
    return w.wsd(security,"profitnotice_deductedearnmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedEarnMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣非后基本每股收益上限时间序列
    return w.wsd(security,"profitnotice_deductedearnmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLastYearDeductedEarnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上年同期扣非后基本每股收益时间序列
    return w.wsd(security,"profitnotice_lastyeardeductedearn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeNetProfitMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净利润上限时间序列
    return w.wsd(security,"profitnotice_netprofitmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeNetProfitMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净利润上限(海外)时间序列
    return w.wsd(security,"qprofitnotice_netprofitmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeNetProfitMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净利润下限时间序列
    return w.wsd(security,"profitnotice_netprofitmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeNetProfitMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净利润下限(海外)时间序列
    return w.wsd(security,"qprofitnotice_netprofitmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeChangeMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净利润同比增长上限时间序列
    return w.wsd(security,"profitnotice_changemax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeChangeMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净利润同比增长上限(海外)时间序列
    return w.wsd(security,"qprofitnotice_changemax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeChangeMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净利润同比增长下限时间序列
    return w.wsd(security,"profitnotice_changemin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeChangeMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净利润同比增长下限(海外)时间序列
    return w.wsd(security,"qprofitnotice_changemin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedProfitMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣非净利润上限时间序列
    return w.wsd(security,"profitnotice_deductedprofitmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedProfitMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣非净利润下限时间序列
    return w.wsd(security,"profitnotice_deductedprofitmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedProfitYoYMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣非净利润同比增长上限时间序列
    return w.wsd(security,"profitnotice_deductedprofityoymax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedProfitYoYMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣非净利润同比增长下限时间序列
    return w.wsd(security,"profitnotice_deductedprofityoymin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeIncomeMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告营业收入上限时间序列
    return w.wsd(security,"profitnotice_incomemax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeIncomeMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告营业收入下限时间序列
    return w.wsd(security,"profitnotice_incomemin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedSalesMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣除后营业收入上限时间序列
    return w.wsd(security,"profitnotice_deductedsalesmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeDeductedSalesMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告扣除后营业收入下限时间序列
    return w.wsd(security,"profitnotice_deductedsalesmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeNetSalesMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净营收上限(海外)时间序列
    return w.wsd(security,"profitnotice_netsalesmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeNetSalesMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净营收上限(海外)时间序列
    return w.wsd(security,"qprofitnotice_netsalesmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeNetSalesMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净营收下限(海外)时间序列
    return w.wsd(security,"profitnotice_netsalesmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeNetSalesMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净营收下限(海外)时间序列
    return w.wsd(security,"qprofitnotice_netsalesmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeNetSalesYoYMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净营收同比增长上限(海外)时间序列
    return w.wsd(security,"profitnotice_netsalesyoymax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeNetSalesYoYMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净营收同比增长上限(海外)时间序列
    return w.wsd(security,"qprofitnotice_netsalesyoymax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeNetSalesYoYMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告净营收同比增长下限(海外)时间序列
    return w.wsd(security,"profitnotice_netsalesyoymin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeNetSalesYoYMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告净营收同比增长下限(海外)时间序列
    return w.wsd(security,"qprofitnotice_netsalesyoymin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeSalesMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告总营收上限(海外)时间序列
    return w.wsd(security,"profitnotice_salesmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeSalesMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告总营收上限(海外)时间序列
    return w.wsd(security,"qprofitnotice_salesmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeSalesMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告总营收下限(海外)时间序列
    return w.wsd(security,"profitnotice_salesmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeSalesMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告总营收下限(海外)时间序列
    return w.wsd(security,"qprofitnotice_salesmin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeSalesYoYMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告总营收同比增长上限(海外)时间序列
    return w.wsd(security,"profitnotice_salesyoymax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeSalesYoYMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告总营收同比增长上限(海外)时间序列
    return w.wsd(security,"qprofitnotice_salesyoymax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeSalesYoYMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预告总营收同比增长下限(海外)时间序列
    return w.wsd(security,"profitnotice_salesyoymin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQProfitNoticeSalesYoYMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预告总营收同比增长下限(海外)时间序列
    return w.wsd(security,"qprofitnotice_salesyoymin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金流量利息保障倍数时间序列
    return w.wsd(security,"ocftointerest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCfpSTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股现金流量净额(TTM)_PIT时间序列
    return w.wsd(security,"fa_cfps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCfpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股现金流量净额时间序列
    return w.wsd(security,"cfps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCfpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_cfps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCashBalChgCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他现金流量调整_GSD时间序列
    return w.wsd(security,"wgsd_cash_bal_chg_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFcFfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业自由现金流量FCFF时间序列
    return w.wsd(security,"fcff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFcFeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权自由现金流量FCFE时间序列
    return w.wsd(security,"fcfe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFcFe2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权自由现金流量FCFE_GSD时间序列
    return w.wsd(security,"wgsd_fcfe2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFcFf2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业自由现金流量_GSD时间序列
    return w.wsd(security,"wgsd_fcff2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFcFfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业自由现金流量_PIT时间序列
    return w.wsd(security,"fa_fcff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFcFeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权自由现金流量_PIT时间序列
    return w.wsd(security,"fa_fcfe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNcGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-净现金流量(TTM)_PIT时间序列
    return w.wsd(security,"fa_ncgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFcFFpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股企业自由现金流量时间序列
    return w.wsd(security,"fcffps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFcFEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股东自由现金流量时间序列
    return w.wsd(security,"fcfeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFcFFps2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股企业自由现金流量_GSD时间序列
    return w.wsd(security,"wgsd_fcffps2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFcFEps2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股东自由现金流量_GSD时间序列
    return w.wsd(security,"wgsd_fcfeps2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaCashBalChgCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他现金流量调整_GSD时间序列
    return w.wsd(security,"wgsd_qfa_cash_bal_chg_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFcFFpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股企业自由现金流量_PIT时间序列
    return w.wsd(security,"fa_fcffps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFcFEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股东自由现金流量_PIT时间序列
    return w.wsd(security,"fa_fcfeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFToInterestDebtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生现金流量净额/带息债务(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocftointerestdebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFToNetDebtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生现金流量净额/净债务(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocftonetdebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入时间序列
    return w.wsd(security,"ocftoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOperateIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/经营活动净收益时间序列
    return w.wsd(security,"ocftooperateincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFTOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额占比时间序列
    return w.wsd(security,"ocftocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getICfTOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动产生的现金流量净额占比时间序列
    return w.wsd(security,"icftocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFcFTOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动产生的现金流量净额占比时间序列
    return w.wsd(security,"fcftocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/负债合计时间序列
    return w.wsd(security,"ocftodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/带息债务时间序列
    return w.wsd(security,"ocftointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToShortDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/流动负债时间序列
    return w.wsd(security,"ocftoshortdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToLongDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/非流动负债时间序列
    return w.wsd(security,"ocftolongdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/净债务时间序列
    return w.wsd(security,"ocftonetdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoyOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额(同比增长率)时间序列
    return w.wsd(security,"yoyocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额(N年,增长率)时间序列
    return w.wsd(security,"growth_ocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入(TTM)时间序列
    return w.wsd(security,"ocftoor_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOperateIncomeTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/经营活动净收益(TTM)时间序列
    return w.wsd(security,"ocftooperateincome_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateCashFlowToOpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业利润(TTM)时间序列
    return w.wsd(security,"operatecashflowtoop_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOCFToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入_GSD时间序列
    return w.wsd(security,"wgsd_ocftosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOCFToOperateIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/经营活动净收益_GSD时间序列
    return w.wsd(security,"wgsd_ocftooperateincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOCFToLiqDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/流动负债_GSD时间序列
    return w.wsd(security,"wgsd_ocftoliqdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOCFToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_ocftodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOCFToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/带息债务_GSD时间序列
    return w.wsd(security,"wgsd_ocftointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOCFToNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/净债务_GSD时间序列
    return w.wsd(security,"wgsd_ocftonetdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoyOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_ocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOperateIncomeTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/经营活动净收益(TTM)_GSD时间序列
    return w.wsd(security,"ocftooperateincome_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateCashFlowToOpTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业利润(TTM)_GSD时间序列
    return w.wsd(security,"operatecashflowtoop_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToSalesTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入(TTM)_GSD时间序列
    return w.wsd(security,"ocftosales_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOperCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_oper_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_invest_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFinCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_fin_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCfOperActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额差额(合计平衡项目)时间序列
    return w.wsd(security,"cf_oper_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsOperNetCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额时间序列
    return w.wsd(security,"stm07_cs_reits_opernetcash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCfInvActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动产生的现金流量净额差额(合计平衡项目)时间序列
    return w.wsd(security,"cf_inv_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsInvestNetCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动产生的现金流量净额时间序列
    return w.wsd(security,"stm07_cs_reits_investnetcash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCfFncActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动产生的现金流量净额差额(合计平衡项目)时间序列
    return w.wsd(security,"cf_fnc_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsFinanceNetCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动产生的现金流量净额时间序列
    return w.wsd(security,"stm07_cs_reits_financenetcash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFToOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入_PIT时间序列
    return w.wsd(security,"fa_ocftoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocftoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFTooAITtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/经营活动净收益(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocftooai_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFToOpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocftoop_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOCFToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/负债合计_PIT时间序列
    return w.wsd(security,"fa_ocftodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/营业收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"ocftoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOperateIncomeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动产生的现金流量净额/经营活动净收益(TTM,只有最新数据)时间序列
    return w.wsd(security,"ocftooperateincome_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetCashFlowsOperActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-经营活动现金流量净额差额(特殊报表科目)时间序列
    return w.wsd(security,"im_net_cash_flows_oper_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetCashFlowsOperActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-经营活动现金流量净额差额说明(特殊报表科目)时间序列
    return w.wsd(security,"im_net_cash_flows_oper_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetCashFlowsOperActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-经营活动现金流量净额差额(合计平衡项目)时间序列
    return w.wsd(security,"im_net_cash_flows_oper_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOcFpsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股经营活动产生的现金流量净额(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocfps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOcFpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股经营活动产生的现金流量净额时间序列
    return w.wsd(security,"ocfps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoyOCFpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股经营活动产生的现金流量净额(同比增长率)时间序列
    return w.wsd(security,"yoyocfps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoyOCFpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股经营活动产生的现金流量净额(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyocfps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestOThCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他投资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_invest_oth_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFinOThCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他筹资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_fin_oth_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOCFToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动产生的现金流量净额/营业收入时间序列
    return w.wsd(security,"qfa_ocftosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOCFToOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动产生的现金流量净额/经营活动净收益时间序列
    return w.wsd(security,"qfa_ocftoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFTOCFQfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动产生的现金流量净额占比时间序列
    return w.wsd(security,"ocftocf_qfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getICfTOCFQfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资活动产生的现金流量净额占比时间序列
    return w.wsd(security,"icftocf_qfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFcFTOCFQfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.筹资活动产生的现金流量净额占比时间序列
    return w.wsd(security,"fcftocf_qfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaOperCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_oper_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaInvestCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_invest_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaFinCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.筹资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_fin_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetCashFlowsOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-经营活动产生的现金流量净额时间序列
    return w.wsd(security,"im_net_cash_flows_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashFlowsOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动产生的现金流量净额时间序列
    return w.wsd(security,"qfa_net_cash_flows_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashFlowsInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资活动产生的现金流量净额时间序列
    return w.wsd(security,"qfa_net_cash_flows_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashFlowsFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.筹资活动产生的现金流量净额时间序列
    return w.wsd(security,"qfa_net_cash_flows_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCFogRTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-经营活动产生的现金流量净额(TTM)_PIT时间序列
    return w.wsd(security,"fa_cfogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCffGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-筹资活动产生的现金流量净额(TTM)_PIT时间序列
    return w.wsd(security,"fa_cffgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCFigRTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-投资活动产生的现金流量净额(TTM)_PIT时间序列
    return w.wsd(security,"fa_cfigr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaInvestOThCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他投资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_invest_oth_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaFinOThCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他筹资活动产生的现金流量净额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_fin_oth_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaImNetCashFlowsOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.间接法-经营活动产生的现金流量净额时间序列
    return w.wsd(security,"qfa_im_net_cash_flows_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDupontAssetsToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益乘数(杜邦分析)时间序列
    return w.wsd(security,"dupont_assetstoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontAssetsToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益乘数(杜邦分析)_GSD时间序列
    return w.wsd(security,"wgsd_dupont_assetstoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustryItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目名称时间序列
    return w.wsd(security,"segment_industry_item",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustrySales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目收入时间序列
    return w.wsd(security,"segment_industry_sales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustryCost1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目成本时间序列
    return w.wsd(security,"segment_industry_cost1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustryProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目毛利时间序列
    return w.wsd(security,"segment_industry_profit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustryGpMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目毛利率时间序列
    return w.wsd(security,"segment_industry_gpmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目名称时间序列
    return w.wsd(security,"segment_product_item",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目收入时间序列
    return w.wsd(security,"segment_product_sales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductCost1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目成本时间序列
    return w.wsd(security,"segment_product_cost1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目毛利时间序列
    return w.wsd(security,"segment_product_profit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductGpMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目毛利率时间序列
    return w.wsd(security,"segment_product_gpmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目名称时间序列
    return w.wsd(security,"segment_region_item",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionSales1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目收入时间序列
    return w.wsd(security,"segment_region_sales1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionCost1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目成本时间序列
    return w.wsd(security,"segment_region_cost1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionProfit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目毛利时间序列
    return w.wsd(security,"segment_region_profit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionGpMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目毛利率时间序列
    return w.wsd(security,"segment_region_gpmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustrySalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目收入(旧)时间序列
    return w.wsd(security,"segment_industry_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustryCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目成本(旧)时间序列
    return w.wsd(security,"segment_industry_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentIndustryProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按行业)-项目毛利(旧)时间序列
    return w.wsd(security,"segment_industry_profit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目收入(旧)时间序列
    return w.wsd(security,"segment_product_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目成本(旧)时间序列
    return w.wsd(security,"segment_product_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentProductProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按产品)-项目毛利(旧)时间序列
    return w.wsd(security,"segment_product_profit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目收入(旧)时间序列
    return w.wsd(security,"segment_region_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目成本(旧)时间序列
    return w.wsd(security,"segment_region_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentRegionProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营构成(按地区)-项目毛利(旧)时间序列
    return w.wsd(security,"segment_region_profit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditCategorySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计意见类别时间序列
    return w.wsd(security,"stmnote_audit_category",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInAuditCategorySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内控_审计意见类别时间序列
    return w.wsd(security,"stmnote_InAudit_category",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProvDePrAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值准备时间序列
    return w.wsd(security,"prov_depr_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems13Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值准备(非经常性损益)时间序列
    return w.wsd(security,"stmnote_Eoitems_13",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve21Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备合计时间序列
    return w.wsd(security,"stmnote_reserve_21",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve22Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-房屋、建筑物时间序列
    return w.wsd(security,"stmnote_reserve_22",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve23Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-机器设备时间序列
    return w.wsd(security,"stmnote_reserve_23",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve24Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-专用设备时间序列
    return w.wsd(security,"stmnote_reserve_24",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve25Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-运输工具时间序列
    return w.wsd(security,"stmnote_reserve_25",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve26Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-通讯设备时间序列
    return w.wsd(security,"stmnote_reserve_26",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve27Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-电子设备时间序列
    return w.wsd(security,"stmnote_reserve_27",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve28Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-办公及其它设备时间序列
    return w.wsd(security,"stmnote_reserve_28",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve29Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值准备-其它设备时间序列
    return w.wsd(security,"stmnote_reserve_29",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve30Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产减值准备时间序列
    return w.wsd(security,"stmnote_reserve_30",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve31Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产减值准备-专利权时间序列
    return w.wsd(security,"stmnote_reserve_31",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve32Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产减值准备-商标权时间序列
    return w.wsd(security,"stmnote_reserve_32",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve33Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产减值准备-职工住房使用权时间序列
    return w.wsd(security,"stmnote_reserve_33",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve34Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产减值准备-土地使用权时间序列
    return w.wsd(security,"stmnote_reserve_34",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0007Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取计提投资资产减值准备时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0007",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaProvDePrAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.资产减值准备时间序列
    return w.wsd(security,"qfa_prov_depr_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLandUseRightsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取土地使用权_GSD时间序列
    return w.wsd(security,"wgsd_land_use_rights",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLandUseRights19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取土地使用权_原值时间序列
    return w.wsd(security,"stmnote_LandUseRights_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLandUseRights20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取土地使用权_累计摊销时间序列
    return w.wsd(security,"stmnote_LandUseRights_20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLandUseRights21Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取土地使用权_减值准备时间序列
    return w.wsd(security,"stmnote_LandUseRights_21",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLandUseRights22Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取土地使用权_账面价值时间序列
    return w.wsd(security,"stmnote_LandUseRights_22",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtReverseRepoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产时间序列
    return w.wsd(security,"prt_reverserepo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:证券时间序列
    return w.wsd(security,"stmnote_SPUAR_0001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:票据时间序列
    return w.wsd(security,"stmnote_SPUAR_0002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:贷款时间序列
    return w.wsd(security,"stmnote_SPUAR_0003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:信托及其他受益权时间序列
    return w.wsd(security,"stmnote_SPUAR_0004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:长期应收款时间序列
    return w.wsd(security,"stmnote_SPUAR_0005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0006Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:其他担保物时间序列
    return w.wsd(security,"stmnote_SPUAR_0006",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr0007Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:减值准备时间序列
    return w.wsd(security,"stmnote_SPUAR_0007",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:股票质押式回购时间序列
    return w.wsd(security,"stmnote_SPUAR_10001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:约定购回式证券时间序列
    return w.wsd(security,"stmnote_SPUAR_10002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:债券买断式回购时间序列
    return w.wsd(security,"stmnote_SPUAR_10003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:债券质押式回购时间序列
    return w.wsd(security,"stmnote_SPUAR_10004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10007Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:债券回购时间序列
    return w.wsd(security,"stmnote_SPUAR_10007",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产:其他时间序列
    return w.wsd(security,"stmnote_SPUAR_10005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSPuAr10006Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产合计时间序列
    return w.wsd(security,"stmnote_SPUAR_10006",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs17Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产_FUND时间序列
    return w.wsd(security,"stm_bs_17",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBsRepoInExChMktSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产(交易所市场)_FUND时间序列
    return w.wsd(security,"stm_bs_repoin_exchmkt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBsRepoInInterBmkTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产(银行间市场)_FUND时间序列
    return w.wsd(security,"stm_bs_repoin_interbmkt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售金融资产收入_FUND时间序列
    return w.wsd(security,"stm_is_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinAssetsAvailForSaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售金融资产时间序列
    return w.wsd(security,"fin_assets_avail_for_sale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFaaViableForSale0001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售金融资产:产生的利得/(损失)时间序列
    return w.wsd(security,"stmnote_FAAviableForSale_0001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFaaViableForSale0002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售金融资产:产生的所得税影响时间序列
    return w.wsd(security,"stmnote_FAAviableForSale_0002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFaaViableForSale0003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售金融资产:前期计入其他综合收益当期转入损益的金额时间序列
    return w.wsd(security,"stmnote_FAAviableForSale_0003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFaaViableForSale0004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售金融资产公允价值变动时间序列
    return w.wsd(security,"stmnote_FAAviableForSale_0004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售金融资产减值损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrDispFinAssetsAvailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取处置可供出售金融资产净增加额时间序列
    return w.wsd(security,"net_incr_disp_fin_assets_avail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecuritiesLending3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出证券:可供出售金融资产时间序列
    return w.wsd(security,"stmnote_securitieslending_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrDispFinAssetsAvailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.处置可供出售金融资产净增加额时间序列
    return w.wsd(security,"qfa_net_incr_disp_fin_assets_avail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecuritiesLending1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出证券合计时间序列
    return w.wsd(security,"stmnote_securitieslending_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecuritiesLending2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出证券:交易性金融资产时间序列
    return w.wsd(security,"stmnote_securitieslending_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecuritiesLending4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出证券:转融通融入证券时间序列
    return w.wsd(security,"stmnote_securitieslending_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecuritiesLending5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出证券:转融通融入证券余额时间序列
    return w.wsd(security,"stmnote_securitieslending_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecuritiesLending6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出证券:减值准备时间序列
    return w.wsd(security,"stmnote_securitieslending_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashDepositsCentralBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及存放中央银行款项时间序列
    return w.wsd(security,"cash_deposits_central_bank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行存款_FUND时间序列
    return w.wsd(security,"stm_bs_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行存款时间序列
    return w.wsd(security,"prt_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCashToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行存款占基金资产净值比时间序列
    return w.wsd(security,"prt_cashtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCashToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行存款占基金资产总值比时间序列
    return w.wsd(security,"prt_cashtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCashValueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行存款市值增长率时间序列
    return w.wsd(security,"prt_cashvaluegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCashToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行存款市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_cashtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankDepositSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金-银行存款时间序列
    return w.wsd(security,"stmnote_bankdeposit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashToStDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金/短期债务时间序列
    return w.wsd(security,"cashtostdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金增长率时间序列
    return w.wsd(security,"yoy_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCashToLiqDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金/流动负债_GSD时间序列
    return w.wsd(security,"wgsd_cashtoliqdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金时间序列
    return w.wsd(security,"stm07_bs_reits_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4412Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金合计时间序列
    return w.wsd(security,"stmnote_DPST_4412",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteCashInvaultSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币资金-库存现金时间序列
    return w.wsd(security,"stmnote_cashinvault",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBorrow4512Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取借款合计时间序列
    return w.wsd(security,"stmnote_Borrow_4512",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStBorrowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期借款时间序列
    return w.wsd(security,"st_borrow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtBorrowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期借款时间序列
    return w.wsd(security,"lt_borrow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPledgeLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押借款时间序列
    return w.wsd(security,"pledge_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRecpBorrowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取取得借款收到的现金时间序列
    return w.wsd(security,"cash_recp_borrow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4512Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期借款小计时间序列
    return w.wsd(security,"stmnote_STBorrow_4512",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4512Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期借款小计时间序列
    return w.wsd(security,"stmnote_LTBorrow_4512",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs70Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期借款_FUND时间序列
    return w.wsd(security,"stm_bs_70",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaLtBorrowToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期借款/资产总计_PIT时间序列
    return w.wsd(security,"fa_ltborrowtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBusLoanRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国际商业借款比率时间序列
    return w.wsd(security,"busloanratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBusLoanRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国际商业借款比率(旧)时间序列
    return w.wsd(security,"busloanratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4506Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取美元短期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_STBorrow_4506",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4507Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取日元短期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_STBorrow_4507",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4508Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取欧元短期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_STBorrow_4508",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4509Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取港币短期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_STBorrow_4509",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4510Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取英镑短期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_STBorrow_4510",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4506Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取美元长期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_LTBorrow_4506",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4507Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取日元长期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_LTBorrow_4507",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4508Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取欧元长期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_LTBorrow_4508",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4509Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取港币长期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_LTBorrow_4509",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4510Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取英镑长期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_LTBorrow_4510",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBorrowCentralBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向中央银行借款时间序列
    return w.wsd(security,"borrow_central_bank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrLoansCentralBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向中央银行借款净增加额时间序列
    return w.wsd(security,"net_incr_loans_central_bank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4505Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取人民币短期借款时间序列
    return w.wsd(security,"stmnote_STBorrow_4505",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4505Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取人民币长期借款时间序列
    return w.wsd(security,"stmnote_LTBorrow_4505",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecpBorrowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.取得借款收到的现金时间序列
    return w.wsd(security,"qfa_cash_recp_borrow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteStBorrow4511Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他货币短期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_STBorrow_4511",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLtBorrow4511Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他货币长期借款(折算人民币)时间序列
    return w.wsd(security,"stmnote_LTBorrow_4511",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7636Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一年内到期的长期借款时间序列
    return w.wsd(security,"stmnote_others_7636",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrLoansCentralBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.向中央银行借款净增加额时间序列
    return w.wsd(security,"qfa_net_incr_loans_central_bank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExtraordinarySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非经常性损益时间序列
    return w.wsd(security,"extraordinary",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems21Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非经常性损益项目小计时间序列
    return w.wsd(security,"stmnote_Eoitems_21",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems24Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非经常性损益项目合计时间序列
    return w.wsd(security,"stmnote_Eoitems_24",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNRglSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非经常性损益_PIT时间序列
    return w.wsd(security,"fa_nrgl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDeductProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常性损益后的净利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_deductprofit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDpYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常性损益后的净利润(同比增长率)时间序列
    return w.wsd(security,"dp_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedProfitTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常性损益后的净利润(TTM)时间序列
    return w.wsd(security,"deductedprofit_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常性损益后的净利润时间序列
    return w.wsd(security,"deductedprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedProfitTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常性损益后的净利润(TTM)_GSD时间序列
    return w.wsd(security,"deductedprofit_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedProfitYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.扣除非经常性损益后的净利润同比增长率时间序列
    return w.wsd(security,"deductedprofit_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeDeductedTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM,扣除非经常性损益)时间序列
    return w.wsd(security,"val_pe_deducted_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失/营业总收入时间序列
    return w.wsd(security,"impairtogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairToOpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失/营业利润时间序列
    return w.wsd(security,"impairtoOP",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失/营业总收入(TTM)时间序列
    return w.wsd(security,"impairtogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairmentTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失(TTM)时间序列
    return w.wsd(security,"impairment_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairLossAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失时间序列
    return w.wsd(security,"impair_loss_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaImpairToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_impairtogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaImpairLossTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失(TTM)_PIT时间序列
    return w.wsd(security,"fa_impairloss_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"impairtogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairmentTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产减值损失(TTM,只有最新数据)时间序列
    return w.wsd(security,"impairment_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherAssetsImpairLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产减值损失时间序列
    return w.wsd(security,"other_assets_impair_loss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产减值损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpairToOpQfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.资产减值损失/营业利润时间序列
    return w.wsd(security,"impairtoop_qfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaImpairLossAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.资产减值损失时间序列
    return w.wsd(security,"qfa_impair_loss_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherImpairSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他资产减值损失时间序列
    return w.wsd(security,"qfa_other_impair",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFineXp4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用明细-利息支出时间序列
    return w.wsd(security,"stmnote_finexp_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFineXp5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用明细-利息收入时间序列
    return w.wsd(security,"stmnote_finexp_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFineXp13Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用明细-利息资本化金额时间序列
    return w.wsd(security,"stmnote_finexp_13",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFineXp6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用明细-汇兑损益时间序列
    return w.wsd(security,"stmnote_finexp_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFineXp7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用明细-手续费时间序列
    return w.wsd(security,"stmnote_finexp_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteFineXp8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用明细-其他时间序列
    return w.wsd(security,"stmnote_finexp_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRdExpYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用同比增长时间序列
    return w.wsd(security,"fa_rdexp_yoy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRdExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用_GSD时间序列
    return w.wsd(security,"wgsd_rd_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsRdFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用时间序列
    return w.wsd(security,"stm07_is_reits_rdfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdSalarySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用-工资薪酬时间序列
    return w.wsd(security,"stmnote_rdsalary",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用-折旧摊销时间序列
    return w.wsd(security,"stmnote_rdda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdLeaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用-租赁费时间序列
    return w.wsd(security,"stmnote_rdlease",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdInvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用-直接投入时间序列
    return w.wsd(security,"stmnote_rdinv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdOthersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用-其他时间序列
    return w.wsd(security,"stmnote_rdothers",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdExpCostToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发费用占营业收入比例时间序列
    return w.wsd(security,"stmnote_Rdexp_costtosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaRdExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.研发费用_GSD时间序列
    return w.wsd(security,"wgsd_qfa_rd_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaRdExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.研发费用时间序列
    return w.wsd(security,"qfa_rd_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税/利润总额时间序列
    return w.wsd(security,"taxtoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税(TTM)时间序列
    return w.wsd(security,"tax_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税(TTM)_GSD时间序列
    return w.wsd(security,"tax_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDIncTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税_GSD时间序列
    return w.wsd(security,"wgsd_inc_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税时间序列
    return w.wsd(security,"tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems22Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税影响数时间序列
    return w.wsd(security,"stmnote_Eoitems_22",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteIncomeTax6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税费用合计时间序列
    return w.wsd(security,"stmnote_incometax_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs78Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税费用_FUND时间序列
    return w.wsd(security,"stm_is_78",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTaxTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所得税(TTM)_PIT时间序列
    return w.wsd(security,"fa_tax_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeferredTaxAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延所得税资产时间序列
    return w.wsd(security,"deferred_tax_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeferredTaxLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延所得税负债时间序列
    return w.wsd(security,"deferred_tax_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDecrDeferredIncTaxAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延所得税资产减少时间序列
    return w.wsd(security,"decr_deferred_inc_tax_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInCrDeferredIncTaxLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延所得税负债增加时间序列
    return w.wsd(security,"incr_deferred_inc_tax_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年末所得税率时间序列
    return w.wsd(security,"stmnote_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteIncomeTax1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期所得税:中国大陆时间序列
    return w.wsd(security,"stmnote_incometax_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteIncomeTax2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期所得税:中国香港时间序列
    return w.wsd(security,"stmnote_incometax_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteIncomeTax3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期所得税:其他境外时间序列
    return w.wsd(security,"stmnote_incometax_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteIncomeTax5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延所得税时间序列
    return w.wsd(security,"stmnote_incometax_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaIncTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.所得税_GSD时间序列
    return w.wsd(security,"wgsd_qfa_inc_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.所得税时间序列
    return w.wsd(security,"qfa_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteIncomeTax4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取以前年度所得税调整时间序列
    return w.wsd(security,"stmnote_incometax_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDeferredTaxAssetsDecrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.递延所得税资产减少时间序列
    return w.wsd(security,"qfa_deferred_tax_assets_decr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInCrDeferredIncTaxLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.递延所得税负债增加时间序列
    return w.wsd(security,"qfa_incr_deferred_inc_tax_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskBetaUnIncomeTaxRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta(剔除所得税率)时间序列
    return w.wsd(security,"risk_betaunincometaxrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGwIntangSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取商誉及无形资产_GSD时间序列
    return w.wsd(security,"wgsd_gw_intang",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGoodwillSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取商誉时间序列
    return w.wsd(security,"goodwill",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取商誉减值损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGoodwillDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取商誉-账面价值时间序列
    return w.wsd(security,"stmnote_goodwilldetail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGoodwillImpairmentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取商誉-减值准备时间序列
    return w.wsd(security,"stmnote_goodwillimpairment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEMplBenPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付职工薪酬时间序列
    return w.wsd(security,"empl_ben_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplPayableAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付职工薪酬合计:本期增加时间序列
    return w.wsd(security,"stmnote_emplpayable_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplPayableSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付职工薪酬合计:期初余额时间序列
    return w.wsd(security,"stmnote_emplpayable_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplPayableEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付职工薪酬合计:期末余额时间序列
    return w.wsd(security,"stmnote_emplpayable_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplPayableDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付职工薪酬合计:本期减少时间序列
    return w.wsd(security,"stmnote_emplpayable_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtEMplBenPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期应付职工薪酬时间序列
    return w.wsd(security,"lt_empl_ben_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业税金及附加合计时间序列
    return w.wsd(security,"stmnote_tax_business",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOperTaxTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业税金及附加(TTM)_PIT时间序列
    return w.wsd(security,"fa_opertax_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他营业税金及附加时间序列
    return w.wsd(security,"stmnote_tax_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIssuingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期报告披露日期时间序列
    return w.wsd(security,"stm_issuingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIssuingDateFsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期报告正报披露日期时间序列
    return w.wsd(security,"stm_issuingdate_fs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmPredictIssuingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期报告预计披露日期时间序列
    return w.wsd(security,"stm_predict_issuingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmRpTSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告起始日期时间序列
    return w.wsd(security,"stm_rpt_s",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmRpTESeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告截止日期时间序列
    return w.wsd(security,"stm_rpt_e",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatelyRdBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新报告期时间序列
    return w.wsd(security,"latelyrd_bt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaErrorCorrectionDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会计差错更正披露日期时间序列
    return w.wsd(security,"fa_errorcorrectiondate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaErrorCorrectionOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否存在会计差错更正时间序列
    return w.wsd(security,"fa_errorcorrectionornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditAmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会计准则类型时间序列
    return w.wsd(security,"stmnote_audit_am",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceTimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩说明会时间时间序列
    return w.wsd(security,"performancetime",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerformanceDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩说明会日期时间序列
    return w.wsd(security,"performancedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEScoreWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取环境维度得分时间序列
    return w.wsd(security,"esg_escore_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSScoreWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社会维度得分时间序列
    return w.wsd(security,"esg_sscore_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGScoreWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取治理维度得分时间序列
    return w.wsd(security,"esg_gscore_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFeeFeeSumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行费用合计时间序列
    return w.wsd(security,"issuefee_feesum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoExpense2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发发行费用时间序列
    return w.wsd(security,"ipo_expense2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoExpenseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发发行费用(旧)时间序列
    return w.wsd(security,"ipo_expense",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListAnnoCeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行结果公告日时间序列
    return w.wsd(security,"cb_list_annocedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundApprovedDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金获批注册日期时间序列
    return w.wsd(security,"fund_approveddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueAnnouncedAteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行公告日时间序列
    return w.wsd(security,"issue_announcedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderAnceDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行公告日期时间序列
    return w.wsd(security,"tender_ancedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAnnCeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上网发行公告日时间序列
    return w.wsd(security,"fellow_anncedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行日期时间序列
    return w.wsd(security,"issue_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIssueDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发发行日期时间序列
    return w.wsd(security,"ipo_issuedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowIssueDatePpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定增发行日期时间序列
    return w.wsd(security,"fellow_issuedate_pp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListDToNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行日期时间序列
    return w.wsd(security,"cb_list_dtonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListDateInStOffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下向机构投资者发行日期时间序列
    return w.wsd(security,"cb_list_dateinstoff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行方式时间序列
    return w.wsd(security,"issue_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发发行方式时间序列
    return w.wsd(security,"ipo_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowIssueTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发发行方式时间序列
    return w.wsd(security,"fellow_issuetype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueObjectSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行对象时间序列
    return w.wsd(security,"issue_object",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowShareholdersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发发行对象时间序列
    return w.wsd(security,"fellow_shareholders",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行份额时间序列
    return w.wsd(security,"issue_unit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueTotalUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行总份额时间序列
    return w.wsd(security,"issue_totalunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsIssueSizeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行规模时间序列
    return w.wsd(security,"fund_reitsissuesize",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundActualScaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际发行规模时间序列
    return w.wsd(security,"fund_actualscale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueTotalSizeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行总规模时间序列
    return w.wsd(security,"issue_totalsize",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueInitiatorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金发起人时间序列
    return w.wsd(security,"issue_initiator",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueLeadUnderwriterSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金主承销商时间序列
    return w.wsd(security,"issue_leadunderwriter",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueDeputySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金销售代理人时间序列
    return w.wsd(security,"issue_deputy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueNominatorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金上市推荐人时间序列
    return w.wsd(security,"issue_nominator",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOeClsPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行封闭期时间序列
    return w.wsd(security,"issue_oeclsperiod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOeCNdNetPurchaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成立条件-净认购份额时间序列
    return w.wsd(security,"issue_oecndnetpurchase",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOeCNdPurchasersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成立条件-认购户数时间序列
    return w.wsd(security,"issue_oecndpurchasers",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMaxCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取募集份额上限时间序列
    return w.wsd(security,"issue_oef_maxcollection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfConfirmRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购份额确认比例时间序列
    return w.wsd(security,"issue_oef_confirmratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfNumPurchasersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开放式基金认购户数时间序列
    return w.wsd(security,"issue_oef_numpurchasers",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueEtFDealShareOnMarketSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市交易份额时间序列
    return w.wsd(security,"issue_etfdealshareonmarket",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOnlineCashOfferingSymbolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上现金发售代码时间序列
    return w.wsd(security,"issue_onlinecashofferingsymbol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFirstMarketFundCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一级市场基金代码时间序列
    return w.wsd(security,"issue_firstmarketfundcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMThDInDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者认购方式时间序列
    return w.wsd(security,"issue_oef_mthdind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMinamTinDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者认购金额下限时间序列
    return w.wsd(security,"issue_oef_minamtind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMaxAmtInDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者认购金额上限时间序列
    return w.wsd(security,"issue_oef_maxamtind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfStartDateInDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者认购起始日时间序列
    return w.wsd(security,"issue_oef_startdateind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfEnddateInDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者认购终止日时间序列
    return w.wsd(security,"issue_oef_enddateind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMThDInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭期机构投资者认购方式时间序列
    return w.wsd(security,"issue_oef_mthdinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfStartDateInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资者设立认购起始日时间序列
    return w.wsd(security,"issue_oef_startdateinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfDndDateInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资者设立认购终止日时间序列
    return w.wsd(security,"issue_oef_dnddateinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMinamTinStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭期机构投资者认购下限时间序列
    return w.wsd(security,"issue_oef_minamtinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfMaxAmtInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭期机构投资者认购上限时间序列
    return w.wsd(security,"issue_oef_maxamtinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueCefInIPurchaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭式基金认购数量时间序列
    return w.wsd(security,"issue_cef_inipurchase",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueCefOverSubSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭式基金超额认购倍数时间序列
    return w.wsd(security,"issue_cef_oversub",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueCefSuccRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭式基金中签率时间序列
    return w.wsd(security,"issue_cef_succratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRaSingIsStartEarlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否提前开始募集时间序列
    return w.wsd(security,"issue_rasing_isstartearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRaSingIsStartDeferredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否延期募集时间序列
    return w.wsd(security,"issue_rasing_isstartdeferred",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRaSingIsEndEarlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否提前结束募集时间序列
    return w.wsd(security,"issue_rasing_isendearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRaSingIsEndDeferredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否延长募集期时间序列
    return w.wsd(security,"issue_rasing_isenddeferred",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOEfDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购天数时间序列
    return w.wsd(security,"issue_oef_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPerUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单位年度分红时间序列
    return w.wsd(security,"div_perunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAccumulatedPerUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单位累计分红时间序列
    return w.wsd(security,"div_accumulatedperunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPayOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度分红总额时间序列
    return w.wsd(security,"div_payout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivTimesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度分红次数时间序列
    return w.wsd(security,"div_times",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAccumulatedPayOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计分红总额时间序列
    return w.wsd(security,"div_accumulatedpayout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAuALaCcmDiv3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度累计分红总额时间序列
    return w.wsd(security,"div_aualaccmdiv3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAuALaCcmDivArdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度累计分红总额(已宣告)时间序列
    return w.wsd(security,"div_aualaccmdiv_ard",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAuALaCcmDivSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度累计分红总额(沪深)时间序列
    return w.wsd(security,"div_aualaccmdiv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAccumulatedTimesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计分红次数时间序列
    return w.wsd(security,"div_accumulatedtimes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPeriodPerUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间单位分红时间序列
    return w.wsd(security,"div_periodperunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPeriodPayOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间分红总额时间序列
    return w.wsd(security,"div_periodpayout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPeriodTimesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间分红次数时间序列
    return w.wsd(security,"div_periodtimes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分红条款时间序列
    return w.wsd(security,"div_clause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCacLawsuitNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间诉讼次数时间序列
    return w.wsd(security,"cac_lawsuitnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCacLawsuitAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间诉讼涉案金额时间序列
    return w.wsd(security,"cac_lawsuitamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCacIllegalityNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间违规处罚次数时间序列
    return w.wsd(security,"cac_illegalitynum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCacIllegalityAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间违规处罚金额时间序列
    return w.wsd(security,"cac_illegalityamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitNonTradableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未上市流通基金份数(封闭式)时间序列
    return w.wsd(security,"unit_nontradable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitTradableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已上市流通基金份数(封闭式)时间序列
    return w.wsd(security,"unit_tradable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTotalAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金资产总值时间序列
    return w.wsd(security,"prt_totalasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTotalAssetChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金资产总值变动时间序列
    return w.wsd(security,"prt_totalassetchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTotalAssetChangeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金资产总值变动率时间序列
    return w.wsd(security,"prt_totalassetchangeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNavToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金净值占基金资产总值比时间序列
    return w.wsd(security,"prt_navtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票市值占基金资产总值比时间序列
    return w.wsd(security,"prt_stocktoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券市值占基金资产总值比时间序列
    return w.wsd(security,"prt_bondtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金市值占基金资产总值比时间序列
    return w.wsd(security,"prt_fundtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtWarrantToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证市值占基金资产总值比时间序列
    return w.wsd(security,"prt_warranttoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产占基金资产总值比时间序列
    return w.wsd(security,"prt_othertoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGovernmentBondToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债市值占基金资产总值比时间序列
    return w.wsd(security,"prt_governmentbondtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFinancialBondToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融债市值占基金资产总值比时间序列
    return w.wsd(security,"prt_financialbondtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondsToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业债市值占基金资产总值比时间序列
    return w.wsd(security,"prt_corporatebondstoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtConvertibleBondToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可转债市值占基金资产总值比时间序列
    return w.wsd(security,"prt_convertiblebondtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueIndustryToAsset2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占基金资产总值比时间序列
    return w.wsd(security,"prt_stockvalue_industrytoasset2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldStockToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股市值占基金资产总值比时间序列
    return w.wsd(security,"prt_heavilyheldstocktoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHkStockToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取港股投资市值占基金资产总值比时间序列
    return w.wsd(security,"prt_hkstocktoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFReverseRepoToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售证券占基金资产总值比例时间序列
    return w.wsd(security,"mmf_reverserepotoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCentralBankBillToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取央行票据市值占基金资产总值比时间序列
    return w.wsd(security,"prt_centralbankbilltoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueTopIndustryToAsset2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业市值占基金资产总值比时间序列
    return w.wsd(security,"prt_stockvalue_topindustrytoasset2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldBondToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券市值占基金资产总值比时间序列
    return w.wsd(security,"prt_heavilyheldbondtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldFundToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金市值占基金资产总值比时间序列
    return w.wsd(security,"prt_heavilyheldfundtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtPFbToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取政策性金融债市值占基金资产总值比时间序列
    return w.wsd(security,"prt_pfbtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业发行债券市值占基金资产总值比时间序列
    return w.wsd(security,"prt_corporatebondtoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldAbsToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券市值占基金资产总值比时间序列
    return w.wsd(security,"prt_heavilyheldabstoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtSecLendingValueToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转融通证券出借业务市值占基金资产总值比时间序列
    return w.wsd(security,"prt_seclendingvaluetoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNetAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金资产净值时间序列
    return w.wsd(security,"prt_netasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNetAssetChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金资产净值变动时间序列
    return w.wsd(security,"prt_netassetchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNetAssetChangeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金资产净值变动率时间序列
    return w.wsd(security,"prt_netassetchangeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCurrencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期基金资产净值币种时间序列
    return w.wsd(security,"prt_currency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStocktonAvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票市值占基金资产净值比时间序列
    return w.wsd(security,"prt_stocktonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_bondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金市值占基金资产净值比时间序列
    return w.wsd(security,"prt_fundtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtWarrantToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证市值占基金资产净值比时间序列
    return w.wsd(security,"prt_warranttonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产占基金资产净值比时间序列
    return w.wsd(security,"prt_othertonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStocktonAvGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_stocktonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_bondtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_fundtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtWarrantToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_warranttonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGovernmentBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债市值占基金资产净值比时间序列
    return w.wsd(security,"prt_governmentbondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGovernmentBondToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_governmentbondtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFinancialBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融债市值占基金资产净值比时间序列
    return w.wsd(security,"prt_financialbondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondsToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业债市值占基金资产净值比时间序列
    return w.wsd(security,"prt_corporatebondstonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtConvertibleBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可转债市值占基金资产净值比时间序列
    return w.wsd(security,"prt_convertiblebondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFinancialBondToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融债市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_financialbondtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondsToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业债市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_corporatebondstonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtConvertibleBondToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可转债市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_convertiblebondtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueIndustryToNav2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占基金资产净值比时间序列
    return w.wsd(security,"prt_stockvalue_industrytonav2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueIndustryToNavGrowth2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占基金资产净值比增长时间序列
    return w.wsd(security,"prt_stockvalue_industrytonavgrowth2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryToNavGrowthWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占基金资产净值比增长(Wind)时间序列
    return w.wsd(security,"prt_industrytonavgrowth_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryToNavGrowthCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占基金资产净值比增长(中信)时间序列
    return w.wsd(security,"prt_industrytonavgrowth_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryToNavGrowthSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占基金资产净值比增长(申万)时间序列
    return w.wsd(security,"prt_industrytonavgrowth_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldStocktonAvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股市值占基金资产净值比时间序列
    return w.wsd(security,"prt_heavilyheldstocktonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFDifferentPtMToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取各期限资产占基金资产净值比例时间序列
    return w.wsd(security,"mmf_differentptmtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHkStocktonAvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取港股投资市值占基金资产净值比时间序列
    return w.wsd(security,"prt_hkstocktonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtReverseRepoToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取买入返售证券占基金资产净值比例时间序列
    return w.wsd(security,"prt_reverserepotonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_othertonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCdsToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同业存单市值占基金资产净值比时间序列
    return w.wsd(security,"prt_CDstonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCentralBankBillToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取央行票据市值占基金资产净值比时间序列
    return w.wsd(security,"prt_centralbankbilltonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtMtnToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中期票据市值占基金资产净值比时间序列
    return w.wsd(security,"prt_mtntonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他债券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_otherbondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCentralBankBillToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取央行票据市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_centralbankbilltonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueTopIndustryToNav2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业市值占基金资产净值比时间序列
    return w.wsd(security,"prt_stockvalue_topindustrytonav2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_heavilyheldbondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldFundToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金市值占基金资产净值比时间序列
    return w.wsd(security,"prt_heavilyheldfundtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCpToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期融资券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_cptonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGicSIndustryValueToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值占基金资产净值比例(Wind全球行业)时间序列
    return w.wsd(security,"prt_gicsindustryvaluetonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueToNavWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值占基金资产净值比(Wind)时间序列
    return w.wsd(security,"prt_industryvaluetonav_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueToNavCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值占基金资产净值比(中信)时间序列
    return w.wsd(security,"prt_industryvaluetonav_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueToNavSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值占基金资产净值比(申万)时间序列
    return w.wsd(security,"prt_industryvaluetonav_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalNetAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.报告期期末基金资产净值时间序列
    return w.wsd(security,"qanal_netasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStocktonAvPassiveInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数投资股票市值占基金资产净值比时间序列
    return w.wsd(security,"prt_stocktonav_passiveinvest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStocktonAvActiveInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取积极投资股票市值占基金资产净值比时间序列
    return w.wsd(security,"prt_stocktonav_activeinvest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtPFbToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取政策性金融债市值占基金资产净值比时间序列
    return w.wsd(security,"prt_pfbtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业发行债券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_corporatebondtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtAbsToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产支持证券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_abstonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtMMitoNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币市场工具市值占基金资产净值比时间序列
    return w.wsd(security,"prt_mmitonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondToNavGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业发行债券市值占基金资产净值比例增长时间序列
    return w.wsd(security,"prt_corporatebondtonavgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopGicSIndustryValueToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值占基金资产净值比例(Wind全球行业)时间序列
    return w.wsd(security,"prt_topgicsindustryvaluetonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryValueToNavWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值占基金资产净值比(Wind)时间序列
    return w.wsd(security,"prt_topindustryvaluetonav_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryValueToNavCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值占基金资产净值比(中信)时间序列
    return w.wsd(security,"prt_topindustryvaluetonav_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryValueToNavSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值占基金资产净值比(申万)时间序列
    return w.wsd(security,"prt_topindustryvaluetonav_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtQdIiCountryRegionInvestmentToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国家/地区投资市值占基金资产净值比例(QDII)时间序列
    return w.wsd(security,"prt_qdii_countryregioninvestmenttonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldAbsToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券市值占基金资产净值比时间序列
    return w.wsd(security,"prt_heavilyheldabstonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtSecLendingValueToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转融通证券出借业务市值占基金资产净值比时间序列
    return w.wsd(security,"prt_seclendingvaluetonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopNStocktonAvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N名重仓股票市值合计占基金资产净值比时间序列
    return w.wsd(security,"prt_topnstocktonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTop5ToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N名重仓债券市值合计占基金资产净值比时间序列
    return w.wsd(security,"prt_top5tonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopNFundToNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N名重仓基金市值合计占基金资产净值比时间序列
    return w.wsd(security,"prt_topnfundtonav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtAvgNetAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期基金日均资产净值时间序列
    return w.wsd(security,"prt_avgnetasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundNetAssetTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产净值(合计)时间序列
    return w.wsd(security,"prt_fundnetasset_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtMergedNavOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产净值是否为合并数据(最新)时间序列
    return w.wsd(security,"prt_mergednavornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtMergedNavOrNot1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产净值是否为合并数据(报告期)时间序列
    return w.wsd(security,"prt_mergednavornot1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundAvgFundScaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金平均规模时间序列
    return w.wsd(security,"fund_avgfundscale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMarketOutlookSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场展望时间序列
    return w.wsd(security,"fund_marketoutlook",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMarketAnalysisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场分析时间序列
    return w.wsd(security,"fund_marketanalysis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票投资市值时间序列
    return w.wsd(security,"prt_stockvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueIndustryTostock2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值占股票投资市值比时间序列
    return w.wsd(security,"prt_stockvalue_industrytostock2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldStockTostockSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股市值占股票投资市值比时间序列
    return w.wsd(security,"prt_heavilyheldstocktostock",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueTopIndustryTostock2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业市值占股票投资市值比时间序列
    return w.wsd(security,"prt_stockvalue_topindustrytostock2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopNStockTostockSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N名重仓股票市值合计占股票投资市值比时间序列
    return w.wsd(security,"prt_topnstocktostock",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValuePassiveInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数投资股票市值时间序列
    return w.wsd(security,"prt_stockvalue_passiveinvest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueActiveInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取积极投资股票市值时间序列
    return w.wsd(security,"prt_stockvalue_activeinvest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHkStockValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取港股投资市值时间序列
    return w.wsd(security,"prt_hkstockvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券投资市值时间序列
    return w.wsd(security,"prt_bondvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGovernmentBondToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债市值占债券投资市值比时间序列
    return w.wsd(security,"prt_governmentbondtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFinancialBondToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融债市值占债券投资市值比时间序列
    return w.wsd(security,"prt_financialbondtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondsToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业债市值占债券投资市值比时间序列
    return w.wsd(security,"prt_corporatebondstobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtConvertibleBondToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可转债市值占债券投资市值比时间序列
    return w.wsd(security,"prt_convertiblebondtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCentralBankBillToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取央行票据市值占债券投资市值比时间序列
    return w.wsd(security,"prt_centralbankbilltobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtPFbToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取政策性金融债占债券投资市值比时间序列
    return w.wsd(security,"prt_pfbtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNcdToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同业存单市值占债券投资市值比时间序列
    return w.wsd(security,"prt_NCDtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldBondToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券市值占债券投资市值比时间序列
    return w.wsd(security,"prt_heavilyheldbondtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业发行债券市值占债券投资市值比时间序列
    return w.wsd(security,"prt_corporatebondtobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTop5ToBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N名重仓债券市值合计占债券投资市值比时间序列
    return w.wsd(security,"prt_top5tobond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金投资市值时间序列
    return w.wsd(security,"prt_fundvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtHeavilyHeldFundToFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金市值占基金投资市值比时间序列
    return w.wsd(security,"prt_heavilyheldfundtofund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundToFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N名重仓基金市值合计占基金投资市值比时间序列
    return w.wsd(security,"prt_topfundtofund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtSiFuturesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股指期货投资市值时间序列
    return w.wsd(security,"prt_SIfutures",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGbFuturesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债期货投资市值时间序列
    return w.wsd(security,"prt_gbfutures",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtWarrantValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证投资市值时间序列
    return w.wsd(security,"prt_warrantvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtSecLendingValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转融通证券出借业务市值时间序列
    return w.wsd(security,"prt_seclendingvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产_GSD时间序列
    return w.wsd(security,"wgsd_assets_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产时间序列
    return w.wsd(security,"prt_other",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs18Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产_FUND时间序列
    return w.wsd(security,"stm_bs_18",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherValueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他资产市值增长率时间序列
    return w.wsd(security,"prt_othervaluegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票市值增长率时间序列
    return w.wsd(security,"prt_stockvaluegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBondValueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券市值增长率时间序列
    return w.wsd(security,"prt_bondvaluegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业发行债券市值增长率时间序列
    return w.wsd(security,"prt_corporatebondgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundValueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金市值增长率时间序列
    return w.wsd(security,"prt_fundvaluegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtWarrantValueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证市值增长率时间序列
    return w.wsd(security,"prt_warrantvaluegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFoundLeverageSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金杠杆率时间序列
    return w.wsd(security,"prt_foundleverage",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGovernmentBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债市值时间序列
    return w.wsd(security,"prt_governmentbond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGovernmentBondGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债市值增长率时间序列
    return w.wsd(security,"prt_governmentbondgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCdsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同业存单市值时间序列
    return w.wsd(security,"prt_CDs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCentralBankBillSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取央行票据市值时间序列
    return w.wsd(security,"prt_centralbankbill",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCentralBankBillGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取央行票据市值增长率时间序列
    return w.wsd(security,"prt_centralbankbillgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFinancialBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融债市值时间序列
    return w.wsd(security,"prt_financialbond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFinancialBondGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融债市值增长率时间序列
    return w.wsd(security,"prt_financialbondgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtPFbValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取政策性金融债市值时间序列
    return w.wsd(security,"prt_pfbvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业发行债券市值时间序列
    return w.wsd(security,"prt_corporatebond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业债市值时间序列
    return w.wsd(security,"prt_corporatebonds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCorporateBondsGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业债市值增长率时间序列
    return w.wsd(security,"prt_corporatebondsgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtCpValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期融资券市值时间序列
    return w.wsd(security,"prt_cpvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtMtnValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中期票据市值时间序列
    return w.wsd(security,"prt_mtnvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtConvertibleBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可转债市值时间序列
    return w.wsd(security,"prt_convertiblebond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtConvertibleBondGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可转债市值增长率时间序列
    return w.wsd(security,"prt_convertiblebondgrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtAbsValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产支持证券市值时间序列
    return w.wsd(security,"prt_absvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtMmIValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取货币市场工具市值时间序列
    return w.wsd(security,"prt_mmivalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtOtherBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他债券市值时间序列
    return w.wsd(security,"prt_otherbond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueIndustry2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值时间序列
    return w.wsd(security,"prt_stockvalue_industry2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtGicSIndustryValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值(Wind全球行业)时间序列
    return w.wsd(security,"prt_gicsindustryvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值(Wind)时间序列
    return w.wsd(security,"prt_industryvalue_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值(中信)时间序列
    return w.wsd(security,"prt_industryvalue_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业投资市值(申万)时间序列
    return w.wsd(security,"prt_industryvalue_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueIndustryValueGrowth2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值增长率时间序列
    return w.wsd(security,"prt_stockvalue_industryvaluegrowth2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueGrowthWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值增长率(Wind)时间序列
    return w.wsd(security,"prt_industryvaluegrowth_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueGrowthCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值增长率(中信)时间序列
    return w.wsd(security,"prt_industryvaluegrowth_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtIndustryValueGrowthSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分行业市值增长率(申万)时间序列
    return w.wsd(security,"prt_industryvaluegrowth_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueTopIndustryName2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业名称时间序列
    return w.wsd(security,"prt_stockvalue_topindustryname2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopGicSIndustryNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业名称(Wind全球行业)时间序列
    return w.wsd(security,"prt_topgicsindustryname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryNameWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业名称(Wind)时间序列
    return w.wsd(security,"prt_topindustryname_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryNameCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业名称(中信)时间序列
    return w.wsd(security,"prt_topindustryname_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryNameSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业名称(申万)时间序列
    return w.wsd(security,"prt_topindustryname_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueTopIndustrySymbol2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业代码时间序列
    return w.wsd(security,"prt_stockvalue_topindustrysymbol2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockValueTopIndustryValue2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业市值时间序列
    return w.wsd(security,"prt_stockvalue_topindustryvalue2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期末持有股票个数(中报、年报)时间序列
    return w.wsd(security,"prt_stockholding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtShareNumStKhlDGStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期不同持仓风格股票只数时间序列
    return w.wsd(security,"prt_sharenum_stkhldgstyle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股股票名称时间序列
    return w.wsd(security,"prt_topstockname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股股票代码时间序列
    return w.wsd(security,"prt_topstockcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最早重仓时间时间序列
    return w.wsd(security,"prt_topstockdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股持股数量时间序列
    return w.wsd(security,"prt_topstockquantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股持股市值时间序列
    return w.wsd(security,"prt_topstockvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockHoldingChangingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股持仓变动时间序列
    return w.wsd(security,"prt_topstockholdingchanging",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopProportionToFloatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股持仓占流通股比例时间序列
    return w.wsd(security,"prt_topproportiontofloating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundNoOfStocksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股票持有基金数时间序列
    return w.wsd(security,"prt_fundnoofstocks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockHeldNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股报告期重仓次数时间序列
    return w.wsd(security,"prt_topstockheldno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtBuyStockCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期买入股票总成本时间序列
    return w.wsd(security,"prt_buystockcost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtSellStockIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期卖出股票总收入时间序列
    return w.wsd(security,"prt_sellstockincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtStockVolumeByBrokerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票成交金额(分券商明细)时间序列
    return w.wsd(security,"prt_stockvolumebybroker",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopBondNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券名称时间序列
    return w.wsd(security,"prt_topbondname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopBondSymbolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券代码时间序列
    return w.wsd(security,"prt_topbondsymbol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopBondQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券持仓数量时间序列
    return w.wsd(security,"prt_topbondquantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopBondValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券持仓市值时间序列
    return w.wsd(security,"prt_topbondvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopBondHoldingChangingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券持仓变动时间序列
    return w.wsd(security,"prt_topbondholdingchanging",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundNoOfBondsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券持有基金数时间序列
    return w.wsd(security,"prt_fundnoofbonds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopAbsNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券名称时间序列
    return w.wsd(security,"prt_topabsname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopAbsSymbolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券代码时间序列
    return w.wsd(security,"prt_topabssymbol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopAbsQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券持仓数量时间序列
    return w.wsd(security,"prt_topabsquantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopAbsValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券持有市值时间序列
    return w.wsd(security,"prt_topabsvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopAbsHoldingChangingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券持仓变动时间序列
    return w.wsd(security,"prt_topabsholdingchanging",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金名称时间序列
    return w.wsd(security,"prt_topfundname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金代码时间序列
    return w.wsd(security,"prt_topfundcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金持仓数量时间序列
    return w.wsd(security,"prt_topfundquantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金持有市值时间序列
    return w.wsd(security,"prt_topfundvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundHoldingChangingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金持仓变动时间序列
    return w.wsd(security,"prt_topfundholdingchanging",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundNoOfFundsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金持有基金数时间序列
    return w.wsd(security,"prt_fundnooffunds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFrequencyOfDeviationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内偏离度的绝对值在0.25%(含)-0.5%间的次数时间序列
    return w.wsd(security,"mmfrequencyofdeviation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmMaxDeviationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内偏离度的最高值时间序列
    return w.wsd(security,"mmmaxdeviation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmmInDeviationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内偏离度的最低值时间序列
    return w.wsd(security,"mmmindeviation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmAvgDeviationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期内每个工作日偏离度的绝对值的简单平均值时间序列
    return w.wsd(security,"mmavgdeviation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsEValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产估值时间序列
    return w.wsd(security,"fund_reitsevalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsDIsTrAmountFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供分配金额(预测)时间序列
    return w.wsd(security,"fund_reitsdistramountf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsDprFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取派息率(预测)时间序列
    return w.wsd(security,"fund_reitsdprf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeAdminSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合管理人员人数时间序列
    return w.wsd(security,"employee_admin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeAdminPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合管理人员人数占比时间序列
    return w.wsd(security,"employee_admin_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合成本率(产险)时间序列
    return w.wsd(security,"stmnote_insur_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212507Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合偿付能力溢额时间序列
    return w.wsd(security,"qstmnote_insur_212507",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212508Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合偿付能力充足率时间序列
    return w.wsd(security,"qstmnote_insur_212508",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212534Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合流动比率:3个月内时间序列
    return w.wsd(security,"qstmnote_insur_212534",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212535Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合流动比率:1年内时间序列
    return w.wsd(security,"qstmnote_insur_212535",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212536Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合流动比率:1年以上时间序列
    return w.wsd(security,"qstmnote_insur_212536",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212537Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合流动比率:1-3年内时间序列
    return w.wsd(security,"qstmnote_insur_212537",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212538Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合流动比率:3-5年内时间序列
    return w.wsd(security,"qstmnote_insur_212538",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212539Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合流动比率:5年以上时间序列
    return w.wsd(security,"qstmnote_insur_212539",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDComPrIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合收益_GSD时间序列
    return w.wsd(security,"wgsd_compr_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsGeneralProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取综合收益总额时间序列
    return w.wsd(security,"stm07_is_reits_generalprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingMarketAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场综合3年评级时间序列
    return w.wsd(security,"rating_marketavg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDComEqForExChSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他综合性收益_GSD时间序列
    return w.wsd(security,"wgsd_com_eq_for_exch",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCompRehIncBsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他综合收益_BS时间序列
    return w.wsd(security,"other_compreh_inc_bs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCompRehIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他综合收益时间序列
    return w.wsd(security,"other_compreh_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa01004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废水综合利用率时间序列
    return w.wsd(security,"esg_ewa01004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingWindAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind综合评级时间序列
    return w.wsd(security,"rating_windavg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaComPrIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.综合收益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_compr_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTCompRehIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.综合收益总额时间序列
    return w.wsd(security,"qfa_tot_compreh_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212529Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最近一次风险综合评级类别时间序列
    return w.wsd(security,"qstmnote_insur_212529",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCompRehIncParentCompSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属普通股东综合收益_GSD时间序列
    return w.wsd(security,"wgsd_compreh_inc_parent_comp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCompRehIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他综合收益时间序列
    return w.wsd(security,"qfa_other_compreh_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTenantReImExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取租户认缴物业维护综合费_GSD时间序列
    return w.wsd(security,"wgsd_tenant_reim_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTCompRehIncMinSHrhLDrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属于少数股东的综合收益总额时间序列
    return w.wsd(security,"tot_compreh_inc_min_shrhldr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGScoreWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind ESG综合得分时间序列
    return w.wsd(security,"esg_score_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiOverall3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券3年评级(综合评级)时间序列
    return w.wsd(security,"rating_shanghaioverall3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiOverall5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券5年评级(综合评级)时间序列
    return w.wsd(security,"rating_shanghaioverall5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaCompRehIncParentCompSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属普通股东综合收益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_compreh_inc_parent_comp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTCompRehIncParentCompSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属于母公司普通股东综合收益总额时间序列
    return w.wsd(security,"tot_compreh_inc_parent_comp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaTenantReImExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.租户认缴物业维护综合费_GSD时间序列
    return w.wsd(security,"wgsd_qfa_tenant_reim_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTCompRehIncMinSHrhLDrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属于少数股东的综合收益总额时间序列
    return w.wsd(security,"qfa_tot_compreh_inc_min_shrhldr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTCompRehIncParentCompSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属于母公司普通股东综合收益总额时间序列
    return w.wsd(security,"qfa_tot_compreh_inc_parent_comp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinAssetsChgCompRehIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取以公允价值计量且其变动计入其他综合收益的金融资产时间序列
    return w.wsd(security,"fin_assets_chg_compreh_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSocialSecurityAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社会保险费:本期增加时间序列
    return w.wsd(security,"stmnote_socialsecurity_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSocialSecuritySbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社会保险费:期初余额时间序列
    return w.wsd(security,"stmnote_socialsecurity_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSocialSecurityEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社会保险费:期末余额时间序列
    return w.wsd(security,"stmnote_socialsecurity_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSocialSecurityDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社会保险费:本期减少时间序列
    return w.wsd(security,"stmnote_socialsecurity_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGRatingCasViSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社会价值投资联盟ESG评级时间序列
    return w.wsd(security,"esg_rating_casvi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRegisterNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取统一社会信用代码时间序列
    return w.wsd(security,"registernumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGMdc01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司是否有独立的公司社会责任报告时间序列
    return w.wsd(security,"esg_mdc01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingYinHe1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)银河1年评级时间序列
    return w.wsd(security,"rating_yinhe1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingYinHe2YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)银河2年评级时间序列
    return w.wsd(security,"rating_yinhe2y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingZhaoShang3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)招商3年评级时间序列
    return w.wsd(security,"rating_zhaoshang3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingHaiTong3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)海通3年评级时间序列
    return w.wsd(security,"rating_haitong3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)投资风格时间序列
    return w.wsd(security,"fund_investstyle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryGxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)所属国信行业名称时间序列
    return w.wsd(security,"industry_gx",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBondScoreSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)债券评分时间序列
    return w.wsd(security,"bondscore",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuersCoreSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)发行人评分时间序列
    return w.wsd(security,"issuerscore",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbstractSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)公司一句话介绍时间序列
    return w.wsd(security,"abstract",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerTotalGeometricReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)任职基金几何总回报时间序列
    return w.wsd(security,"fund_manager_totalgeometricreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowNetPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)净值价格时间序列
    return w.wsd(security,"fellow_netprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDefaultSourceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)估值来源时间序列
    return w.wsd(security,"defaultsource",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTheOPricePerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)区间理论价时间序列
    return w.wsd(security,"theo_price_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs83Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)基金投资收益时间序列
    return w.wsd(security,"stm_is_83",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQACcmFocusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)累计关注人数_雪球时间序列
    return w.wsd(security,"xq_accmfocus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQACcmCommentsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)累计讨论次数_雪球时间序列
    return w.wsd(security,"xq_accmcomments",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQACcmSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)累计交易分享数_雪球时间序列
    return w.wsd(security,"xq_accmshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQFocusAddedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)一周新增关注_雪球时间序列
    return w.wsd(security,"xq_focusadded",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQCommentsAddedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)一周新增讨论数_雪球时间序列
    return w.wsd(security,"xq_commentsadded",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQSharesAddedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)一周新增交易分享数_雪球时间序列
    return w.wsd(security,"xq_sharesadded",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQWowFocusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)一周关注增长率_雪球时间序列
    return w.wsd(security,"xq_WOW_focus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQWowCommentsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)一周讨论增长率_雪球时间序列
    return w.wsd(security,"xq_WOW_comments",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getXQWowSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)一周交易分享增长率_雪球时间序列
    return w.wsd(security,"xq_WOW_shares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareCategorySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)大股东类型时间序列
    return w.wsd(security,"sharecategory",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsrC12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)所属证监会行业名称时间序列
    return w.wsd(security,"industry_CSRC12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPayOutRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度现金分红比例(沪深)时间序列
    return w.wsd(security,"div_payoutratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareNonTradableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流通股(沪深)时间序列
    return w.wsd(security,"share_nontradable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYieldCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价收益率(中证指数)(旧)时间序列
    return w.wsd(security,"yield_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价净价(中证指数)(旧)时间序列
    return w.wsd(security,"net_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirtyCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价全价(中证指数)(旧)时间序列
    return w.wsd(security,"dirty_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getModiDuraCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价修正久期(中证指数)(旧)时间序列
    return w.wsd(security,"modidura_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCNvXTyCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价凸性(中证指数)(旧)时间序列
    return w.wsd(security,"cnvxty_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNetCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发募集资金净额(旧)时间序列
    return w.wsd(security,"ipo_netcollection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发价格(旧)时间序列
    return w.wsd(security,"ipo_price",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoExpectedCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发预计募集资金(旧)时间序列
    return w.wsd(security,"ipo_expectedcollection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCollectionOldSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东售股金额(旧)时间序列
    return w.wsd(security,"ipo_collection_oldshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoUsFeesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发承销保荐费用(旧)时间序列
    return w.wsd(security,"ipo_usfees",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFeeDiscountOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)是否费率优惠时间序列
    return w.wsd(security,"fund_feediscountornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMinPurchaseDiscountsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)最低申购折扣费率时间序列
    return w.wsd(security,"fund_minpurchasediscounts",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMinaIpDiscountsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)最低定投折扣率时间序列
    return w.wsd(security,"fund_minaipdiscounts",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)兼职人员比例时间序列
    return w.wsd(security,"esg_sem01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPepSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)市盈率百分位时间序列
    return w.wsd(security,"val_pep",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavWinLossRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)基金盈利概率时间序列
    return w.wsd(security,"NAV_winlossratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMaturityDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)基金到期日时间序列
    return w.wsd(security,"fund_maturitydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFoundDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)成立日期时间序列
    return w.wsd(security,"founddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLeadUndRNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)主办券商(持续督导)时间序列
    return w.wsd(security,"ipo_leadundr_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFrMindPDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)公司独立董事(历任)时间序列
    return w.wsd(security,"frmindpdirector",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSecNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券简称时间序列
    return w.wsd(security,"sec_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSecName1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券简称(支持历史)时间序列
    return w.wsd(security,"sec_name1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSecEnglishnameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券英文简称时间序列
    return w.wsd(security,"sec_englishname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市日期时间序列
    return w.wsd(security,"ipo_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBackdoorDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取借壳上市日期时间序列
    return w.wsd(security,"backdoordate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFListedDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF上市日期时间序列
    return w.wsd(security,"fund_etflisteddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsListedDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取REITs上市日期时间序列
    return w.wsd(security,"fund__reitslisteddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoJurisDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下配售部分上市日期时间序列
    return w.wsd(security,"ipo_jurisdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInStIsDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向战略投资者配售部分上市日期时间序列
    return w.wsd(security,"ipo_instisdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowInStListDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向机构投资者增发部分上市日期时间序列
    return w.wsd(security,"fellow_instlistdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExchangeCnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易所中文名称时间序列
    return w.wsd(security,"exchange_cn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExChEngSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易所英文简称时间序列
    return w.wsd(security,"exch_eng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市板时间序列
    return w.wsd(security,"mkt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSecStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券存续状态时间序列
    return w.wsd(security,"sec_status",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAdmonitionDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取戴帽摘帽时间时间序列
    return w.wsd(security,"riskadmonition_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeListDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取摘牌日期时间序列
    return w.wsd(security,"delist_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueCurrencyCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行币种时间序列
    return w.wsd(security,"issuecurrencycode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易币种时间序列
    return w.wsd(security,"curr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValBsHrMarketValue4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取B股市值(含限售股,交易币种)时间序列
    return w.wsd(security,"val_bshrmarketvalue4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValBsHrMarketValue2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取B股市值(不含限售股,交易币种)时间序列
    return w.wsd(security,"val_bshrmarketvalue2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSettlementModeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易结算模式时间序列
    return w.wsd(security,"fund_settlementmode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getParValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股面值时间序列
    return w.wsd(security,"parvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoParSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行时每股面值时间序列
    return w.wsd(security,"ipo_par",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLotSizeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每手股数时间序列
    return w.wsd(security,"lotsize",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTunItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易单位时间序列
    return w.wsd(security,"tunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCountrySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属国家或地区代码时间序列
    return w.wsd(security,"country",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBaseDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基期时间序列
    return w.wsd(security,"basedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBaseValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基点时间序列
    return w.wsd(security,"basevalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcPvbPSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基点价值时间序列
    return w.wsd(security,"calc_pvbp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVoBpCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价基点价值(中债)时间序列
    return w.wsd(security,"vobp_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVoBpShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价基点价值(上清所)时间序列
    return w.wsd(security,"vobp_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalBasePointValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均基点价值时间序列
    return w.wsd(security,"anal_basepointvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBaseValueIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权基点价值时间序列
    return w.wsd(security,"basevalue_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcFloatAddBpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计算浮息债隐含加息基点时间序列
    return w.wsd(security,"calc_floataddbp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNumberOfConstituentsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成份个数时间序列
    return w.wsd(security,"numberofconstituents",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNumberOfConstituents2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成份个数(支持历史)时间序列
    return w.wsd(security,"numberofconstituents2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFirstDayOfConstituentsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最早成份日期时间序列
    return w.wsd(security,"firstdayofconstituents",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMethodologySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权方式时间序列
    return w.wsd(security,"methodology",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepoBriefingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券简介时间序列
    return w.wsd(security,"repo_briefing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLaunchDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发布日期时间序列
    return w.wsd(security,"launchdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券曾用名时间序列
    return w.wsd(security,"prename",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExChCitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市地点时间序列
    return w.wsd(security,"exch_city",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrackedByFundsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪标的基金代码时间序列
    return w.wsd(security,"trackedbyfunds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSuperiorCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上级行业指数代码时间序列
    return w.wsd(security,"superiorcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradeCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券代码时间序列
    return w.wsd(security,"trade_code",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCodeChangeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券代码变更日期时间序列
    return w.wsd(security,"codechangedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnchorBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主证券代码时间序列
    return w.wsd(security,"anchorbond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMajorIndexCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主指数代码时间序列
    return w.wsd(security,"majorindexcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSubIndexCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取副指数代码时间序列
    return w.wsd(security,"subindexcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRelationCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跨市场代码时间序列
    return w.wsd(security,"relationCode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBcLcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司债对应上市公司代码时间序列
    return w.wsd(security,"bclc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中债招标发行代码时间序列
    return w.wsd(security,"tendrst_code",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSzSeDistRibCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取深交所分销代码时间序列
    return w.wsd(security,"szse_distribcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司可转债简称时间序列
    return w.wsd(security,"cbname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsShareNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司美股简称时间序列
    return w.wsd(security,"ussharename",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStockClassSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票种类时间序列
    return w.wsd(security,"stockclass",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIssuingSystemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行制度时间序列
    return w.wsd(security,"ipo_issuingsystem",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListsTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属上市标准时间序列
    return w.wsd(security,"liststd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFeaturedListsTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取北交所准入标准时间序列
    return w.wsd(security,"featuredliststd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCompIndex2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否属于重要指数成份时间序列
    return w.wsd(security,"compindex2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConceptSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属概念板块时间序列
    return w.wsd(security,"concept",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getScaleStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属规模风格类型时间序列
    return w.wsd(security,"scalestyle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShScSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否沪港通买入标的时间序列
    return w.wsd(security,"SHSC",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShSc2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否深港通买入标的时间序列
    return w.wsd(security,"SHSC2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getParallelCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否并行代码时间序列
    return w.wsd(security,"parallelcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSecTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券类型时间序列
    return w.wsd(security,"sec_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBackdoorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否借壳上市时间序列
    return w.wsd(security,"backdoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否上市时间序列
    return w.wsd(security,"list",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListingOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否上市公司时间序列
    return w.wsd(security,"listingornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskWarningSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否属于风险警示板时间序列
    return w.wsd(security,"riskwarning",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOfficialStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数风格时间序列
    return w.wsd(security,"officialstyle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属产业链板块时间序列
    return w.wsd(security,"chain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLargeCommoditySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属大宗商品概念板块时间序列
    return w.wsd(security,"largecommodity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDepositAryBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存托机构时间序列
    return w.wsd(security,"depositarybank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLeadUndRN1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主办券商(持续督导)时间序列
    return w.wsd(security,"ipo_leadundr_n1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoMarketMakerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取做市商名称时间序列
    return w.wsd(security,"ipo_marketMaker",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarketMakeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取做市首日时间序列
    return w.wsd(security,"marketmakedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTransferTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易类型时间序列
    return w.wsd(security,"transfertype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqMarketMakerNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取做市商家数时间序列
    return w.wsd(security,"neeq_marketmakernum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqParkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌园区时间序列
    return w.wsd(security,"neeq_park",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqListAnnDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌公告日时间序列
    return w.wsd(security,"neeq_listanndate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqMarketMakeAnnDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转做市公告日时间序列
    return w.wsd(security,"neeq_marketmakeanndate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNeeQgIcsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属挂牌公司投资型行业名称时间序列
    return w.wsd(security,"industry_neeqgics",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNeeQgIcsCodeInvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属挂牌公司投资型行业代码时间序列
    return w.wsd(security,"industry_neeqgicscode_inv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNeeQgIcsCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属挂牌公司投资型行业板块代码时间序列
    return w.wsd(security,"industry_neeqgicscode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNeEqConceptSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属新三板概念类板块时间序列
    return w.wsd(security,"industry_neeqconcept",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqLevelSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属分层时间序列
    return w.wsd(security,"neeq_level",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqStandardSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属创新层标准时间序列
    return w.wsd(security,"neeq_standard",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTutorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌企业上市辅导券商时间序列
    return w.wsd(security,"ipo_tutor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTutoringStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌企业上市辅导开始日期时间序列
    return w.wsd(security,"ipo_tutoring_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTutoringEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌企业上市辅导结束日期时间序列
    return w.wsd(security,"ipo_tutoring_enddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqListingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌日时间序列
    return w.wsd(security,"neeq_listingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqListDateInnovationLevelSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取创新层挂牌日时间序列
    return w.wsd(security,"neeq_listdate_innovationlevel",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeEqSuspensionDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取挂牌公司转板北交所前停牌日时间序列
    return w.wsd(security,"neeq_suspensionday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCompNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司中文名称时间序列
    return w.wsd(security,"comp_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCompNameEngSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司英文名称时间序列
    return w.wsd(security,"comp_name_eng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNature1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司属性时间序列
    return w.wsd(security,"nature1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNatureSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司属性(旧)时间序列
    return w.wsd(security,"nature",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareholderNatureSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东公司属性时间序列
    return w.wsd(security,"shareholdernature",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyGuarantorNatureSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人公司属性时间序列
    return w.wsd(security,"agency_guarantornature",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInstitutionTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融机构类型时间序列
    return w.wsd(security,"institutiontype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCorpScaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业规模时间序列
    return w.wsd(security,"corpscale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBankTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市公司(银行)类型时间序列
    return w.wsd(security,"banktype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFoundDate1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成立日期时间序列
    return w.wsd(security,"founddate1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpEstablishmentDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人成立日期时间序列
    return w.wsd(security,"fund_corpestablishmentdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRegCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取注册资本时间序列
    return w.wsd(security,"regcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRegCapitalCurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取注册资本币种时间序列
    return w.wsd(security,"regcapitalcur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpRegisteredCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人注册资本时间序列
    return w.wsd(security,"fund_corpregisteredcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChairmanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取法定代表人时间序列
    return w.wsd(security,"chairman",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLegalRepresentativeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取法定代表人(支持历史)时间序列
    return w.wsd(security,"legalrepresentative",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFiscalDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会计年结日时间序列
    return w.wsd(security,"fiscaldate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营范围时间序列
    return w.wsd(security,"business",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBriefingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司简介时间序列
    return w.wsd(security,"briefing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareholderBriefingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东公司简介时间序列
    return w.wsd(security,"shareholderbriefing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyGuarantorBriefingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人公司简介时间序列
    return w.wsd(security,"agency_guarantorbriefing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMajorProductTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营产品类型时间序列
    return w.wsd(security,"majorproducttype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMajorProductNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营产品名称时间序列
    return w.wsd(security,"majorproductname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取员工总数时间序列
    return w.wsd(security,"employee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeePcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取母公司员工人数时间序列
    return w.wsd(security,"employee_pc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdministrativeDivisionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属行政区划时间序列
    return w.wsd(security,"administrativedivision",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属行政区划代码时间序列
    return w.wsd(security,"admincode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCsrCJurisdictionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属证监会辖区时间序列
    return w.wsd(security,"csrcjurisdiction",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProvinceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取省份时间序列
    return w.wsd(security,"province",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取城市时间序列
    return w.wsd(security,"city",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpCitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人注册城市时间序列
    return w.wsd(security,"fund_corpcity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAddressSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取注册地址时间序列
    return w.wsd(security,"address",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpAddressSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人注册地址时间序列
    return w.wsd(security,"fund_corpaddress",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOfficeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取办公地址时间序列
    return w.wsd(security,"office",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpOfficeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人办公地址时间序列
    return w.wsd(security,"fund_corpoffice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getZipCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取邮编时间序列
    return w.wsd(security,"zipcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpZipSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人邮编时间序列
    return w.wsd(security,"fund_corpzip",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPhoneSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司电话时间序列
    return w.wsd(security,"phone",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司传真时间序列
    return w.wsd(security,"fax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司电子邮件地址时间序列
    return w.wsd(security,"email",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWebsiteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司网站时间序列
    return w.wsd(security,"website",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDIsCloserSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信息披露人时间序列
    return w.wsd(security,"discloser",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMediaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信息指定披露媒体时间序列
    return w.wsd(security,"media",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOrganizationCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取组织机构代码时间序列
    return w.wsd(security,"organizationcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReportCurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取记账本位币时间序列
    return w.wsd(security,"report_cur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerShortenedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人中文简称时间序列
    return w.wsd(security,"issuershortened",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMainProductSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主要产品及业务时间序列
    return w.wsd(security,"mainproduct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCompPreNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司曾用名时间序列
    return w.wsd(security,"compprename",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbIssueOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否发行可转债时间序列
    return w.wsd(security,"cbissueornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVoteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否存在投票权差异时间序列
    return w.wsd(security,"vote",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSeiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属战略性新兴产业分类时间序列
    return w.wsd(security,"sei",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getZJtXorNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否专精特新企业时间序列
    return w.wsd(security,"zjtxornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsrC12NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属证监会行业名称时间序列
    return w.wsd(security,"industry_csrc12_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsrCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属证监会行业名称(旧)时间序列
    return w.wsd(security,"industry_CSRC",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsrCCode12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属证监会行业代码时间序列
    return w.wsd(security,"industry_CSRCcode12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsrCCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属证监会行业代码(旧)时间序列
    return w.wsd(security,"industry_CSRCcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业名称时间序列
    return w.wsd(security,"industry_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySw2021Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业名称(2021)时间序列
    return w.wsd(security,"industry_sw_2021",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业名称(港股)时间序列
    return w.wsd(security,"industry_sw_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySw2021HkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业名称(港股)(2021)时间序列
    return w.wsd(security,"industry_sw_2021_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业代码时间序列
    return w.wsd(security,"industry_swcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwCode2021Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业代码(2021)时间序列
    return w.wsd(security,"industry_swcode_2021",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwCodeHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业代码(港股)时间序列
    return w.wsd(security,"industry_swcode_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwCode2021HkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业代码(港股)(2021)时间序列
    return w.wsd(security,"industry_swcode_2021_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwOriginCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业原始代码时间序列
    return w.wsd(security,"industry_sworigincode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustrySwOriginCode2021Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业原始代码(2021)时间序列
    return w.wsd(security,"industry_sworigincode_2021",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万行业指数代码时间序列
    return w.wsd(security,"indexcode_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信行业名称时间序列
    return w.wsd(security,"industry_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCitiCHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信行业名称(港股)时间序列
    return w.wsd(security,"industry_citic_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCitiCCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信行业代码时间序列
    return w.wsd(security,"industry_citiccode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCitiCCodeHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信行业代码(港股)时间序列
    return w.wsd(security,"industry_citiccode_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信行业指数代码时间序列
    return w.wsd(security,"indexcode_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeCitiCHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信证券港股通指数代码(港股)时间序列
    return w.wsd(security,"indexcode_citic_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexNameCitiCHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中信证券港股通指数名称(港股)时间序列
    return w.wsd(security,"indexname_citic_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerIndustryCcXiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中诚信行业名称时间序列
    return w.wsd(security,"issuer_industry_ccxi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryGicS2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废弃行业时间序列
    return w.wsd(security,"industry_gics2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryHsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属恒生行业名称时间序列
    return w.wsd(security,"industry_HS",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustry2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属行业名称(支持历史)时间序列
    return w.wsd(security,"industry2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属行业代码(支持历史)时间序列
    return w.wsd(security,"industrycode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属行业板块名称(支持历史)时间序列
    return w.wsd(security,"industryname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中证行业名称时间序列
    return w.wsd(security,"industry_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCsiCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属中证行业代码时间序列
    return w.wsd(security,"industry_csicode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryNcCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属国民经济行业代码时间序列
    return w.wsd(security,"industry_nccode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCJscSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属长江行业名称时间序列
    return w.wsd(security,"industry_cjsc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeCJscSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属长江行业指数代码时间序列
    return w.wsd(security,"indexcode_cjsc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属国证行业名称时间序列
    return w.wsd(security,"industry_cn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryCnCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属国证行业代码时间序列
    return w.wsd(security,"industry_cncode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeCnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属国证行业指数代码时间序列
    return w.wsd(security,"indexcode_cn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getThematicIndustrySibSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属科创板主题行业时间序列
    return w.wsd(security,"thematicindustry_sib",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBoardChairmenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事长时间序列
    return w.wsd(security,"boardchairmen",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenBcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事长薪酬时间序列
    return w.wsd(security,"stmnote_mgmt_ben_bc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCeoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总经理时间序列
    return w.wsd(security,"ceo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenCeoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总经理薪酬时间序列
    return w.wsd(security,"stmnote_mgmt_ben_ceo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpManagerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人总经理时间序列
    return w.wsd(security,"fund_corpmanager",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDIsCloser1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会秘书时间序列
    return w.wsd(security,"discloser1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenDIsCloserSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会秘书薪酬时间序列
    return w.wsd(security,"stmnote_mgmt_ben_discloser",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSar1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券事务代表时间序列
    return w.wsd(security,"sar1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenSarSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券事务代表薪酬时间序列
    return w.wsd(security,"stmnote_mgmt_ben_sar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCfOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务总监时间序列
    return w.wsd(security,"cfo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenCfOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务总监薪酬时间序列
    return w.wsd(security,"stmnote_mgmt_ben_cfo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCrtInDpDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司独立董事(现任)时间序列
    return w.wsd(security,"crtindpdirector",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSUciNdpDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司独立董事(历任)时间序列
    return w.wsd(security,"sucindpdirector",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司董事时间序列
    return w.wsd(security,"director",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSUcDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司董事(历任)时间序列
    return w.wsd(security,"sucdirector",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSupervisorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司监事时间序列
    return w.wsd(security,"supervisor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSUcSupervisorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司监事(历任)时间序列
    return w.wsd(security,"sucsupervisor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExecutivesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司高管时间序列
    return w.wsd(security,"executives",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSUcExecutivesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公司高管(历任)时间序列
    return w.wsd(security,"sucexecutives",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenTop3BSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金额前三的董事薪酬合计时间序列
    return w.wsd(security,"stmnote_mgmt_ben_top3b",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMGmtBenTop3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金额前三的高管薪酬合计时间序列
    return w.wsd(security,"stmnote_mgmt_ben_top3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeBoardSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会人数时间序列
    return w.wsd(security,"employee_board",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeExecutiveDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非独立董事人数时间序列
    return w.wsd(security,"employee_executivedirector",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeInDpDirectorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取独立董事人数时间序列
    return w.wsd(security,"employee_indpdirector",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeMGmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取高管人数时间序列
    return w.wsd(security,"employee_mgmt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeTechCoreSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心技术人员人数时间序列
    return w.wsd(security,"employee_techcore",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAuditorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计机构时间序列
    return w.wsd(security,"auditor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAuditor2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计机构(支持历史)时间序列
    return w.wsd(security,"auditor2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAuditorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发审计机构时间序列
    return w.wsd(security,"ipo_auditor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCloSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取法律顾问时间序列
    return w.wsd(security,"clo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经办律师时间序列
    return w.wsd(security,"lic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLawErSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发经办律师时间序列
    return w.wsd(security,"ipo_lawer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItSvaAgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产评估机构时间序列
    return w.wsd(security,"fund__reitsvaag",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经办评估人员时间序列
    return w.wsd(security,"vic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBanksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主要往来银行时间序列
    return w.wsd(security,"banks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeProducerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产人员人数时间序列
    return w.wsd(security,"employee_producer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeProducerPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产人员人数占比时间序列
    return w.wsd(security,"employee_producer_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeSaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售人员人数时间序列
    return w.wsd(security,"employee_sale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeSalePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售人员人数占比时间序列
    return w.wsd(security,"employee_sale_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeServerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客服人员人数时间序列
    return w.wsd(security,"employee_server",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeServerPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客服人员人数占比时间序列
    return w.wsd(security,"employee_server_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeTechSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取技术人员人数时间序列
    return w.wsd(security,"employee_tech",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeTechPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取技术人员人数占比时间序列
    return w.wsd(security,"employee_tech_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeFinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务人员人数时间序列
    return w.wsd(security,"employee_fin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeFinPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务人员人数占比时间序列
    return w.wsd(security,"employee_fin_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeHrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取人事人员人数时间序列
    return w.wsd(security,"employee_hr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeHrPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取人事人员人数占比时间序列
    return w.wsd(security,"employee_hr_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeExCuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行政人员人数时间序列
    return w.wsd(security,"employee_excu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeExCuPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行政人员人数占比时间序列
    return w.wsd(security,"employee_excu_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeRcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取风控稽核人员人数时间序列
    return w.wsd(security,"employee_rc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeRcPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取风控稽核人员人数占比时间序列
    return w.wsd(security,"employee_rc_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeePurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取采购仓储人员人数时间序列
    return w.wsd(security,"employee_pur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeePurPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取采购仓储人员人数占比时间序列
    return w.wsd(security,"employee_pur_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeOThDeptSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他人员人数时间序列
    return w.wsd(security,"employee_othdept",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeePhdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取博士人数时间序列
    return w.wsd(security,"employee_PHD",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeePhdPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取博士人数占比时间序列
    return w.wsd(security,"employee_PHD_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeMsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取硕士人数时间序列
    return w.wsd(security,"employee_MS",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeMsPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取硕士人数占比时间序列
    return w.wsd(security,"employee_MS_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeBaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本科人数时间序列
    return w.wsd(security,"employee_BA",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeBaPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本科人数占比时间序列
    return w.wsd(security,"employee_BA_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeCollSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取专科人数时间序列
    return w.wsd(security,"employee_coll",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeCollPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取专科人数占比时间序列
    return w.wsd(security,"employee_coll_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeHighschoolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取高中及以下人数时间序列
    return w.wsd(security,"employee_highschool",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeHighschoolPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取高中及以下人数占比时间序列
    return w.wsd(security,"employee_highschool_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeOThDegreeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他学历人数时间序列
    return w.wsd(security,"employee_othdegree",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeOThDegreePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他学历人数占比时间序列
    return w.wsd(security,"employee_othdegree_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmployeeOThDeptPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他专业人员人数占比时间序列
    return w.wsd(security,"employee_othdept_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTotalSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总股本时间序列
    return w.wsd(security,"total_shares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaTotalSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取备考总股本(并购后)时间序列
    return w.wsd(security,"matotalshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareToTSharesPreSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市前总股本时间序列
    return w.wsd(security,"share_totshares_pre",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoToTCapAfterIssueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发后总股本(上市日)时间序列
    return w.wsd(security,"ipo_totcapafterissue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoToTCapBeforeIssueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发前总股本时间序列
    return w.wsd(security,"ipo_totcapbeforeissue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoToTCapAfterIssueEstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计发行后总股本时间序列
    return w.wsd(security,"ipo_totcapafterissue_est",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctLiqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股东持股比例(相对总股本)时间序列
    return w.wsd(security,"holder_pct_liq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFreeFloatSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自由流通股本时间序列
    return w.wsd(security,"free_float_shares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTotalOtcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取三板合计时间序列
    return w.wsd(security,"share_totalotc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareHSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取香港上市股时间序列
    return w.wsd(security,"share_h",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOverSeaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取海外上市股时间序列
    return w.wsd(security,"share_oversea",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTotalTradableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股合计时间序列
    return w.wsd(security,"share_totaltradable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTotalRestrictedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股合计时间序列
    return w.wsd(security,"share_totalrestricted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareNonTradable2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流通股时间序列
    return w.wsd(security,"share_nontradable2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfInvestorNonTrAdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原非流通股股东有效申购户数时间序列
    return w.wsd(security,"cb_result_efinvestornontrad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfAmNtNonTrAdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原非流通股股东有效申购金额时间序列
    return w.wsd(security,"cb_result_efamntnontrad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultRationAmtNonTrAdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原非流通股股东获配金额时间序列
    return w.wsd(security,"cb_result_rationamtnontrad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareNtrDPrFShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取优先股时间序列
    return w.wsd(security,"share_ntrd_prfshare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPfDStKSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取优先股_GSD时间序列
    return w.wsd(security,"wgsd_pfd_stk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDvdPfDAdjSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取优先股利及其他调整项_GSD时间序列
    return w.wsd(security,"wgsd_dvd_pfd_adj",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDvdPfDAdjSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.优先股利及其他调整项_GSD时间序列
    return w.wsd(security,"wgsd_qfa_dvd_pfd_adj",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherEquityInstrumentsPreSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他权益工具:优先股时间序列
    return w.wsd(security,"other_equity_instruments_PRE",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareIssuingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已发行数量时间序列
    return w.wsd(security,"share_issuing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareIssuingMktSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股本时间序列
    return w.wsd(security,"share_issuing_mkt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdStateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(国家持股)时间序列
    return w.wsd(security,"share_rtd_state",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdStateJurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(国有法人持股)时间序列
    return w.wsd(security,"share_rtd_statejur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdSubOtherDomesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(其他内资持股合计)时间序列
    return w.wsd(security,"share_rtd_subotherdomes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdDomesJurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(境内法人持股)时间序列
    return w.wsd(security,"share_rtd_domesjur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(机构配售股份)时间序列
    return w.wsd(security,"share_rtd_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdDomeSnpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(境内自然人持股)时间序列
    return w.wsd(security,"share_rtd_domesnp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdSubFrgNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(外资持股合计)时间序列
    return w.wsd(security,"share_rtd_subfrgn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdFrgNJurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(境外法人持股)时间序列
    return w.wsd(security,"share_rtd_frgnjur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdFrgNNpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(境外自然人持股)时间序列
    return w.wsd(security,"share_rtd_frgnnp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedAPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押比例时间序列
    return w.wsd(security,"share_pledgeda_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareLiqAPledgedPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无限售股份质押比例时间序列
    return w.wsd(security,"share_liqa_pledgedpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRestrictedAPledgedPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有限售股份质押比例时间序列
    return w.wsd(security,"share_restricteda_pledgedpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareLiqAPledgedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无限售股份质押数量时间序列
    return w.wsd(security,"share_liqa_pledged",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRestrictedAPledgedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有限售股份质押数量时间序列
    return w.wsd(security,"share_restricteda_pledged",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedRepurchaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押待购回余量时间序列
    return w.wsd(security,"share_pledged_repurchase",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdUnlockingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售解禁日期时间序列
    return w.wsd(security,"share_rtd_unlockingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTradableCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期解禁数量时间序列
    return w.wsd(security,"share_tradable_current",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdBAnceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未流通数量时间序列
    return w.wsd(security,"share_rtd_bance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdDataTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取解禁数据类型时间序列
    return w.wsd(security,"share_rtd_datatype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdDataTypeFwdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日之后最近一次解禁数据类型时间序列
    return w.wsd(security,"share_rtd_datatype_fwd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTradableShareTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取解禁股份性质时间序列
    return w.wsd(security,"share_tradable_sharetype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTradableShareTypeFwdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日之后最近一次解禁股份性质时间序列
    return w.wsd(security,"share_tradable_sharetype_fwd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRTdUnlockingDateFwdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日之后最近一次解禁日期时间序列
    return w.wsd(security,"share_rtd_unlockingdate_fwd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareTradableCurrentFwdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日之后最近一次解禁数量时间序列
    return w.wsd(security,"share_tradable_current_fwd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcTradableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通三板股时间序列
    return w.wsd(security,"share_otctradable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcTradableControllerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股(控股股东或实际控制人)时间序列
    return w.wsd(security,"share_otctradable_controller",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcTradableBackboneSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股(核心员工)时间序列
    return w.wsd(security,"share_otctradable_backbone",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcTradableOthersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股(其他)时间序列
    return w.wsd(security,"share_otctradable_others",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcRestrictedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售三板股时间序列
    return w.wsd(security,"share_otcrestricted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcRestrictedControllerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(控股股东或实际控制人)时间序列
    return w.wsd(security,"share_otcrestricted_controller",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareRestrictedMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(高管持股)时间序列
    return w.wsd(security,"share_restricted_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcRestrictedBackboneSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(核心员工)时间序列
    return w.wsd(security,"share_otcrestricted_backbone",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareOtcRestrictedOthersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售股份(其他)时间序列
    return w.wsd(security,"share_otcrestricted_others",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitMergedSharesOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取份额是否为合并数据时间序列
    return w.wsd(security,"unit_mergedsharesornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderMergedHoldingOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有份额是否为合并数据时间序列
    return w.wsd(security,"holder_mergedholdingornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitFloorTradingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取场内流通份额时间序列
    return w.wsd(security,"unit_floortrading",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitFloorTradingChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期场内流通份额变化时间序列
    return w.wsd(security,"unit_floortradingchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitPurchaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期总申购份额时间序列
    return w.wsd(security,"unit_purchase",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitRedemptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期总赎回份额时间序列
    return w.wsd(security,"unit_redemption",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitNetPurchaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期申购赎回净额时间序列
    return w.wsd(security,"unit_netpurchase",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitPurchaseQTySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度总申购份额时间序列
    return w.wsd(security,"unit_purchase_qty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitRedemptionQTySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度总赎回份额时间序列
    return w.wsd(security,"unit_redemption_qty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitNetQuarterlyRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度净申购赎回率时间序列
    return w.wsd(security,"unit_netquarterlyratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnitNetPurchaseQTySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度申购赎回净额时间序列
    return w.wsd(security,"unit_netpurchase_qty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTop10PctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大股东持股比例合计时间序列
    return w.wsd(security,"holder_top10pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTop10QuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大股东持股数量合计时间序列
    return w.wsd(security,"holder_top10quantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTop10LiqQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大流通股东持股数量合计时间序列
    return w.wsd(security,"holder_top10liqquantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedAHolderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东累计质押数量时间序列
    return w.wsd(security,"share_pledgeda_holder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedALargestHolderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东累计质押数量(旧)时间序列
    return w.wsd(security,"share_pledgeda_largestholder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedAPctHolderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东累计质押数占持股数比例时间序列
    return w.wsd(security,"share_pledgeda_pct_holder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePledgedAPctLargestHolderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东累计质押数占持股数比例(旧)时间序列
    return w.wsd(security,"share_pledgeda_pct_largestholder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareFrozenAHolderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东累计冻结数量时间序列
    return w.wsd(security,"share_frozena_holder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareFrozenAPctHolderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东累计冻结数占持股数比例时间序列
    return w.wsd(security,"share_frozena_pct_holder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderRpTControllerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公布实际控制人名称时间序列
    return w.wsd(security,"holder_rptController",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderControllerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际控制人名称时间序列
    return w.wsd(security,"holder_controller",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderControllerAtTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际控制人属性时间序列
    return w.wsd(security,"holder_controllerattr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderInstituteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构股东名称时间序列
    return w.wsd(security,"holder_institute",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东名称时间序列
    return w.wsd(security,"holder_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东持股数量时间序列
    return w.wsd(security,"holder_quantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东持股比例时间序列
    return w.wsd(security,"holder_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSumPctTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取前5大股东持股比例之和_PIT时间序列
    return w.wsd(security,"holder_sumpcttop5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSumsQuPctTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取前5大股东持股比例平方之和_PIT时间序列
    return w.wsd(security,"holder_sumsqupcttop5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSumsQuPctTop10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取前10大股东持股比例平方之和_PIT时间序列
    return w.wsd(security,"holder_sumsqupcttop10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderShareCategorySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东持股股本性质时间序列
    return w.wsd(security,"holder_sharecategory",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderQuantityRestrictedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东持有的限售股份数时间序列
    return w.wsd(security,"holder_quantity_restricted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNatureSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东性质时间序列
    return w.wsd(security,"holder_nature",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderCategorySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构股东类型时间序列
    return w.wsd(security,"holder_category",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderLiqNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股东名称时间序列
    return w.wsd(security,"holder_liqname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderLiqQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股东持股数量时间序列
    return w.wsd(security,"holder_liqquantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderLiqPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股东持股比例时间序列
    return w.wsd(security,"holder_liqpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderLiqShareCategorySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流通股东持股股本性质时间序列
    return w.wsd(security,"holder_liqsharecategory",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderAvgNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取户均持股数量时间序列
    return w.wsd(security,"holder_avgnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderAvgPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取户均持股比例时间序列
    return w.wsd(security,"holder_avgpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderHAvgPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取户均持股比例半年增长率时间序列
    return w.wsd(security,"holder_havgpctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderQAvgPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取户均持股比例季度增长率时间序列
    return w.wsd(security,"holder_qavgpctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderAvgPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对上一报告期户均持股比例差时间序列
    return w.wsd(security,"holder_avgpctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderHAvgChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取户均持股数半年增长率时间序列
    return w.wsd(security,"holder_havgchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderQAvgChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取户均持股数季度增长率时间序列
    return w.wsd(security,"holder_qavgchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金持股数量时间序列
    return w.wsd(security,"holder_totalbyfund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalBySSFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社保基金持股数量时间序列
    return w.wsd(security,"holder_totalbyssfund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByBySecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取券商持股数量时间序列
    return w.wsd(security,"holder_totalbybysec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByByWMpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取券商理财产品持股数量时间序列
    return w.wsd(security,"holder_totalbybywmp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByHfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取阳光私募持股数量时间序列
    return w.wsd(security,"holder_totalbyhf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByInSurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险公司持股数量时间序列
    return w.wsd(security,"holder_totalbyinsur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByCorpPensionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业年金持股数量时间序列
    return w.wsd(security,"holder_totalbycorppension",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByTrustCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信托公司持股数量时间序列
    return w.wsd(security,"holder_totalbytrustcorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByFinanceCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务公司持股数量时间序列
    return w.wsd(security,"holder_totalbyfinancecorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行持股数量时间序列
    return w.wsd(security,"holder_totalbybank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByGeneralCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一般法人持股数量时间序列
    return w.wsd(security,"holder_totalbygeneralcorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderTotalByLnFCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非金融类上市公司持股数量时间序列
    return w.wsd(security,"holder_totalbylnfcorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金持股比例时间序列
    return w.wsd(security,"holder_pctbyfund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctBySSFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取社保基金持股比例时间序列
    return w.wsd(security,"holder_pctbyssfund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctBySecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取券商持股比例时间序列
    return w.wsd(security,"holder_pctbysec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByByWMpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取券商理财产品持股比例时间序列
    return w.wsd(security,"holder_pctbybywmp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByHfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取阳光私募持股比例时间序列
    return w.wsd(security,"holder_pctbyhf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByInSurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险公司持股比例时间序列
    return w.wsd(security,"holder_pctbyinsur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByCorpPensionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业年金持股比例时间序列
    return w.wsd(security,"holder_pctbycorppension",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByTrustCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信托公司持股比例时间序列
    return w.wsd(security,"holder_pctbytrustcorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByFinanceCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务公司持股比例时间序列
    return w.wsd(security,"holder_pctbyfinancecorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行持股比例时间序列
    return w.wsd(security,"holder_pctbybank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByGeneralCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一般法人持股比例时间序列
    return w.wsd(security,"holder_pctbygeneralcorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPctByLnFCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非金融类上市公司持股比例时间序列
    return w.wsd(security,"holder_pctbylnfcorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNumISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股机构数时间序列
    return w.wsd(security,"holder_num_i",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNumFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股基金数时间序列
    return w.wsd(security,"holder_num_fund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNumSSFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股社保基金数时间序列
    return w.wsd(security,"holder_num_ssfund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderNumInSurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股保险公司数时间序列
    return w.wsd(security,"holder_num_insur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPriceFellowOnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定向增发价格时间序列
    return w.wsd(security,"holder_price_fellowon",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPriceMajorShareholdersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取大股东增持价格时间序列
    return w.wsd(security,"holder_price_Majorshareholders",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPriceEsOpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取员工持股计划买入价格时间序列
    return w.wsd(security,"holder_price_ESOP",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderMergedNumberOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有人户数是否为合并数据时间序列
    return w.wsd(security,"holder_mergednumberornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderInstitutionHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资者持有份额时间序列
    return w.wsd(security,"holder_institution_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderInstitutionTotalHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资者持有份额(合计)时间序列
    return w.wsd(security,"holder_institution_totalholding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderInstitutionHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资者持有比例时间序列
    return w.wsd(security,"holder_institution_holdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderInstitutionTotalHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构投资者持有比例(合计)时间序列
    return w.wsd(security,"holder_institution_totalholdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderMNgEmpHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理人员工持有份额时间序列
    return w.wsd(security,"holder_mngemp_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderMNgEmpHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理人员工持有比例时间序列
    return w.wsd(security,"holder_mngemp_holdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderCorpHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理公司持有份额时间序列
    return w.wsd(security,"holder_corp_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderCorpHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理公司持有比例时间序列
    return w.wsd(security,"holder_corp_holdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPersonalHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者持有份额时间序列
    return w.wsd(security,"holder_personal_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPersonalTotalHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者持有份额(合计)时间序列
    return w.wsd(security,"holder_personal_totalholding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPersonalHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者持有比例时间序列
    return w.wsd(security,"holder_personal_holdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderPersonalTotalHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人投资者持有比例(合计)时间序列
    return w.wsd(security,"holder_personal_totalholdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderTop10HoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大持有人持有份额合计时间序列
    return w.wsd(security,"fund_holder_top10_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderTop10HoldingMmFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大持有人持有份额合计(货币)时间序列
    return w.wsd(security,"fund_holder_top10_holdingmmf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderTop10PctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大持有人持有比例合计时间序列
    return w.wsd(security,"fund_holder_top10_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderTop10PctMmFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前十大持有人持有比例合计(货币)时间序列
    return w.wsd(security,"fund_holder_top10_pctmmf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSingleHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单一投资者报告期末持有份额时间序列
    return w.wsd(security,"holder_single_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSingleTotalHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单一投资者报告期末持有份额合计时间序列
    return w.wsd(security,"holder_single_totalholding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSingleHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单一投资者报告期末持有比例时间序列
    return w.wsd(security,"holder_single_holdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHolderSingleTotalHoldingPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单一投资者报告期末持有比例合计时间序列
    return w.wsd(security,"holder_single_totalholdingpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBondQualifiedInvestorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合格投资者类型时间序列
    return w.wsd(security,"bond_qualified_investor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHoldFundsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有基金家数时间序列
    return w.wsd(security,"fundhold_funds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHoldRatioOfPositionToAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金持有数量合计占存量比时间序列
    return w.wsd(security,"fundhold_ratioofpositiontoamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHoldPositionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金持有数量合计时间序列
    return w.wsd(security,"fundhold_position",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBondHolderNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有人名称时间序列
    return w.wsd(security,"bondholder_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人名称时间序列
    return w.wsd(security,"fund_holder_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderNameListingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人名称(上市公告)时间序列
    return w.wsd(security,"fund_holder_namelisting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBondHolderPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有人持有比例时间序列
    return w.wsd(security,"bondholder_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人持有比例时间序列
    return w.wsd(security,"fund_holder_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderPctListingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人持有比例(上市公告)时间序列
    return w.wsd(security,"fund_holder_pctlisting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderPctMmFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人持有比例(货币)时间序列
    return w.wsd(security,"fund_holder_pctmmf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBondHolderQuantitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有人持有数量时间序列
    return w.wsd(security,"bondholder_quantity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHoldBondNamesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有基金名称时间序列
    return w.wsd(security,"fundholdbond_names",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHoldBondValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金持债市值时间序列
    return w.wsd(security,"fundholdbond_value",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHoldBondRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金持债市值占发行量比时间序列
    return w.wsd(security,"fundholdbond_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪(深)股通持股数量时间序列
    return w.wsd(security,"share_N",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareHkSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取港股通持股数量时间序列
    return w.wsd(security,"share_HKS",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareHkShSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪市港股通持股数量时间序列
    return w.wsd(security,"share_HKSH",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getShareHkSzSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取深市港股通持股数量时间序列
    return w.wsd(security,"share_HKSZ",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪(深)股通持股占比时间序列
    return w.wsd(security,"share_pct_N",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctNToFreeFloatSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪(深)股通持股占自由流通股比例时间序列
    return w.wsd(security,"share_pct_Ntofreefloat",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctHkSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取港股通持股占比时间序列
    return w.wsd(security,"share_pct_HKS",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctHkShSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取沪市港股通持股占比时间序列
    return w.wsd(security,"share_pct_HKSH",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharePctHkSzSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取深市港股通持股占比时间序列
    return w.wsd(security,"share_pct_HKSZ",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFullNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券全称时间序列
    return w.wsd(security,"fullname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerUpdatedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债务主体时间序列
    return w.wsd(security,"issuerupdated",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerActualSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际发行人时间序列
    return w.wsd(security,"issuer_actual",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getParSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券初始面值时间序列
    return w.wsd(security,"par",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestParSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券最新面值时间序列
    return w.wsd(security,"latestpar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行总额时间序列
    return w.wsd(security,"issueamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrancheSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取各级发行总额时间序列
    return w.wsd(security,"tranche",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbIssueAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转债发行总额时间序列
    return w.wsd(security,"cb_issueamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueAmountPlanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计划发行总额时间序列
    return w.wsd(security,"issue_amountplan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderAmountPlanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计划发行总额(文字)时间序列
    return w.wsd(security,"tender_amountplan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstAmountActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际发行总额时间序列
    return w.wsd(security,"tendrst_amountact",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrancheRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取各级占比时间序列
    return w.wsd(security,"trancheratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOutstandingBalanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券余额时间序列
    return w.wsd(security,"outstandingbalance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaTotalAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存量债券余额时间序列
    return w.wsd(security,"fina_totalamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinalTotalAmOutAnytimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存量债券余额(支持历史)时间序列
    return w.wsd(security,"final_totalamout_anytime",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaMatSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存量债券余额(按期限)时间序列
    return w.wsd(security,"fina_mat",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBondBalanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国债余额(做市后)时间序列
    return w.wsd(security,"tbondbalance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCarryDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取起息日期时间序列
    return w.wsd(security,"carrydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCarryEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计息截止日时间序列
    return w.wsd(security,"carryenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaturityDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取到期日期时间序列
    return w.wsd(security,"maturitydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTermSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券期限(年)时间序列
    return w.wsd(security,"term",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTerm2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券期限(文字)时间序列
    return w.wsd(security,"term2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利率类型时间序列
    return w.wsd(security,"interesttype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取票面利率(发行时)时间序列
    return w.wsd(security,"couponrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponTxtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利率说明时间序列
    return w.wsd(security,"coupontxt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseInterest6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取补偿利率说明时间序列
    return w.wsd(security,"clause_interest_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPaymentTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计息方式时间序列
    return w.wsd(security,"paymenttype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getActualBenchmarkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计息基准时间序列
    return w.wsd(security,"actualbenchmark",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息票品种时间序列
    return w.wsd(security,"coupon",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFormSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取凭证类别时间序列
    return w.wsd(security,"form",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestFrequencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每年付息次数时间序列
    return w.wsd(security,"interestfrequency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPaymentDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年付息日时间序列
    return w.wsd(security,"paymentdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponDateTxtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取付息日说明时间序列
    return w.wsd(security,"coupondatetxt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxFreeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否免税时间序列
    return w.wsd(security,"taxfree",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税率时间序列
    return w.wsd(security,"taxrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMktPriceTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市价类型时间序列
    return w.wsd(security,"mktpricetype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRedemptionBeginningSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取兑付日时间序列
    return w.wsd(security,"redemption_beginning",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRedemptionRegBeginningSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取兑付登记日时间序列
    return w.wsd(security,"redemption_regbeginning",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRedemptionFeeRationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取兑付费率时间序列
    return w.wsd(security,"redemption_feeration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepaymentMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取偿还方式时间序列
    return w.wsd(security,"repaymentmethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPaymentOrderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取偿付顺序时间序列
    return w.wsd(security,"paymentorder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIsAssetOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产是否出表时间序列
    return w.wsd(security,"isassetout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsSPvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计划管理人时间序列
    return w.wsd(security,"abs_spv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOriginalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原始权益人时间序列
    return w.wsd(security,"fund__reitsoriginal",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOrComSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原始权益人企业性质时间序列
    return w.wsd(security,"fund__reitsorcom",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsPenetrateActRuAlDebtorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取穿透信用主体时间序列
    return w.wsd(security,"abs_penetrateactrualdebtor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerBankTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人(银行)类型时间序列
    return w.wsd(security,"issuer_banktype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepoLastEstDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新交易日期时间序列
    return w.wsd(security,"repo_lastestdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCurrentLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前贷款笔数时间序列
    return w.wsd(security,"abs_currentloan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCurrentLoansSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前贷款余额时间序列
    return w.wsd(security,"abs_currentloans",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCurrentWarmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前加权平均贷款剩余期限时间序列
    return w.wsd(security,"abs_currentwarm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCurrentWtGAvgRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前加权平均贷款利率时间序列
    return w.wsd(security,"abs_currentwtgavgrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCumulativeDefaultRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计违约率时间序列
    return w.wsd(security,"abs_cumulativedefaultrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsDelinquencyRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取严重拖欠率时间序列
    return w.wsd(security,"abs_delinquencyrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCreditNormalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承销团成员时间序列
    return w.wsd(security,"abs_creditnormal",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsIndustrySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体行业时间序列
    return w.wsd(security,"abs_industry",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsIndustry1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体性质时间序列
    return w.wsd(security,"abs_industry1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsProvinceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体地区时间序列
    return w.wsd(security,"abs_province",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsAgencyTrustee1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托机构时间序列
    return w.wsd(security,"abs_agency_trustee1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsFullNameProSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目名称时间序列
    return w.wsd(security,"abs_fullnamepro",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsNameProSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目简称时间序列
    return w.wsd(security,"abs_namepro",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsProjectCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目代码时间序列
    return w.wsd(security,"abs_projectcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsPayBackSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取还本方式时间序列
    return w.wsd(security,"abs_payback",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrepayMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提前还本方式时间序列
    return w.wsd(security,"prepaymethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsBorrowerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基础债务人时间序列
    return w.wsd(security,"abs_borrower",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCoreIndustrySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基础债务人行业时间序列
    return w.wsd(security,"abs_coreindustry",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCoreProvinceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基础债务人地区时间序列
    return w.wsd(security,"abs_coreprovince",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCorePropertySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基础债务人性质时间序列
    return w.wsd(security,"abs_coreproperty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsRecommendCprSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取早偿率时间序列
    return w.wsd(security,"abs_recommendcpr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsWeightedAverageMaturityWithPrepaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均期限时间序列
    return w.wsd(security,"abs_weightedaveragematuritywithprepay",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCreditSupportSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用支持时间序列
    return w.wsd(security,"abs_creditsupport",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsDealOutStStandingAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目余额时间序列
    return w.wsd(security,"abs_dealoutststandingamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsFiExdCapitalCostRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资金成本时间序列
    return w.wsd(security,"abs_fiexdcapitalcostrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCapYieldPerTermOfSubSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取次级每期收益率上限时间序列
    return w.wsd(security,"abs_capyieldpertermofSUB",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsSelfSustainingProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自持比例时间序列
    return w.wsd(security,"abs_selfsustainingproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsLegalMaturitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取法定到期日时间序列
    return w.wsd(security,"abs_legalmaturity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsPaymentDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付日时间序列
    return w.wsd(security,"abs_paymentdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsFirstPaymentDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首次支付日时间序列
    return w.wsd(security,"abs_firstpaymentdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsExpectedMaturityWithPrepaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取早偿预期到期日时间序列
    return w.wsd(security,"abs_expectedmaturitywithprepay",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsCutoffDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初始起算日时间序列
    return w.wsd(security,"abs_cutoffdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsStartDateOfAssetClearingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取清算起始日时间序列
    return w.wsd(security,"abs_startdateofassetclearing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsEnddateOfAssetClearingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取清算结束日时间序列
    return w.wsd(security,"abs_enddateofassetclearing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsDefIGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取差额支付承诺人时间序列
    return w.wsd(security,"abs_defiguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsTrusteeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取专项计划托管人时间序列
    return w.wsd(security,"abs_trustee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsAssetServiceAgencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产服务机构时间序列
    return w.wsd(security,"abs_assetserviceagency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccountTreatmentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会计处理时间序列
    return w.wsd(security,"accounttreatment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChinaBondL1TypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中债债券一级分类时间序列
    return w.wsd(security,"chinabondl1type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getChinaBondL2TypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中债债券二级分类时间序列
    return w.wsd(security,"chinabondl2type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMunicipalBondWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否城投债(Wind)时间序列
    return w.wsd(security,"municipalbondWind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMunicipalBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否城投债时间序列
    return w.wsd(security,"municipalbond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMunicipalBondyYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否城投债(YY)时间序列
    return w.wsd(security,"municipalbondYY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCityInvestmentBondGeoWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取城投行政级别(Wind)时间序列
    return w.wsd(security,"cityinvestmentbondgeoWind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCityInvestmentBondGeoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取城投行政级别时间序列
    return w.wsd(security,"cityinvestmentbondgeo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMultiMktOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否跨市场交易时间序列
    return w.wsd(security,"multimktornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSubordinateOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否次级债时间序列
    return w.wsd(security,"subordinateornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMixCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否混合资本债券时间序列
    return w.wsd(security,"mixcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueAdditionalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否增发时间序列
    return w.wsd(security,"issueadditional",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdditionalToSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发债对应原债券时间序列
    return w.wsd(security,"additionalto",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerpetualOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否永续债时间序列
    return w.wsd(security,"perpetualornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBaseRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准利率时间序列
    return w.wsd(security,"baserate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCmBirSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准利率确定方式时间序列
    return w.wsd(security,"cmbir",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBaseRate2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准利率(发行时)时间序列
    return w.wsd(security,"baserate2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBaseRate3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准利率(指定日期)时间序列
    return w.wsd(security,"baserate3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcFloatBenchSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计算浮息债隐含基准利率时间序列
    return w.wsd(security,"calc_floatbench",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSpreadSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定利差时间序列
    return w.wsd(security,"spread",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFirstPriceDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首个定价日时间序列
    return w.wsd(security,"issue_firstpricedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponRate2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取票面利率(当期)时间序列
    return w.wsd(security,"couponrate2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponRate3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取票面利率(指定日期)时间序列
    return w.wsd(security,"couponrate3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSpread2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权后利差时间序列
    return w.wsd(security,"spread2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestFloorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保底利率时间序列
    return w.wsd(security,"interestfloor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEmbeddedOptSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否含权债时间序列
    return w.wsd(security,"embeddedopt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特殊条款时间序列
    return w.wsd(security,"clause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseAbbrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特殊条款(缩写)时间序列
    return w.wsd(security,"clauseabbr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定条款文字时间序列
    return w.wsd(security,"clauseitem",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExecMaturityEmbeddedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取含权债行权期限时间序列
    return w.wsd(security,"execmaturityembedded",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEObSpecialInStrutIonsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取含权债期限特殊说明时间序列
    return w.wsd(security,"eobspecialinstrutions",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrepaymentDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提前还本日时间序列
    return w.wsd(security,"prepaymentdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrepayPortionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提前还本比例时间序列
    return w.wsd(security,"prepayportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRedemptionDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回日时间序列
    return w.wsd(security,"redemptiondate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepurchaseDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售日时间序列
    return w.wsd(security,"repurchasedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedemptionPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回价格时间序列
    return w.wsd(security,"clause_calloption_redemptionprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedemptionMemoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回价格说明时间序列
    return w.wsd(security,"clause_calloption_redemptionmemo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionResellingPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售价格时间序列
    return w.wsd(security,"clause_putoption_resellingprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionResellingPriceExplainAtionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售价格说明时间序列
    return w.wsd(security,"clause_putoption_resellingpriceexplaination",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionAdditionalPriceMemoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取附加回售价格说明时间序列
    return w.wsd(security,"clause_putoption_additionalpricememo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPutCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售代码时间序列
    return w.wsd(security,"putcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepurchaseBeginDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售登记起始日时间序列
    return w.wsd(security,"repurchasebegindate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRepurchaseEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售登记截止日时间序列
    return w.wsd(security,"repurchaseenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFunDarRialDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权资金到账日时间序列
    return w.wsd(security,"fundarrialdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponAdjMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取票面利率调整上限时间序列
    return w.wsd(security,"couponadj_max",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCouponAdjMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取票面利率调整下限时间序列
    return w.wsd(security,"couponadj_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRecordDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回登记日时间序列
    return w.wsd(security,"clause_calloption_recorddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人时间序列
    return w.wsd(security,"agency_guarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateRateGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人评级时间序列
    return w.wsd(security,"rate_rateguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateFwdGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人评级展望时间序列
    return w.wsd(security,"rate_fwdguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateChNgGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人评级变动方向时间序列
    return w.wsd(security,"rate_chngguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateAgencyGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保人评级评级机构时间序列
    return w.wsd(security,"rate_agencyguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyReGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取再担保人时间序列
    return w.wsd(security,"agency_reguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateBeginGuarantorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行时担保人评级时间序列
    return w.wsd(security,"rate_beginguarantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyGrNtTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保方式时间序列
    return w.wsd(security,"agency_grnttype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarTermSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保期限时间序列
    return w.wsd(security,"guarterm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarRangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保范围时间序列
    return w.wsd(security,"guarrange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyGrNtRangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保条款文字时间序列
    return w.wsd(security,"agency_grntrange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCounterGuarSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取反担保情况时间序列
    return w.wsd(security,"counterguar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCvnTPerHundredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标准券折算金额(每百元面值)时间序列
    return w.wsd(security,"cvntperhundred",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCollateralCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押券代码时间序列
    return w.wsd(security,"collateralcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCollateralNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押券简称时间序列
    return w.wsd(security,"collateralname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPledGableOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否可质押时间序列
    return w.wsd(security,"fund_pledgableornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateOfStdBndCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价式回购折算率(中证指数)时间序列
    return w.wsd(security,"rateofstdbndcsi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseInterest5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否随存款利率调整时间序列
    return w.wsd(security,"clause_interest_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseInterest8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否有利息补偿时间序列
    return w.wsd(security,"clause_interest_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseInterestCompensationInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取补偿利率时间序列
    return w.wsd(security,"clause_interest_compensationinterest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCompensationInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取补偿利率(公布)时间序列
    return w.wsd(security,"clause_compensationinterest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseProcessModeInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息处理方式时间序列
    return w.wsd(security,"clause_processmodeinterest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股代码时间序列
    return w.wsd(security,"underlyingcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股简称时间序列
    return w.wsd(security,"underlyingname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2RelativeSwapShareMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对转股期时间序列
    return w.wsd(security,"clause_conversion_2_relativeswapsharemonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2SwapShareStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自愿转股起始日期时间序列
    return w.wsd(security,"clause_conversion_2_swapsharestartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2SwapShareEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自愿转股终止日期时间序列
    return w.wsd(security,"clause_conversion_2_swapshareenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2IsForcedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否强制转股时间序列
    return w.wsd(security,"clause_conversion_2_isforced",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2ForceConvertDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取强制转股日时间序列
    return w.wsd(security,"clause_conversion_2_forceconvertdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2ForceConvertPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取强制转股价格时间序列
    return w.wsd(security,"clause_conversion_2_forceconvertprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2SwapSharePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股价格时间序列
    return w.wsd(security,"clause_conversion2_swapshareprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversionCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股代码时间序列
    return w.wsd(security,"clause_conversion_code",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2ConversionProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转换比例时间序列
    return w.wsd(security,"clause_conversion2_conversionproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2BondLotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未转股余额时间序列
    return w.wsd(security,"clause_conversion2_bondlot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2BondProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未转股比例时间序列
    return w.wsd(security,"clause_conversion2_bondproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseConversion2ConversionProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股价随派息调整时间序列
    return w.wsd(security,"clause_conversion_2_conversionproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetItemSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特别向下修正条款全文时间序列
    return w.wsd(security,"clause_reset_item",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetIsExitResetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否有特别向下修正条款时间序列
    return w.wsd(security,"clause_reset_isexitreset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特别修正起始时间时间序列
    return w.wsd(security,"clause_reset_resetstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetPeriodEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特别修正结束时间时间序列
    return w.wsd(security,"clause_reset_resetperiodenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetMaxTimespanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重设触发计算最大时间区间时间序列
    return w.wsd(security,"clause_reset_resetmaxtimespan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetTimespanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重设触发计算时间区间时间序列
    return w.wsd(security,"clause_reset_resettimespan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetTriggerRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取触发比例时间序列
    return w.wsd(security,"clause_reset_resettriggerratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionTriggerProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回触发比例时间序列
    return w.wsd(security,"clause_calloption_triggerproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionRedeemTriggerProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售触发比例时间序列
    return w.wsd(security,"clause_putoption_redeem_triggerproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetRangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特别修正幅度时间序列
    return w.wsd(security,"clause_reset_resetrange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetStockPriceLowestLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取修正价格底线说明时间序列
    return w.wsd(security,"clause_reset_stockpricelowestlimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetResetTimesLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取修正次数限制时间序列
    return w.wsd(security,"clause_reset_resettimeslimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseResetTimePointClauseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取时点修正条款全文时间序列
    return w.wsd(security,"clause_reset_timepointclause",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRelativeCallOptionPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对赎回期时间序列
    return w.wsd(security,"clause_calloption_relativecalloptionperiod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedemptionTimesPerYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每年可赎回次数时间序列
    return w.wsd(security,"clause_calloption_redemptiontimesperyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionConditionalRedeemStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取条件赎回起始日期时间序列
    return w.wsd(security,"clause_calloption_conditionalredeemstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionConditionalRedeemEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取条件赎回截止日期时间序列
    return w.wsd(security,"clause_calloption_conditionalredeemenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedeemMaxSpanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回触发计算最大时间区间时间序列
    return w.wsd(security,"clause_calloption_redeemmaxspan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionRedeemSpanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回触发计算时间区间时间序列
    return w.wsd(security,"clause_calloption_redeemspan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionInterestDisposingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息处理时间序列
    return w.wsd(security,"clause_putoption_interestdisposing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionTimeRedemptionTimesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取时点赎回数时间序列
    return w.wsd(security,"clause_calloption_timeredemptiontimes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConditionalCallPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有条件赎回价时间序列
    return w.wsd(security,"conditionalcallprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaturityCallPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取到期赎回价时间序列
    return w.wsd(security,"maturitycallprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionTriggerPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回触发价时间序列
    return w.wsd(security,"clause_calloption_triggerprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClauseCallOptionNoticeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回公告日时间序列
    return w.wsd(security,"clause_calloption_noticedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackPeriodObSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对回售期时间序列
    return w.wsd(security,"clause_putoption_putbackperiodobs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionConditionalPutBackStartEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取条件回售起始日期时间序列
    return w.wsd(security,"clause_putoption_conditionalputbackstartenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无条件回售起始日期时间序列
    return w.wsd(security,"clause_putoption_putbackstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionConditionalPutBackEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取条件回售截止日期时间序列
    return w.wsd(security,"clause_putoption_conditionalputbackenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackTriggerMaxSpanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售触发计算最大时间区间时间序列
    return w.wsd(security,"clause_putoption_putbacktriggermaxspan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackTriggerSpanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售触发计算时间区间时间序列
    return w.wsd(security,"clause_putoption_putbacktriggerspan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackTimesPerYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每年回售次数时间序列
    return w.wsd(security,"clause_putoption_putbacktimesperyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无条件回售期时间序列
    return w.wsd(security,"clause_putoption_putbackperiod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无条件回售结束日期时间序列
    return w.wsd(security,"clause_putoption_putbackenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无条件回售价时间序列
    return w.wsd(security,"clause_putoption_putbackprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionTimePutBackTimesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取时点回售数时间序列
    return w.wsd(security,"clause_putoption_timeputbacktimes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionPutBackAdditionalConditionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取附加回售条件时间序列
    return w.wsd(security,"clause_putoption_putbackadditionalcondition",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConditionalPutPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有条件回售价时间序列
    return w.wsd(security,"conditionalputprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionTriggerPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售触发价时间序列
    return w.wsd(security,"clause_putoption_triggerprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClausePutOptionNoticeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售公告日时间序列
    return w.wsd(security,"clause_putoption_noticedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行时债项评级时间序列
    return w.wsd(security,"creditrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行时主体评级时间序列
    return w.wsd(security,"issuer_rating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssuerRatingOutlookSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行时主体评级展望时间序列
    return w.wsd(security,"issuerratingoutlook",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateCreditRatingAgencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人委托评级机构时间序列
    return w.wsd(security,"rate_creditratingagency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIsSurerCreditRatingCompanySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发债主体评级机构时间序列
    return w.wsd(security,"issurercreditratingcompany",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新债项评级时间序列
    return w.wsd(security,"amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLatestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新债项评级日期时间序列
    return w.wsd(security,"rate_latest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLatest1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新债项评级日期(指定机构)时间序列
    return w.wsd(security,"rate_latest1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateChangesOfRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新债项评级变动方向时间序列
    return w.wsd(security,"rate_changesofrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateStyleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新债项评级评级类型时间序列
    return w.wsd(security,"rate_style",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLowestIsSurerCreditRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行人最新最低评级时间序列
    return w.wsd(security,"lowestissurercreditrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateRateBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债项评级时间序列
    return w.wsd(security,"rate_ratebond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateChNgBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债项评级变动方向时间序列
    return w.wsd(security,"rate_chngbond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateAgencyBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债项评级机构时间序列
    return w.wsd(security,"rate_agencybond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateFormerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史债项评级时间序列
    return w.wsd(security,"rate_former",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInStYyBondRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)债项评级(YY)时间序列
    return w.wsd(security,"inst_yybondrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestIsSurerCreditRating2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体评级时间序列
    return w.wsd(security,"latestissurercreditrating2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateFwdIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体评级展望时间序列
    return w.wsd(security,"rate_fwdissuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateChNgIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体评级变动方向时间序列
    return w.wsd(security,"rate_chngissuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateAgencyIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体评级评级机构时间序列
    return w.wsd(security,"rate_agencyissuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInStYyIssuerRatingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体评级(YY)时间序列
    return w.wsd(security,"inst_yyissuerrating",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInStYyIssuerRatingHisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主体评级历史(YY)时间序列
    return w.wsd(security,"inst_yyissuerratinghis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日主体评级时间序列
    return w.wsd(security,"rate_issuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateIssuerFormerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发债主体历史信用等级时间序列
    return w.wsd(security,"rate_issuerformer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditLineSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新授信额度时间序列
    return w.wsd(security,"credit_line",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditLineUsedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新已使用授信额度时间序列
    return w.wsd(security,"credit_lineused",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditLineUnusedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新未使用授信额度时间序列
    return w.wsd(security,"credit_lineunused",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditLineUsed2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史已使用授信额度时间序列
    return w.wsd(security,"credit_lineused2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditFormerLineSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史授信额度时间序列
    return w.wsd(security,"credit_formerline",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditLineDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新授信日期时间序列
    return w.wsd(security,"credit_linedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarLatestBalanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新担保余额时间序列
    return w.wsd(security,"guar_latestbalance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarLatestInwardsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新对内担保余额时间序列
    return w.wsd(security,"guar_latestinwards",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarLatestOutwardsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新对外担保余额时间序列
    return w.wsd(security,"guar_latestoutwards",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarFormerBalanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史担保余额时间序列
    return w.wsd(security,"guar_formerbalance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarFormerInwardsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对内担保余额时间序列
    return w.wsd(security,"guar_formerinwards",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGuarFormerOutwardsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对外担保余额时间序列
    return w.wsd(security,"guar_formeroutwards",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmUnuEsDAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际可用剩余额度时间序列
    return w.wsd(security,"dcm_unuesdamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmUeSdAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已使用注册额度时间序列
    return w.wsd(security,"dcm_uesdamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmFirstIssueEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首期发行截止日时间序列
    return w.wsd(security,"dcm_firstissueenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmMeetingDataSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未使用注册会议日期时间序列
    return w.wsd(security,"dcm_meetingdata",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmExpirationDataSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未使用额度有效期时间序列
    return w.wsd(security,"dcm_expirationdata",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新注册文件编号时间序列
    return w.wsd(security,"dcm_number",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmUnderwriterSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未使用额度主承销商时间序列
    return w.wsd(security,"dcm_underwriter",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDCmAcCumAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史累计注册额度时间序列
    return w.wsd(security,"dcm_accumamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaTotalAmount2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间发行债券总额时间序列
    return w.wsd(security,"fina_totalamount2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaTotalNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间发行债券数目时间序列
    return w.wsd(security,"fina_totalnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaRemainingNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存量债券数目时间序列
    return w.wsd(security,"fina_remainingnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInfoNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金简称时间序列
    return w.wsd(security,"fund_info_name",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNameOfficialSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金简称(官方)时间序列
    return w.wsd(security,"name_official",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFullNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金全称时间序列
    return w.wsd(security,"fund_fullname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFullNameEnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金全称(英文)时间序列
    return w.wsd(security,"fund_fullnameen",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExchangeShortnameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金场内简称时间序列
    return w.wsd(security,"fund_exchangeshortname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExchangeShortnameExtendSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金扩位场内简称时间序列
    return w.wsd(security,"fund_exchangeshortnameextend",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundIssuerShortnameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行机构自编简称时间序列
    return w.wsd(security,"fund_issuershortname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExistingYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成立年限时间序列
    return w.wsd(security,"fund_existingyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMinHoldingPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金最短持有期时间序列
    return w.wsd(security,"fund_minholdingperiod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPtMYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金存续期时间序列
    return w.wsd(security,"fund_ptmyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPtMDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余存续期时间序列
    return w.wsd(security,"fund_ptmday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundBenchmarkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩比较基准时间序列
    return w.wsd(security,"fund_benchmark",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundChangeOfBenchmarkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩比较基准变更说明时间序列
    return w.wsd(security,"fund_changeofbenchmark",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBenchReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩比较基准增长率时间序列
    return w.wsd(security,"bench_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavBenchReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期业绩比较基准增长率时间序列
    return w.wsd(security,"NAV_benchreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavBenchStdDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期业绩比较基准增长率标准差时间序列
    return w.wsd(security,"NAV_benchstddev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalBenchReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.业绩比较基准收益率时间序列
    return w.wsd(security,"qanal_benchreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalStdBenchReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.业绩比较基准收益率标准差时间序列
    return w.wsd(security,"qanal_stdbenchreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundBenchIndexCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准指数代码时间序列
    return w.wsd(security,"fund_benchindexcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestObjectSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资目标时间序列
    return w.wsd(security,"fund_investobject",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestScopeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资范围时间序列
    return w.wsd(security,"fund_investscope",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestmentProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资品种比例限制时间序列
    return w.wsd(security,"fund_investmentproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHkScInvestmentProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取港股通股票投资比例说明时间序列
    return w.wsd(security,"fund_hkscinvestmentproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestConceptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资理念时间序列
    return w.wsd(security,"fund_investconception",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestmentRegionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资区域时间序列
    return w.wsd(security,"fund_investmentregion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestingRegionDescriptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主要投资区域说明时间序列
    return w.wsd(security,"fund_investingregiondescription",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundParValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取面值时间序列
    return w.wsd(security,"fund_parvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInitialSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否初始基金时间序列
    return w.wsd(security,"fund_initial",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundStructuredFundOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否分级基金时间序列
    return w.wsd(security,"fund_structuredfundornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReGulOpenFundOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否定期开放基金时间序列
    return w.wsd(security,"fund_regulopenfundornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSidePocketFundOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否使用侧袋机制时间序列
    return w.wsd(security,"fund_sidepocketfundornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExceptionStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取产品异常状态时间序列
    return w.wsd(security,"fund_exceptionstatus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOperatePeriodClsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭运作期时间序列
    return w.wsd(security,"fund_operateperiod_cls",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpectedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预期收益率(文字)时间序列
    return w.wsd(security,"expectedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundTransitionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金转型说明时间序列
    return w.wsd(security,"fund_fundtransition",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundValuationMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金估值方法时间序列
    return w.wsd(security,"fund_valuationmethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRiskReturnCharactersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取风险收益特征时间序列
    return w.wsd(security,"fund_riskreturn_characters",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarketRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场风险提示时间序列
    return w.wsd(security,"marketrisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getManagementRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理风险提示时间序列
    return w.wsd(security,"managementrisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechnicalRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取技术风险提示时间序列
    return w.wsd(security,"technicalrisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRedemptionRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回风险提示时间序列
    return w.wsd(security,"redemptionrisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherRisksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他风险提示时间序列
    return w.wsd(security,"otherrisks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFrontendCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金前端代码时间序列
    return w.wsd(security,"fund_frontendcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundBackendCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金后端代码时间序列
    return w.wsd(security,"fund_backendcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInitialCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金初始代码时间序列
    return w.wsd(security,"fund_initialcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRelatedCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取关联基金代码时间序列
    return w.wsd(security,"fund_relatedcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundAMacCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金业协会编码时间序列
    return w.wsd(security,"fund_AMACcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundBWMpRecordCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取理财产品登记编码时间序列
    return w.wsd(security,"fund_bwmp_recordcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundIssuerCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行机构自编代码时间序列
    return w.wsd(security,"fund_issuercode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExchangeCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取理财产品交易所代码时间序列
    return w.wsd(security,"fund_exchangecode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPeQuotationCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取机构间私募产品报价系统编码时间序列
    return w.wsd(security,"fund_pequotationcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSetUpdateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金成立日时间序列
    return w.wsd(security,"fund_setupdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMaturityDate2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金到期日时间序列
    return w.wsd(security,"fund_maturitydate_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDateSuspensionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金暂停运作日时间序列
    return w.wsd(security,"fund_date_suspension",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDateResumptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金恢复运作日时间序列
    return w.wsd(security,"fund_date_resumption",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCuStStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开始托管日期时间序列
    return w.wsd(security,"fund_custstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCusTendDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取托管结束日期时间序列
    return w.wsd(security,"fund_custenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRecognitionDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取互认基金批复日期时间序列
    return w.wsd(security,"fund_recognitiondate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExpectedEndingDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计封闭期结束日时间序列
    return w.wsd(security,"fund_expectedendingday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExpectedOpenDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计下期开放日时间序列
    return w.wsd(security,"fund_expectedopenday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundStartDateOfClosureSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定开基金封闭起始日时间序列
    return w.wsd(security,"fund_startdateofclosure",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundLastOpenDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定开基金上一开放日时间序列
    return w.wsd(security,"fund_lastopenday",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOpenDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定开基金开放日(支持历史)时间序列
    return w.wsd(security,"fund_opendays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundNumOfOpenDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定开基金已开放次数时间序列
    return w.wsd(security,"fund_numofopendays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListDataDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市公告数据截止日期时间序列
    return w.wsd(security,"listdatadate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMGrCompSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人时间序列
    return w.wsd(security,"fund_mgrcomp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFundManagementCompanySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人简称时间序列
    return w.wsd(security,"fund_corp_fundmanagementcompany",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpNameEngSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人英文名称时间序列
    return w.wsd(security,"fund_corpnameeng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpChairmanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人法人代表时间序列
    return w.wsd(security,"fund_corpchairman",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpPhoneSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人电话时间序列
    return w.wsd(security,"fund_corpphone",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人传真时间序列
    return w.wsd(security,"fund_corpfax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpEmailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人电子邮箱时间序列
    return w.wsd(security,"fund_corpemail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpWebsiteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人主页时间序列
    return w.wsd(security,"fund_corpwebsite",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtNonMoneyNetAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人资产净值合计(非货币)时间序列
    return w.wsd(security,"prt_nonmoneynetassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundCoTotalNetAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人资产净值合计时间序列
    return w.wsd(security,"prt_fundcototalnetassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundCoTotalNetAssetsRankingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人资产净值合计排名时间序列
    return w.wsd(security,"prt_fundcototalnetassetsranking",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtFundCoTnaChangeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理人资产净值合计变动率时间序列
    return w.wsd(security,"prt_fundcotnachangeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCustodianBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金托管人时间序列
    return w.wsd(security,"fund_custodianbank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRegistrarSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金注册与过户登记人时间序列
    return w.wsd(security,"issue_registrar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyFAdvisorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务顾问时间序列
    return w.wsd(security,"agency_fadvisor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1504Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:财务顾问业务时间序列
    return w.wsd(security,"stmnote_sec_1504",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1524Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:财务顾问业务时间序列
    return w.wsd(security,"stmnote_sec_1524",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundWmIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行理财发行人时间序列
    return w.wsd(security,"fund_wmissuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundForeignInvestmentAdvisorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取境外投资顾问时间序列
    return w.wsd(security,"fund_foreigninvestmentadvisor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundForeignCustodianSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取境外托管人时间序列
    return w.wsd(security,"fund_foreigncustodian",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCounselorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取律师事务所时间序列
    return w.wsd(security,"fund_counselor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPrimaryDealersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一级交易商时间序列
    return w.wsd(security,"fund_primarydealers",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金类型时间序列
    return w.wsd(security,"fund_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFirstInvestTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资类型(一级分类)时间序列
    return w.wsd(security,"fund_firstinvesttype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资类型(二级分类)时间序列
    return w.wsd(security,"fund_investtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestType2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资类型时间序列
    return w.wsd(security,"fund_investtype2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestTypeAnytimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资类型(支持历史)时间序列
    return w.wsd(security,"fund_investtype_anytime",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestTypeEngSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资类型(英文)时间序列
    return w.wsd(security,"fund_investtypeeng",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRiskLevelSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金风险等级时间序列
    return w.wsd(security,"fund_risklevel",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRiskLevelFilingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金风险等级(公告口径)时间序列
    return w.wsd(security,"fund_risklevelfiling",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSMfType2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金分级类型时间序列
    return w.wsd(security,"fund_smftype2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSimilarFundNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金数量时间序列
    return w.wsd(security,"fund_similarfundno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundThemeTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属主题基金类别时间序列
    return w.wsd(security,"fund_themetype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundThemeTypeConceptSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属主题基金类别(Wind概念)时间序列
    return w.wsd(security,"fund_themetype_concept",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundThemeTypeIndustrySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属主题基金类别(Wind行业)时间序列
    return w.wsd(security,"fund_themetype_industry",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundThemeTypeIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属主题基金类别(Wind股票指数)时间序列
    return w.wsd(security,"fund_themetype_index",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagementFeeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费率时间序列
    return w.wsd(security,"fund_managementfeeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagementFeeRatio2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费率(支持历史)时间序列
    return w.wsd(security,"fund_managementfeeratio2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFloatingMgNtFeedEScripSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取浮动管理费率说明时间序列
    return w.wsd(security,"fund_floatingmgntfeedescrip",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTrusteeMgNtFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托人固定管理费率(信托)时间序列
    return w.wsd(security,"fund_trusteemgntfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvAdviserMgNtFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资顾问固定管理费率(信托)时间序列
    return w.wsd(security,"fund_invadvisermgntfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFloatingMgNtFeeOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否收取浮动管理费时间序列
    return w.wsd(security,"fund_floatingmgntfeeornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCustodianFeeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取托管费率时间序列
    return w.wsd(security,"fund_custodianfeeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCustodianFeeRatio2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取托管费率(支持历史)时间序列
    return w.wsd(security,"fund_custodianfeeratio2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSaleFeeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售服务费率时间序列
    return w.wsd(security,"fund_salefeeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSaleFeeRatio2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售服务费率(支持历史)时间序列
    return w.wsd(security,"fund_salefeeratio2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPurchaseFeeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高申购费率时间序列
    return w.wsd(security,"fund_purchasefeeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedemptionFeeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高赎回费率时间序列
    return w.wsd(security,"fund_redemptionfeeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSubscriptionFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购费率时间序列
    return w.wsd(security,"fund_subscriptionfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSubscriptionFee2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取认购费率(支持历史)时间序列
    return w.wsd(security,"fund_subscriptionfee2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPurchaseFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购费率时间序列
    return w.wsd(security,"fund_purchasefee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPurchaseFee2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购费率(支持历史)时间序列
    return w.wsd(security,"fund_purchasefee2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMPChMaxFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购费率上限时间序列
    return w.wsd(security,"fund_pchredm_pchmaxfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedemptionFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回费率时间序列
    return w.wsd(security,"fund_redemptionfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedemptionFee2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回费率(支持历史)时间序列
    return w.wsd(security,"fund_redemptionfee2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMMaxRedMFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回费率上限时间序列
    return w.wsd(security,"fund_pchredm_maxredmfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundIndexUsageFeeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数使用费率时间序列
    return w.wsd(security,"fund_indexusagefeeratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPurchaseAndRedemptionAbbreviationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购赎回简称时间序列
    return w.wsd(security,"fund_purchaseandredemptionabbreviation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDQStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购赎回状态时间序列
    return w.wsd(security,"fund_dq_status",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPcHmStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购状态时间序列
    return w.wsd(security,"fund_pchmstatus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedMStatusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回状态时间序列
    return w.wsd(security,"fund_redmstatus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMPChStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购起始日时间序列
    return w.wsd(security,"fund_pchredm_pchstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购起始日期时间序列
    return w.wsd(security,"ipo_op_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMLargePChMaxAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单日大额申购限额时间序列
    return w.wsd(security,"fund_pchredm_largepchmaxamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMPcHmInAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购金额下限(场外)时间序列
    return w.wsd(security,"fund_pchredm_pchminamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMPcHmInAmtFloorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购金额下限(场内)时间序列
    return w.wsd(security,"fund_pchredm_pchminamt_floor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedMStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回起始日时间序列
    return w.wsd(security,"fund_redmstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChRedMRedMmInAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单笔赎回份额下限时间序列
    return w.wsd(security,"fund_pchredm_redmminamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPChConfirmDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购确认日时间序列
    return w.wsd(security,"fund_pchconfirmdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedMConfirmDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回确认日时间序列
    return w.wsd(security,"fund_redmconfirmdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRedMarriAlDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回划款日时间序列
    return w.wsd(security,"fund_redmarrialdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFundNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取旗下基金数时间序列
    return w.wsd(security,"fund_corp_fundno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFiveStarFundsPropSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取五星基金占比时间序列
    return w.wsd(security,"fund_corp_fivestarfundsprop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpFourStarFundsPropSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取四星基金占比时间序列
    return w.wsd(security,"fund_corp_fourstarfundsprop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCorpTeamStabilitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取团队稳定性时间序列
    return w.wsd(security,"fund_corp_teamstability",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTrackIndexCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪指数代码时间序列
    return w.wsd(security,"fund_trackindexcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTrackIndexNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪指数名称时间序列
    return w.wsd(security,"fund_trackindexname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTrackDeviationThresholdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取日均跟踪偏离度阈值(业绩基准)时间序列
    return w.wsd(security,"fund_trackdeviation_threshold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTrackErrorThresholdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化跟踪误差阈值(业绩基准)时间序列
    return w.wsd(security,"fund_trackerror_threshold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSMfTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分级基金类别时间序列
    return w.wsd(security,"fund_smftype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSMfCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分级基金母基金代码时间序列
    return w.wsd(security,"fund_smfcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSMfaCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分级基金优先级代码时间序列
    return w.wsd(security,"fund_smfacode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSmFbCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分级基金普通级代码时间序列
    return w.wsd(security,"fund_smfbcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSplitRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆分比率时间序列
    return w.wsd(security,"fund_splitratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSubShareProportionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分级份额占比时间序列
    return w.wsd(security,"fund_subshareproportion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInitialLeverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初始杠杆时间序列
    return w.wsd(security,"fund_initiallever",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundAAyeIlDInfoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取约定年收益率表达式时间序列
    return w.wsd(security,"fund_aayeildinfo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPairConversionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否配对转换时间序列
    return w.wsd(security,"fund_pairconversion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDiscountPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期折算周期时间序列
    return w.wsd(security,"fund_discountperiod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDiscountMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期折算条款时间序列
    return w.wsd(security,"fund_discountmethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundUpDiscountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向上触点折算条款时间序列
    return w.wsd(security,"fund_updiscount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDownDiscountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向下触点折算条款时间序列
    return w.wsd(security,"fund_downdiscount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedCycleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保本周期时间序列
    return w.wsd(security,"fund_guaranteedcycle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedCycleStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保本周期起始日期时间序列
    return w.wsd(security,"fund_guaranteedcycle_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedCycleEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保本周期终止日期时间序列
    return w.wsd(security,"fund_guaranteedcycle_enddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedFeeRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保本费率时间序列
    return w.wsd(security,"fund_guaranteedfeerate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundWarrantOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保证人时间序列
    return w.wsd(security,"fund_warrantor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundWarrantOrIntroductionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保证人简介时间序列
    return w.wsd(security,"fund_warrantorintroduction",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedTriggerRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保本触发收益率时间序列
    return w.wsd(security,"fund_guaranteedtriggerratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedTriggerTxtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保本触发机制说明时间序列
    return w.wsd(security,"fund_guaranteedtriggertxt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPlanTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计划类型(券商集合理财)时间序列
    return w.wsd(security,"fund_plantype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPerformanceFeeOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否提取业绩报酬(券商集合理财)时间序列
    return w.wsd(security,"fund_performancefeeornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPerformanceFeeMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业绩报酬提取方法时间序列
    return w.wsd(security,"fund_performancefeemethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMgNtFeeExplainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费说明时间序列
    return w.wsd(security,"fund_mgntfeeexplain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrustTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信托类别(信托)时间序列
    return w.wsd(security,"trust_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrustInvestFieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信托投资领域时间序列
    return w.wsd(security,"trust_investfield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrustSourceTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信托产品类别时间序列
    return w.wsd(security,"trust_sourcetype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundExpectedRateOfReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计年收益率(信托)时间序列
    return w.wsd(security,"fund_expectedrateofreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundStructuredOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否结构化产品(信托)时间序列
    return w.wsd(security,"fund_structuredornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTrusteeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托人(信托)时间序列
    return w.wsd(security,"fund_trustee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSecuritiesBrokerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券经纪人(信托)时间序列
    return w.wsd(security,"fund_securitiesbroker",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundIssuingPlaceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行地(信托)时间序列
    return w.wsd(security,"fund_issuingplace",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFloatingRateNoteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取浮动收益说明(信托)时间序列
    return w.wsd(security,"fund_floatingratenote",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGeneralBeneficialAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一般受益权金额(信托)时间序列
    return w.wsd(security,"fund_generalbeneficialamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPriorityBeneficialAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取优先受益权金额(信托)时间序列
    return w.wsd(security,"fund_prioritybeneficialamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPriorityToGeneralSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取委托资金比(优先/一般)(信托)时间序列
    return w.wsd(security,"fund_prioritytogeneral",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundIssuedContractAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行信托合同总数(信托)时间序列
    return w.wsd(security,"fund_issuedcontractamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdvanceCreditDescSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用增级情况时间序列
    return w.wsd(security,"advancecredit_desc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnticipateYieldDescSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预期收益率说明时间序列
    return w.wsd(security,"anticipateyield_desc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTrustRelatedFirmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信托项目关联企业名称时间序列
    return w.wsd(security,"trust_relatedfirm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSubStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售起始日期时间序列
    return w.wsd(security,"fund_substartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSubEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售截止日期时间序列
    return w.wsd(security,"fund_subenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundTargetScaleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取目标规模时间序列
    return w.wsd(security,"fund_targetscale",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEffSubsCrHoleDerNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有效认购户数时间序列
    return w.wsd(security,"fund_effsubscrholederno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMinBuyAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低参与金额时间序列
    return w.wsd(security,"fund_minbuyamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMinAddBuyAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取追加认购最低金额时间序列
    return w.wsd(security,"fund_minaddbuyamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagersBuyAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理人参与金额时间序列
    return w.wsd(security,"fund_managersbuyamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOpenDayIllUsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开放日说明时间序列
    return w.wsd(security,"fund_opendayillus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCloseDayIllUsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取封闭期说明时间序列
    return w.wsd(security,"fund_closedayillus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFirstInvestStrategySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资策略分类(一级)(私募)时间序列
    return w.wsd(security,"fund_firstinveststrategy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSecondInvestStrategySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资策略分类(二级)(私募)时间序列
    return w.wsd(security,"fund_secondinveststrategy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueChannelSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取产品发行渠道时间序列
    return w.wsd(security,"issue_channel",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInvestmentAdvisorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资顾问时间序列
    return w.wsd(security,"fund_investmentadvisor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavUpdateFrequencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金净值更新频率时间序列
    return w.wsd(security,"NAV_updatefrequency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavUpdateCompletenessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金净值完整度时间序列
    return w.wsd(security,"NAV_updatecompleteness",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManageScaleIntervalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取协会备案管理人在管规模时间序列
    return w.wsd(security,"fund_managescaleinterval",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundGuaranteedOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否保本时间序列
    return w.wsd(security,"fund_guaranteedornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundLcRiskLevelSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行理财风险等级(银行)时间序列
    return w.wsd(security,"fund_lcrisklevel",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOperationModeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取产品运作方式时间序列
    return w.wsd(security,"fund_operationmode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundBusinessModeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取业务模式时间序列
    return w.wsd(security,"fund_businessmode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReturnStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益起始日时间序列
    return w.wsd(security,"fund_returnstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReturnEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益终止日时间序列
    return w.wsd(security,"fund_returnenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundActualDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际运作期限时间序列
    return w.wsd(security,"fund_actualduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMaxSubScripAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取委托金额上限时间序列
    return w.wsd(security,"fund_maxsubscripamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundActualAnnualYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际年化收益率时间序列
    return w.wsd(security,"fund_actualannualyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundActualMaturityDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际到期日时间序列
    return w.wsd(security,"fund_actualmaturitydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundInterestPayMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取付息方式说明时间序列
    return w.wsd(security,"fund_interestpaymethod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFundArrivalDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资金到账天数时间序列
    return w.wsd(security,"fund_fundarrivaldays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEarlyTerminationOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否可提前终止时间序列
    return w.wsd(security,"fund_earlyterminationornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCNdPreTerminationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提前终止条件时间序列
    return w.wsd(security,"fund_cndpretermination",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundCNdpUrchRedemptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购赎回条件时间序列
    return w.wsd(security,"fund_cndpurchredemption",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundUnderlyingTargetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益挂钩标的时间序列
    return w.wsd(security,"fund_underlyingtarget",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundMainRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主要风险点时间序列
    return w.wsd(security,"fund_mainrisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产类型时间序列
    return w.wsd(security,"fund__reitstype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsInfoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目介绍时间序列
    return w.wsd(security,"fund__reitsinfo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPriceMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取询价区间上限时间序列
    return w.wsd(security,"fund__reitspricemax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPriceMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取询价区间下限时间序列
    return w.wsd(security,"fund__reitspricemin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSIsTDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略发售起始日时间序列
    return w.wsd(security,"fund__reitssistdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSienDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略发售截止日时间序列
    return w.wsd(security,"fund__reitssiendate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSiShareSubSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略投资方认购份额时间序列
    return w.wsd(security,"fund_reitssisharesub",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSiShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略配售份额时间序列
    return w.wsd(security,"fund__reitssishare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSiShareRaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略配售份额占比时间序列
    return w.wsd(security,"fund__reitssisharera",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSiRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略投资方认购比例时间序列
    return w.wsd(security,"fund_reitssiratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOffStDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下发售起始日时间序列
    return w.wsd(security,"fund__reitsoffstdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOffendAteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下发售截止日时间序列
    return w.wsd(security,"fund__reitsoffendate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItSoIsHareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下认购份额时间序列
    return w.wsd(security,"fund_reitsoishare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOffShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下配售份额时间序列
    return w.wsd(security,"fund__reitsoffshare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOffShareRaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下配售份额占比时间序列
    return w.wsd(security,"fund__reitsoffsharera",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItSoIRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资方认购比例时间序列
    return w.wsd(security,"fund_reitsoiratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPbsTDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公众发售起始日时间序列
    return w.wsd(security,"fund__reitspbstdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPBenDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公众发售截止日时间序列
    return w.wsd(security,"fund__reitspbendate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPiShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公众认购份额时间序列
    return w.wsd(security,"fund_reitspishare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPbShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公众配售份额时间序列
    return w.wsd(security,"fund__reitspbshare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPbShareRaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公众配售份额占比时间序列
    return w.wsd(security,"fund__reitspbsharera",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPiRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公众投资方认购比例时间序列
    return w.wsd(security,"fund_reitspiratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsOpRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目运营风险时间序列
    return w.wsd(security,"fund__reitsoprisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsAsNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产名称时间序列
    return w.wsd(security,"fund__reitsasname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsLocationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产所在地时间序列
    return w.wsd(security,"fund__reitslocation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsComNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取项目公司名称时间序列
    return w.wsd(security,"fund__reitscomname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下机构自营投资账户配售数量时间序列
    return w.wsd(security,"fund__reitspis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPimSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下机构自营投资账户配售金额时间序列
    return w.wsd(security,"fund__reitspim",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPirSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下机构自营投资账户配售份额占比时间序列
    return w.wsd(security,"fund__reitspir",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPfsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下私募基金配售数量时间序列
    return w.wsd(security,"fund__reitspfs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPFmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下私募基金配售金额时间序列
    return w.wsd(security,"fund__reitspfm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsPFrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下私募基金配售份额占比时间序列
    return w.wsd(security,"fund__reitspfr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsIsSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下保险资金投资账户配售数量时间序列
    return w.wsd(security,"fund__reitsiss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsIsMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下保险资金投资账户配售金额时间序列
    return w.wsd(security,"fund__reitsism",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsIsRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下保险资金投资账户配售份额占比时间序列
    return w.wsd(security,"fund__reitsisr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsTrsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下集合信托计划配售数量时间序列
    return w.wsd(security,"fund__reitstrs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsTrmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下集合信托计划配售金额时间序列
    return w.wsd(security,"fund__reitstrm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsTrRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下集合信托计划配售份额占比时间序列
    return w.wsd(security,"fund__reitstrr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsScSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下证券公司集合资产管理计划配售数量时间序列
    return w.wsd(security,"fund__reitsscs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSCmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下证券公司集合资产管理计划配售金额时间序列
    return w.wsd(security,"fund__reitsscm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSCrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下证券公司集合资产管理计划配售份额占比时间序列
    return w.wsd(security,"fund__reitsscr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSCssSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下证券公司单一资产管理计划配售数量时间序列
    return w.wsd(security,"fund__reitsscss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsScSmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下证券公司单一资产管理计划配售金额时间序列
    return w.wsd(security,"fund__reitsscsm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsSCsrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下证券公司单一资产管理计划配售份额占比时间序列
    return w.wsd(security,"fund__reitsscsr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItsLimitedShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取限售份额时间序列
    return w.wsd(security,"fund_reitslimitedshare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYieldCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价收益率(%)(中债)时间序列
    return w.wsd(security,"yield_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价净价(中债)时间序列
    return w.wsd(security,"net_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirtyCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价全价(中债)时间序列
    return w.wsd(security,"dirty_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPriceCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取日终估价全价(中债)时间序列
    return w.wsd(security,"price_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getModiDuraCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价修正久期(中债)时间序列
    return w.wsd(security,"modidura_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMatUCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取待偿年限(年)(中债)时间序列
    return w.wsd(security,"matu_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccruedInterestCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应计利息(中债)时间序列
    return w.wsd(security,"accruedinterest_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccRIntDayEndCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取日终应计利息(中债)时间序列
    return w.wsd(security,"accrint_dayend_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSprDuraCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价利差久期(中债)时间序列
    return w.wsd(security,"sprdura_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestDurationCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价利率久期(中债)时间序列
    return w.wsd(security,"interestduration_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSpreadYieldCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取点差收益率(中债)时间序列
    return w.wsd(security,"spreadyield_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCNvXTyCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价凸性(中债)时间序列
    return w.wsd(security,"cnvxty_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSPrcNxtCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价利差凸性(中债)时间序列
    return w.wsd(security,"sprcnxt_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestCNvXTyCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价利率凸性(中债)时间序列
    return w.wsd(security,"interestcnvxty_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMcYieldCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算收益率(%)(中债)时间序列
    return w.wsd(security,"mcyield_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMCnetCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算净价(中债)时间序列
    return w.wsd(security,"mcnet_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMDirtyCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权平均结算全价(中债)时间序列
    return w.wsd(security,"mdirty_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLatestMirCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场隐含评级(中债)时间序列
    return w.wsd(security,"rate_latestMIR_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateHistoricalMirCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场历史隐含评级(中债)时间序列
    return w.wsd(security,"rate_historicalMIR_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastDateCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新估值日期(中债)时间序列
    return w.wsd(security,"lastdate_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExerciseCouponRateCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估算的行权后票面利率时间序列
    return w.wsd(security,"exercisecouponrate_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLatestParCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余本金(中债)时间序列
    return w.wsd(security,"latestpar_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYieldCsi1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价收益率(中证指数)时间序列
    return w.wsd(security,"yield_csi1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCsi1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价净价(中证指数)时间序列
    return w.wsd(security,"net_csi1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirtyCsi1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价全价(中证指数)时间序列
    return w.wsd(security,"dirty_csi1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getModiDuraCsi1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价修正久期(中证指数)时间序列
    return w.wsd(security,"modidura_csi1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccruedInterestCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应计利息(中证指数)时间序列
    return w.wsd(security,"accruedinterest_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCNvXTyCsi1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价凸性(中证指数)时间序列
    return w.wsd(security,"cnvxty_csi1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastDateCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新估值日期(中证指数)时间序列
    return w.wsd(security,"lastdate_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateLatestMirCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取隐含评级(中证指数)时间序列
    return w.wsd(security,"rate_latestMIR_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRateDefaultCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取隐含违约率(中证指数)时间序列
    return w.wsd(security,"rate_default_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbValCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可交换债估值(中证指数)时间序列
    return w.wsd(security,"ebval_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbOptionValCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可交换债期权价值(中证指数)时间序列
    return w.wsd(security,"eboptionval_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbBondPreCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可交换债纯债溢价率(中证指数)时间序列
    return w.wsd(security,"ebbondpre_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbValYieldCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可交换债估值收益率(中证指数)时间序列
    return w.wsd(security,"ebvalyield_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbConversionPreCsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可交换债转股溢价率(中证指数)时间序列
    return w.wsd(security,"ebconversionpre_csi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYieldShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价收益率(上清所)时间序列
    return w.wsd(security,"yield_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价净价(上清所)时间序列
    return w.wsd(security,"net_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDirtyShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价全价(上清所)时间序列
    return w.wsd(security,"dirty_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getModiDuraShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价修正久期(上清所)时间序列
    return w.wsd(security,"modidura_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccruedInterestShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应计利息(上清所)时间序列
    return w.wsd(security,"accruedinterest_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCNvXTyShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估价凸性(上清所)时间序列
    return w.wsd(security,"cnvxty_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLastDateShcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新估值日期(上清所)时间序列
    return w.wsd(security,"lastdate_shc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDQCloseCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数值(中债)时间序列
    return w.wsd(security,"dq_close_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDQAmountCnBdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现券结算量(中债)时间序列
    return w.wsd(security,"dq_amount_cnbd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalCapConvexitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均市值法凸性时间序列
    return w.wsd(security,"anal_capconvexity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalCapDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均市值法久期时间序列
    return w.wsd(security,"anal_capduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalCapYTMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均市值法到期收益率时间序列
    return w.wsd(security,"anal_capytm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalCashFlowConvexitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均现金流法凸性时间序列
    return w.wsd(security,"anal_cashflowconvexity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalCashFlowDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均现金流法久期时间序列
    return w.wsd(security,"anal_cashflowduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalCashFlowYTMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均现金流法到期收益率时间序列
    return w.wsd(security,"anal_cashflowytm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalIpRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均派息率时间序列
    return w.wsd(security,"anal_ipratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均待偿期时间序列
    return w.wsd(security,"anal_period",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAmountFixedIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上证固收平台成交金额时间序列
    return w.wsd(security,"amount_fixedincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBinetBidWtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边买入净价(加权平均)时间序列
    return w.wsd(security,"binetbid_wt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBibiDrTWtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边买入收益率(加权平均)时间序列
    return w.wsd(security,"bibidrt_wt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBinetAskWtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边卖出净价(加权平均)时间序列
    return w.wsd(security,"binetask_wt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBiasKrTWtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边卖出收益率(加权平均)时间序列
    return w.wsd(security,"biaskrt_wt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBinetBidBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边买入净价(最优)时间序列
    return w.wsd(security,"binetbid_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBibiDrTBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边买入收益率(最优)时间序列
    return w.wsd(security,"bibidrt_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBinetAskBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边卖出净价(最优)时间序列
    return w.wsd(security,"binetask_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBiasKrTBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边卖出收益率(最优)时间序列
    return w.wsd(security,"biaskrt_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBIqTvOlmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双边报价笔数时间序列
    return w.wsd(security,"biqtvolm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetBidAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价买入净价(算术平均)时间序列
    return w.wsd(security,"netbid_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBidRtAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价买入收益率(算术平均)时间序列
    return w.wsd(security,"bidrt_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeTaskAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价卖出净价(算术平均)时间序列
    return w.wsd(security,"netask_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAskRtAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价卖出收益率(算术平均)时间序列
    return w.wsd(security,"askrt_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetBidBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价买入净价(最优)时间序列
    return w.wsd(security,"netbid_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBidRtBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价买入收益率(最优)时间序列
    return w.wsd(security,"bidrt_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNeTaskBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价卖出净价(最优)时间序列
    return w.wsd(security,"netask_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAskRtBstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价卖出收益率(最优)时间序列
    return w.wsd(security,"askrt_bst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQtVolMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报价总笔数时间序列
    return w.wsd(security,"qtvolm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间成交金额时间序列
    return w.wsd(security,"pq_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单位净值时间序列
    return w.wsd(security,"nav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundNavCurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单位净值币种时间序列
    return w.wsd(security,"fund_navcur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNav2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取单位净值(不前推)时间序列
    return w.wsd(security,"nav2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavUnitTransformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单位净值(支持转型基金)时间序列
    return w.wsd(security,"NAV_unit_transform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权单位净值时间序列
    return w.wsd(security,"NAV_adj",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdj2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权单位净值(不前推)时间序列
    return w.wsd(security,"NAV_adj2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAccSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计单位净值时间序列
    return w.wsd(security,"NAV_acc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAccumulatedTransformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计单位净值(支持转型基金)时间序列
    return w.wsd(security,"NAV_accumulated_transform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjustedTransformSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权单位净值(支持转型基金)时间序列
    return w.wsd(security,"NAV_adjusted_transform",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权单位净值增长时间序列
    return w.wsd(security,"NAV_adj_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAccChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计单位净值增长时间序列
    return w.wsd(security,"NAV_acc_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权单位净值增长率时间序列
    return w.wsd(security,"NAV_adj_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAccReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计单位净值增长率时间序列
    return w.wsd(security,"NAV_acc_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRelNavAdjReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取复权单位净值相对大盘增长率时间序列
    return w.wsd(security,"rel_NAV_adj_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjReturn1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期复权单位净值增长率时间序列
    return w.wsd(security,"NAV_adj_return1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavHighPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高单位净值时间序列
    return w.wsd(security,"NAV_high_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHighestNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高单位净值日时间序列
    return w.wsd(security,"fund_highestnav_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavLowPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低单位净值时间序列
    return w.wsd(security,"NAV_low_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundLowestNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低单位净值日时间序列
    return w.wsd(security,"fund_lowestnav_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjHighPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高复权单位净值时间序列
    return w.wsd(security,"NAV_adj_high_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHighestAdjNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高复权单位净值日时间序列
    return w.wsd(security,"fund_highestadjnav_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAdjLowPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低复权单位净值时间序列
    return w.wsd(security,"NAV_adj_low_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundLowestAdjNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低复权单位净值日时间序列
    return w.wsd(security,"fund_lowestadjnav_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAccHighPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高累计单位净值时间序列
    return w.wsd(security,"NAV_acc_high_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHighestAcCumNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高累计单位净值日时间序列
    return w.wsd(security,"fund_highestaccumnav_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavAccLowPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低累计单位净值时间序列
    return w.wsd(security,"NAV_acc_low_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundLowestAcCumNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低累计单位净值日时间序列
    return w.wsd(security,"fund_lowestaccumnav_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSiNavAdjReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自成立日起复权单位净值增长率时间序列
    return w.wsd(security,"SI_nav_adj_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavSellPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投连险卖出价时间序列
    return w.wsd(security,"NAV_sellprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最近基金净值日期时间序列
    return w.wsd(security,"NAV_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavExRightDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最新净值除权日时间序列
    return w.wsd(security,"NAV_exrightdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavPublishTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金净值公布类型时间序列
    return w.wsd(security,"NAV_publishtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavDivReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金分红净值增长率时间序列
    return w.wsd(security,"NAV_div_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavOverBenchReturnPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净值超越基准收益率时间序列
    return w.wsd(security,"NAV_over_bench_return_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavOverBenchReturnFrEqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净值超越基准收益频率时间序列
    return w.wsd(security,"NAV_over_bench_return_freq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavOverBenchReturnFrEq2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净值超越基准收益频率(百分比)时间序列
    return w.wsd(security,"NAV_over_bench_return_freq2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn1WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1周回报时间序列
    return w.wsd(security,"return_1w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking1WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1周回报排名时间序列
    return w.wsd(security,"periodreturnranking_1w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1月回报时间序列
    return w.wsd(security,"return_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1月回报排名时间序列
    return w.wsd(security,"periodreturnranking_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近3月回报时间序列
    return w.wsd(security,"return_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近3月回报排名时间序列
    return w.wsd(security,"periodreturnranking_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近6月回报时间序列
    return w.wsd(security,"return_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近6月回报排名时间序列
    return w.wsd(security,"periodreturnranking_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1年回报时间序列
    return w.wsd(security,"return_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近1年回报排名时间序列
    return w.wsd(security,"periodreturnranking_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn2YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近2年回报时间序列
    return w.wsd(security,"return_2y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking2YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近2年回报排名时间序列
    return w.wsd(security,"periodreturnranking_2y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近3年回报时间序列
    return w.wsd(security,"return_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近3年回报排名时间序列
    return w.wsd(security,"periodreturnranking_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近5年回报时间序列
    return w.wsd(security,"return_5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近5年回报排名时间序列
    return w.wsd(security,"periodreturnranking_5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturn10YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近10年回报时间序列
    return w.wsd(security,"return_10y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRanking10YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近10年回报排名时间序列
    return w.wsd(security,"periodreturnranking_10y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturnYTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取今年以来回报时间序列
    return w.wsd(security,"return_ytd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRankingYTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取今年以来回报排名时间序列
    return w.wsd(security,"periodreturnranking_ytd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturnStdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成立以来回报时间序列
    return w.wsd(security,"return_std",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturnMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单月度回报时间序列
    return w.wsd(security,"return_m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturnQSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度回报时间序列
    return w.wsd(security,"return_q",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReturnYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单年度回报时间序列
    return w.wsd(security,"return_y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodReturnRankingYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单年度回报排名时间序列
    return w.wsd(security,"periodreturnranking_y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerFundAvgReturnPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间平均收益率时间序列
    return w.wsd(security,"peer_fund_avg_return_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerFundReturnRankPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(字符串)时间序列
    return w.wsd(security,"peer_fund_return_rank_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerFundReturnRankPropPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(百分比)时间序列
    return w.wsd(security,"peer_fund_return_rank_prop_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerSamReturnRankPropPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(百分比)(券商集合理财)时间序列
    return w.wsd(security,"peer_SAM_return_rank_prop_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerHfReturnRankPropPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(百分比)(阳光私募)时间序列
    return w.wsd(security,"peer_HF_return_rank_prop_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerSamReturnRankPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(券商集合理财)时间序列
    return w.wsd(security,"peer_SAM_return_rank_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerHfReturnRankPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(阳光私募)时间序列
    return w.wsd(security,"peer_HF_return_rank_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeerHf2ReturnRankPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同类基金区间收益排名(阳光私募,投资策略)时间序列
    return w.wsd(security,"peer_HF2_return_rank_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期净值增长率时间序列
    return w.wsd(security,"NAV_return",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavStdDevReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期净值增长率标准差时间序列
    return w.wsd(security,"NAV_stddevreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavBenchDevReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期净值增长率减基准增长率时间序列
    return w.wsd(security,"NAV_benchdevreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavStdDevNavBenchSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期净值增长率减基准增长率标准差时间序列
    return w.wsd(security,"NAV_stddevnavbench",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFCarryOverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取份额结转方式时间序列
    return w.wsd(security,"mmf_carryover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFCarryOverDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取份额结转日期类型时间序列
    return w.wsd(security,"mmf_carryoverdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFAnnualIZedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取7日年化收益率时间序列
    return w.wsd(security,"mmf_annualizedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFAvgAnnualIZedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间7日年化收益率均值时间序列
    return w.wsd(security,"mmf_avgannualizedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFVarAnnualIZedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间7日年化收益率方差时间序列
    return w.wsd(security,"mmf_varannualizedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFUnitYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取万份基金单位收益时间序列
    return w.wsd(security,"mmf_unityield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFAvgUnitYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间万份基金单位收益均值时间序列
    return w.wsd(security,"mmf_avgunityield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFTotalUnitYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间万份基金单位收益总值时间序列
    return w.wsd(security,"mmf_totalunityield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMmFVarUnitYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间万份基金单位收益方差时间序列
    return w.wsd(security,"mmf_varunityield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDividendYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股息率(报告期)时间序列
    return w.wsd(security,"dividendyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDividendYield2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股息率(近12个月)时间序列
    return w.wsd(security,"dividendyield2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValDividendYield2IssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发布方股息率(近12个月)时间序列
    return w.wsd(security,"val_dividendyield2_issuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPep2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率百分位时间序列
    return w.wsd(security,"val_pep2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPePercentileSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率分位数时间序列
    return w.wsd(security,"val_pe_percentile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbPercentileSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市净率分位数时间序列
    return w.wsd(security,"val_pb_percentile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValDividendPercentileSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股息率分位数时间序列
    return w.wsd(security,"val_dividend_percentile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPsPercentileSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市销率分位数时间序列
    return w.wsd(security,"val_ps_percentile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPcfPercentileSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率分位数时间序列
    return w.wsd(security,"val_pcf_percentile",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTargetNpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权激励目标净利润时间序列
    return w.wsd(security,"targetnp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVolRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取量比时间序列
    return w.wsd(security,"vol_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiLoiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持买单量比上交易日增减时间序列
    return w.wsd(security,"oi_loic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiSOicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持卖单量比上交易日增减时间序列
    return w.wsd(security,"oi_soic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsSharesPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下有效报价申购量比例时间序列
    return w.wsd(security,"ipo_VSSharesPct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInvsSharesPctASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下高于有效报价上限的申购量比例时间序列
    return w.wsd(security,"ipo_InvSSharesPct_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHistoryLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近期创历史新低时间序列
    return w.wsd(security,"history_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHistoryLowDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近期创历史新低次数时间序列
    return w.wsd(security,"history_low_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStageHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近期创阶段新高时间序列
    return w.wsd(security,"stage_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHistoryHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近期创历史新高时间序列
    return w.wsd(security,"history_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHistoryHighDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近期创历史新高次数时间序列
    return w.wsd(security,"history_high_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStageLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近期创阶段新低时间序列
    return w.wsd(security,"stage_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUpDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取连涨天数时间序列
    return w.wsd(security,"up_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDownDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取连跌天数时间序列
    return w.wsd(security,"down_days",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBreakoutMaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向上有效突破均线时间序列
    return w.wsd(security,"breakout_ma",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBreakdownMaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向下有效突破均线时间序列
    return w.wsd(security,"breakdown_ma",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAnalStageHighNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成份创阶段新高数量时间序列
    return w.wsd(security,"techanal_stagehigh_num",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAnalStageLowNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成份创阶段新低数量时间序列
    return w.wsd(security,"techanal_stagelow_num",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBullBearMaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取均线多空头排列看涨看跌时间序列
    return w.wsd(security,"bull_bear_ma",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechUpNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数成份上涨数量时间序列
    return w.wsd(security,"tech_upnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDownNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数成份下跌数量时间序列
    return w.wsd(security,"tech_downnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechLimitUpNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数成份涨停数量时间序列
    return w.wsd(security,"tech_limitupnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechLimitDownNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数成份跌停数量时间序列
    return w.wsd(security,"tech_limitdownnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCompIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成份分红对指数影响时间序列
    return w.wsd(security,"div_compindex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnnualYeIlD100WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益率(年化,最近100周)时间序列
    return w.wsd(security,"annualyeild_100w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnnualYeIlD24MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益率(年化,最近24个月)时间序列
    return w.wsd(security,"annualyeild_24m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnnualYeIlD60MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益率(年化,最近60个月)时间序列
    return w.wsd(security,"annualyeild_60m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnnualStDeVr100WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化波动率(最近100周)时间序列
    return w.wsd(security,"annualstdevr_100w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnnualStDeVr24MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化波动率(最近24个月)时间序列
    return w.wsd(security,"annualstdevr_24m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnnualStDeVr60MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化波动率(最近60个月)时间序列
    return w.wsd(security,"annualstdevr_60m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益率时间序列
    return w.wsd(security,"avgreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAvgReturnYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益率(年化)时间序列
    return w.wsd(security,"avgreturny",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAvgReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益率_FUND时间序列
    return w.wsd(security,"risk_avgreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGemReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取几何平均收益率时间序列
    return w.wsd(security,"risk_gemreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank720Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_总计时间序列
    return w.wsd(security,"stmnote_bank_720",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank731Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_企业贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_731",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank732Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_个人贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_732",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank733Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_票据贴现时间序列
    return w.wsd(security,"stmnote_bank_733",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank734Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_个人住房贷款时间序列
    return w.wsd(security,"stmnote_bank_734",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank735Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_个人消费贷款时间序列
    return w.wsd(security,"stmnote_bank_735",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank736Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_信用卡应收账款时间序列
    return w.wsd(security,"stmnote_bank_736",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank737Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_经营性贷款时间序列
    return w.wsd(security,"stmnote_bank_737",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank738Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_汽车贷款时间序列
    return w.wsd(security,"stmnote_bank_738",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank739Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_其他个人贷款时间序列
    return w.wsd(security,"stmnote_bank_739",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank791Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_信用贷款时间序列
    return w.wsd(security,"stmnote_bank_791",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank792Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_保证贷款时间序列
    return w.wsd(security,"stmnote_bank_792",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank793Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_抵押贷款时间序列
    return w.wsd(security,"stmnote_bank_793",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank794Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_质押贷款时间序列
    return w.wsd(security,"stmnote_bank_794",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank47Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_短期贷款时间序列
    return w.wsd(security,"stmnote_bank_47",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank49Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均收益率_中长期贷款时间序列
    return w.wsd(security,"stmnote_bank_49",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnnualIntervalYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间收益率(年化)时间序列
    return w.wsd(security,"risk_annualintervalyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskMaxDownsideSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大回撤时间序列
    return w.wsd(security,"risk_maxdownside",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskMaxDownsideRecoverDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大回撤恢复天数时间序列
    return w.wsd(security,"risk_maxdownside_recoverdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgMaxDownsideSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大回撤同类平均时间序列
    return w.wsd(security,"risk_siml_avgmaxdownside",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskMaxDownsideDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大回撤区间日期时间序列
    return w.wsd(security,"risk_maxdownside_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerMaxDrawDownSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任期最大回撤时间序列
    return w.wsd(security,"fund_manager_maxdrawdown",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStDeVrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取波动率时间序列
    return w.wsd(security,"stdevr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStDeVrySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取波动率(年化)时间序列
    return w.wsd(security,"stdevry",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskStDevYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化波动率时间序列
    return w.wsd(security,"risk_stdevyearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgStDevYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化波动率同类平均时间序列
    return w.wsd(security,"risk_siml_avgstdevyearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVolumeVolatilitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易量波动率_PIT时间序列
    return w.wsd(security,"tech_volumevolatility",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImpliedVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转债隐含波动率时间序列
    return w.wsd(security,"impliedvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskVolatilityRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股与市场波动率比值_PIT时间序列
    return w.wsd(security,"risk_volatilityratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskReSidVol252Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取252日残差收益波动率_PIT时间序列
    return w.wsd(security,"risk_residvol252",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStDcOfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标准差系数时间序列
    return w.wsd(security,"stdcof",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskNonSYsRisk1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非系统风险时间序列
    return w.wsd(security,"risk_nonsysrisk1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskNonSYsRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非系统风险_FUND时间序列
    return w.wsd(security,"risk_nonsysrisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余期限(天)时间序列
    return w.wsd(security,"day",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPtMYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余期限(年)时间序列
    return w.wsd(security,"ptmyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTermIfExerciseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权剩余期限(年)时间序列
    return w.wsd(security,"termifexercise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTermNoteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特殊剩余期限说明时间序列
    return w.wsd(security,"termnote",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTermNote1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取特殊剩余期限时间序列
    return w.wsd(security,"termnote1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightedRtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权剩余期限(按本息)时间序列
    return w.wsd(security,"weightedrt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWeightedRt2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权剩余期限(按本金)时间序列
    return w.wsd(security,"weightedrt2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccruedInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应计利息时间序列
    return w.wsd(security,"accruedinterest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcAccRIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日应计利息时间序列
    return w.wsd(security,"calc_accrint",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccruedDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已计息天数时间序列
    return w.wsd(security,"accrueddays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalPreCupNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上一付息日时间序列
    return w.wsd(security,"anal_precupn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNxcUpnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下一付息日时间序列
    return w.wsd(security,"nxcupn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNxcUpnDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下一付息日久期时间序列
    return w.wsd(security,"nxcupn_duration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNxcUpn2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取距下一付息日天数时间序列
    return w.wsd(security,"nxcupn2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqSuspendStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期停牌起始日时间序列
    return w.wsd(security,"pq_suspendstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPqSuspendEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期停牌截止日时间序列
    return w.wsd(security,"pq_suspendenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYTMBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收盘到期收益率时间序列
    return w.wsd(security,"ytm_b",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYTcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赎回收益率时间序列
    return w.wsd(security,"ytc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYTPSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回售收益率时间序列
    return w.wsd(security,"ytp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准久期时间序列
    return w.wsd(security,"bduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBDurationIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权基准久期时间序列
    return w.wsd(security,"Bduration_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利差久期时间序列
    return w.wsd(security,"sduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSDurationIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权利差久期时间序列
    return w.wsd(security,"Sduration_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDailyCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日现金流时间序列
    return w.wsd(security,"dailycf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDailyCfIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日利息现金流时间序列
    return w.wsd(security,"dailycf_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDailyCfPrInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指定日本金现金流时间序列
    return w.wsd(security,"dailycf_prin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRCyTmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取票面调整收益率时间序列
    return w.wsd(security,"RCYTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcAdjYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价格算票面调整收益率时间序列
    return w.wsd(security,"calc_adjyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNxOptionDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下一行权日时间序列
    return w.wsd(security,"nxoptiondate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYTMIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权收益率时间序列
    return w.wsd(security,"YTM_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDurationIfExerciseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权久期时间序列
    return w.wsd(security,"durationifexercise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getModiDurationIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权修正久期时间序列
    return w.wsd(security,"modiduration_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConvexityIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权凸性时间序列
    return w.wsd(security,"convexity_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBConvexityIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权基准凸性时间序列
    return w.wsd(security,"Bconvexity_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSConvexityIfExeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取行权利差凸性时间序列
    return w.wsd(security,"Sconvexity_ifexe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取1月久期时间序列
    return w.wsd(security,"duration_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取3月久期时间序列
    return w.wsd(security,"duration_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取6月久期时间序列
    return w.wsd(security,"duration_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取1年久期时间序列
    return w.wsd(security,"duration_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration2YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取2年久期时间序列
    return w.wsd(security,"duration_2y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取3年久期时间序列
    return w.wsd(security,"duration_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration4YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取4年久期时间序列
    return w.wsd(security,"duration_4y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取5年久期时间序列
    return w.wsd(security,"duration_5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration15YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取15年久期时间序列
    return w.wsd(security,"duration_15y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration7YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取7年久期时间序列
    return w.wsd(security,"duration_7y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration9YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取9年久期时间序列
    return w.wsd(security,"duration_9y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration10YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取10年久期时间序列
    return w.wsd(security,"duration_10y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration20YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取20年久期时间序列
    return w.wsd(security,"duration_20y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDuration30YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取30年久期时间序列
    return w.wsd(security,"duration_30y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDurationShortSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短边久期时间序列
    return w.wsd(security,"duration_short",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDurationLongSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长边久期时间序列
    return w.wsd(security,"duration_long",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期收益率时间序列
    return w.wsd(security,"curyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYTMCbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取纯债到期收益率时间序列
    return w.wsd(security,"ytm_cb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStrBValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取纯债价值时间序列
    return w.wsd(security,"strbvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStrBPremiumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取纯债溢价时间序列
    return w.wsd(security,"strbpremium",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStrBPremiumRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取纯债溢价率时间序列
    return w.wsd(security,"strbpremiumratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股价时间序列
    return w.wsd(security,"convprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股比例时间序列
    return w.wsd(security,"convratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转换价值时间序列
    return w.wsd(security,"convvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVPremiumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股溢价时间序列
    return w.wsd(security,"convpremium",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVPremiumRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股溢价率时间序列
    return w.wsd(security,"convpremiumratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVpESeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股市盈率时间序列
    return w.wsd(security,"convpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVpBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股市净率时间序列
    return w.wsd(security,"convpb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingPeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股市盈率时间序列
    return w.wsd(security,"underlyingpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingPbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取正股市净率时间序列
    return w.wsd(security,"underlyingpb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDiluteRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转股稀释率时间序列
    return w.wsd(security,"diluterate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLDiluteRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对流通股稀释率时间序列
    return w.wsd(security,"ldiluterate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDoubleLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取双低时间序列
    return w.wsd(security,"doublelow",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfCVf2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取转换因子时间序列
    return w.wsd(security,"tbf_cvf2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfCVfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转换因子(指定合约)时间序列
    return w.wsd(security,"tbf_cvf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfCVf3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取转换因子(主力合约)时间序列
    return w.wsd(security,"tbf_cvf3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交割利息时间序列
    return w.wsd(security,"tbf_interest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfPaymentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间利息时间序列
    return w.wsd(security,"tbf_payment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfDeliverPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交割成本时间序列
    return w.wsd(security,"tbf_deliverprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfInvoicePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发票价格时间序列
    return w.wsd(security,"tbf_invoiceprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfSpreadSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期现价差时间序列
    return w.wsd(security,"tbf_spread",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfBasisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基差时间序列
    return w.wsd(security,"tbf_basis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIfBasisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基差(股指期货)时间序列
    return w.wsd(security,"if_basis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalBasisAnnualYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基差年化收益率(股指期货)时间序列
    return w.wsd(security,"anal_basisannualyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalBasisPercentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基差率(股指期货)时间序列
    return w.wsd(security,"anal_basispercent",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalBasisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基差(商品期货)时间序列
    return w.wsd(security,"anal_basis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalBasisPercent2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基差率(商品期货)时间序列
    return w.wsd(security,"anal_basispercent2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfNetBasisSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净基差时间序列
    return w.wsd(security,"tbf_netbasis",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfFyTmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取远期收益率时间序列
    return w.wsd(security,"tbf_FYTM",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcCleanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全价算净价时间序列
    return w.wsd(security,"calc_clean",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcDirtySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净价算全价时间序列
    return w.wsd(security,"calc_dirty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取麦考利久期时间序列
    return w.wsd(security,"calc_duration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcMDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取修正久期时间序列
    return w.wsd(security,"calc_mduration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcConVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取凸性时间序列
    return w.wsd(security,"calc_conv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYCCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对应到期收益率曲线代码时间序列
    return w.wsd(security,"YCCode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcChinaBondSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益率曲线(中债样本券)时间序列
    return w.wsd(security,"calc_chinabond",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiSharpe3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券3年评级(夏普比率)时间序列
    return w.wsd(security,"rating_shanghaisharpe3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiTiming3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券3年评级(择时能力)时间序列
    return w.wsd(security,"rating_shanghaitiming3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiStocking3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券3年评级(选证能力)时间序列
    return w.wsd(security,"rating_shanghaistocking3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiSharpe5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券5年评级(夏普比率)时间序列
    return w.wsd(security,"rating_shanghaisharpe5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiTiming5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券5年评级(择时能力)时间序列
    return w.wsd(security,"rating_shanghaitiming5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingShanghaiStocking5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上海证券5年评级(选证能力)时间序列
    return w.wsd(security,"rating_shanghaistocking5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRating3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金3年评级时间序列
    return w.wsd(security,"rating_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRating5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金5年评级时间序列
    return w.wsd(security,"rating_5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskReturnYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化收益率时间序列
    return w.wsd(security,"risk_returnyearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskReturnYearlyTradeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化收益率(工作日)时间序列
    return w.wsd(security,"risk_returnyearly_tradedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerGeometricAnnualIZedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取几何平均年化收益率时间序列
    return w.wsd(security,"fund_manager_geometricannualizedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerArithmeticAnnualIZedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取算术平均年化收益率时间序列
    return w.wsd(security,"fund_manager_arithmeticannualizedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerGeometricAvgAnnualYieldOverBenchSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取超越基准几何平均年化收益率时间序列
    return w.wsd(security,"fund_manager_geometricavgannualyieldoverbench",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerArithmeticAvgAnnualYieldOverBenchSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取超越基准算术平均年化收益率时间序列
    return w.wsd(security,"fund_manager_arithmeticavgannualyieldoverbench",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskNavOverBenchAnnualReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间净值超越基准年化收益率时间序列
    return w.wsd(security,"risk_navoverbenchannualreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnnualIntervalYieldTradeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间收益率(工作日年化)时间序列
    return w.wsd(security,"risk_annualintervalyield_tradedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAvgRiskReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均风险收益率时间序列
    return w.wsd(security,"risk_avgriskreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGemAvgRiskReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取几何平均风险收益率时间序列
    return w.wsd(security,"risk_gemavgriskreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTrackDeviationTrackIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取日跟踪偏离度(跟踪指数)时间序列
    return w.wsd(security,"risk_trackdeviation_trackindex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAvgTrackDeviationBenchmarkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间跟踪偏离度均值(业绩基准)时间序列
    return w.wsd(security,"risk_avgtrackdeviation_benchmark",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAvgTrackDeviationTrackIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间跟踪偏离度均值(跟踪指数)时间序列
    return w.wsd(security,"risk_avgtrackdeviation_trackindex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskDownsideSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回撤(相对前期高点)时间序列
    return w.wsd(security,"risk_downside",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskMaxUpsideSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大上涨时间序列
    return w.wsd(security,"risk_maxupside",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskCorreCoefficientSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相关系数时间序列
    return w.wsd(security,"risk_correcoefficient",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskCorreCoefficientTrackIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相关系数(跟踪指数)时间序列
    return w.wsd(security,"risk_correcoefficient_trackindex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDdNcrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下跌相关系数_PIT时间序列
    return w.wsd(security,"tech_ddncr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskHisRelationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股与市场相关系数_PIT时间序列
    return w.wsd(security,"risk_hisrelation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskR2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可决系数时间序列
    return w.wsd(security,"risk_r2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskStDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益标准差时间序列
    return w.wsd(security,"risk_stdev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnnUstDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益标准差(年化)时间序列
    return w.wsd(security,"risk_annustdev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskExStDev252Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取252日超额收益标准差_PIT时间序列
    return w.wsd(security,"risk_exstdev252",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskDownsideStDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下行标准差时间序列
    return w.wsd(security,"risk_downsidestdev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskUpsideStDevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上行标准差时间序列
    return w.wsd(security,"risk_upsidestdev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskDownsideRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下行风险时间序列
    return w.wsd(security,"risk_downsiderisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgDownsideRiskSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下行风险同类平均时间序列
    return w.wsd(security,"risk_siml_avgdownsiderisk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWinRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间胜率时间序列
    return w.wsd(security,"win_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskDurationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金组合久期时间序列
    return w.wsd(security,"risk_duration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskInterestSensitivitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场利率敏感性时间序列
    return w.wsd(security,"risk_interestsensitivity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取选时能力时间序列
    return w.wsd(security,"risk_time",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskStockSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取选股能力时间序列
    return w.wsd(security,"risk_stock",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTrackErrorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪误差时间序列
    return w.wsd(security,"risk_trackerror",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTrackErrorTrackIndexSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪误差(跟踪指数)时间序列
    return w.wsd(security,"risk_trackerror_trackindex",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnNuTrackErrorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跟踪误差(年化)时间序列
    return w.wsd(security,"risk_annutrackerror",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskInfoRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信息比率时间序列
    return w.wsd(security,"risk_inforatio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnNuInfoRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信息比率(年化)时间序列
    return w.wsd(security,"risk_annuinforatio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleStyleCoefficientSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取风格系数时间序列
    return w.wsd(security,"style_stylecoefficient",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleStyleAttributeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取风格属性时间序列
    return w.wsd(security,"style_styleattribute",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleMarketValueStyleAttributeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市值-风格属性时间序列
    return w.wsd(security,"style_marketvaluestyleattribute",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleMarketValueAttributeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市值属性时间序列
    return w.wsd(security,"style_marketvalueattribute",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleAveragePositionTimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均持仓时间时间序列
    return w.wsd(security,"style_averagepositiontime",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleHyAveragePositionTimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均持仓时间(半年)时间序列
    return w.wsd(security,"style_hy_averagepositiontime",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleInvConcentrationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资集中度时间序列
    return w.wsd(security,"style_invconcentration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleComMisAccountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取佣金规模比时间序列
    return w.wsd(security,"style_commisaccount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteHighestMonthlyReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高单月回报时间序列
    return w.wsd(security,"absolute_highestmonthlyreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteLowestMonthlyReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低单月回报时间序列
    return w.wsd(security,"absolute_lowestmonthlyreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteSimLAvgLowestMonthlyReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低单月回报同类平均时间序列
    return w.wsd(security,"absolute_siml_avglowestmonthlyreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteConUpsMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取连涨月数时间序列
    return w.wsd(security,"absolute_conupsmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteCondOwnsMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取连跌月数时间序列
    return w.wsd(security,"absolute_condownsmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteLongestConUpMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最长连续上涨月数时间序列
    return w.wsd(security,"absolute_longestconupmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteMaxIncreaseOfUpMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最长连续上涨整月涨幅时间序列
    return w.wsd(security,"absolute_maxincreaseofupmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteLongestConDownMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最长连续下跌月数时间序列
    return w.wsd(security,"absolute_longestcondownmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteMaxFallOfDownMonthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最长连续下跌整月跌幅时间序列
    return w.wsd(security,"absolute_maxfallofdownmonth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteUpDownMonthRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上涨/下跌月数比时间序列
    return w.wsd(security,"absolute_updownmonthratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteProfitMonthPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取盈利百分比时间序列
    return w.wsd(security,"absolute_profitmonthper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteProfitPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间盈利百分比时间序列
    return w.wsd(security,"absolute_profitper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteAvgIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均收益时间序列
    return w.wsd(security,"absolute_avgincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaPtToMvAvg5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取5年平均收益市值比_PIT时间序列
    return w.wsd(security,"fa_pttomvavg5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteAvgLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均损失时间序列
    return w.wsd(security,"absolute_avgloss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskEspaRamSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取参数平均损失值ES时间序列
    return w.wsd(security,"risk_esparam",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskEsHistoricalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历史平均损失值ES时间序列
    return w.wsd(security,"risk_eshistorical",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteMonthlyCompositeReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取月度复合回报时间序列
    return w.wsd(security,"absolute_monthlycompositereturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteAvgMonthlyReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均月度回报时间序列
    return w.wsd(security,"absolute_avgmonthlyreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteHighestQuatreTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高季度回报时间序列
    return w.wsd(security,"absolute_highestquatreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsoluteLowestQuatreTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低季度回报时间序列
    return w.wsd(security,"absolute_lowestquatreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundDaysToConversionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剩余折算天数时间序列
    return w.wsd(security,"fund_daystoconversion",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalSMfEarningSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分级基金收益分配方式时间序列
    return w.wsd(security,"anal_smfearning",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalImpliedYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取隐含收益率时间序列
    return w.wsd(security,"anal_impliedyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalTDiscountRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取整体折溢价率时间序列
    return w.wsd(security,"anal_tdiscountratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalDIsRatioDeviSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取折溢价比率偏离系数时间序列
    return w.wsd(security,"anal_disratiodevi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalNavLeverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净值杠杆时间序列
    return w.wsd(security,"anal_navlever",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalPriceLeverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价格杠杆时间序列
    return w.wsd(security,"anal_pricelever",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalSmFbNamedCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取名义资金成本时间序列
    return w.wsd(security,"anal_smfbnamedcost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalSmFbFactualCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际资金成本时间序列
    return w.wsd(security,"anal_smfbfactualcost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalNextDiscountDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下一定期折算日时间序列
    return w.wsd(security,"anal_nextdiscountdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundAgreedAnNuYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期约定年收益率时间序列
    return w.wsd(security,"fund_agreedannuyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalNextAAYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下期约定年收益率时间序列
    return w.wsd(security,"anal_nextaayield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalUpDiscountThresholdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上折阈值时间序列
    return w.wsd(security,"anal_updiscount_threshold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalDownDiscountThresholdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下折阈值时间序列
    return w.wsd(security,"anal_downdiscount_threshold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalUpDiscountPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上折母基金需涨时间序列
    return w.wsd(security,"anal_updiscount_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalDownDiscountPctChangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下折母基金需跌时间序列
    return w.wsd(security,"anal_downdiscount_pctchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiLoiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持买单量时间序列
    return w.wsd(security,"oi_loi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiLvOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持买单量(品种)时间序列
    return w.wsd(security,"oi_lvoi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiLNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持买单量进榜会员名称时间序列
    return w.wsd(security,"oi_lname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiLvNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持买单量(品种)会员名称时间序列
    return w.wsd(security,"oi_lvname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiSoISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持卖单量时间序列
    return w.wsd(security,"oi_soi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiSvOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持卖单量(品种)时间序列
    return w.wsd(security,"oi_svoi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiSNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持卖单量进榜会员名称时间序列
    return w.wsd(security,"oi_sname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiSvNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持卖单量(品种)会员名称时间序列
    return w.wsd(security,"oi_svname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOiNvOiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净持仓(品种)时间序列
    return w.wsd(security,"oi_nvoi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业总收入时间序列
    return w.wsd(security,"grps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrpS2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_grps2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaGrpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业总收入_PIT时间序列
    return w.wsd(security,"fa_grps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOrPsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业收入(TTM)_PIT时间序列
    return w.wsd(security,"orps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOrPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业收入时间序列
    return w.wsd(security,"orps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOrPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业收入_GSD时间序列
    return w.wsd(security,"wgsd_orps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOrPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业收入_PIT时间序列
    return w.wsd(security,"fa_orps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSurplusCapitalPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股资本公积时间序列
    return w.wsd(security,"surpluscapitalps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCapSurPpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股资本公积_PIT时间序列
    return w.wsd(security,"fa_capsurpps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSurplusReservePsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股盈余公积时间序列
    return w.wsd(security,"surplusreserveps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSppSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股盈余公积_PIT时间序列
    return w.wsd(security,"fa_spps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnDistributedPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股未分配利润时间序列
    return w.wsd(security,"undistributedps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaUnDistributedPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股未分配利润_PIT时间序列
    return w.wsd(security,"fa_undistributedps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRetainedPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股留存收益时间序列
    return w.wsd(security,"retainedps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRetainedPs2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股留存收益_GSD时间序列
    return w.wsd(security,"wgsd_retainedps2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRetainedPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股留存收益_PIT时间序列
    return w.wsd(security,"fa_retainedps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股息税前利润时间序列
    return w.wsd(security,"ebitps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItPs2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股息税前利润_GSD时间序列
    return w.wsd(security,"wgsd_ebitps2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化净资产收益率时间序列
    return w.wsd(security,"roe_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoa2YearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化总资产报酬率时间序列
    return w.wsd(security,"roa2_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoaYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年化总资产净利率时间序列
    return w.wsd(security,"roa_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售净利率时间序列
    return w.wsd(security,"netprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitMarginTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售净利率(TTM)时间序列
    return w.wsd(security,"netprofitmargin_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售净利率_GSD时间序列
    return w.wsd(security,"wgsd_netprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitMarginTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售净利率(TTM)_GSD时间序列
    return w.wsd(security,"netprofitmargin_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetProfitMarginTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售净利率(TTM)_PIT时间序列
    return w.wsd(security,"fa_netprofitmargin_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitMarginTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售净利率(TTM,只有最新数据)时间序列
    return w.wsd(security,"netprofitmargin_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitMarginDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣非后销售净利率时间序列
    return w.wsd(security,"netprofitmargin_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售净利率时间序列
    return w.wsd(security,"qfa_netprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNetProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售净利率_GSD时间序列
    return w.wsd(security,"wgsd_qfa_netprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率时间序列
    return w.wsd(security,"grossprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossProfitMarginTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率(TTM)时间序列
    return w.wsd(security,"grossprofitmargin_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrossProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率_GSD时间序列
    return w.wsd(security,"wgsd_grossprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossProfitMarginTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率(TTM)_GSD时间序列
    return w.wsd(security,"grossprofitmargin_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaGrossProfitMarginTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率(TTM)_PIT时间序列
    return w.wsd(security,"fa_grossprofitmargin_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossProfitMarginTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售毛利率(TTM,只有最新数据)时间序列
    return w.wsd(security,"grossprofitmargin_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgGmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测销售毛利率(GM)平均值(可选类型)时间序列
    return w.wsd(security,"west_avggm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxGmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测销售毛利率(GM)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxgm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMingMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测销售毛利率(GM)最小值(可选类型)时间序列
    return w.wsd(security,"west_mingm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMediaGmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测销售毛利率(GM)中值(可选类型)时间序列
    return w.wsd(security,"west_mediagm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdGmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测销售毛利率(GM)标准差值(可选类型)时间序列
    return w.wsd(security,"west_stdgm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaGrossProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售毛利率时间序列
    return w.wsd(security,"qfa_grossprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaGrossProfitMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售毛利率_GSD时间序列
    return w.wsd(security,"wgsd_qfa_grossprofitmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCogsToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售成本率时间序列
    return w.wsd(security,"cogstosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCogsToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售成本率_GSD时间序列
    return w.wsd(security,"wgsd_cogstosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSalesToCostTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售成本率(TTM)_PIT时间序列
    return w.wsd(security,"fa_salestocost_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNpToCostExpenseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成本费用利润率时间序列
    return w.wsd(security,"nptocostexpense",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaProtoCostTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成本费用利润率(TTM)_PIT时间序列
    return w.wsd(security,"fa_protocost_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNpToCostExpenseQfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.成本费用利润率时间序列
    return w.wsd(security,"nptocostexpense_qfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售期间费用率时间序列
    return w.wsd(security,"expensetosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseToSalesTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售期间费用率(TTM)时间序列
    return w.wsd(security,"expensetosales_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseToSalesTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售期间费用率(TTM)_GSD时间序列
    return w.wsd(security,"expensetosales_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaExpenseToSalesTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售期间费用率(TTM)_PIT时间序列
    return w.wsd(security,"fa_expensetosales_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseToSalesTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售期间费用率(TTM,只有最新数据)时间序列
    return w.wsd(security,"expensetosales_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营业务比率时间序列
    return w.wsd(security,"optoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToEBTQfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.主营业务比率时间序列
    return w.wsd(security,"optoebt_qfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/营业总收入时间序列
    return w.wsd(security,"profittogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/营业总收入(TTM)时间序列
    return w.wsd(security,"profittogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontNpToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_dupont_nptosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitToGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"profittogr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaProfitToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_profittogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"profittogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaProfitToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润/营业总收入时间序列
    return w.wsd(security,"qfa_profittogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业总收入时间序列
    return w.wsd(security,"optogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业总收入(TTM)时间序列
    return w.wsd(security,"optogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOpToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_optogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"optogr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOpToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_optogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"optogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOpToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业利润/营业总收入时间序列
    return w.wsd(security,"qfa_optogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润/营业总收入时间序列
    return w.wsd(security,"ebittogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontEbItToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_dupont_ebittosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbItToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_ebittogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本/营业总收入时间序列
    return w.wsd(security,"gctogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本/营业总收入(TTM)时间序列
    return w.wsd(security,"gctogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGcToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_gctogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcToGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本/营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"gctogr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOctoGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_octogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"gctogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaGcToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业总成本/营业总收入时间序列
    return w.wsd(security,"qfa_gctogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用/营业总收入时间序列
    return w.wsd(security,"operateexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用/营业总收入(TTM)时间序列
    return w.wsd(security,"operateexpensetogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOperateExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_operateexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseToGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用/营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"operateexpensetogr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSellExpenseToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_sellexpensetogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"operateexpensetogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSaleExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售费用/营业总收入时间序列
    return w.wsd(security,"qfa_saleexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用/营业总收入时间序列
    return w.wsd(security,"adminexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用/营业总收入(TTM)时间序列
    return w.wsd(security,"adminexpensetogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAdminExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_adminexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseToGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用/营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"adminexpensetogr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaAdminExpenseToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_adminexpensetogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"adminexpensetogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaAdminExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.管理费用/营业总收入时间序列
    return w.wsd(security,"qfa_adminexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用/营业总收入时间序列
    return w.wsd(security,"finaexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseToGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用/营业总收入(TTM)时间序列
    return w.wsd(security,"finaexpensetogr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFinaExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_finaexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseToGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用/营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"finaexpensetogr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFinaExpenseToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用/营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_finaexpensetogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseToGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用/营业总收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"finaexpensetogr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaFinaExpenseToGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.财务费用/营业总收入时间序列
    return w.wsd(security,"qfa_finaexpensetogr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额时间序列
    return w.wsd(security,"operateincometoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeToEBTTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额(TTM)时间序列
    return w.wsd(security,"operateincometoebt_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOperateIncomeToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额_GSD时间序列
    return w.wsd(security,"wgsd_operateincometoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeToEBTTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额(TTM)_GSD时间序列
    return w.wsd(security,"operateincometoebt_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOperIncomeToPbtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额_PIT时间序列
    return w.wsd(security,"fa_operincometopbt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOperIncomeToPbtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_operincometopbt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeToEBTTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益/利润总额(TTM,只有最新数据)时间序列
    return w.wsd(security,"operateincometoebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOperateIncomeToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动净收益/利润总额时间序列
    return w.wsd(security,"qfa_operateincometoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益/利润总额时间序列
    return w.wsd(security,"investincometoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeToEBTTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益/利润总额(TTM)时间序列
    return w.wsd(security,"investincometoebt_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestIncomeToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益/利润总额_GSD时间序列
    return w.wsd(security,"wgsd_investincometoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeToEBTTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益/利润总额(TTM)_GSD时间序列
    return w.wsd(security,"investincometoebt_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaChgValueToPbtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益/利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_chgvaluetopbt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeToEBTTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益/利润总额(TTM,只有最新数据)时间序列
    return w.wsd(security,"investincometoebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInvestIncomeToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.价值变动净收益/利润总额时间序列
    return w.wsd(security,"qfa_investincometoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperateProfitToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额/利润总额时间序列
    return w.wsd(security,"nonoperateprofittoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperateProfitToEBTTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额/利润总额(TTM)时间序列
    return w.wsd(security,"nonoperateprofittoebt_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNonOperateProfitToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额/利润总额_GSD时间序列
    return w.wsd(security,"wgsd_nonoperateprofittoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperateProfitToEBTTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额/利润总额(TTM)_GSD时间序列
    return w.wsd(security,"nonoperateprofittoebt_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNonOperProfitToPbtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额/利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_nonoperprofittopbt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperateProfitToEBTTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额/利润总额(TTM,只有最新数据)时间序列
    return w.wsd(security,"nonoperateprofittoebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedProfitToProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常损益后的净利润/净利润时间序列
    return w.wsd(security,"deductedprofittoprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDeductedProfitToProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常损益后的净利润/净利润_GSD时间序列
    return w.wsd(security,"wgsd_deductedprofittoprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDeductedProfitToProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.扣除非经常损益后的净利润/净利润时间序列
    return w.wsd(security,"qfa_deductedprofittoprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSalesCashIntoOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金/营业收入时间序列
    return w.wsd(security,"salescashintoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSalesCashIntoOrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金/营业收入(TTM)时间序列
    return w.wsd(security,"salescashintoor_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSalesCashToOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金/营业收入_PIT时间序列
    return w.wsd(security,"fa_salescashtoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSalesCashToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金/营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_salescashtoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSalesCashIntoOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金/营业收入(TTM,只有最新数据)时间序列
    return w.wsd(security,"salescashintoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSalesCashIntoOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售商品提供劳务收到的现金/营业收入时间序列
    return w.wsd(security,"qfa_salescashintoor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetProfitCashCoverSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润现金含量时间序列
    return w.wsd(security,"fa_netprofitcashcover",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCapitalizedTodaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本支出/折旧和摊销时间序列
    return w.wsd(security,"capitalizedtoda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCapitalizedTodaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本支出/折旧和摊销_GSD时间序列
    return w.wsd(security,"wgsd_capitalizedtoda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营性现金净流量/营业总收入时间序列
    return w.wsd(security,"ocftosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToInvestStockDividendSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金满足投资比率时间序列
    return w.wsd(security,"ocftoinveststockdividend",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToOpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金营运指数时间序列
    return w.wsd(security,"ocftoop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全部资产现金回收率时间序列
    return w.wsd(security,"ocftoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToDividendSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金股利保障倍数时间序列
    return w.wsd(security,"ocftodividend",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCashDivCoverTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金股利保障倍数(TTM)_PIT时间序列
    return w.wsd(security,"fa_cashdivcover_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDebtToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产负债率时间序列
    return w.wsd(security,"debttoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDebtToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产负债率_GSD时间序列
    return w.wsd(security,"wgsd_debttoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDebtToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产负债率_PIT时间序列
    return w.wsd(security,"fa_debttoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDebtToEqYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产负债率时间序列
    return w.wsd(security,"fa_debttoeqy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAnnouncedDeductedDebtToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剔除预收账款的资产负债率(公告值)_GSD时间序列
    return w.wsd(security,"wgsd_announceddeducteddebttoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedDebtToAssets2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取剔除预收款项后的资产负债率时间序列
    return w.wsd(security,"deducteddebttoassets2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeductedDebtToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剔除预收款项后的资产负债率(公告口径)时间序列
    return w.wsd(security,"deducteddebttoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDeductedDebtToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取剔除预收账款后的资产负债率_GSD时间序列
    return w.wsd(security,"wgsd_deducteddebttoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongDebtToLongCaptIAlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期资本负债率时间序列
    return w.wsd(security,"longdebttolongcaptial",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongCapitalToInvestmentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期资产适合率时间序列
    return w.wsd(security,"longcapitaltoinvestment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetsToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益乘数时间序列
    return w.wsd(security,"assetstoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益乘数_GSD时间序列
    return w.wsd(security,"wgsd_assetstoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益比时间序列
    return w.wsd(security,"equity_to_asset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEquityAssetRadioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益比率_PIT时间序列
    return w.wsd(security,"fa_equityassetradio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCatoAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产/总资产时间序列
    return w.wsd(security,"catoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCatoAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产/总资产_GSD时间序列
    return w.wsd(security,"wgsd_catoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNcaToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产/总资产时间序列
    return w.wsd(security,"ncatoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNcaToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产/总资产_GSD时间序列
    return w.wsd(security,"wgsd_ncatoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurrentDebtToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债权益比率时间序列
    return w.wsd(security,"currentdebttoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongDebtToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债权益比率时间序列
    return w.wsd(security,"longdebttoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTangibleAssetsToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/总资产时间序列
    return w.wsd(security,"tangibleassetstoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTangibleAssetsToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/总资产_GSD时间序列
    return w.wsd(security,"wgsd_tangibleassetstoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityToTotalCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/全部投入资本时间序列
    return w.wsd(security,"equitytototalcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntDebtToTotalCapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务/全部投入资本时间序列
    return w.wsd(security,"intdebttototalcap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInterestDebtToTotalCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务/全部投入资本_GSD时间序列
    return w.wsd(security,"wgsd_interestdebttototalcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInterestDebtToCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务/全部投入资本_PIT时间序列
    return w.wsd(security,"fa_interestdebttocapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurrentDebtToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债/负债合计时间序列
    return w.wsd(security,"currentdebttodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCurrentDebtToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_currentdebttodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongDebToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债/负债合计时间序列
    return w.wsd(security,"longdebtodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLongDebToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_longdebtodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNcaToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本固定化比率时间序列
    return w.wsd(security,"ncatoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIbDebtRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有息负债率时间序列
    return w.wsd(security,"ibdebtratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动比率时间序列
    return w.wsd(security,"current",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动比率_GSD时间序列
    return w.wsd(security,"wgsd_current",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动比率_PIT时间序列
    return w.wsd(security,"fa_current",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQuickSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取速动比率时间序列
    return w.wsd(security,"quick",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQuickSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取速动比率_GSD时间序列
    return w.wsd(security,"wgsd_quick",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaQuickSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取速动比率_PIT时间序列
    return w.wsd(security,"fa_quick",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSuperQuickSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取超速动比率_PIT时间序列
    return w.wsd(security,"fa_superquick",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保守速动比率时间序列
    return w.wsd(security,"cashratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCashRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保守速动比率_GSD时间序列
    return w.wsd(security,"wgsd_cashratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashToCurrentDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金比率时间序列
    return w.wsd(security,"cashtocurrentdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOCFToQuickDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金到期债务比时间序列
    return w.wsd(security,"ocftoquickdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDebtToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取产权比率时间序列
    return w.wsd(security,"debttoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDebtToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取产权比率_GSD时间序列
    return w.wsd(security,"wgsd_debttoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDebtToEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取产权比率_PIT时间序列
    return w.wsd(security,"fa_debttoequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetDebtRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净负债率时间序列
    return w.wsd(security,"fa_netdebtratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetDebtRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净负债率_GSD时间序列
    return w.wsd(security,"wgsd_netdebtratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetDebtRatioArdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净负债率(公告值)_GSD时间序列
    return w.wsd(security,"wgsd_netdebtratio_ard",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/负债合计时间序列
    return w.wsd(security,"equitytodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEquityToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_equitytodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/带息债务时间序列
    return w.wsd(security,"equitytointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEquityToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/带息债务_GSD时间序列
    return w.wsd(security,"wgsd_equitytointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEquityToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/带息债务_PIT时间序列
    return w.wsd(security,"fa_equitytointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTangibleAssetToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/负债合计时间序列
    return w.wsd(security,"tangibleassettodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTangibleAssetToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_tangibleassettodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTangAssetToIntDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/带息债务时间序列
    return w.wsd(security,"tangassettointdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTangibleAssetToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/带息债务_GSD时间序列
    return w.wsd(security,"wgsd_tangibleassettointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTangibleAssetToNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/净债务时间序列
    return w.wsd(security,"tangibleassettonetdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTangibleAssetToNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产/净债务_GSD时间序列
    return w.wsd(security,"wgsd_tangibleassettonetdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDebtToTangibleEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形净值债务率时间序列
    return w.wsd(security,"debttotangibleequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDebtToTangibleAFyBlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形净值债务率_PIT时间序列
    return w.wsd(security,"fa_debttotangibleafybl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDatoDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税折旧摊销前利润/负债合计时间序列
    return w.wsd(security,"ebitdatodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItDatoDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税折旧摊销前利润/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_ebitdatodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOcFicFToCurrentDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非筹资性现金净流量与流动负债的比率时间序列
    return w.wsd(security,"ocficftocurrentdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOcFicFToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非筹资性现金净流量与负债总额的比率时间序列
    return w.wsd(security,"ocficftodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongDebtToWorkingCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期债务与营运资金比率时间序列
    return w.wsd(security,"longdebttoworkingcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLongDebtToWorkingCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期债务与营运资金比率_GSD时间序列
    return w.wsd(security,"wgsd_longdebttoworkingcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongDebtToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期负债占比时间序列
    return w.wsd(security,"longdebttodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetDebtToEvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净债务/股权价值时间序列
    return w.wsd(security,"netdebttoev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestDebtToEvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务/股权价值时间序列
    return w.wsd(security,"interestdebttoev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业周期时间序列
    return w.wsd(security,"turndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业周期_GSD时间序列
    return w.wsd(security,"wgsd_turndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTurnDaysTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业周期(TTM)_PIT时间序列
    return w.wsd(security,"fa_turndays_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净营业周期时间序列
    return w.wsd(security,"netturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货周转天数时间序列
    return w.wsd(security,"invturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货周转天数_GSD时间序列
    return w.wsd(security,"wgsd_invturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInvTurnDaysTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货周转天数(TTM)_PIT时间序列
    return w.wsd(security,"fa_invturndays_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArturNDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转天数时间序列
    return w.wsd(security,"arturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDArturNDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转天数_GSD时间序列
    return w.wsd(security,"wgsd_arturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaArturNDaysTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转天数(TTM)_PIT时间序列
    return w.wsd(security,"fa_arturndays_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getApTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款周转天数时间序列
    return w.wsd(security,"apturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDApTurnDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款周转天数_GSD时间序列
    return w.wsd(security,"wgsd_apturndays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaApTurnDaysTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款周转天数(TTM)_PIT时间序列
    return w.wsd(security,"fa_apturndays_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货周转率时间序列
    return w.wsd(security,"invturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货周转率_GSD时间序列
    return w.wsd(security,"wgsd_invturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInvTurnTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_invturn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArturNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转率时间序列
    return w.wsd(security,"arturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaArturNReserveSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转率(含坏账准备)时间序列
    return w.wsd(security,"fa_arturn_reserve",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDArturNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转率_GSD时间序列
    return w.wsd(security,"wgsd_arturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaArturNTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_arturn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaArnRTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款及应收票据周转率时间序列
    return w.wsd(security,"fa_arnrturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCaTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产周转率时间序列
    return w.wsd(security,"caturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCaTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产周转率_GSD时间序列
    return w.wsd(security,"wgsd_caturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCurRtAssetsTRateTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_currtassetstrate_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurrentAssetsTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产周转率时间序列
    return w.wsd(security,"non_currentassetsturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateCaptIAlTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营运资本周转率时间序列
    return w.wsd(security,"operatecaptialturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产周转率时间序列
    return w.wsd(security,"faturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFaTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产周转率_GSD时间序列
    return w.wsd(security,"wgsd_faturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFaTurnTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_faturn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetsTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产周转率时间序列
    return w.wsd(security,"assetsturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTurnoverTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产周转率(TTM)时间序列
    return w.wsd(security,"turnover_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产周转率_GSD时间序列
    return w.wsd(security,"wgsd_assetsturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTaTurnTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_taturn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getApTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款周转率时间序列
    return w.wsd(security,"apturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDApTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款周转率_GSD时间序列
    return w.wsd(security,"wgsd_apturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaApTurnTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_apturn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaApNpTurnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款及应付票据周转率时间序列
    return w.wsd(security,"fa_apnpturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCashTurnRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金周转率时间序列
    return w.wsd(security,"fa_cashturnratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(同比增长率)时间序列
    return w.wsd(security,"yoyprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产(同比增长率)时间序列
    return w.wsd(security,"yoy_equity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总负债(同比增长率)时间序列
    return w.wsd(security,"yoydebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产(同比增长率)时间序列
    return w.wsd(security,"yoy_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(同比增长率)时间序列
    return w.wsd(security,"yoy_or",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoyoPSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(同比增长率)时间序列
    return w.wsd(security,"yoyop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoyoP2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(同比增长率)2时间序列
    return w.wsd(security,"yoyop2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYOyEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(同比增长率)时间序列
    return w.wsd(security,"yoyebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoy_or",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoyoP2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyop2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYOyEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(同比增长率)时间序列
    return w.wsd(security,"yoy_tr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金净流量(同比增长率)时间序列
    return w.wsd(security,"yoycf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoy_tr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYepsBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益(同比增长率)时间序列
    return w.wsd(security,"yoyeps_basic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYepsDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取稀释每股收益(同比增长率)时间序列
    return w.wsd(security,"yoyeps_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoYProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润同比增长率时间序列
    return w.wsd(security,"qfa_yoyprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYepsBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyeps_basic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYepsDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取稀释每股收益(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyeps_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoYSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业收入同比增长率时间序列
    return w.wsd(security,"qfa_yoysales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoyoPSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业利润同比增长率时间序列
    return w.wsd(security,"qfa_yoyop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoYGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业总收入同比增长率时间序列
    return w.wsd(security,"qfa_yoygr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoYepsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.每股收益(同比增长率)时间序列
    return w.wsd(security,"qfa_yoyeps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoYCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金净流量(同比增长率)时间序列
    return w.wsd(security,"qfa_yoycf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(摊薄)(同比增长率)时间序列
    return w.wsd(security,"yoyroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(摊薄)(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(同比增长率)时间序列
    return w.wsd(security,"yoynetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoynetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoyOCFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营性现金净流量(同比增长率)时间序列
    return w.wsd(security,"qfa_yoyocf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaYoYNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属母公司股东的净利润同比增长率时间序列
    return w.wsd(security,"qfa_yoynetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYNetProfitDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润-扣除非经常损益(同比增长率)时间序列
    return w.wsd(security,"yoynetprofit_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYNetProfitDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润-扣除非经常损益(同比增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoynetprofit_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计(相对年初增长率)时间序列
    return w.wsd(security,"yoyassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计(相对年初增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYbPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产(相对年初增长率)时间序列
    return w.wsd(security,"yoybps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYbPsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产(相对年初增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoybps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(相对年初增长率)时间序列
    return w.wsd(security,"yoyequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDYoYEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(相对年初增长率)_GSD时间序列
    return w.wsd(security,"wgsd_yoyequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDupontNpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润/净利润时间序列
    return w.wsd(security,"dupont_np",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontNpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润/净利润_GSD时间序列
    return w.wsd(security,"wgsd_dupont_np",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDupontTaxBurdenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/利润总额时间序列
    return w.wsd(security,"dupont_taxburden",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontTaxBurdenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润/利润总额_GSD时间序列
    return w.wsd(security,"wgsd_dupont_taxburden",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDupontIntBurdenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额/息税前利润时间序列
    return w.wsd(security,"dupont_intburden",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontIntBurdenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额/息税前利润_GSD时间序列
    return w.wsd(security,"wgsd_dupont_intburden",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWorkingCapitalToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营运资本/总资产时间序列
    return w.wsd(security,"workingcapitaltoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRetainedEarningsToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取留存收益/总资产时间序列
    return w.wsd(security,"retainedearningstoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBookValueToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益合计(含少数)/负债总计时间序列
    return w.wsd(security,"bookvaluetodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRevenueToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入/总资产时间序列
    return w.wsd(security,"revenuetoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期贷款_3个月以内时间序列
    return w.wsd(security,"stmnote_bank_0001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期贷款_3个月至1年时间序列
    return w.wsd(security,"stmnote_bank_0002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期贷款_1年以上3年以内时间序列
    return w.wsd(security,"stmnote_bank_0003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期贷款_3年以上时间序列
    return w.wsd(security,"stmnote_bank_0004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期贷款合计时间序列
    return w.wsd(security,"stmnote_bank_0005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSeg1701Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营业务收入时间序列
    return w.wsd(security,"stmnote_seg_1701",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSeg1702Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营业务成本时间序列
    return w.wsd(security,"stmnote_seg_1702",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1543Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产管理业务收入时间序列
    return w.wsd(security,"stmnote_sec_1543",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1553Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产管理业务净收入时间序列
    return w.wsd(security,"stmnote_sec_1553",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAumIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产管理费收入_GSD时间序列
    return w.wsd(security,"wgsd_aum_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetManageIncDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定向资产管理业务收入时间序列
    return w.wsd(security,"stmnote_assetmanage_inc_d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetManageIncCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取集合资产管理业务收入时间序列
    return w.wsd(security,"stmnote_assetmanage_inc_c",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetManageIncSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取专项资产管理业务收入时间序列
    return w.wsd(security,"stmnote_assetmanage_inc_s",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaAumIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.资产管理费收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_aum_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetIncCustomerAssetManagementBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托客户资产管理业务净收入时间序列
    return w.wsd(security,"net_inc_customerasset-managementbusiness",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetIncCustomerAssetManagementBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.受托客户资产管理业务净收入时间序列
    return w.wsd(security,"qfa_net_inc_customerasset-managementbusiness",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1502Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:受托客户资产管理业务时间序列
    return w.wsd(security,"stmnote_sec_1502",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1522Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:受托客户资产管理业务时间序列
    return w.wsd(security,"stmnote_sec_1522",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs81Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资收益_FUND时间序列
    return w.wsd(security,"stm_is_81",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净投资收益率时间序列
    return w.wsd(security,"stmnote_insur_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总投资收益率时间序列
    return w.wsd(security,"stmnote_insur_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净投资收益时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0010Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总投资收益时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0010",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0009Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他投资收益时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0009",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRecpReturnInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取取得投资收益收到的现金时间序列
    return w.wsd(security,"cash_recp_return_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票投资收益_FUND时间序列
    return w.wsd(security,"stm_is_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs75Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金投资收益_FUND时间序列
    return w.wsd(security,"stm_is_75",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券投资收益_FUND时间序列
    return w.wsd(security,"stm_is_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs201Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证投资收益_FUND时间序列
    return w.wsd(security,"stm_is_201",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecpReturnInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.取得投资收益收到的现金时间序列
    return w.wsd(security,"qfa_cash_recp_return_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs71Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产支持证券投资收益_FUND时间序列
    return w.wsd(security,"stm_is_71",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIncInvestAsSocJVENtpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对联营企业和合营企业的投资收益时间序列
    return w.wsd(security,"inc_invest_assoc_jv_entp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaIncInvestAsSocJVENtpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.对联营企业和合营企业的投资收益时间序列
    return w.wsd(security,"qfa_inc_invest_assoc_jv_entp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDeductedProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.扣除非经常损益后的净利润时间序列
    return w.wsd(security,"qfa_deductedprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOperateIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动净收益时间序列
    return w.wsd(security,"qfa_operateincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInvestIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.价值变动净收益时间序列
    return w.wsd(security,"qfa_investincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaRoeDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净资产收益率(扣除非经常损益)时间序列
    return w.wsd(security,"qfa_roe_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCGrGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业总收入环比增长率时间序列
    return w.wsd(security,"qfa_cgrgr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCGrSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业收入环比增长率时间序列
    return w.wsd(security,"qfa_cgrsales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCGroPSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业利润环比增长率时间序列
    return w.wsd(security,"qfa_cgrop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCGrProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润环比增长率时间序列
    return w.wsd(security,"qfa_cgrprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCGrNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属母公司股东的净利润环比增长率时间序列
    return w.wsd(security,"qfa_cgrnetprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRevenuePpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取人均创收时间序列
    return w.wsd(security,"wgsd_revenuepp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDProfitPpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取人均创利时间序列
    return w.wsd(security,"wgsd_profitpp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSalaryPpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取人均薪酬时间序列
    return w.wsd(security,"wgsd_salarypp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOrGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_orgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTpGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_tpgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOiGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-营业利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_oigr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNpGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-净利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_npgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNppCGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-归属母公司股东的净利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_nppcgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaGpmgRTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-毛利率(TTM)_PIT时间序列
    return w.wsd(security,"fa_gpmgr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTagRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-总资产_PIT时间序列
    return w.wsd(security,"fa_tagr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNAgrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增长率-净资产_PIT时间序列
    return w.wsd(security,"fa_nagr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEGroSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取5年收益增长率_PIT时间序列
    return w.wsd(security,"fa_egro",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavReturnNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金N日净值增长率时间序列
    return w.wsd(security,"NAV_return_nd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthCAgrNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润复合年增长率时间序列
    return w.wsd(security,"growth_cagr_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthGp1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_gp_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthGp3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_gp_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCAgrNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润复合年增长率_GSD时间序列
    return w.wsd(security,"wgsd_cagr_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSGroSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取5年营业收入增长率_PIT时间序列
    return w.wsd(security,"fa_sgro",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCAgrTotalProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额复合年增长率时间序列
    return w.wsd(security,"cagr_totalprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(N年,增长率)时间序列
    return w.wsd(security,"growth_profit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthNp1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_np_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthNp3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_np_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthAsset1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_asset_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthAsset3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_asset_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthDebt1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总负债(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_debt_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthDebt3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总负债(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_debt_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCAgrTotalProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额复合年增长率_GSD时间序列
    return w.wsd(security,"wgsd_cagr_totalprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRevenueGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近三年营收复合增长率时间序列
    return w.wsd(security,"ipo_revenuegrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthCAgrTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入复合年增长率时间序列
    return w.wsd(security,"growth_cagr_tr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(N年,增长率)时间序列
    return w.wsd(security,"growth_or",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthOpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(N年,增长率)时间序列
    return w.wsd(security,"growth_op",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(N年,增长率)时间序列
    return w.wsd(security,"growth_ebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计(N年,增长率)时间序列
    return w.wsd(security,"growth_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthTotalEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益(N年,增长率)时间序列
    return w.wsd(security,"growth_totalequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthOp1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_op_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthOp3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_op_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEBt1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税前利润(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_ebt_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEBt3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税前利润(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_ebt_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCAgrTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入复合年增长率_GSD时间序列
    return w.wsd(security,"wgsd_cagr_tr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_or",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthOpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_op",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEBtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_ebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthTotalEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_totalequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(N年,增长率)时间序列
    return w.wsd(security,"growth_gr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthGcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本(N年,增长率)时间序列
    return w.wsd(security,"growth_gc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthProfitToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售利润率(N年,增长率)时间序列
    return w.wsd(security,"growth_profittosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthSales1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总营业收入(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_sales_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthSales3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总营业收入(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_sales_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthBpS1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_bps_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthBpS3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_bps_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthGrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_gr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthGcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_gc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthProfitToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售利润率(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_profittosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(N年,增长率)时间序列
    return w.wsd(security,"growth_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthTotalEquity1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益合计(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_totalequity_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthTotalEquity3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益合计(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_totalequity_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEps1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_eps_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEps3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_eps_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthOperateIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益(N年,增长率)时间序列
    return w.wsd(security,"growth_operateincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthInvestIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益(N年,增长率)时间序列
    return w.wsd(security,"growth_investincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthOperateIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_operateincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthInvestIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_investincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(N年,增长率)时间序列
    return w.wsd(security,"growth_equity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEquity1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(近1年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_equity_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEquity3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(近3年增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_equity_3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_equity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(N年,增长率)时间序列
    return w.wsd(security,"growth_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrowthNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(N年,增长率)_GSD时间序列
    return w.wsd(security,"wgsd_growth_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrowthNetProfitDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润-扣除非经常损益(N年,增长率)时间序列
    return w.wsd(security,"growth_netprofit_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetsGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产差额(特殊报表科目)时间序列
    return w.wsd(security,"assets_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetsGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产差额说明(特殊报表科目)时间序列
    return w.wsd(security,"assets_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetsNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产差额(合计平衡项目)时间序列
    return w.wsd(security,"assets_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsAllAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计时间序列
    return w.wsd(security,"stm07_bs_reits_allassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGainAssetDispositionsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产处置收益时间序列
    return w.wsd(security,"gain_asset_dispositions",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs72Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产支持证券投资_FUND时间序列
    return w.wsd(security,"stm_bs_72",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产合计_FUND时间序列
    return w.wsd(security,"stm_bs_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs69Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产支持证券利息收入_FUND时间序列
    return w.wsd(security,"stm_is_69",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs105Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产支持证券投资公允价值变动收益_FUND时间序列
    return w.wsd(security,"stm_is_105",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoaTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产回报率(TTM)_PIT时间序列
    return w.wsd(security,"fa_roa_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaToTAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计_PIT时间序列
    return w.wsd(security,"fa_totassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetMrQSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资产总计(MRQ,只有最新数据)时间序列
    return w.wsd(security,"asset_mrq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(平均)时间序列
    return w.wsd(security,"roe_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(加权)时间序列
    return w.wsd(security,"roe_basic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(摊薄)时间序列
    return w.wsd(security,"roe_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(扣除/平均)时间序列
    return w.wsd(security,"roe_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeExBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(扣除/加权)时间序列
    return w.wsd(security,"roe_exbasic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeExDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(扣除/摊薄)时间序列
    return w.wsd(security,"roe_exdiluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE-增发条件时间序列
    return w.wsd(security,"roe_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoa2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率ROA时间序列
    return w.wsd(security,"roa2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率ROA时间序列
    return w.wsd(security,"roa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE时间序列
    return w.wsd(security,"roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(TTM)时间序列
    return w.wsd(security,"roe_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeTtMAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(TTM,平均)时间序列
    return w.wsd(security,"fa_roe_ttmavg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoa2TtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率(TTM)时间序列
    return w.wsd(security,"roa2_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitToAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率-不含少数股东损益(TTM)时间序列
    return w.wsd(security,"netprofittoassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率_GSD时间序列
    return w.wsd(security,"wgsd_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoeDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(摊薄)_GSD时间序列
    return w.wsd(security,"wgsd_roe_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoeDeductedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(扣除)_GSD时间序列
    return w.wsd(security,"wgsd_roe_deducted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoeExDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(扣除/摊薄)_GSD时间序列
    return w.wsd(security,"wgsd_roe_exdiluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoeYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(年化)_GSD时间序列
    return w.wsd(security,"wgsd_roe_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率_GSD时间序列
    return w.wsd(security,"wgsd_roa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoaYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率(年化)_GSD时间序列
    return w.wsd(security,"wgsd_roa_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoa2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率ROA_GSD时间序列
    return w.wsd(security,"wgsd_roa2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoa2YearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率(年化)_GSD时间序列
    return w.wsd(security,"wgsd_roa2_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(TTM)_GSD时间序列
    return w.wsd(security,"roe_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoaTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率(TTM)_GSD时间序列
    return w.wsd(security,"roa_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitToAssets2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率-不含少数股东损益(TTM)_GSD时间序列
    return w.wsd(security,"netprofittoassets2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoa2TtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率(TTM)_GSD时间序列
    return w.wsd(security,"roa2_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产_GSD时间序列
    return w.wsd(security,"wgsd_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(平均)_PIT时间序列
    return w.wsd(security,"fa_roe_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeWGtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(加权)_PIT时间序列
    return w.wsd(security,"fa_roe_wgt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(摊薄)_PIT时间序列
    return w.wsd(security,"fa_roe_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeExBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(扣除/加权)_PIT时间序列
    return w.wsd(security,"fa_roe_exbasic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeExDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(扣除/摊薄)_PIT时间序列
    return w.wsd(security,"fa_roe_exdiluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeNpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率(TTM)_PIT时间序列
    return w.wsd(security,"fa_roenp_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoaEbItTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率(TTM)_PIT时间序列
    return w.wsd(security,"fa_roaebit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetProfitToAssetsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率-不含少数股东损益(TTM)_PIT时间序列
    return w.wsd(security,"fa_netprofittoassets_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNaTurnTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产周转率(TTM)_PIT时间序列
    return w.wsd(security,"fa_naturn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资产收益率ROE(TTM,只有最新数据)时间序列
    return w.wsd(security,"roe_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoa2TtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产报酬率ROA(TTM,只有最新数据)时间序列
    return w.wsd(security,"roa2_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoaTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总资产净利率ROA(TTM,只有最新数据)时间序列
    return w.wsd(security,"roa_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getYoYFixedAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产投资扩张率时间序列
    return w.wsd(security,"yoy_fixedassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTangibleAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产时间序列
    return w.wsd(security,"tangibleasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStAssetLiqRatioRMbNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期资产流动性比率(人民币)时间序列
    return w.wsd(security,"st_asset_liq_ratio_rmb_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankAssetLiqRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期资产流动性比率(本外币)时间序列
    return w.wsd(security,"stmnote_bank_assetliqratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStAssetLiqRatioNormBNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期资产流动性比率(外币)时间序列
    return w.wsd(security,"st_asset_liq_ratio_normb_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank351Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生息资产时间序列
    return w.wsd(security,"stmnote_bank_351",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank58Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生息资产收益率时间序列
    return w.wsd(security,"stmnote_bank_58",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank57Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生息资产平均余额时间序列
    return w.wsd(security,"stmnote_bank_57",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStAssetLiqRatioRMbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期资产流动性比率(人民币)(旧)时间序列
    return w.wsd(security,"st_asset_liq_ratio_rmb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStAssetLiqRatioNormBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期资产流动性比率(外币)(旧)时间序列
    return w.wsd(security,"st_asset_liq_ratio_normb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7808Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它资产时间序列
    return w.wsd(security,"stmnote_insur_7808",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212512Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取认可资产时间序列
    return w.wsd(security,"qstmnote_insur_212512",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTangibleAsset2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产_GSD时间序列
    return w.wsd(security,"wgsd_tangibleasset2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsCurRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产合计_GSD时间序列
    return w.wsd(security,"wgsd_assets_curr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPpeNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产净值_GSD时间序列
    return w.wsd(security,"wgsd_ppe_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getContAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合同资产时间序列
    return w.wsd(security,"cont_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurAssetsGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产差额(特殊报表科目)时间序列
    return w.wsd(security,"cur_assets_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurAssetsGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cur_assets_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurAssetsNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产差额(合计平衡项目)时间序列
    return w.wsd(security,"cur_assets_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsLiquidAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产合计时间序列
    return w.wsd(security,"stm07_bs_reits_liquidasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFixAssetsToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产(合计)时间序列
    return w.wsd(security,"fix_assets_tot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFixAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产时间序列
    return w.wsd(security,"fix_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFixAssetsDispSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产清理时间序列
    return w.wsd(security,"fix_assets_disp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOilAndNaturalGasAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取油气资产时间序列
    return w.wsd(security,"oil_and_natural_gas_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntangAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产时间序列
    return w.wsd(security,"intang_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDePrFaCogADpBaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产折旧、油气资产折耗、生产性生物资产折旧时间序列
    return w.wsd(security,"depr_fa_coga_dpba",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAMortIntangAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产摊销时间序列
    return w.wsd(security,"amort_intang_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLossSCrFaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产报废损失时间序列
    return w.wsd(security,"loss_scr_fa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产-原值时间序列
    return w.wsd(security,"stmnote_assetdetail_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产-累计折旧时间序列
    return w.wsd(security,"stmnote_assetdetail_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产-减值准备时间序列
    return w.wsd(security,"stmnote_assetdetail_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产-净额时间序列
    return w.wsd(security,"stmnote_assetdetail_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAvOfASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产-净值时间序列
    return w.wsd(security,"stmnote_avofa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail13Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取油气资产-原值时间序列
    return w.wsd(security,"stmnote_assetdetail_13",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取油气资产-累计折耗时间序列
    return w.wsd(security,"stmnote_assetdetail_14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail15Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取油气资产-减值准备时间序列
    return w.wsd(security,"stmnote_assetdetail_15",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail16Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取油气资产-净额时间序列
    return w.wsd(security,"stmnote_assetdetail_16",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail17Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产-原值时间序列
    return w.wsd(security,"stmnote_assetdetail_17",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail18Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产-累计摊销时间序列
    return w.wsd(security,"stmnote_assetdetail_18",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产-减值准备时间序列
    return w.wsd(security,"stmnote_assetdetail_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产-净额时间序列
    return w.wsd(security,"stmnote_assetdetail_20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopAbsWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓资产支持证券Wind代码时间序列
    return w.wsd(security,"prt_topabswindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCurAssetsRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动资产比率_PIT时间序列
    return w.wsd(security,"fa_curassetsratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFixedAssetToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产比率_PIT时间序列
    return w.wsd(security,"fa_fixedassettoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaIntangAssetRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无形资产比率_PIT时间序列
    return w.wsd(security,"fa_intangassetratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTangibleAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形资产_PIT时间序列
    return w.wsd(security,"fa_tangibleasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFixAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定资产合计_PIT时间序列
    return w.wsd(security,"fa_fixassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvgRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)平均值时间序列
    return w.wsd(security,"est_avgroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)最大值时间序列
    return w.wsd(security,"est_maxroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)最小值时间序列
    return w.wsd(security,"est_minroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)中值时间序列
    return w.wsd(security,"est_medianroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)标准差时间序列
    return w.wsd(security,"est_stdroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvgRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)平均值时间序列
    return w.wsd(security,"est_avgroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)最大值时间序列
    return w.wsd(security,"est_maxroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)最小值时间序列
    return w.wsd(security,"est_minroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)中值时间序列
    return w.wsd(security,"est_medianroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)标准差时间序列
    return w.wsd(security,"est_stdroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)平均值(可选类型)时间序列
    return w.wsd(security,"west_avgroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)最小值(可选类型)时间序列
    return w.wsd(security,"west_minroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)中值(可选类型)时间序列
    return w.wsd(security,"west_medianroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测总资产收益率(ROA)标准差(可选类型)时间序列
    return w.wsd(security,"west_stdroa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)平均值(可选类型)时间序列
    return w.wsd(security,"west_avgroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)最小值(可选类型)时间序列
    return w.wsd(security,"west_minroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)中值(可选类型)时间序列
    return w.wsd(security,"west_medianroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净资产收益率(ROE)标准差(可选类型)时间序列
    return w.wsd(security,"west_stdroe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产BPS时间序列
    return w.wsd(security,"bps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBpSAdjustSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产BPS(最新股本摊薄)时间序列
    return w.wsd(security,"bps_adjust",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBpSNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产BPS(最新公告)时间序列
    return w.wsd(security,"bps_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank421Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非生息资产时间序列
    return w.wsd(security,"stmnote_bank_421",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec33Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取表内外资产总额时间序列
    return w.wsd(security,"stmnote_sec_33",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7809Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总投资资产时间序列
    return w.wsd(security,"stmnote_insur_7809",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产_GSD时间序列
    return w.wsd(security,"wgsd_bps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDBpSNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产(最新公告)_GSD时间序列
    return w.wsd(security,"wgsd_bps_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDupontRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平均净资产收益率_GSD时间序列
    return w.wsd(security,"wgsd_dupont_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsLtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产合计_GSD时间序列
    return w.wsd(security,"wgsd_assets_lt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPropRightUseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取使用权资产时间序列
    return w.wsd(security,"prop_right_use",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurAssetsGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产差额(特殊报表科目)时间序列
    return w.wsd(security,"non_cur_assets_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurAssetsGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产差额说明(特殊报表科目)时间序列
    return w.wsd(security,"non_cur_assets_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurAssetsNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产差额(合计平衡项目)时间序列
    return w.wsd(security,"non_cur_assets_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsNonLiquidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产合计时间序列
    return w.wsd(security,"stm07_bs_reits_nonliquid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetLossDispNonCurAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产处置净损失时间序列
    return w.wsd(security,"net_loss_disp_noncur_asset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDePrePropRightUseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取使用权资产折旧时间序列
    return w.wsd(security,"depre_prop_right_use",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产处置损益时间序列
    return w.wsd(security,"stmnote_Eoitems_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValLnToTAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对数总资产_PIT时间序列
    return w.wsd(security,"val_lntotassets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股净资产_PIT时间序列
    return w.wsd(security,"fa_bps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaAccaTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金流资产比-资产回报率(TTM)_PIT时间序列
    return w.wsd(security,"fa_acca_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNonCurAssetsRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动资产比率_PIT时间序列
    return w.wsd(security,"fa_noncurassetsratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDebtsAssetRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债务总资产比_PIT时间序列
    return w.wsd(security,"fa_debtsassetratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank133NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权风险资产净额时间序列
    return w.wsd(security,"stmnote_bank_133_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankRWeightedAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权风险资产净额(2013)时间序列
    return w.wsd(security,"stmnote_bank_RweightedAssets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank133Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权风险资产净额(旧)时间序列
    return w.wsd(security,"stmnote_bank_133",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetManageSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托管理资产总规模时间序列
    return w.wsd(security,"stmnote_assetmanage",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益投资资产分红收入时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsCurROThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他流动资产_GSD时间序列
    return w.wsd(security,"wgsd_assets_curr_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPpeNetOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他固定资产净值_GSD时间序列
    return w.wsd(security,"wgsd_ppe_net_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsBusCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取出售固定资产收到的现金_GSD时间序列
    return w.wsd(security,"wgsd_assets_bus_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThCurAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他流动资产时间序列
    return w.wsd(security,"oth_cur_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyBusAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代理业务资产时间序列
    return w.wsd(security,"agency_bus_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndependentAccTAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取独立账户资产时间序列
    return w.wsd(security,"independent_acct_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDerivativeFinAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取衍生金融资产时间序列
    return w.wsd(security,"derivative_fin_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCashRecpDispFiOltASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取处置固定资产、无形资产和其他长期资产收回的现金净额时间序列
    return w.wsd(security,"net_cash_recp_disp_fiolta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashPayAcqConstFiOltASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取购建固定资产、无形资产和其他长期资产支付的现金时间序列
    return w.wsd(security,"cash_pay_acq_const_fiolta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLossDispFiOltASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取处置固定资产、无形资产和其他长期资产的损失时间序列
    return w.wsd(security,"loss_disp_fiolta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaGainAssetDispositionsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.资产处置收益时间序列
    return w.wsd(security,"qfa_gain_asset_dispositions",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非货币性资产交换损益时间序列
    return w.wsd(security,"stmnote_Eoitems_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs109Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取衍生金融资产_FUND时间序列
    return w.wsd(security,"stm_bs_109",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAssetDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股申购资产规模报备日时间序列
    return w.wsd(security,"ipo_assetdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoaAvg5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取5年平均资产回报率_PIT时间序列
    return w.wsd(security,"fa_roaavg5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAbsUnderlyingTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ABS基础资产分类时间序列
    return w.wsd(security,"abs_underlyingtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvgBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)平均值时间序列
    return w.wsd(security,"est_avgbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最大值时间序列
    return w.wsd(security,"est_maxbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最小值时间序列
    return w.wsd(security,"est_minbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)中值时间序列
    return w.wsd(security,"est_medianbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)标准差时间序列
    return w.wsd(security,"est_stdbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvgBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)平均值(币种转换)时间序列
    return w.wsd(security,"est_avgbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最大值(币种转换)时间序列
    return w.wsd(security,"est_maxbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMinBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最小值(币种转换)时间序列
    return w.wsd(security,"est_minbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)中值(币种转换)时间序列
    return w.wsd(security,"est_medianbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStdBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)标准差(币种转换)时间序列
    return w.wsd(security,"est_stdbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)平均值(可选类型)时间序列
    return w.wsd(security,"west_avgbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最小值(可选类型)时间序列
    return w.wsd(security,"west_minbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)中值(可选类型)时间序列
    return w.wsd(security,"west_medianbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdBpSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)标准差(可选类型)时间序列
    return w.wsd(security,"west_stdbps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_avgbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_medianbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdBpS1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产(BPS)标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdbps1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestBpSSurpriseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产Surprise(可选类型)时间序列
    return w.wsd(security,"west_bps_surprise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestBpSSurprisePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测每股净资产Surprise百分比(可选类型)时间序列
    return w.wsd(security,"west_bps_surprise_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资本/净资产时间序列
    return w.wsd(security,"stmnote_sec_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净资产收益率ROE时间序列
    return w.wsd(security,"qfa_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.总资产净利率ROA时间序列
    return w.wsd(security,"qfa_roa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaRoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净资产收益率ROE_GSD时间序列
    return w.wsd(security,"wgsd_qfa_roe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaRoaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.总资产净利率ROA_GSD时间序列
    return w.wsd(security,"wgsd_qfa_roa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestTradingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易性金融资产_GSD时间序列
    return w.wsd(security,"wgsd_invest_trading",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAssetsLtOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非流动资产_GSD时间序列
    return w.wsd(security,"wgsd_assets_lt_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConsumptiveBioAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取消耗性生物资产时间序列
    return w.wsd(security,"consumptive_bio_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProductiveBioAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产性生物资产时间序列
    return w.wsd(security,"productive_bio_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThNonCurAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非流动资产时间序列
    return w.wsd(security,"oth_non_cur_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产性生物资产-原值时间序列
    return w.wsd(security,"stmnote_assetdetail_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产性生物资产-累计折旧时间序列
    return w.wsd(security,"stmnote_assetdetail_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产性生物资产-减值准备时间序列
    return w.wsd(security,"stmnote_assetdetail_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取生产性生物资产-净额时间序列
    return w.wsd(security,"stmnote_assetdetail_12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs71Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易性金融资产_FUND时间序列
    return w.wsd(security,"stm_bs_71",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaLtDebtToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期负债/资产总计_PIT时间序列
    return w.wsd(security,"fa_ltdebttoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaBondsPayableToAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付债券/资产总计_PIT时间序列
    return w.wsd(security,"fa_bondspayabletoasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankRWeightedAssetsCrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用风险加权资产(2013)时间序列
    return w.wsd(security,"stmnote_bank_RweightedAssets_cr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankRWeightedAssetsMrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场风险加权资产(2013)时间序列
    return w.wsd(security,"stmnote_bank_RweightedAssets_mr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankRWeightedAssetsOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取操作风险加权资产(2013)时间序列
    return w.wsd(security,"stmnote_bank_RweightedAssets_or",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundSalesFinAssetsRpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取卖出回购金融资产款时间序列
    return w.wsd(security,"fund_sales_fin_assets_rp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFncLeasesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融资租入固定资产时间序列
    return w.wsd(security,"fa_fnc_leases",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDePrFaCogADpBaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.固定资产折旧、油气资产折耗、生产性生物资产折旧时间序列
    return w.wsd(security,"qfa_depr_fa_coga_dpba",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaAMortIntangAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.无形资产摊销时间序列
    return w.wsd(security,"qfa_amort_intang_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaLossSCrFaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.固定资产报废损失时间序列
    return w.wsd(security,"qfa_loss_scr_fa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGuarantee6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保总额占净资产比例时间序列
    return w.wsd(security,"stmnote_guarantee_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs13Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取卖出回购金融资产支出_FUND时间序列
    return w.wsd(security,"stm_is_13",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgBpSFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股净资产(FY1)时间序列
    return w.wsd(security,"west_avgbps_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgBpSFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股净资产(FY2)时间序列
    return w.wsd(security,"west_avgbps_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgBpSFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股净资产(FY3)时间序列
    return w.wsd(security,"west_avgbps_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1513Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入:金融资产回购业务收入时间序列
    return w.wsd(security,"stmnote_sec_1513",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRealEstateNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取房地产物业相关资产净值_GSD时间序列
    return w.wsd(security,"wgsd_real_estate_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThNonCurFinaAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非流动金融资产时间序列
    return w.wsd(security,"oth_non_cur_fina_asset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrDispTfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取处置交易性金融资产净增加额时间序列
    return w.wsd(security,"net_incr_disp_tfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetLossDispNonCurAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.非流动资产处置净损失时间序列
    return w.wsd(security,"qfa_net_loss_disp_noncur_asset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDePrePropRightUseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.使用权资产折旧时间序列
    return w.wsd(security,"qfa_depre_prop_right_use",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEquityToFixedAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益/固定资产_PIT时间序列
    return w.wsd(security,"fa_equitytofixedasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1533Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息净收入:金融资产回购业务收入时间序列
    return w.wsd(security,"stmnote_sec_1533",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaAssetsBusCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.出售固定资产收到的现金_GSD时间序列
    return w.wsd(security,"wgsd_qfa_assets_bus_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHfSAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取划分为持有待售的资产时间序列
    return w.wsd(security,"hfs_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashRecpDispFiOltASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.处置固定资产、无形资产和其他长期资产收回的现金净额时间序列
    return w.wsd(security,"qfa_net_cash_recp_disp_fiolta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPayAcqConstFiOltASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.购建固定资产、无形资产和其他长期资产支付的现金时间序列
    return w.wsd(security,"qfa_cash_pay_acq_const_fiolta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaLossDispFiOltASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.处置固定资产、无形资产和其他长期资产的损失时间序列
    return w.wsd(security,"qfa_loss_disp_fiolta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurAssetsDueWithin1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一年内到期的非流动资产时间序列
    return w.wsd(security,"non_cur_assets_due_within_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinAssetsAmortizedCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取以摊余成本计量的金融资产时间序列
    return w.wsd(security,"fin_assets_amortizedcost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTerFinAsSIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取以摊余成本计量的金融资产终止确认收益时间序列
    return w.wsd(security,"ter_fin_ass_income",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaFaFncLeasesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.融资租入固定资产时间序列
    return w.wsd(security,"qfa_fa_fnc_leases",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-消耗性生物资产时间序列
    return w.wsd(security,"stmnote_inv_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrDispTfaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.处置交易性金融资产净增加额时间序列
    return w.wsd(security,"qfa_net_incr_disp_tfa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItToAssets2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润(TTM)/总资产时间序列
    return w.wsd(security,"ebittoassets2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItToAssetsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润(TTM)/总资产_GSD时间序列
    return w.wsd(security,"ebittoassets_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems28Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有(或处置)交易性金融资产和负债产生的公允价值变动损益时间序列
    return w.wsd(security,"stmnote_Eoitems_28",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaTerFinAsSIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.以摊余成本计量的金融资产终止确认收益时间序列
    return w.wsd(security,"qfa_ter_fin_ass_income",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrMinnaVUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申购赎回最小申购赎回单位资产净值时间序列
    return w.wsd(security,"fund_etfpr_minnav_unit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradableFinAssetsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取以公允价值计量且其变动计入当期损益的金融资产时间序列
    return w.wsd(security,"tradable_fin_assets",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债差额(特殊报表科目)时间序列
    return w.wsd(security,"liab_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债差额说明(特殊报表科目)时间序列
    return w.wsd(security,"liab_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债差额(合计平衡项目)时间序列
    return w.wsd(security,"liab_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsAllDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债合计时间序列
    return w.wsd(security,"stm07_bs_reits_alldebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBSHrhLDrEqYGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债及股东权益差额(特殊报表科目)时间序列
    return w.wsd(security,"liab_shrhldr_eqy_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBSHrhLDrEqYGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债及股东权益差额说明(特殊报表科目)时间序列
    return w.wsd(security,"liab_shrhldr_eqy_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBSHrhLDrEqYNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债及股东权益差额(合计平衡项目)时间序列
    return w.wsd(security,"liab_shrhldr_eqy_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTLiaBSHrhLDrEqYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债及股东权益总计时间序列
    return w.wsd(security,"tot_liab_shrhldr_eqy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs33Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债合计_FUND时间序列
    return w.wsd(security,"stm_bs_33",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs39Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债及持有人权益合计_FUND时间序列
    return w.wsd(security,"stm_bs_39",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsDebtEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债和所有者权益总计时间序列
    return w.wsd(security,"stm07_bs_reits_debtequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaToTliAbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债合计_PIT时间序列
    return w.wsd(security,"fa_totliab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDebtMrQSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取负债合计(MRQ,只有最新数据)时间序列
    return w.wsd(security,"debt_mrq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsStKhlDrSEqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总负债及总权益_GSD时间序列
    return w.wsd(security,"wgsd_liabs_stkhldrs_eq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank381Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取计息负债时间序列
    return w.wsd(security,"stmnote_bank_381",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取计息负债成本率时间序列
    return w.wsd(security,"stmnote_bank_60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank59Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取计息负债平均余额时间序列
    return w.wsd(security,"stmnote_bank_59",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNoneInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息负债时间序列
    return w.wsd(security,"fa_noneinterestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212513Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取认可负债时间序列
    return w.wsd(security,"qstmnote_insur_212513",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsContractSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合同负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_contract",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsCurRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债合计_GSD时间序列
    return w.wsd(security,"wgsd_liabs_curr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getContLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取合同负债时间序列
    return w.wsd(security,"cont_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurLiaBGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债差额(特殊报表科目)时间序列
    return w.wsd(security,"cur_liab_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurLiaBGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cur_liab_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCurLiaBNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债差额(合计平衡项目)时间序列
    return w.wsd(security,"cur_liab_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsLiquidDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动负债合计时间序列
    return w.wsd(security,"stm07_bs_reits_liquiddebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLeaseObligationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取租赁负债时间序列
    return w.wsd(security,"lease_obligation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProvisionsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计负债时间序列
    return w.wsd(security,"provisions",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他负债时间序列
    return w.wsd(security,"oth_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems18Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计负债产生的损益时间序列
    return w.wsd(security,"stmnote_Eoitems_18",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs32Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他负债_FUND时间序列
    return w.wsd(security,"stm_bs_32",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaUnCurDebtToWorkCapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期负债/营运资金_PIT时间序列
    return w.wsd(security,"fa_uncurdebttoworkcap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank431Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非计息负债时间序列
    return w.wsd(security,"stmnote_bank_431",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资本负债率时间序列
    return w.wsd(security,"stmnote_sec_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsLtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债合计_GSD时间序列
    return w.wsd(security,"wgsd_liabs_lt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurLiaBGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债差额(特殊报表科目)时间序列
    return w.wsd(security,"non_cur_liab_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurLiaBGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债差额说明(特殊报表科目)时间序列
    return w.wsd(security,"non_cur_liab_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurLiaBNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债差额(合计平衡项目)时间序列
    return w.wsd(security,"non_cur_liab_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTNonCurLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非流动负债合计时间序列
    return w.wsd(security,"tot_non_cur_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExInterestDebtCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息流动负债时间序列
    return w.wsd(security,"exinterestdebt_current",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDExInterestDebtCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息流动负债_GSD时间序列
    return w.wsd(security,"wgsd_exinterestdebt_current",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsCurROThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他流动负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_curr_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsInSurContractSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险合同负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_insur_contract",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsInvestContractSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资合同负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_invest_contract",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThCurLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他流动负债时间序列
    return w.wsd(security,"oth_cur_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyBusLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代理业务负债时间序列
    return w.wsd(security,"agency_bus_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndependentAccTLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取独立账户负债时间序列
    return w.wsd(security,"independent_acct_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDerivativeFinLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取衍生金融负债时间序列
    return w.wsd(security,"derivative_fin_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs74Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取衍生金融负债_FUND时间序列
    return w.wsd(security,"stm_bs_74",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCFotoCurlIAbsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金流动负债比(TTM)_PIT时间序列
    return w.wsd(security,"fa_cfotocurliabs_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCashToCurlIAbsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金流动负债比率_PIT时间序列
    return w.wsd(security,"fa_cashtocurliabs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNicuRDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息流动负债_PIT时间序列
    return w.wsd(security,"fa_nicurdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExInterestDebtNonCurrentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息非流动负债时间序列
    return w.wsd(security,"exinterestdebt_noncurrent",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOpToDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/负债合计_GSD时间序列
    return w.wsd(security,"wgsd_optodebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDExInterestDebtNonCurrent2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息非流动负债_GSD时间序列
    return w.wsd(security,"wgsd_exinterestdebt_noncurrent2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsTradingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易性金融负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_trading",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLiAbsLtOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非流动负债_GSD时间序列
    return w.wsd(security,"wgsd_liabs_lt_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThNonCurLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非流动负债时间序列
    return w.wsd(security,"oth_non_cur_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs73Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易性金融负债_FUND时间序列
    return w.wsd(security,"stm_bs_73",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNinoCurDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无息非流动负债_PIT时间序列
    return w.wsd(security,"fa_ninocurdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOpToLiqDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/流动负债_GSD时间序列
    return w.wsd(security,"wgsd_optoliqdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeferredIncCurLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延收益-流动负债时间序列
    return w.wsd(security,"deferred_inc_cur_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHfSLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取划分为持有待售的负债时间序列
    return w.wsd(security,"hfs_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeferredIncNonCurLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延收益-非流动负债时间序列
    return w.wsd(security,"deferred_inc_non_cur_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonCurLiaBDueWithin1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一年内到期的非流动负债时间序列
    return w.wsd(security,"non_cur_liab_due_within_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7639Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期融资债(其他流动负债)时间序列
    return w.wsd(security,"stmnote_others_7639",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTradableFinLiaBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取以公允价值计量且其变动计入当期损益的金融负债时间序列
    return w.wsd(security,"tradable_fin_liab",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsAllEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所有者权益合计时间序列
    return w.wsd(security,"stm07_bs_reits_allequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取期初所有者权益(基金净值)时间序列
    return w.wsd(security,"stm_navchange_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取期末所有者权益(基金净值)时间序列
    return w.wsd(security,"stm_navchange_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属于母公司所有者权益合计时间序列
    return w.wsd(security,"stm07_bs_reits_equity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEquityToCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属于母公司所有者权益合计/全部投入资本_PIT时间序列
    return w.wsd(security,"fa_equitytocapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDChgCashCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物净增加额_GSD时间序列
    return w.wsd(security,"wgsd_chg_cash_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrCashCashEquGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物净增加额差额(特殊报表科目)时间序列
    return w.wsd(security,"net_incr_cash_cash_equ_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrCashCashEquGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物净增加额差额说明(特殊报表科目)时间序列
    return w.wsd(security,"net_incr_cash_cash_equ_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrCashCashEquNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物净增加额差额(合计平衡项目)时间序列
    return w.wsd(security,"net_incr_cash_cash_equ_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsCashAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物净增加额时间序列
    return w.wsd(security,"stm07_cs_reits_cashadd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaChgCashCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金及现金等价物净增加额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_chg_cash_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrCashCashEquImSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-现金及现金等价物净增加额时间序列
    return w.wsd(security,"net_incr_cash_cash_equ_im",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrCashCashEquDmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金及现金等价物净增加额时间序列
    return w.wsd(security,"qfa_net_incr_cash_cash_equ_dm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrCashCashEquImSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.间接法-现金及现金等价物净增加额时间序列
    return w.wsd(security,"qfa_net_incr_cash_cash_equ_im",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaGrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_gr_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(TTM)时间序列
    return w.wsd(security,"gr_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入(TTM)_GSD时间序列
    return w.wsd(security,"gr_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsSIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总收入时间序列
    return w.wsd(security,"stm07_is_reits_sincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTOperRevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业总收入时间序列
    return w.wsd(security,"qfa_tot_oper_rev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDatoSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA/营业总收入时间序列
    return w.wsd(security,"ebitdatosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItDatoSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA/营业总收入_GSD时间序列
    return w.wsd(security,"wgsd_ebitdatosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(TTM)_VAL_PIT时间序列
    return w.wsd(security,"or_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(TTM)时间序列
    return w.wsd(security,"or_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOrTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(TTM)_GSD时间序列
    return w.wsd(security,"or_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入时间序列
    return w.wsd(security,"stm07_is_reits_income",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_or_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总营业收入_GSD时间序列
    return w.wsd(security,"wgsd_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArdIsSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总营业收入(公布值)_GSD时间序列
    return w.wsd(security,"ard_is_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesSurpriseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入Surprise(可选类型)时间序列
    return w.wsd(security,"west_sales_surprise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesSurprisePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业收入Surprise百分比(可选类型)时间序列
    return w.wsd(security,"west_sales_surprise_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSalesOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他营业收入_GSD时间序列
    return w.wsd(security,"wgsd_sales_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)时间序列
    return w.wsd(security,"west_sales_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY2)时间序列
    return w.wsd(security,"west_sales_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY3)时间序列
    return w.wsd(security,"west_sales_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOperRevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业收入时间序列
    return w.wsd(security,"qfa_oper_rev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy11MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)变化率_1M_PIT时间序列
    return w.wsd(security,"west_sales_fy1_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy13MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)变化率_3M_PIT时间序列
    return w.wsd(security,"west_sales_fy1_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy16MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)变化率_6M_PIT时间序列
    return w.wsd(security,"west_sales_fy1_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy1Chg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)的变化_1M_PIT时间序列
    return w.wsd(security,"west_sales_fy1_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy1Chg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)的变化_3M_PIT时间序列
    return w.wsd(security,"west_sales_fy1_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesFy1Chg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)的变化_6M_PIT时间序列
    return w.wsd(security,"west_sales_fy1_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdSalesFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)标准差_PIT时间序列
    return w.wsd(security,"west_stdsales_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestSalesMaxMinFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业收入(FY1)最大与一致预测营业收入(FY1)最小值的变化率_PIT时间序列
    return w.wsd(security,"west_salesmaxmin_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业收入(TTM)时间序列
    return w.wsd(security,"optoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEBtToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额/营业收入(TTM)时间序列
    return w.wsd(security,"ebttoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToOrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业收入(TTM)_GSD时间序列
    return w.wsd(security,"optoor_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEBtToOrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额/营业收入(TTM)_GSD时间序列
    return w.wsd(security,"ebttoor_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.总营业收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOpToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_optoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaPbtToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额/营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_pbttoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaSalesOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他营业收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_sales_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdExpToSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发支出总额占营业收入比例时间序列
    return w.wsd(security,"stmnote_RDexptosales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润/营业收入(TTM)时间序列
    return w.wsd(security,"netprofittoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitToOrTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润/营业收入(TTM)_GSD时间序列
    return w.wsd(security,"netprofittoor_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetProfitToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润/营业收入(TTM)_PIT时间序列
    return w.wsd(security,"fa_netprofittoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1510Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入合计时间序列
    return w.wsd(security,"stmnote_sec_1510",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1512Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入:金融企业往来业务收入时间序列
    return w.wsd(security,"stmnote_sec_1512",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入_GSD时间序列
    return w.wsd(security,"wgsd_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入时间序列
    return w.wsd(security,"int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs80Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息收入_FUND时间序列
    return w.wsd(security,"stm_is_80",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank411Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非利息收入时间序列
    return w.wsd(security,"stmnote_bank_411",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank30Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非利息收入占比时间序列
    return w.wsd(security,"stmnote_bank_30",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank710Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_总计时间序列
    return w.wsd(security,"stmnote_bank_710",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank721Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_企业贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_721",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank722Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_个人贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_722",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank723Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_票据贴现时间序列
    return w.wsd(security,"stmnote_bank_723",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank724Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_个人住房贷款时间序列
    return w.wsd(security,"stmnote_bank_724",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank725Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_个人消费贷款时间序列
    return w.wsd(security,"stmnote_bank_725",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank726Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_信用卡应收账款时间序列
    return w.wsd(security,"stmnote_bank_726",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank727Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_经营性贷款时间序列
    return w.wsd(security,"stmnote_bank_727",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank728Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_汽车贷款时间序列
    return w.wsd(security,"stmnote_bank_728",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank729Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_其他个人贷款时间序列
    return w.wsd(security,"stmnote_bank_729",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank781Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_信用贷款时间序列
    return w.wsd(security,"stmnote_bank_781",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank782Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_保证贷款时间序列
    return w.wsd(security,"stmnote_bank_782",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank783Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_抵押贷款时间序列
    return w.wsd(security,"stmnote_bank_783",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank784Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_质押贷款时间序列
    return w.wsd(security,"stmnote_bank_784",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank841Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_短期贷款时间序列
    return w.wsd(security,"stmnote_bank_841",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank842Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款利息收入_中长期贷款时间序列
    return w.wsd(security,"stmnote_bank_842",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息收入_FUND时间序列
    return w.wsd(security,"stm_is_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券利息收入_FUND时间序列
    return w.wsd(security,"stm_is_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs76Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他利息收入_FUND时间序列
    return w.wsd(security,"stm_is_76",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInterestIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息收入时间序列
    return w.wsd(security,"qfa_interest_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用:利息收入时间序列
    return w.wsd(security,"fin_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取固定息证券投资利息收入时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaFinIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.财务费用:利息收入时间序列
    return w.wsd(security,"qfa_fin_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSurPremUnearnedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已赚保费时间序列
    return w.wsd(security,"insur_prem_unearned",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPremiumsEarnedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净已赚保费_GSD时间序列
    return w.wsd(security,"wgsd_premiums_earned",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInSurPremUnearnedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.已赚保费时间序列
    return w.wsd(security,"qfa_insur_prem_unearned",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaPremiumsEarnedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净已赚保费_GSD时间序列
    return w.wsd(security,"wgsd_qfa_premiums_earned",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1500Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入合计时间序列
    return w.wsd(security,"stmnote_sec_1500",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1501Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:证券经纪业务时间序列
    return w.wsd(security,"stmnote_sec_1501",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1503Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:证券承销业务时间序列
    return w.wsd(security,"stmnote_sec_1503",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1505Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:保荐业务时间序列
    return w.wsd(security,"stmnote_sec_1505",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1506Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:投资咨询业务时间序列
    return w.wsd(security,"stmnote_sec_1506",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1507Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入:期货经纪业务时间序列
    return w.wsd(security,"stmnote_sec_1507",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFeeComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入_GSD时间序列
    return w.wsd(security,"wgsd_fee_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHandlingChrGComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金收入时间序列
    return w.wsd(security,"handling_chrg_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaFeeComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.手续费及佣金收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_fee_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaHandlingChrGComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.手续费及佣金收入时间序列
    return w.wsd(security,"qfa_handling_chrg_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTPremIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保费业务收入时间序列
    return w.wsd(security,"tot_prem_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReInSurIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分保费收入时间序列
    return w.wsd(security,"reinsur_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaReInSurIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.分保费收入时间序列
    return w.wsd(security,"qfa_reinsur_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPremiumReInsurersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分出保费_GSD时间序列
    return w.wsd(security,"wgsd_premium_reinsurers",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPremCededSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分出保费时间序列
    return w.wsd(security,"prem_ceded",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaPremiumReInsurersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.分出保费_GSD时间序列
    return w.wsd(security,"wgsd_qfa_premium_reinsurers",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaPremCededSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.分出保费时间序列
    return w.wsd(security,"qfa_prem_ceded",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnearnedPremRsRvWithdrawSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提取未到期责任准备金时间序列
    return w.wsd(security,"unearned_prem_rsrv_withdraw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaUnearnedPremRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.提取未到期责任准备金时间序列
    return w.wsd(security,"qfa_unearned_prem_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetIncAgencyBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代理买卖证券业务净收入时间序列
    return w.wsd(security,"net_inc_agencybusiness",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetIncAgencyBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.代理买卖证券业务净收入时间序列
    return w.wsd(security,"qfa_net_inc_agencybusiness",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetIncUnderwritingBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券承销业务净收入时间序列
    return w.wsd(security,"net_inc_underwriting-business",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetIncUnderwritingBusinessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.证券承销业务净收入时间序列
    return w.wsd(security,"qfa_net_inc_underwriting-business",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherOperIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他业务收入时间序列
    return w.wsd(security,"other_oper_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSeg1703Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他业务收入(附注)时间序列
    return w.wsd(security,"stmnote_seg_1703",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherOperIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他业务收入时间序列
    return w.wsd(security,"qfa_other_oper_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1530Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息净收入合计时间序列
    return w.wsd(security,"stmnote_sec_1530",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1532Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息净收入:金融企业往来业务收入时间序列
    return w.wsd(security,"stmnote_sec_1532",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDIntIncNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息净收入_GSD时间序列
    return w.wsd(security,"wgsd_int_inc_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息净收入时间序列
    return w.wsd(security,"net_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaIntIncNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息净收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_int_inc_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息净收入时间序列
    return w.wsd(security,"qfa_net_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1520Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入合计时间序列
    return w.wsd(security,"stmnote_sec_1520",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1521Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:证券经纪业务时间序列
    return w.wsd(security,"stmnote_sec_1521",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1523Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:证券承销业务时间序列
    return w.wsd(security,"stmnote_sec_1523",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1525Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:保荐业务时间序列
    return w.wsd(security,"stmnote_sec_1525",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1526Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:投资咨询业务时间序列
    return w.wsd(security,"stmnote_sec_1526",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1527Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:期货经纪业务时间序列
    return w.wsd(security,"stmnote_sec_1527",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1554Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入:其他业务时间序列
    return w.wsd(security,"stmnote_sec_1554",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFeeComMIncNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入_GSD时间序列
    return w.wsd(security,"wgsd_fee_comm_inc_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetFeeAndCommissionIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金净收入时间序列
    return w.wsd(security,"net_fee_and_commission_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaFeeComMIncNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.手续费及佣金净收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_fee_comm_inc_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetFeeAndCommissionIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.手续费及佣金净收入时间序列
    return w.wsd(security,"qfa_net_fee_and_commission_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetOtherOperIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他业务净收益时间序列
    return w.wsd(security,"net_other_oper_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetOtherOperIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他业务净收益时间序列
    return w.wsd(security,"qfa_net_other_oper_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本(TTM)时间序列
    return w.wsd(security,"gc_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本(TTM)_GSD时间序列
    return w.wsd(security,"gc_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsSCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本时间序列
    return w.wsd(security,"stm07_is_reits_scost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperatingCost2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本2时间序列
    return w.wsd(security,"operating_cost2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaGcTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本(TTM)_PIT时间序列
    return w.wsd(security,"fa_gc_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGcTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业总成本(TTM,只有最新数据)时间序列
    return w.wsd(security,"gc_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOperatingCost2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业总成本2时间序列
    return w.wsd(security,"qfa_operating_cost2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTOperCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业总成本时间序列
    return w.wsd(security,"qfa_tot_oper_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCostTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业成本-非金融类(TTM)时间序列
    return w.wsd(security,"cost_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCostTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业成本-非金融类(TTM)_GSD时间序列
    return w.wsd(security,"cost_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOperCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业成本_GSD时间序列
    return w.wsd(security,"wgsd_oper_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业成本时间序列
    return w.wsd(security,"stm07_is_reits_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOcNfTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业成本-非金融类(TTM)_PIT时间序列
    return w.wsd(security,"fa_ocnf_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCostTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业成本-非金融类(TTM,只有最新数据)时间序列
    return w.wsd(security,"cost_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcSurpriseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本Surprise(可选类型)时间序列
    return w.wsd(security,"west_avgoc_surprise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcSurprisePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业成本Surprise百分比(可选类型)时间序列
    return w.wsd(security,"west_avgoc_surprise_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业成本(FY1)时间序列
    return w.wsd(security,"west_avgoc_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业成本(FY2)时间序列
    return w.wsd(security,"west_avgoc_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOcFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业成本(FY3)时间序列
    return w.wsd(security,"west_avgoc_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaOperCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业成本_GSD时间序列
    return w.wsd(security,"wgsd_qfa_oper_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOperCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业成本时间序列
    return w.wsd(security,"qfa_oper_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestExpenseTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息支出(TTM)_GSD时间序列
    return w.wsd(security,"interestexpense_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息支出_GSD时间序列
    return w.wsd(security,"wgsd_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息支出时间序列
    return w.wsd(security,"int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs72Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息支出_FUND时间序列
    return w.wsd(security,"stm_is_72",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInterestExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息支出(TTM)_PIT时间序列
    return w.wsd(security,"fa_interestexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank649Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息支出_存款总额时间序列
    return w.wsd(security,"stmnote_bank_649",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank631Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息支出_个人定期存款时间序列
    return w.wsd(security,"stmnote_bank_631",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank632Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息支出_个人活期存款时间序列
    return w.wsd(security,"stmnote_bank_632",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank633Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息支出_公司定期存款时间序列
    return w.wsd(security,"stmnote_bank_633",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank634Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息支出_公司活期存款时间序列
    return w.wsd(security,"stmnote_bank_634",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank635Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款利息支出_其它存款时间序列
    return w.wsd(security,"stmnote_bank_635",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息支出_GSD时间序列
    return w.wsd(security,"wgsd_qfa_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInterestExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息支出时间序列
    return w.wsd(security,"qfa_interest_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHandlingChrGComMExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金支出时间序列
    return w.wsd(security,"handling_chrg_comm_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaHandlingChrGComMExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.手续费及佣金支出时间序列
    return w.wsd(security,"qfa_handling_chrg_comm_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业支出-金融类(TTM)时间序列
    return w.wsd(security,"expense_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业支出-金融类(TTM)_GSD时间序列
    return w.wsd(security,"expense_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业支出时间序列
    return w.wsd(security,"oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOEfTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业支出-金融类(TTM)_PIT时间序列
    return w.wsd(security,"fa_oef_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业支出-金融类(TTM,只有最新数据)时间序列
    return w.wsd(security,"expense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOperExpToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总营业支出_GSD时间序列
    return w.wsd(security,"wgsd_oper_exp_tot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业支出时间序列
    return w.wsd(security,"qfa_oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaOperExpToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.总营业支出_GSD时间序列
    return w.wsd(security,"wgsd_qfa_oper_exp_tot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税金及附加时间序列
    return w.wsd(security,"stm07_is_reits_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs26Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取税金及附加_FUND时间序列
    return w.wsd(security,"stm_is_26",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaTaxesSurchargesOpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.税金及附加时间序列
    return w.wsd(security,"qfa_taxes_surcharges_ops",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用(TTM)时间序列
    return w.wsd(security,"operateexpense_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用(TTM)_GSD时间序列
    return w.wsd(security,"operateexpense_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSalesExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用_GSD时间序列
    return w.wsd(security,"wgsd_sales_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsSalesFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用时间序列
    return w.wsd(security,"stm07_is_reits_salesfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSellExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用(TTM)_PIT时间序列
    return w.wsd(security,"fa_sellexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售费用(TTM,只有最新数据)时间序列
    return w.wsd(security,"operateexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSellingDistExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售费用时间序列
    return w.wsd(security,"qfa_selling_dist_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7630Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取租赁费(销售费用)时间序列
    return w.wsd(security,"stmnote_others_7630",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7626Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取工资薪酬(销售费用)时间序列
    return w.wsd(security,"stmnote_others_7626",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7628Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取折旧摊销(销售费用)时间序列
    return w.wsd(security,"stmnote_others_7628",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7632Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取仓储运输费(销售费用)时间序列
    return w.wsd(security,"stmnote_others_7632",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7633Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取广告宣传推广费(销售费用)时间序列
    return w.wsd(security,"stmnote_others_7633",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用(TTM)时间序列
    return w.wsd(security,"adminexpense_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用(TTM)_GSD时间序列
    return w.wsd(security,"adminexpense_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDMgTExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用_GSD时间序列
    return w.wsd(security,"wgsd_mgt_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsManageFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用时间序列
    return w.wsd(security,"stm07_is_reits_managefee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaAdminExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用(TTM)_PIT时间序列
    return w.wsd(security,"fa_adminexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdminExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取管理费用(TTM,只有最新数据)时间序列
    return w.wsd(security,"adminexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaGerLAdminExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.管理费用时间序列
    return w.wsd(security,"qfa_gerl_admin_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7631Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取租赁费(管理费用)时间序列
    return w.wsd(security,"stmnote_others_7631",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7627Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取工资薪酬(管理费用)时间序列
    return w.wsd(security,"stmnote_others_7627",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7629Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取折旧摊销(管理费用)时间序列
    return w.wsd(security,"stmnote_others_7629",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用(TTM)时间序列
    return w.wsd(security,"finaexpense_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用(TTM)_GSD时间序列
    return w.wsd(security,"finaexpense_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsFinanceFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用时间序列
    return w.wsd(security,"stm07_is_reits_financefee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用:利息费用时间序列
    return w.wsd(security,"fin_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinExpCsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用_CS时间序列
    return w.wsd(security,"fin_exp_cs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFinaExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用(TTM)_PIT时间序列
    return w.wsd(security,"fa_finaexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinaExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取财务费用(TTM,只有最新数据)时间序列
    return w.wsd(security,"finaexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaFinExpIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.财务费用时间序列
    return w.wsd(security,"qfa_fin_exp_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaFinIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.财务费用:利息费用时间序列
    return w.wsd(security,"qfa_fin_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaFinExpCsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.财务费用_CS时间序列
    return w.wsd(security,"qfa_fin_exp_cs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditImpairLoss2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用减值损失时间序列
    return w.wsd(security,"credit_impair_loss2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCreditImpairLoss2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.信用减值损失时间序列
    return w.wsd(security,"qfa_credit_impair_loss2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrepaySurRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取退保金时间序列
    return w.wsd(security,"prepay_surr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaPrepaySurRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.退保金时间序列
    return w.wsd(security,"qfa_prepay_surr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetClaimExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取赔付支出净额时间序列
    return w.wsd(security,"net_claim_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetClaimExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.赔付支出净额时间序列
    return w.wsd(security,"qfa_net_claim_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInSurContRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提取保险责任准备金时间序列
    return w.wsd(security,"net_insur_cont_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInSurContRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.提取保险责任准备金时间序列
    return w.wsd(security,"qfa_net_insur_cont_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDvdExpInsuredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单红利支出时间序列
    return w.wsd(security,"dvd_exp_insured",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDvdExpInsuredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.保单红利支出时间序列
    return w.wsd(security,"qfa_dvd_exp_insured",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReinsuranceExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分保费用时间序列
    return w.wsd(security,"reinsurance_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReInSurExpRecoverableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取摊回分保费用时间序列
    return w.wsd(security,"reinsur_exp_recoverable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaReinsuranceExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.分保费用时间序列
    return w.wsd(security,"qfa_reinsurance_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaReInSurExpRecoverableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.摊回分保费用时间序列
    return w.wsd(security,"qfa_reinsur_exp_recoverable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClaimExpRecoverableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取摊回赔付支出时间序列
    return w.wsd(security,"claim_exp_recoverable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaClaimExpRecoverableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.摊回赔付支出时间序列
    return w.wsd(security,"qfa_claim_exp_recoverable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInSurRsRvRecoverableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取摊回保险责任准备金时间序列
    return w.wsd(security,"Insur_rsrv_recoverable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInSurRsRvRecoverableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.摊回保险责任准备金时间序列
    return w.wsd(security,"qfa_Insur_rsrv_recoverable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他业务成本时间序列
    return w.wsd(security,"other_oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSeg1704Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他业务成本(附注)时间序列
    return w.wsd(security,"stmnote_seg_1704",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他业务成本时间序列
    return w.wsd(security,"qfa_other_oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetIncOtherOpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他经营净收益时间序列
    return w.wsd(security,"net_inc_other_ops",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetIncOtherOpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他经营净收益时间序列
    return w.wsd(security,"qfa_net_inc_other_ops",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetGainChgFvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公允价值变动净收益时间序列
    return w.wsd(security,"net_gain_chg_fv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetGainChgFvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.公允价值变动净收益时间序列
    return w.wsd(security,"qfa_net_gain_chg_fv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInvestIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资净收益时间序列
    return w.wsd(security,"net_invest_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInvestIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资净收益时间序列
    return w.wsd(security,"qfa_net_invest_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetExposureHedgeBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净敞口套期收益时间序列
    return w.wsd(security,"net_exposure_hedge_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetExposureHedgeBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净敞口套期收益时间序列
    return w.wsd(security,"qfa_net_exposure_hedge_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetGainFxTransSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取汇兑净收益时间序列
    return w.wsd(security,"net_gain_fx_trans",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetGainFxTransSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.汇兑净收益时间序列
    return w.wsd(security,"qfa_net_gain_fx_trans",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherGrantsIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他收益时间序列
    return w.wsd(security,"other_grants_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherGrantsIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他收益时间序列
    return w.wsd(security,"qfa_other_grants_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpProfitGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润差额(特殊报表科目)时间序列
    return w.wsd(security,"opprofit_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpProfitGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润差额说明(特殊报表科目)时间序列
    return w.wsd(security,"opprofit_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpProfitNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润差额(合计平衡项目)时间序列
    return w.wsd(security,"opprofit_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestInStNumOpMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润率(OPM)预测机构家数(可选类型)时间序列
    return w.wsd(security,"west_instnum_opm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxToOrTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/利润总额(TTM)时间序列
    return w.wsd(security,"taxtoor_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(TTM)时间序列
    return w.wsd(security,"op_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOpToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/利润总额_GSD时间序列
    return w.wsd(security,"wgsd_optoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpToEBTTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/利润总额(TTM)_GSD时间序列
    return w.wsd(security,"optoebt_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(TTM)_GSD时间序列
    return w.wsd(security,"op_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润_GSD时间序列
    return w.wsd(security,"wgsd_ebit_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润时间序列
    return w.wsd(security,"stm07_is_reits_profit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOpToPbtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润/利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_optopbt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_op_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业利润(TTM,只有最新数据)时间序列
    return w.wsd(security,"op_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOpToEBTTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非营业利润/利润总额(TTM)_GSD时间序列
    return w.wsd(security,"nonoptoebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非营业利润(TTM)_GSD时间序列
    return w.wsd(security,"nonop_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGoPmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润率(OPM)平均值(可选类型)时间序列
    return w.wsd(security,"west_avgopm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxOpMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润率(OPM)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxopm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMinoPmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润率(OPM)最小值(可选类型)时间序列
    return w.wsd(security,"west_minopm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMediaOpMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润率(OPM)中值(可选类型)时间序列
    return w.wsd(security,"west_mediaopm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDoPmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润率(OPM)标准差值(可选类型)时间序列
    return w.wsd(security,"west_stdopm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitSurpriseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润Surprise(可选类型)时间序列
    return w.wsd(security,"west_avgoperatingprofit_surprise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitSurprisePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测营业利润Surprise百分比(可选类型)时间序列
    return w.wsd(security,"west_avgoperatingprofit_surprise_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOppSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业利润_PIT时间序列
    return w.wsd(security,"fa_opps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOppSTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股营业利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_opps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业利润(FY1)时间序列
    return w.wsd(security,"west_avgoperatingprofit_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业利润(FY2)时间序列
    return w.wsd(security,"west_avgoperatingprofit_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgOperatingProfitFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测营业利润(FY3)时间序列
    return w.wsd(security,"west_avgoperatingprofit_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaEbItOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_ebit_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOpProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业利润时间序列
    return w.wsd(security,"qfa_opprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperRevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收入时间序列
    return w.wsd(security,"non_oper_rev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNonOperRevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业外收入时间序列
    return w.wsd(security,"qfa_non_oper_rev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers4504Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取政府补助_营业外收入时间序列
    return w.wsd(security,"stmnote_others_4504",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外支出时间序列
    return w.wsd(security,"non_oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNonOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营业外支出时间序列
    return w.wsd(security,"qfa_non_oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额差额(特殊报表科目)时间序列
    return w.wsd(security,"profit_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额差额说明(特殊报表科目)时间序列
    return w.wsd(security,"profit_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额差额(合计平衡项目)时间序列
    return w.wsd(security,"profit_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEBtTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(TTM)时间序列
    return w.wsd(security,"ebt_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEBtTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(TTM)_GSD时间序列
    return w.wsd(security,"ebt_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsSumProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额时间序列
    return w.wsd(security,"stm07_is_reits_sumprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEBtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_ebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEBtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利润总额(TTM,只有最新数据)时间序列
    return w.wsd(security,"ebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTSurpriseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额Surprise(可选类型)时间序列
    return w.wsd(security,"west_avgebt_surprise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTSurprisePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测利润总额Surprise百分比(可选类型)时间序列
    return w.wsd(security,"west_avgebt_surprise_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxToEBTTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税项/利润总额(TTM)时间序列
    return w.wsd(security,"taxtoebt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTaxToEBTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税项/利润总额_GSD时间序列
    return w.wsd(security,"wgsd_taxtoebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTaxToEBTTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取税项/利润总额(TTM)_GSD时间序列
    return w.wsd(security,"taxtoebt_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTaxToProfitBtTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取税项/利润总额(TTM)_PIT时间序列
    return w.wsd(security,"fa_taxtoprofitbt_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测利润总额(FY1)时间序列
    return w.wsd(security,"west_avgebt_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测利润总额(FY2)时间序列
    return w.wsd(security,"west_avgebt_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebTFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测利润总额(FY3)时间序列
    return w.wsd(security,"west_avgebt_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利润总额时间序列
    return w.wsd(security,"qfa_tot_profit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnconfirmedInvestLossBsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未确认的投资损失_BS时间序列
    return w.wsd(security,"unconfirmed_invest_loss_bs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnconfirmedInvestLossIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未确认的投资损失时间序列
    return w.wsd(security,"unconfirmed_invest_loss_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnconfirmedInvestLossCsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未确认的投资损失_CS时间序列
    return w.wsd(security,"unconfirmed_invest_loss_cs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaUnconfirmedInvestLossIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.未确认的投资损失时间序列
    return w.wsd(security,"qfa_unconfirmed_invest_loss_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaUnconfirmedInvestLossCsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.未确认的投资损失_CS时间序列
    return w.wsd(security,"qfa_unconfirmed_invest_loss_cs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitIsGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润差额(特殊报表科目)时间序列
    return w.wsd(security,"net_profit_is_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitIsGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润差额说明(特殊报表科目)时间序列
    return w.wsd(security,"net_profit_is_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitIsNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润差额(合计平衡项目)时间序列
    return w.wsd(security,"net_profit_is_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_profit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(TTM)时间序列
    return w.wsd(security,"profit_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(TTM)_GSD时间序列
    return w.wsd(security,"profit_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNoGaapProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(Non-GAAP)_GSD时间序列
    return w.wsd(security,"wgsd_nogaapprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润_GSD时间序列
    return w.wsd(security,"wgsd_net_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetIncCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润_CS_GSD时间序列
    return w.wsd(security,"wgsd_net_inc_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07IsReItsNetProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润时间序列
    return w.wsd(security,"stm07_is_reits_netprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitCsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润_CS时间序列
    return w.wsd(security,"net_profit_cs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs79Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润_FUND时间序列
    return w.wsd(security,"stm_is_79",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs79TotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利润(合计)_FUND时间序列
    return w.wsd(security,"stm_is_79_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getManetProfitFy0Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取备考净利润(FY0,并购后)时间序列
    return w.wsd(security,"manetprofit_fy0",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getManetProfitFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取备考净利润(FY1,并购后)时间序列
    return w.wsd(security,"manetprofit_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getManetProfitFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取备考净利润(FY2,并购后)时间序列
    return w.wsd(security,"manetprofit_fy2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getManetProfitFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取备考净利润(FY3,并购后)时间序列
    return w.wsd(security,"manetprofit_fy3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitSurpriseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润Surprise(可选类型)时间序列
    return w.wsd(security,"west_netprofit_surprise",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitSurprisePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测净利润Surprise百分比(可选类型)时间序列
    return w.wsd(security,"west_netprofit_surprise_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEarnMom8QTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取八季度净利润变化趋势_PIT时间序列
    return w.wsd(security,"fa_earnmom8qtr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)时间序列
    return w.wsd(security,"west_netprofit_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY2)时间序列
    return w.wsd(security,"west_netprofit_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY3)时间序列
    return w.wsd(security,"west_netprofit_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConnPToProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持续经营净利润/税后利润(TTM)_GSD时间序列
    return w.wsd(security,"connptoprofit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConnPTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持续经营净利润(TTM)_GSD时间序列
    return w.wsd(security,"connp_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNoGaapProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润(Non-GAAP)_GSD时间序列
    return w.wsd(security,"wgsd_qfa_nogaapprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDContinueOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持续经营净利润_GSD时间序列
    return w.wsd(security,"wgsd_continue_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNetIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_net_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNetIncCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润_CS_GSD时间序列
    return w.wsd(security,"wgsd_qfa_net_inc_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitContinuedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持续经营净利润时间序列
    return w.wsd(security,"net_profit_continued",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitDiscontinuedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取终止经营净利润时间序列
    return w.wsd(security,"net_profit_discontinued",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetProfitIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润时间序列
    return w.wsd(security,"qfa_net_profit_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetProfitCsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.净利润_CS时间序列
    return w.wsd(security,"qfa_net_profit_cs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期实现净利润时间序列
    return w.wsd(security,"stmnote_profitapr_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy11MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)变化率_1M_PIT时间序列
    return w.wsd(security,"west_netprofit_fy1_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy13MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)变化率_3M_PIT时间序列
    return w.wsd(security,"west_netprofit_fy1_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy16MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)变化率_6M_PIT时间序列
    return w.wsd(security,"west_netprofit_fy1_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy1Chg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)的变化_1M_PIT时间序列
    return w.wsd(security,"west_netprofit_fy1_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy1Chg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)的变化_3M_PIT时间序列
    return w.wsd(security,"west_netprofit_fy1_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitFy1Chg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)的变化_6M_PIT时间序列
    return w.wsd(security,"west_netprofit_fy1_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdNetProfitFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)标准差_PIT时间序列
    return w.wsd(security,"west_stdnetprofit_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestNetProfitMaxMinFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测净利润(FY1)最大与一致预测净利润(FY1)最小值的变化率_PIT时间序列
    return w.wsd(security,"west_netprofitmaxmin_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonConnPTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非持续经营净利润(TTM)_GSD时间序列
    return w.wsd(security,"nonconnp_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDiscOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非持续经营净利润_GSD时间序列
    return w.wsd(security,"wgsd_disc_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetIncDilSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属普通股东净利润_GSD时间序列
    return w.wsd(security,"wgsd_net_inc_dil",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(TTM)_VAL_PIT时间序列
    return w.wsd(security,"netprofit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(TTM)时间序列
    return w.wsd(security,"netprofit_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetProfitTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(TTM)_GSD时间序列
    return w.wsd(security,"netprofit_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDeductedProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除非经常损益后净利润_GSD时间序列
    return w.wsd(security,"wgsd_deductedprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaContinueOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.持续经营净利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_continue_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNpBelongToParComShSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润时间序列
    return w.wsd(security,"np_belongto_parcomsh",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetProfitContinuedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.持续经营净利润时间序列
    return w.wsd(security,"qfa_net_profit_continued",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetProfitDiscontinuedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.终止经营净利润时间序列
    return w.wsd(security,"qfa_net_profit_discontinued",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的净利润(TTM)_PIT时间序列
    return w.wsd(security,"fa_netprofit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDiscOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.非持续经营净利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_disc_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNetIncDilSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属普通股东净利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_net_inc_dil",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDeductedProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.扣除非经常损益后净利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_deductedprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNpBelongToParComShSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.归属母公司股东的净利润时间序列
    return w.wsd(security,"qfa_np_belongto_parcomsh",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期经营活动产生的基金净值变动数(本期净利润)时间序列
    return w.wsd(security,"stm_navchange_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMinorityInterestTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东损益(TTM)时间序列
    return w.wsd(security,"minorityinterest_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMinorityInterestTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东损益(TTM)_GSD时间序列
    return w.wsd(security,"minorityinterest_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDMinIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东损益_GSD时间序列
    return w.wsd(security,"wgsd_min_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMinorityIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东损益时间序列
    return w.wsd(security,"minority_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems23Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东损益影响数时间序列
    return w.wsd(security,"stmnote_Eoitems_23",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaMinInterestTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东损益(TTM)_PIT时间序列
    return w.wsd(security,"fa_mininterest_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaMinIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.少数股东损益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_min_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaMinorityIntIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.少数股东损益时间序列
    return w.wsd(security,"qfa_minority_int_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEpsBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益_GSD时间序列
    return w.wsd(security,"wgsd_eps_basic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEpsBasicIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益时间序列
    return w.wsd(security,"eps_basic_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEpsBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本每股收益_PIT时间序列
    return w.wsd(security,"fa_eps_basic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProfitNoticeLastYearBasicEarnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上年同期基本每股收益时间序列
    return w.wsd(security,"profitnotice_lastyearbasicearn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaEpsBasicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.基本每股收益EPS_GSD时间序列
    return w.wsd(security,"wgsd_qfa_eps_basic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEpsDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取稀释每股收益_GSD时间序列
    return w.wsd(security,"wgsd_eps_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEpsDilutedIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取稀释每股收益时间序列
    return w.wsd(security,"eps_diluted_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEpsDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取稀释每股收益_PIT时间序列
    return w.wsd(security,"fa_eps_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaEpsDilutedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.稀释每股收益EPS_GSD时间序列
    return w.wsd(security,"wgsd_qfa_eps_diluted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaToTPremIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.保费总收入时间序列
    return w.wsd(security,"qfa_tot_prem_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaGrossMargin2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.毛利_GSD时间序列
    return w.wsd(security,"wgsd_qfa_grossmargin2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaGrossMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.毛利时间序列
    return w.wsd(security,"qfa_grossmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSegmentSalesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营收入构成时间序列
    return w.wsd(security,"segment_sales",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSeg1501Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取海外业务收入时间序列
    return w.wsd(security,"stmnote_seg_1501",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取期初未分配利润时间序列
    return w.wsd(security,"stmnote_profitapr_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付普通股股利时间序列
    return w.wsd(security,"stmnote_profitapr_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取提取法定盈余公积时间序列
    return w.wsd(security,"stmnote_profitapr_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取提取任意盈余公积时间序列
    return w.wsd(security,"stmnote_profitapr_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取转增股本时间序列
    return w.wsd(security,"stmnote_profitapr_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCapitalization2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股转增股本(已宣告)时间序列
    return w.wsd(security,"div_capitalization2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCapitalizationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股转增股本时间序列
    return w.wsd(security,"div_capitalization",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取年末未分配利润时间序列
    return w.wsd(security,"stmnote_profitapr_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteProfitApr10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取提取一般风险准备时间序列
    return w.wsd(security,"stmnote_profitapr_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGuarantee1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保发生额合计时间序列
    return w.wsd(security,"stmnote_guarantee_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGuarantee4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取对控股子公司担保发生额合计时间序列
    return w.wsd(security,"stmnote_guarantee_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGuarantee2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取担保余额合计时间序列
    return w.wsd(security,"stmnote_guarantee_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGuarantee3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取关联担保余额合计时间序列
    return w.wsd(security,"stmnote_guarantee_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteGuarantee5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取违规担保总额时间序列
    return w.wsd(security,"stmnote_guarantee_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssociated1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取向关联方销售产品金额时间序列
    return w.wsd(security,"stmnote_associated_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssociated2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取向关联方采购产品金额时间序列
    return w.wsd(security,"stmnote_associated_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssociated3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取向关联方提供资金发生额时间序列
    return w.wsd(security,"stmnote_associated_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssociated4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取向关联方提供资金余额时间序列
    return w.wsd(security,"stmnote_associated_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssociated5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取关联方向上市公司提供资金发生额时间序列
    return w.wsd(security,"stmnote_associated_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssociated6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取关联方向上市公司提供资金余额时间序列
    return w.wsd(security,"stmnote_associated_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditAgencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计单位时间序列
    return w.wsd(security,"stmnote_audit_agency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInAuditAgencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内控_审计单位时间序列
    return w.wsd(security,"stmnote_InAudit_agency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditCpaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取签字注册会计师时间序列
    return w.wsd(security,"stmnote_audit_cpa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditExpenseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期实付审计费用时间序列
    return w.wsd(security,"stmnote_audit_expense",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计报告披露日期时间序列
    return w.wsd(security,"stmnote_audit_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditInterpretationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计结果说明时间序列
    return w.wsd(security,"stmnote_audit_interpretation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInAuditInterpretationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内控_审计结果说明时间序列
    return w.wsd(security,"stmnote_InAudit_interpretation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuditKamSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取关键审计事项时间序列
    return w.wsd(security,"stmnote_audit_kam",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInAuditCpaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内控_签字审计师时间序列
    return w.wsd(security,"stmnote_InAudit_cpa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInAuditIssuingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内控报告披露日期时间序列
    return w.wsd(security,"stmnote_InAudit_issuingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-原材料时间序列
    return w.wsd(security,"stmnote_inv_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-在产品时间序列
    return w.wsd(security,"stmnote_inv_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-产成品时间序列
    return w.wsd(security,"stmnote_inv_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-低值易耗品时间序列
    return w.wsd(security,"stmnote_inv_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-包装物时间序列
    return w.wsd(security,"stmnote_inv_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-委托加工材料时间序列
    return w.wsd(security,"stmnote_inv_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-委托代销商品时间序列
    return w.wsd(security,"stmnote_inv_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInv8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-已加工未结算时间序列
    return w.wsd(security,"stmnote_inv_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvGoodsShipSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货明细-发出商品时间序列
    return w.wsd(security,"stmnote_inv_goodsship",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货合计时间序列
    return w.wsd(security,"stmnote_invtot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteArTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款余额时间序列
    return w.wsd(security,"stmnote_ar_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAr1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款-金额时间序列
    return w.wsd(security,"stmnote_ar_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAr2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款-比例时间序列
    return w.wsd(security,"stmnote_ar_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAr3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款-坏账准备时间序列
    return w.wsd(security,"stmnote_ar_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteArCatSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款-坏账准备(按性质)时间序列
    return w.wsd(security,"stmnote_ar_cat",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteArDebtorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款-主要欠款人时间序列
    return w.wsd(security,"stmnote_ar_debtor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteArDebtorNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款-主要欠款人名称时间序列
    return w.wsd(security,"stmnote_ar_debtorname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他应收款-金额时间序列
    return w.wsd(security,"stmnote_or",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取坏账准备合计时间序列
    return w.wsd(security,"stmnote_reserve_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取坏账准备-应收账款时间序列
    return w.wsd(security,"stmnote_reserve_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取坏账准备-其它应收款时间序列
    return w.wsd(security,"stmnote_reserve_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期投资跌价准备合计时间序列
    return w.wsd(security,"stmnote_reserve_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期投资跌价准备-股票投资时间序列
    return w.wsd(security,"stmnote_reserve_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期投资跌价准备-债券投资时间序列
    return w.wsd(security,"stmnote_reserve_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备合计时间序列
    return w.wsd(security,"stmnote_reserve_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-库存商品时间序列
    return w.wsd(security,"stmnote_reserve_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-原材料时间序列
    return w.wsd(security,"stmnote_reserve_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-产成品时间序列
    return w.wsd(security,"stmnote_reserve_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-低值易耗品时间序列
    return w.wsd(security,"stmnote_reserve_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-开发成本时间序列
    return w.wsd(security,"stmnote_reserve_12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve13Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-包装物时间序列
    return w.wsd(security,"stmnote_reserve_13",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-在途物资时间序列
    return w.wsd(security,"stmnote_reserve_14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve15Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-在产品时间序列
    return w.wsd(security,"stmnote_reserve_15",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve16Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-开发产品时间序列
    return w.wsd(security,"stmnote_reserve_16",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve17Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价准备-自制半成品时间序列
    return w.wsd(security,"stmnote_reserve_17",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve18Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期投资减值准备合计时间序列
    return w.wsd(security,"stmnote_reserve_18",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期投资减值准备-长期股权投资时间序列
    return w.wsd(security,"stmnote_reserve_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期投资减值准备-长期债权投资时间序列
    return w.wsd(security,"stmnote_reserve_20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve35Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取在建工程减值准备时间序列
    return w.wsd(security,"stmnote_reserve_35",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve36Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取委托贷款减值准备时间序列
    return w.wsd(security,"stmnote_reserve_36",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve37Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营证券跌价准备时间序列
    return w.wsd(security,"stmnote_reserve_37",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteReserve38Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款呆账准备时间序列
    return w.wsd(security,"stmnote_reserve_38",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资性房地产-原值时间序列
    return w.wsd(security,"stmnote_assetdetail_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资性房地产-累计折旧时间序列
    return w.wsd(security,"stmnote_assetdetail_6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资性房地产-减值准备时间序列
    return w.wsd(security,"stmnote_assetdetail_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAssetDetail8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资性房地产-净额时间序列
    return w.wsd(security,"stmnote_assetdetail_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteCashDeposits1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存放中央银行法定准备金时间序列
    return w.wsd(security,"stmnote_cash_deposits_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteCashDeposits2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存放中央银行超额存款准备金时间序列
    return w.wsd(security,"stmnote_cash_deposits_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4405Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取人民币存款时间序列
    return w.wsd(security,"stmnote_DPST_4405",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4406Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取美元存款(折算人民币)时间序列
    return w.wsd(security,"stmnote_DPST_4406",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4407Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取日元存款(折算人民币)时间序列
    return w.wsd(security,"stmnote_DPST_4407",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4408Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取欧元存款(折算人民币)时间序列
    return w.wsd(security,"stmnote_DPST_4408",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4409Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取港币存款(折算人民币)时间序列
    return w.wsd(security,"stmnote_DPST_4409",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4410Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取英镑存款(折算人民币)时间序列
    return w.wsd(security,"stmnote_DPST_4410",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteDpsT4411Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他货币存款(折算人民币)时间序列
    return w.wsd(security,"stmnote_DPST_4411",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteOthers7637Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一年内到期的应付债券时间序列
    return w.wsd(security,"stmnote_others_7637",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取税收返还、减免时间序列
    return w.wsd(security,"stmnote_Eoitems_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取政府补助时间序列
    return w.wsd(security,"stmnote_Eoitems_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资金占用费时间序列
    return w.wsd(security,"stmnote_Eoitems_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业合并产生的损益时间序列
    return w.wsd(security,"stmnote_Eoitems_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取委托投资损益时间序列
    return w.wsd(security,"stmnote_Eoitems_12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债务重组损益时间序列
    return w.wsd(security,"stmnote_Eoitems_14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems15Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业重组费用时间序列
    return w.wsd(security,"stmnote_Eoitems_15",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems16Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易产生的损益时间序列
    return w.wsd(security,"stmnote_Eoitems_16",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems17Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取同一控制下企业合并产生的子公司当期净损益时间序列
    return w.wsd(security,"stmnote_Eoitems_17",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems29Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取单独进行减值测试的应收款项减值准备转回时间序列
    return w.wsd(security,"stmnote_Eoitems_29",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems30Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取对外委托贷款取得的收益时间序列
    return w.wsd(security,"stmnote_Eoitems_30",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems31Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取公允价值法计量的投资性房地产价值变动损益时间序列
    return w.wsd(security,"stmnote_Eoitems_31",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems32Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取法规要求一次性损益调整影响时间序列
    return w.wsd(security,"stmnote_Eoitems_32",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems33Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托经营取得的托管费收入时间序列
    return w.wsd(security,"stmnote_Eoitems_33",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他营业外收支净额时间序列
    return w.wsd(security,"stmnote_Eoitems_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEoItems20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取中国证监会认定的其他项目时间序列
    return w.wsd(security,"stmnote_Eoitems_20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取坏账损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货跌价损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取发放贷款和垫款减值损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteImpairmentLoss9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有至到期投资减值损失时间序列
    return w.wsd(security,"stmnote_ImpairmentLoss_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdExpCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期费用化研发支出时间序列
    return w.wsd(security,"stmnote_RDexp_cost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdExpCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取本期资本化研发支出时间序列
    return w.wsd(security,"stmnote_RDexp_capital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发支出合计时间序列
    return w.wsd(security,"stmnote_RDexp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdEmployeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发人员数量时间序列
    return w.wsd(security,"stmnote_RDemployee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteRdEmployeePctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发人员数量占比时间序列
    return w.wsd(security,"stmnote_RDemployee_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteLoans1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取转融通融入资金时间序列
    return w.wsd(security,"stmnote_loans_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteCustomerTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取大客户名称时间序列
    return w.wsd(security,"stmnote_customertop5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSalesTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取大客户销售收入时间序列
    return w.wsd(security,"stmnote_sales_top5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSalesPctTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取大客户销售收入占比时间序列
    return w.wsd(security,"stmnote_sales_pct_top5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSalesTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取前五大客户销售收入总额时间序列
    return w.wsd(security,"stmnote_salestop5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSalesTop5PctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前五大客户销售收入占比时间序列
    return w.wsd(security,"stmnote_salestop5_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSupplierTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取大供应商名称时间序列
    return w.wsd(security,"stmnote_suppliertop5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNotePurchaseTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取大供应商采购金额时间序列
    return w.wsd(security,"stmnote_purchase_top5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNotePurchasePctTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取大供应商采购金额占比时间序列
    return w.wsd(security,"stmnote_purchase__pct_top5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNotePurchaseTop5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取前五大供应商采购金额总额时间序列
    return w.wsd(security,"stmnote_purchasetop5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNotePurchaseTop5PctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前五大供应商采购金额占比时间序列
    return w.wsd(security,"stmnote_purchasetop5_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBenAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工资、奖金、津贴和补贴:本期增加时间序列
    return w.wsd(security,"stmnote_ben_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBenSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工资、奖金、津贴和补贴:期初余额时间序列
    return w.wsd(security,"stmnote_ben_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBenEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工资、奖金、津贴和补贴:期末余额时间序列
    return w.wsd(security,"stmnote_ben_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBenDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工资、奖金、津贴和补贴:本期减少时间序列
    return w.wsd(security,"stmnote_ben_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEduAndUnionFundsAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工会经费和职工教育经费:本期增加时间序列
    return w.wsd(security,"stmnote_eduandunionfunds_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEduAndUnionFundsSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工会经费和职工教育经费:期初余额时间序列
    return w.wsd(security,"stmnote_eduandunionfunds_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEduAndUnionFundsEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工会经费和职工教育经费:期末余额时间序列
    return w.wsd(security,"stmnote_eduandunionfunds_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEduAndUnionFundsDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工会经费和职工教育经费:本期减少时间序列
    return w.wsd(security,"stmnote_eduandunionfunds_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteWelfareAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取职工福利费:本期增加时间序列
    return w.wsd(security,"stmnote_welfare_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteWelfareSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取职工福利费:期初余额时间序列
    return w.wsd(security,"stmnote_welfare_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteWelfareEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取职工福利费:期末余额时间序列
    return w.wsd(security,"stmnote_welfare_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteWelfareDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取职工福利费:本期减少时间序列
    return w.wsd(security,"stmnote_welfare_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteHousingFundAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取住房公积金:本期增加时间序列
    return w.wsd(security,"stmnote_housingfund_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteHousingFundSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取住房公积金:期初余额时间序列
    return w.wsd(security,"stmnote_housingfund_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteHousingFundEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取住房公积金:期末余额时间序列
    return w.wsd(security,"stmnote_housingfund_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteHousingFundDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取住房公积金:本期减少时间序列
    return w.wsd(security,"stmnote_housingfund_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBasicPenAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本养老保险:本期增加时间序列
    return w.wsd(security,"stmnote_basicpen_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBasicPenSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本养老保险:期初余额时间序列
    return w.wsd(security,"stmnote_basicpen_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBasicPenEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本养老保险:期末余额时间序列
    return w.wsd(security,"stmnote_basicpen_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBasicPenDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本养老保险:本期减少时间序列
    return w.wsd(security,"stmnote_basicpen_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMaternityInSAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生育保险费:本期增加时间序列
    return w.wsd(security,"stmnote_maternityins_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMaternityInSSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生育保险费:期初余额时间序列
    return w.wsd(security,"stmnote_maternityins_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMaternityInSEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生育保险费:期末余额时间序列
    return w.wsd(security,"stmnote_maternityins_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMaternityInSDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取生育保险费:本期减少时间序列
    return w.wsd(security,"stmnote_maternityins_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteUneMplInSAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取失业保险费:本期增加时间序列
    return w.wsd(security,"stmnote_unemplins_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteUneMplInSSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取失业保险费:期初余额时间序列
    return w.wsd(security,"stmnote_unemplins_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteUneMplInSEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取失业保险费:期末余额时间序列
    return w.wsd(security,"stmnote_unemplins_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteUneMplInSDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取失业保险费:本期减少时间序列
    return w.wsd(security,"stmnote_unemplins_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMedInSAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取医疗保险费:本期增加时间序列
    return w.wsd(security,"stmnote_medins_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMedInSSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取医疗保险费:期初余额时间序列
    return w.wsd(security,"stmnote_medins_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMedInSEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取医疗保险费:期末余额时间序列
    return w.wsd(security,"stmnote_medins_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteMedInSDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取医疗保险费:本期减少时间序列
    return w.wsd(security,"stmnote_medins_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplInjuryInSAddSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工伤保险费:本期增加时间序列
    return w.wsd(security,"stmnote_emplinjuryins_add",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplInjuryInSSbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工伤保险费:期初余额时间序列
    return w.wsd(security,"stmnote_emplinjuryins_sb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplInjuryInSEbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工伤保险费:期末余额时间序列
    return w.wsd(security,"stmnote_emplinjuryins_eb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteEMplInjuryInSDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工伤保险费:本期减少时间序列
    return w.wsd(security,"stmnote_emplinjuryins_de",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxConsumptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取消费税时间序列
    return w.wsd(security,"stmnote_tax_consumption",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxConstructionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取城建税时间序列
    return w.wsd(security,"stmnote_tax_construction",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxEdeSupplementTarYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取教育费附加时间序列
    return w.wsd(security,"stmnote_tax_edesupplementtary",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxUrbanLandUseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取土地使用税时间序列
    return w.wsd(security,"stmnote_tax_urbanlanduse",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxBuildingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取房产税时间序列
    return w.wsd(security,"stmnote_tax_building",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteTaxStampSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取印花税时间序列
    return w.wsd(security,"stmnote_tax_stamp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.基金利润时间序列
    return w.wsd(security,"qanal_income",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalTotalIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.基金利润(合计)时间序列
    return w.wsd(security,"qanal_totalincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalDeCuteDNetIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.报告期利润扣减当期公允价值变动损益后的净额时间序列
    return w.wsd(security,"qanal_decutednetincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalBenchDevReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.超额收益率时间序列
    return w.wsd(security,"qanal_benchdevreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQAnalStdBenchDevReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.超额收益率标准差时间序列
    return w.wsd(security,"qanal_stdbenchdevreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期利润时间序列
    return w.wsd(security,"anal_income",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalNetIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期利润扣减当期公允价值变动损益后的净额时间序列
    return w.wsd(security,"anal_netincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalAvgNetIncomePerUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期加权平均份额利润时间序列
    return w.wsd(security,"anal_avgnetincomeperunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalDIsTriButAbleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告期末可供分配基金利润时间序列
    return w.wsd(security,"anal_distributable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAnalAvgNavReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金加权平均净值利润率时间序列
    return w.wsd(security,"anal_avgnavreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金申购款时间序列
    return w.wsd(security,"stm_navchange_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange7PaidInCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金申购款(实收基金)时间序列
    return w.wsd(security,"stm_navchange_7_paidincapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金赎回款时间序列
    return w.wsd(security,"stm_navchange_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNavChange8PaidInCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金赎回款(实收基金)时间序列
    return w.wsd(security,"stm_navchange_8_paidincapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs18Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取信息披露费时间序列
    return w.wsd(security,"stm_is_18",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIDcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发信息披露费时间序列
    return w.wsd(security,"ipo_idc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBsGoldContractInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收黄金合约拆借孳息时间序列
    return w.wsd(security,"stm_bs_goldcontractinterest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCommissionTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易佣金(合计值)时间序列
    return w.wsd(security,"commission_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCommissionDetailedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易佣金(分券商明细)时间序列
    return w.wsd(security,"commission_detailed",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsNotesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收票据及应收账款时间序列
    return w.wsd(security,"stm07_bs_reits_notes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsOthersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他应收款(合计)时间序列
    return w.wsd(security,"stm07_bs_reits_others",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资性房地产租金收入时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsRealEstateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资性房地产时间序列
    return w.wsd(security,"stm07_bs_reits_realestate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付票据及应付账款时间序列
    return w.wsd(security,"stm07_bs_reits_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPaymentUnearnedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预收款项_GSD时间序列
    return w.wsd(security,"wgsd_payment_unearned",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsRecIPtsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预收款项时间序列
    return w.wsd(security,"stm07_bs_reits_recipts",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应交税费时间序列
    return w.wsd(security,"stm07_bs_reits_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsOtherPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他应付款(合计)时间序列
    return w.wsd(security,"stm07_bs_reits_otherpayable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsPaidInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实收资本(或股本)时间序列
    return w.wsd(security,"stm07_bs_reits_paidin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsCapitalReserveSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本公积金时间序列
    return w.wsd(security,"stm07_bs_reits_capitalreserve",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsSurplusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取盈余公积金时间序列
    return w.wsd(security,"stm07_bs_reits_surplus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07BsReItsUndIsTriRProfitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未分配利润时间序列
    return w.wsd(security,"stm07_bs_reits_undistrirprofit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs75Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取未分配利润_FUND时间序列
    return w.wsd(security,"stm_bs_75",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsOperCashInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流入小计时间序列
    return w.wsd(security,"stm07_cs_reits_opercashin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSToTCashInFlowsOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动现金流入小计时间序列
    return w.wsd(security,"qfa_stot_cash_inflows_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsOperCashOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流出小计时间序列
    return w.wsd(security,"stm07_cs_reits_opercashout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSToTCashOutFlowsOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营活动现金流出小计时间序列
    return w.wsd(security,"qfa_stot_cash_outflows_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsSalesCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品、提供劳务收到的现金时间序列
    return w.wsd(security,"stm07_cs_reits_salescash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecpSgAndRsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售商品、提供劳务收到的现金时间序列
    return w.wsd(security,"qfa_cash_recp_sg_and_rs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsBuyCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取购买商品、接受劳务支付的现金时间序列
    return w.wsd(security,"stm07_cs_reits_buycash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPayGoodsPUrchSerVRecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.购买商品、接受劳务支付的现金时间序列
    return w.wsd(security,"qfa_cash_pay_goods_purch_serv_rec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付的各项税费时间序列
    return w.wsd(security,"stm07_cs_reits_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaPayAllTyPTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付的各项税费时间序列
    return w.wsd(security,"qfa_pay_all_typ_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsPaidCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付其他与经营活动有关的现金时间序列
    return w.wsd(security,"stm07_cs_reits_paidcash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCashPayRalOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付其他与经营活动有关的现金时间序列
    return w.wsd(security,"qfa_other_cash_pay_ral_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsInvestCashInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流入小计时间序列
    return w.wsd(security,"stm07_cs_reits_investcashin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSToTCashInFlowsInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资活动现金流入小计时间序列
    return w.wsd(security,"qfa_stot_cash_inflows_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsInvestCashOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流出小计时间序列
    return w.wsd(security,"stm07_cs_reits_investcashout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSToTCashOutFlowsInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资活动现金流出小计时间序列
    return w.wsd(security,"qfa_stot_cash_outflows_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsFinanceCashInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流入小计时间序列
    return w.wsd(security,"stm07_cs_reits_financecashin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSToTCashInFlowsFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.筹资活动现金流入小计时间序列
    return w.wsd(security,"qfa_stot_cash_inflows_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStm07CsReItsFinanceCashOutSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流出小计时间序列
    return w.wsd(security,"stm07_cs_reits_financecashout",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaSToTCashOutFlowsFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.筹资活动现金流出小计时间序列
    return w.wsd(security,"qfa_stot_cash_outflows_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundStmIssuingDateQTySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取季度报告披露日期时间序列
    return w.wsd(security,"fund_stm_issuingdate_qty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundStmIssuingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中(年)报披露日期时间序列
    return w.wsd(security,"fund_stm_issuingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashBeforeTax2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股利(税前)(已宣告)时间序列
    return w.wsd(security,"div_cashbeforetax2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashAfterTax2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股利(税后)(已宣告)时间序列
    return w.wsd(security,"div_cashaftertax2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivStock2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股红股(已宣告)时间序列
    return w.wsd(security,"div_stock2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivStockSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股红股时间序列
    return w.wsd(security,"div_stock",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashAfterTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股利(税后)时间序列
    return w.wsd(security,"div_cashaftertax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashPaidAfterTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间每股股利(税后)时间序列
    return w.wsd(security,"div_cashpaidaftertax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashBeforeTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股利(税前)时间序列
    return w.wsd(security,"div_cashbeforetax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashPaidBeforeTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间每股股利(税前)时间序列
    return w.wsd(security,"div_cashpaidbeforetax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivCashAndStockSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股分红送转时间序列
    return w.wsd(security,"div_cashandstock",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivProgressSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分红方案进度时间序列
    return w.wsd(security,"div_progress",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivObjectSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分红对象时间序列
    return w.wsd(security,"div_object",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivIfDivSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否分红时间序列
    return w.wsd(security,"div_ifdiv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分红基准股本时间序列
    return w.wsd(security,"div_shares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteAuALaCcmDivSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金分红总额时间序列
    return w.wsd(security,"stmnote_aualaccmdiv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAuAlCashDividendSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度现金分红总额时间序列
    return w.wsd(security,"div_aualcashdividend",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAuALaCcmDiv2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间现金分红总额时间序列
    return w.wsd(security,"div_aualaccmdiv2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivRecordDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权登记日时间序列
    return w.wsd(security,"div_recorddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueRecDateShareBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取B股股权登记日时间序列
    return w.wsd(security,"rightsissue_recdateshareb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationChKindAteSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售股权登记日时间序列
    return w.wsd(security,"cb_list_rationchkindate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowRecordDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向老股东配售股权登记日时间序列
    return w.wsd(security,"fellow_recorddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivExDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取除权除息日时间序列
    return w.wsd(security,"div_exdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPayDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取派息日时间序列
    return w.wsd(security,"div_paydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivTrDDateShareBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取红股上市交易日时间序列
    return w.wsd(security,"div_trddateshareb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPreDisclosureDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预披露公告日时间序列
    return w.wsd(security,"div_preDisclosureDate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssuePrePlanDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预案公告日时间序列
    return w.wsd(security,"rightsissue_preplandate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRefRMkdPrePlanDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会预案公告日时间序列
    return w.wsd(security,"refrmkd_preplandate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbWarAnnoDateMeetingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东大会公告日时间序列
    return w.wsd(security,"cb_war_annodatemeeting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivImpDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分红实施公告日时间序列
    return w.wsd(security,"div_impdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivDivPct3YearAccUSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取三年累计分红占比(再融资条件)时间序列
    return w.wsd(security,"div_divpct_3yearaccu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivDivPctAccUSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市以来分红率时间序列
    return w.wsd(security,"div_divpct_accu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivPayOutRatio2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度现金分红比例时间序列
    return w.wsd(security,"div_payoutRatio2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivFrEqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度现金分红次数时间序列
    return w.wsd(security,"div_freq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivAuALaCcmDivPerShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年度累计单位分红时间序列
    return w.wsd(security,"div_aualaccmdivpershare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDivDividendRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金分红比例时间序列
    return w.wsd(security,"div_dividendratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发上市日期时间序列
    return w.wsd(security,"ipo_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPrice2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发价格时间序列
    return w.wsd(security,"ipo_price2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行数量合计时间序列
    return w.wsd(security,"ipo_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNewSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股发行数量时间序列
    return w.wsd(security,"ipo_newshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOldSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东售股数量时间序列
    return w.wsd(security,"ipo_oldshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOldSharesRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股转让比例时间序列
    return w.wsd(security,"ipo_oldsharesratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCollectionTotalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取募集资金总额(含股东售股)时间序列
    return w.wsd(security,"ipo_collection_total",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发募集资金时间序列
    return w.wsd(security,"ipo_collection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNetCollectionTureSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发募集资金净额时间序列
    return w.wsd(security,"ipo_netcollection_ture",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCollectionOldShares2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东售股金额时间序列
    return w.wsd(security,"ipo_collection_oldshares2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoExpectedCollection2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发预计募集资金时间序列
    return w.wsd(security,"ipo_expectedcollection2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPoCOnlineSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行数量(回拨前)时间序列
    return w.wsd(security,"ipo_poc_online",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPoCOfflineSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下发行数量(回拨前)时间序列
    return w.wsd(security,"ipo_poc_offline",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueIssueOlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行数量时间序列
    return w.wsd(security,"issue_issueol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListIssueVolOnLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行数量(不含优先配售)时间序列
    return w.wsd(security,"cb_list_issuevolonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowOtcAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下发行数量时间序列
    return w.wsd(security,"fellow_otcamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsSharesSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行有效申购数量时间序列
    return w.wsd(security,"ipo_VSShares_s",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行有效认购倍数时间序列
    return w.wsd(security,"ipo_subratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIntvsSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国际发行有效申购数量时间序列
    return w.wsd(security,"ipo_intvsshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIntSubRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国际发行有效申购倍数时间序列
    return w.wsd(security,"ipo_intsubratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoWpIpReleasingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申报预披露日时间序列
    return w.wsd(security,"ipo_WpipReleasingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPubOfFrDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招股公告日时间序列
    return w.wsd(security,"ipo_puboffrdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLeadUndRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发主承销商时间序列
    return w.wsd(security,"ipo_leadundr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSponsorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发保荐机构时间序列
    return w.wsd(security,"ipo_sponsor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNominatorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发保荐机构(上市推荐人)时间序列
    return w.wsd(security,"ipo_nominator",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoDeputyUndRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发副主承销商时间序列
    return w.wsd(security,"ipo_deputyundr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLegalAdvisorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发保荐人律师时间序列
    return w.wsd(security,"ipo_legaladvisor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoUsFees2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发承销保荐费用时间序列
    return w.wsd(security,"ipo_usfees2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCommissionRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股配售经纪佣金费率时间序列
    return w.wsd(security,"ipo_commissionrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAuditFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发审计费用时间序列
    return w.wsd(security,"ipo_auditfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLawFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发法律费用时间序列
    return w.wsd(security,"ipo_lawfee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoGreenShoeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否行使超额配售权时间序列
    return w.wsd(security,"ipo_greenshoe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoBackMechanismSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否触发回拨机制时间序列
    return w.wsd(security,"ipo_backmechanism",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIsSuVolPlannedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计划发行总数时间序列
    return w.wsd(security,"ipo_issuvolplanned",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoDTooRatioPlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申购一手中签率时间序列
    return w.wsd(security,"ipo_dtooratio_pl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoMinSubscriptionPlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取稳购1手最低申购股数时间序列
    return w.wsd(security,"ipo_minsubscription_pl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOverAllotVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取超额配售数量时间序列
    return w.wsd(security,"ipo_overallot_vol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubNumASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发售甲组申购人数时间序列
    return w.wsd(security,"ipo_subnum_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubNumBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发售乙组申购人数时间序列
    return w.wsd(security,"ipo_subnum_b",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发售申购人数时间序列
    return w.wsd(security,"ipo_subnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLStNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首日上市数量时间序列
    return w.wsd(security,"ipo_lstnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoListDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市天数时间序列
    return w.wsd(security,"ipo_listdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTradeDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市交易天数时间序列
    return w.wsd(security,"ipo_tradedays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLimitUpDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新股未开板涨停板天数时间序列
    return w.wsd(security,"ipo_limitupdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLimitUpOpenDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开板日时间序列
    return w.wsd(security,"ipo_limitupopendate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCashRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行中签率时间序列
    return w.wsd(security,"ipo_cashratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSSharesUpLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购数量上限时间序列
    return w.wsd(security,"ipo_SShares_uplimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSAmtUpLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购资金上限时间序列
    return w.wsd(security,"ipo_SAmt_uplimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCashEffAccSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行有效申购户数时间序列
    return w.wsd(security,"ipo_casheffacc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOvRSubRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上超额认购倍数时间序列
    return w.wsd(security,"ipo_ovrsubratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoBFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上冻结资金时间序列
    return w.wsd(security,"ipo_Bfund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPurchaseCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购代码时间序列
    return w.wsd(security,"ipo_purchasecode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoGiveUpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上放弃认购数量时间序列
    return w.wsd(security,"ipo_giveup",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOtcCashPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购配售比例时间序列
    return w.wsd(security,"ipo_otc_cash_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpVolumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购总量时间序列
    return w.wsd(security,"ipo_op_volume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下冻结资金时间序列
    return w.wsd(security,"ipo_op_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsPriceMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下有效报价下限时间序列
    return w.wsd(security,"ipo_VSprice_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsPriceMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下有效报价上限时间序列
    return w.wsd(security,"ipo_VSPrice_max",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下有效报价申购量时间序列
    return w.wsd(security,"ipo_VSShares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtToJurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下超额认购倍数时间序列
    return w.wsd(security,"fellow_amttojur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下超额认购倍数(回拨前)时间序列
    return w.wsd(security,"ipo_VSRatio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInvsSharesASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下高于有效报价上限的申购量时间序列
    return w.wsd(security,"ipo_InvSShares_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpUpLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购数量上限时间序列
    return w.wsd(security,"ipo_op_uplimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpDownLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购数量下限时间序列
    return w.wsd(security,"ipo_op_downlimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListStepSizeSubsCrOfFlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购步长时间序列
    return w.wsd(security,"list_stepsizesubscroffl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpNumOffRingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购报价数量时间序列
    return w.wsd(security,"ipo_op_numoffring",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpNumOfPmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购配售对象家数时间序列
    return w.wsd(security,"ipo_op_numofpmt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpNumOfInQSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购询价对象家数时间序列
    return w.wsd(security,"ipo_op_numofinq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLotWinningNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下询价机构获配数量时间序列
    return w.wsd(security,"ipo_lotwinningnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPSharesAbcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者获配数量时间序列
    return w.wsd(security,"ipo_Pshares_abc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpVolumeAbcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者申购数量时间序列
    return w.wsd(security,"ipo_op_volume_abc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNInstitutionalAbcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者获配家数时间序列
    return w.wsd(security,"ipo_Ninstitutional_abc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLotteryRateAbcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者中签率时间序列
    return w.wsd(security,"ipo_lotteryrate_abc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPSharesPctAbcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者配售数量占比时间序列
    return w.wsd(security,"ipo_Psharespct_abc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoVsSharesPctAbcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者有效申购数量占比时间序列
    return w.wsd(security,"ipo_VSsharespct_abc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPSharesMfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下公募基金获配数量时间序列
    return w.wsd(security,"ipo_PShares_mf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPSharesSSfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下社保基金获配数量时间序列
    return w.wsd(security,"ipo_PShares_ssf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPSharesSpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下企业年金获配数量时间序列
    return w.wsd(security,"ipo_PShares_SP",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPSharesIfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下保险资金获配数量时间序列
    return w.wsd(security,"ipo_PShares_IF",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSiAllotmentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略配售获配股份数时间序列
    return w.wsd(security,"ipo_siallotment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSiAllotmentRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取战略配售获配股份占比时间序列
    return w.wsd(security,"ipo_siallotmentratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoUnderwriterAllotmentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主承销商战略获配股份数时间序列
    return w.wsd(security,"ipo_underwriterallotment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoUnderwriterAllotmentRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主承销商战略获配股份占比时间序列
    return w.wsd(security,"ipo_underwriterallotmentratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAllotmentSubjectsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下配售对象名称时间序列
    return w.wsd(security,"ipo_allotmentsubjects",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAllOtwaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者分类限售配售方式时间序列
    return w.wsd(security,"ipo_allotway",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPShareRestrictPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者分类配售限售比例时间序列
    return w.wsd(security,"ipo_pshare_restrictpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoWGtAvgPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申报价格加权平均数时间序列
    return w.wsd(security,"ipo_wgtavgprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoMedianPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申报价格中位数时间序列
    return w.wsd(security,"ipo_medianprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubscriptionPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价申报价格时间序列
    return w.wsd(security,"ipo_subscriptionprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubscriptionSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价申报数量时间序列
    return w.wsd(security,"ipo_subscriptionshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInquirySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价配售对象家数时间序列
    return w.wsd(security,"ipo_inquiry",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInquiryInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价询价对象家数时间序列
    return w.wsd(security,"ipo_inquiry_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSPriceMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价下限时间序列
    return w.wsd(security,"ipo_SPrice_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSPriceMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价上限时间序列
    return w.wsd(security,"ipo_SPrice_max",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSSharesTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价申购总量时间序列
    return w.wsd(security,"ipo_SShares_t",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价申购倍数(回拨前)时间序列
    return w.wsd(security,"ipo_Sratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInquiryMvCalDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取询价市值计算参考日时间序列
    return w.wsd(security,"ipo_inquirymv_caldate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInquiryMvMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下询价市值门槛时间序列
    return w.wsd(security,"ipo_inquirymv_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInquiryMvMinASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下询价市值门槛(A类)时间序列
    return w.wsd(security,"ipo_inquirymv_min_a",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInquiryMvMinThemEstrTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下询价市值门槛(主题与战略)时间序列
    return w.wsd(security,"ipo_inquirymv_min_themestrt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPriceMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行价格下限(底价)时间序列
    return w.wsd(security,"ipo_price_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPriceMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行价格上限时间序列
    return w.wsd(security,"ipo_price_max",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoUndRTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发承销方式时间序列
    return w.wsd(security,"ipo_undrtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoDistOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发分销商时间序列
    return w.wsd(security,"ipo_distor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInterCordTorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发国际协调人时间序列
    return w.wsd(security,"ipo_intercordtor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSponsorRepresentativeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发保荐人代表时间序列
    return w.wsd(security,"ipo_sponsorrepresentative",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAuditCpaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发签字会计师时间序列
    return w.wsd(security,"ipo_audit_cpa",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoLawFirmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发经办律所时间序列
    return w.wsd(security,"ipo_lawfirm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoApplicationDeadlineSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者报备截止日时间序列
    return w.wsd(security,"ipo_applicationdeadline",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoApplicationDeadlineTimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下投资者报备截止时间时间序列
    return w.wsd(security,"ipo_applicationdeadline_time",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueLiStanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市公告日时间序列
    return w.wsd(security,"issue_listance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInQAnnCeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价公告日时间序列
    return w.wsd(security,"ipo_inq_anncedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInQStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价起始日时间序列
    return w.wsd(security,"ipo_inq_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInQEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价截止日时间序列
    return w.wsd(security,"ipo_inq_enddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInQResultDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步询价结果公告日时间序列
    return w.wsd(security,"ipo_inqresultdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPReplacingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取初步配售结果公告日时间序列
    return w.wsd(security,"ipo_preplacingdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOpEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购截止日期时间序列
    return w.wsd(security,"ipo_op_enddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下定价日时间序列
    return w.wsd(security,"ipo_pDate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOffSubPayDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购缴款日时间序列
    return w.wsd(security,"ipo_offsubpaydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoMvRegDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上市值申购登记日时间序列
    return w.wsd(security,"ipo_MVRegDate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRefundDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上中签结果公告日时间序列
    return w.wsd(security,"ipo_refunddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoCapPayDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购缴款日时间序列
    return w.wsd(security,"ipo_cappaydate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRsDateSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现场推介起始日期时间序列
    return w.wsd(security,"ipo_RSDate_s",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRsDateESeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现场推介截止日期时间序列
    return w.wsd(security,"ipo_RSDate_e",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPlacingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下配售结果公告日时间序列
    return w.wsd(security,"ipo_placingDate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOtherStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它发行起始日期时间序列
    return w.wsd(security,"ipo_otherstartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOtherEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它发行截止日期时间序列
    return w.wsd(security,"ipo_otherenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoTutoringStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取辅导备案日时间序列
    return w.wsd(security,"ipo_tutoring_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubmitRegisTDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取提交注册日时间序列
    return w.wsd(security,"ipo_submit_regist_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRegisTDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取注册成功日(证监会审核批文日)时间序列
    return w.wsd(security,"ipo_regist_date",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoMrQDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取申报基准日时间序列
    return w.wsd(security,"ipo_mrqdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOrStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下报备起始日时间序列
    return w.wsd(security,"ipo_or_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoDilutedPeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发市盈率(摊薄)时间序列
    return w.wsd(security,"ipo_dilutedpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoWeightedPeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发市盈率(加权)时间序列
    return w.wsd(security,"ipo_weightedpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoPbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行市净率时间序列
    return w.wsd(security,"ipo_pb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoIndustryPeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发时所属行业市盈率时间序列
    return w.wsd(security,"ipo_industryPe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAmountEstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计发行股数时间序列
    return w.wsd(security,"ipo_amount_est",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoNetCollectionEstSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预计募投项目投资总额时间序列
    return w.wsd(security,"ipo_netcollection_est",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoBeyondActualColleCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取首发超募资金时间序列
    return w.wsd(security,"ipo_beyondactualcollec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoUnderwritingFeesShareholderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取售股股东应摊承销与保荐费用时间序列
    return w.wsd(security,"ipo_underwritingfees_shareholder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoSubByDIsTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承销商认购余额时间序列
    return w.wsd(security,"ipo_subbydistr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoReallocationPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回拨比例时间序列
    return w.wsd(security,"ipo_ReallocationPct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAmtToInStInvestorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向战略投资者配售数量时间序列
    return w.wsd(security,"ipo_amttoinstinvestor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoAmtToOtherSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它发行数量时间序列
    return w.wsd(security,"ipo_amttoother",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRdInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近三年研发投入占比时间序列
    return w.wsd(security,"ipo_rdinvest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInvestAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近三年研发投入累计额时间序列
    return w.wsd(security,"ipo_investamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRdPersonSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发人员占比时间序列
    return w.wsd(security,"ipo_rdperson",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoInventionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发明专利个数时间序列
    return w.wsd(security,"ipo_invention",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoRevenueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取近一年营收额时间序列
    return w.wsd(security,"ipo_revenue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPoQeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取被剔除的申报量占比时间序列
    return w.wsd(security,"poqe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowProgressSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发进度时间序列
    return w.wsd(security,"fellow_progress",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发价格时间序列
    return w.wsd(security,"fellow_price",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发数量时间序列
    return w.wsd(security,"fellow_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowListedDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发上市日时间序列
    return w.wsd(security,"fellow_listeddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发募集资金时间序列
    return w.wsd(security,"fellow_collection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCollectionTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间增发募集资金合计时间序列
    return w.wsd(security,"fellow_collection_t",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowExpenseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发费用时间序列
    return w.wsd(security,"fellow_expense",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowNetCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发实际募集资金时间序列
    return w.wsd(security,"fellow_netcollection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowBenchmarkPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定向增发基准价格时间序列
    return w.wsd(security,"fellow_benchmarkprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPriceToReservePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定向增发预案价格相对基准价格比率时间序列
    return w.wsd(security,"fellow_pricetoreserveprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPriceToBenchmarkPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定向增发实际价格相对基准价格比率时间序列
    return w.wsd(security,"fellow_pricetobenchmarkprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间定增次数时间序列
    return w.wsd(security,"fellow_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowTotalRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总中签率时间序列
    return w.wsd(security,"fellow_totalratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPublicRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发行中签率时间序列
    return w.wsd(security,"fellow_publicratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowUndRTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发承销方式时间序列
    return w.wsd(security,"fellow_undrtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowLeadUndRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发主承销商时间序列
    return w.wsd(security,"fellow_leadundr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowDeputyUndRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发保荐机构(上市推荐人)时间序列
    return w.wsd(security,"fellow_deputyundr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowNominatorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发分销商时间序列
    return w.wsd(security,"fellow_nominator",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowDistOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总有效申购户数时间序列
    return w.wsd(security,"fellow_distor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowInterCodNatOrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总有效申购股数时间序列
    return w.wsd(security,"fellow_intercodnator",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCashRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总超额认购倍数时间序列
    return w.wsd(security,"fellow_cashratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCapRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发行认购有效申购户数时间序列
    return w.wsd(security,"fellow_capratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCashAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发行比例认购有效申购股数时间序列
    return w.wsd(security,"fellow_cashamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCashEffAccSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发行超额认购倍数时间序列
    return w.wsd(security,"fellow_casheffacc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCapeFfAccSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东优先配售有效申购户数时间序列
    return w.wsd(security,"fellow_capeffacc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowCapeFfAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东优先配售有效申购股数时间序列
    return w.wsd(security,"fellow_capeffamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowSubAccByPubSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它公众投资者有效申购户数时间序列
    return w.wsd(security,"fellow_subaccbypub",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowOverSubRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它公众投资者有效申购股数时间序列
    return w.wsd(security,"fellow_oversubratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtByPlacingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下机构投资者有效申购户数时间序列
    return w.wsd(security,"fellow_amtbyplacing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowSubAmtByPlacingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下机构投资者有效申购股数时间序列
    return w.wsd(security,"fellow_subamtbyplacing",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtToInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上向老股东优先配售数量时间序列
    return w.wsd(security,"fellow_amttoinst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtToInCorpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上向老股东优先配售比例时间序列
    return w.wsd(security,"fellow_amttoincorp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowOtcPreAmtOrgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下向老股东优先配售数量时间序列
    return w.wsd(security,"fellow_otcpreamt_org",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtOtherPubSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向其它公众投资者配售数量时间序列
    return w.wsd(security,"fellow_amt_otherpub",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtTargetedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定向配售数量时间序列
    return w.wsd(security,"fellow_amt_targeted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtOrgTradableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向原流通股东定向配售数量时间序列
    return w.wsd(security,"fellow_amt_orgtradable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowAmtFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向基金配售数量时间序列
    return w.wsd(security,"fellow_amt_fund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowOtcAmtPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下发售比例时间序列
    return w.wsd(security,"fellow_otcamt_pct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueSubByDIsTrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承销商认购余股时间序列
    return w.wsd(security,"rightsissue_subbydistr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowOfferingDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发公告日时间序列
    return w.wsd(security,"fellow_offeringdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowIssueDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发行日时间序列
    return w.wsd(security,"fellow_issuedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowOtcDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向网下增发日期时间序列
    return w.wsd(security,"fellow_otcdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowIecApprovalDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发审委通过公告日时间序列
    return w.wsd(security,"fellow_IECApprovalDate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPayStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向老股东配售缴款起始日时间序列
    return w.wsd(security,"fellow_paystartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPayEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向老股东配售缴款截止日时间序列
    return w.wsd(security,"fellow_payenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowApprovalDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发获准日期时间序列
    return w.wsd(security,"fellow_approvaldate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowRoadshowDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上路演日时间序列
    return w.wsd(security,"fellow_roadshowdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHandlingDatePiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非公开发行股票受理日时间序列
    return w.wsd(security,"handlingDate_pi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowRegisterDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股份登记日时间序列
    return w.wsd(security,"fellow_registerdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPubAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公开发行数量时间序列
    return w.wsd(security,"fellow_pubamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowDiscNtRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取折扣率时间序列
    return w.wsd(security,"fellow_discntratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowTrnFfAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回拨数量时间序列
    return w.wsd(security,"fellow_trnffamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPriceMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发预案价上限时间序列
    return w.wsd(security,"fellow_pricemax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowPriceMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发预案价下限时间序列
    return w.wsd(security,"fellow_pricemin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowDilutedPeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发市盈率(摊薄)时间序列
    return w.wsd(security,"fellow_dilutedpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFellowWeightedPeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发市盈率(加权)时间序列
    return w.wsd(security,"fellow_weightedpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstimatedNetCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取增发预计募集资金时间序列
    return w.wsd(security,"estimated_netcollection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueProgressSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股进度时间序列
    return w.wsd(security,"rightsissue_progress",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssuePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股价格时间序列
    return w.wsd(security,"rightsissue_price",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股募集资金时间序列
    return w.wsd(security,"rightsissue_collection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueCollectionTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间配股募集资金合计时间序列
    return w.wsd(security,"rightsissue_collection_t",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueExpenseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股费用时间序列
    return w.wsd(security,"rightsissue_expense",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueNetCollectionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股实际募集资金时间序列
    return w.wsd(security,"rightsissue_netcollection",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueBaseShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基准股本时间序列
    return w.wsd(security,"rightsissue_baseshare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssuePerShareSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股配股数时间序列
    return w.wsd(security,"rightsissue_pershare",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssuePlanAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取计划配股数时间序列
    return w.wsd(security,"rightsissue_planamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际配股数时间序列
    return w.wsd(security,"rightsissue_amount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueActLNumToStateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国有股实际配股数时间序列
    return w.wsd(security,"rightsissue_actlnumtostate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueActLNumToJurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取法人股实际配股数时间序列
    return w.wsd(security,"rightsissue_actlnumtojur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueActLNumToEmpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取职工股实际配股数时间序列
    return w.wsd(security,"rightsissue_actlnumtoemp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueActLNumToTRsfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转配股实际配股数时间序列
    return w.wsd(security,"rightsissue_actlnumtotrsf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueActLNumToTrDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已流通股实际配股数时间序列
    return w.wsd(security,"rightsissue_actlnumtotrd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueTheOrNumToStateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国有股理论配股数时间序列
    return w.wsd(security,"rightsissue_theornumtostate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueTheOrNumToJurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取法人股理论配股数时间序列
    return w.wsd(security,"rightsissue_theornumtojur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueTheOrNumToEmpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取职工股理论配股数时间序列
    return w.wsd(security,"rightsissue_theornumtoemp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueTheOrNumToTRsfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取转配股理论配股数时间序列
    return w.wsd(security,"rightsissue_theornumtotrsf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueTheOrNumToTrDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已流通股理论配股数时间序列
    return w.wsd(security,"rightsissue_theornumtotrd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueUp5PctNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股5%以上大股东持股数时间序列
    return w.wsd(security,"rightsissue_up5pctnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueUp5PctTheOrNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股5%以上的大股东理论认购股数时间序列
    return w.wsd(security,"rightsissue_up5pcttheornum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueUp5PctActLNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持股5%以上大股东认购股数时间序列
    return w.wsd(security,"rightsissue_up5pctactlnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueExDividendDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股除权日时间序列
    return w.wsd(security,"rightsissue_exdividenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueListedDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股上市日时间序列
    return w.wsd(security,"rightsissue_listeddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderPaymentDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取缴款起始日时间序列
    return w.wsd(security,"tender_paymentdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssuePayEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取缴款终止日时间序列
    return w.wsd(security,"rightsissue_payenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueApprovedDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股获准公告日时间序列
    return w.wsd(security,"rightsissue_approveddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueAnnCeDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股公告日时间序列
    return w.wsd(security,"rightsissue_anncedate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHandlingDateRsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股受理日时间序列
    return w.wsd(security,"handlingDate_rs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueLeadUndRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股主承销商时间序列
    return w.wsd(security,"rightsissue_leadundr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股方式时间序列
    return w.wsd(security,"rightsissue_type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueUndRTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股承销方式时间序列
    return w.wsd(security,"rightsissue_undrtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueDeputyUndRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股分销商时间序列
    return w.wsd(security,"rightsissue_deputyundr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueMaxPricePrePlanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股预案价上限时间序列
    return w.wsd(security,"rightsissue_maxpricepreplan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRightsIssueMinPricePrePlanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取配股预案价下限时间序列
    return w.wsd(security,"rightsissue_minpricepreplan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderTenderDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招投标日期时间序列
    return w.wsd(security,"tender_tenderdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFirstIssueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行起始日期时间序列
    return w.wsd(security,"issue_firstissue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFirstIssueOlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行起始日期时间序列
    return w.wsd(security,"issue_firstissueol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueLastIssueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行截止日期时间序列
    return w.wsd(security,"issue_lastissue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueLastIssueOlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行截止日期时间序列
    return w.wsd(security,"issue_lastissueol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderDistRibBeginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分销起始日期时间序列
    return w.wsd(security,"tender_distribbegin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderDIsTribeNdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分销截至日期时间序列
    return w.wsd(security,"tender_distribend",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderPayEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取缴款截止日时间序列
    return w.wsd(security,"tender_payenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderConfirmDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资金到账确认时间时间序列
    return w.wsd(security,"tender_confirmdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderTransferDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券过户时间时间序列
    return w.wsd(security,"tender_transferdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOfficialDocDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证监会/发改委批文日时间序列
    return w.wsd(security,"issue_officialdocdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRegDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行注册日期时间序列
    return w.wsd(security,"issue_regdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRegNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行注册文件号时间序列
    return w.wsd(security,"issue_regnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRegAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行注册额度时间序列
    return w.wsd(security,"issue_regamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueIssueYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行年度时间序列
    return w.wsd(security,"issue_issueyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueIssueNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行期号时间序列
    return w.wsd(security,"issue_issuenumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderExchangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标场所时间序列
    return w.wsd(security,"tender_exchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyUnderWritTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承销方式时间序列
    return w.wsd(security,"agency_underwrittype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueIssuePriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行价格时间序列
    return w.wsd(security,"issue_issueprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstFinalPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最终发行价格时间序列
    return w.wsd(security,"tendrst_finalprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueRarAIsOlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行认购数量限制说明时间序列
    return w.wsd(security,"issue_raraisol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundUseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取募集资金用途时间序列
    return w.wsd(security,"funduse",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderMethodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标方式时间序列
    return w.wsd(security,"tender_method",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderObjectSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标标的时间序列
    return w.wsd(security,"tender_object",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderAimInvStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标对象时间序列
    return w.wsd(security,"tender_aiminvst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderTimeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标时间时间序列
    return w.wsd(security,"tender_time",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderExplanationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中标确定方式说明时间序列
    return w.wsd(security,"tender_explanation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderCmpTamNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取竞争性招标总额时间序列
    return w.wsd(security,"tender_cmptamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderUnderwritingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本承销额度时间序列
    return w.wsd(security,"tender_underwriting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderAddRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本承销额追加比例时间序列
    return w.wsd(security,"tender_addratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderAdditiveRightsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本承销额增加权利时间序列
    return w.wsd(security,"tender_additiverights",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderThresholdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投标利率下限时间序列
    return w.wsd(security,"tender_threshold",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderCeilingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投标利率上限时间序列
    return w.wsd(security,"tender_ceiling",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderTenderUnitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本投标单位时间序列
    return w.wsd(security,"tender_tenderunit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderLowestAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每标位最低投标量时间序列
    return w.wsd(security,"tender_lowestamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderHighestAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每标位最高投标量时间序列
    return w.wsd(security,"tender_highestamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderExpLnTenderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投标说明时间序列
    return w.wsd(security,"tender_explntender",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否发行失败时间序列
    return w.wsd(security,"issueok",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstDoCumTNumberSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标书编号时间序列
    return w.wsd(security,"tendrst_documtnumber",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstPayAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取缴款总金额时间序列
    return w.wsd(security,"tendrst_payamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstUnderwritingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取基本承购总额时间序列
    return w.wsd(security,"tendrst_underwriting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取招标总量时间序列
    return w.wsd(security,"tendrst_amnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstTenderAmountSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投标(申购)总量时间序列
    return w.wsd(security,"tendrst_tenderamount",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstOughtTenderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应投家数时间序列
    return w.wsd(security,"tendrst_oughttender",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstInvestorTenderedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投标家数时间序列
    return w.wsd(security,"tendrst_investortendered",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstEffectInvestorsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有效投标(申购)家数时间序列
    return w.wsd(security,"tendrst_effectinvestors",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstTendersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投标笔数时间序列
    return w.wsd(security,"tendrst_tenders",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstEffectTenderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有效笔数时间序列
    return w.wsd(security,"tendrst_effecttender",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstInEffectTenderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取无效笔数时间序列
    return w.wsd(security,"tendrst_ineffecttender",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstEffectAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有效投标总量时间序列
    return w.wsd(security,"tendrst_effectamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstHightestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高投标价位时间序列
    return w.wsd(security,"tendrst_hightest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstLowestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低投标价位时间序列
    return w.wsd(security,"tendrst_lowest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstWinningAmNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中标总量时间序列
    return w.wsd(security,"tendrst_winningamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstPrivateTradeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营中标总量时间序列
    return w.wsd(security,"tendrst_privatetrade",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstMarGwInBidderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取边际中标价位中标总量时间序列
    return w.wsd(security,"tendrst_margwinbidder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstWinnerBidderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中标家数时间序列
    return w.wsd(security,"tendrst_winnerbidder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstWinningBidderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中标笔数时间序列
    return w.wsd(security,"tendrst_winningbidder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstHightPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最高中标价位时间序列
    return w.wsd(security,"tendrst_hightprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstLowPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低中标价位时间序列
    return w.wsd(security,"tendrst_lowprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstMargaMNtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取边际中标价位投标总量时间序列
    return w.wsd(security,"tendrst_margamnt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstReferYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取参考收益率时间序列
    return w.wsd(security,"tendrst_referyield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstFinAnCouponSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最终票面利率时间序列
    return w.wsd(security,"tendrst_financoupon",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstBidRateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全场中标利率时间序列
    return w.wsd(security,"tendrst_bidrate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstBidPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全场中标价格时间序列
    return w.wsd(security,"tendrst_bidprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTendRstBidSpreadSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全场中标利差时间序列
    return w.wsd(security,"tendrst_bidspread",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIpoOvRSubRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取超额认购倍数时间序列
    return w.wsd(security,"ipo_ovrsubratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListExcessPcHonLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行超额认购倍数(不含优先配售)时间序列
    return w.wsd(security,"cb_list_excesspchonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyLeadUnderwriterSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主承销商时间序列
    return w.wsd(security,"agency_leadunderwriter",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyLeadUnderwritersNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主承销商(简称)时间序列
    return w.wsd(security,"agency_leadunderwriterSN",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyDeputyUnderwriterSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取副主承销商时间序列
    return w.wsd(security,"agency_deputyunderwriter",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCreditRatingAgencySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用评估机构时间序列
    return w.wsd(security,"creditratingagency",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyBookRunnerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取簿记管理人时间序列
    return w.wsd(security,"agency_Bookrunner",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyDistributorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分销商时间序列
    return w.wsd(security,"agency_distributor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyTrusteeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取托管人时间序列
    return w.wsd(security,"agency_trustee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyBondTrusteeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托管理人时间序列
    return w.wsd(security,"agency_bondtrustee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyExAccountantSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会计师事务所时间序列
    return w.wsd(security,"agency_exaccountant",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyRecommendErSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上市保荐机构(上市推荐人)时间序列
    return w.wsd(security,"agency_recommender",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyBookkeeperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取账簿管理人(海外)时间序列
    return w.wsd(security,"agency_bookkeeper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyUnderwriterSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取牵头经办人(海外)时间序列
    return w.wsd(security,"agency_underwriter",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyBookSupporterSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取集中簿记建档系统技术支持机构时间序列
    return w.wsd(security,"agency_booksupporter",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyCertificationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取绿色债券认证机构时间序列
    return w.wsd(security,"agency_certification",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAgencyFundBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取募集资金专项账户开户行时间序列
    return w.wsd(security,"agency_fundbank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFeeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行费率时间序列
    return w.wsd(security,"issue_fee",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderUnderwritingCostSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承揽费时间序列
    return w.wsd(security,"tender_underwritingcost",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFeeUnderWRtspOnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承销保荐费用时间序列
    return w.wsd(security,"issuefee_underwrtspon",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFeeAcContSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取会计师费用时间序列
    return w.wsd(security,"issuefee_accont",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFeeLegalConsLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取律师费用时间序列
    return w.wsd(security,"issuefee_legalconsl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTenderCommissionChargeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取兑付手续费时间序列
    return w.wsd(security,"tender_commissioncharge",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListPermitDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发审委审批通过日期时间序列
    return w.wsd(security,"cb_list_permitdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售日期时间序列
    return w.wsd(security,"cb_list_rationdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationPayMtDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售缴款日时间序列
    return w.wsd(security,"cb_list_rationpaymtdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultExpLnRationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售说明时间序列
    return w.wsd(security,"cb_result_explnration",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售代码时间序列
    return w.wsd(security,"cb_list_rationcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationNameSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售简称时间序列
    return w.wsd(security,"cb_list_rationname",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationPriceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售价格时间序列
    return w.wsd(security,"cb_list_rationprice",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationRatioDeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售比例分母时间序列
    return w.wsd(security,"cb_list_rationratiode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultRationAmtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股配售额时间序列
    return w.wsd(security,"cb_result_rationamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListRationVolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向老股东配售数量时间序列
    return w.wsd(security,"cb_list_rationvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListOriginalsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取老股东配售户数时间序列
    return w.wsd(security,"cb_list_originals",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListPChaseCodeOnLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行申购代码时间序列
    return w.wsd(security,"cb_list_pchasecodeonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListPChNameOnLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行申购名称时间序列
    return w.wsd(security,"cb_list_pchnameonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListPChPriceOnLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上发行申购价格时间序列
    return w.wsd(security,"cb_list_pchpriceonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbListVolInStOffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下向机构投资者发行数量(不含优先配售)时间序列
    return w.wsd(security,"cb_list_volinstoff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultRationCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定金比例时间序列
    return w.wsd(security,"cb_result_rationcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListFloorSubsCrOfFlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购下限时间序列
    return w.wsd(security,"list_floorsubscroffl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListLimitSubsCrOfFlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下申购上限时间序列
    return w.wsd(security,"list_limitsubscroffl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListFloorSubsCroNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购下限时间序列
    return w.wsd(security,"list_floorsubscronl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListStepSizeSubsCroNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购步长时间序列
    return w.wsd(security,"list_stepsizesubscronl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getListLimitSubsCroNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上申购上限时间序列
    return w.wsd(security,"list_limitsubscronl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultAVaiRationAmtTrAdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原流通股股东可配售额时间序列
    return w.wsd(security,"cb_result_avairationamttrad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfInvestorsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原流通股股东有效申购户数时间序列
    return w.wsd(security,"cb_result_efinvestors",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfSubsCrPamTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原流通股股东有效申购金额时间序列
    return w.wsd(security,"cb_result_efsubscrpamt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultPlaceAmNttRadSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取原流通股股东获配金额时间序列
    return w.wsd(security,"cb_result_placeamnttrad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfSubsCRpoNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上有效申购户数时间序列
    return w.wsd(security,"cb_result_efsubscrponl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfSubsCrPamToNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上有效申购金额时间序列
    return w.wsd(security,"cb_result_efsubscrpamtonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultRationAmToNlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上获配金额时间序列
    return w.wsd(security,"cb_result_rationamtonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultRationRatioOnLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上获配比例时间序列
    return w.wsd(security,"cb_result_rationratioonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultSuCrateOnLSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网上中签率时间序列
    return w.wsd(security,"cb_result_sucrateonl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfSubsCRpOffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下有效申购户数时间序列
    return w.wsd(security,"cb_result_efsubscrpoff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultEfSubsCrPamToFfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下有效申购金额时间序列
    return w.wsd(security,"cb_result_efsubscrpamtoff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultRationAmtOffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下获配金额时间序列
    return w.wsd(security,"cb_result_rationamtoff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultSuCrateOffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下中签率时间序列
    return w.wsd(security,"cb_result_sucrateoff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbResultBalanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取包销余额时间序列
    return w.wsd(security,"cb_result_balance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryValueCitiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值(中信)时间序列
    return w.wsd(security,"prt_topindustryvalue_citic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryValueSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值(申万)时间序列
    return w.wsd(security,"prt_topindustryvalue_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGMdc01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取第三方审查机构时间序列
    return w.wsd(security,"esg_mdc01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGMdc01004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取报告范围时间序列
    return w.wsd(security,"esg_mdc01004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGMdc01005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取编制依据时间序列
    return w.wsd(security,"esg_mdc01005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGMdc01007Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否遵循/对照联交所标准时间序列
    return w.wsd(security,"esg_mdc01007",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem01004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总温室气体排放时间序列
    return w.wsd(security,"esg_eem01004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem01008Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取温室气体减排量时间序列
    return w.wsd(security,"esg_eem01008",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem01011Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否就气候变化机会进行讨论时间序列
    return w.wsd(security,"esg_eem01011",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem01012Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否就气候变化风险进行讨论时间序列
    return w.wsd(security,"esg_eem01012",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem02001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取氮氧化物排放时间序列
    return w.wsd(security,"esg_eem02001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取二氧化硫排放时间序列
    return w.wsd(security,"esg_eem02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem02003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取悬浮粒子/颗粒物时间序列
    return w.wsd(security,"esg_eem02003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem03001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取有害废弃物量时间序列
    return w.wsd(security,"esg_eem03001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem03002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取无害废弃物量时间序列
    return w.wsd(security,"esg_eem03002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem03003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废弃物总量时间序列
    return w.wsd(security,"esg_eem03003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEem03004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废弃物回收量时间序列
    return w.wsd(security,"esg_eem03004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总能源消耗时间序列
    return w.wsd(security,"esg_ere01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取耗电总量时间序列
    return w.wsd(security,"esg_ere01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取节省用电量时间序列
    return w.wsd(security,"esg_ere01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取煤碳使用量时间序列
    return w.wsd(security,"esg_ere01004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取天然气消耗时间序列
    return w.wsd(security,"esg_ere01005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01006Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取燃油消耗时间序列
    return w.wsd(security,"esg_ere01006",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre01007Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取节能量时间序列
    return w.wsd(security,"esg_ere01007",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre02001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取纸消耗量时间序列
    return w.wsd(security,"esg_ere02001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEre02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废纸回收量时间序列
    return w.wsd(security,"esg_ere02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取总用水量时间序列
    return w.wsd(security,"esg_ewa01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取节省水量时间序列
    return w.wsd(security,"esg_ewa01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取水循环与再利用的总量时间序列
    return w.wsd(security,"esg_ewa01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废水/污水排放量时间序列
    return w.wsd(security,"esg_ewa02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa02003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取废水处理量时间序列
    return w.wsd(security,"esg_ewa02003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEwa02004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取氨氮时间序列
    return w.wsd(security,"esg_ewa02004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEot01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否重点排污单位时间序列
    return w.wsd(security,"esg_eot01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEot02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取环保超标或其他违规次数时间序列
    return w.wsd(security,"esg_eot02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会规模时间序列
    return w.wsd(security,"esg_gbo01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会出席率时间序列
    return w.wsd(security,"esg_gbo01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会召开数时间序列
    return w.wsd(security,"esg_gbo01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取参加少于75%会议的董事人数时间序列
    return w.wsd(security,"esg_gbo01004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取监事会召开数时间序列
    return w.wsd(security,"esg_gbo01005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01006Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取监事出席率时间序列
    return w.wsd(security,"esg_gbo01006",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01007Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否设有监事委员会主席时间序列
    return w.wsd(security,"esg_gbo01007",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01008Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取提名委员会会议数时间序列
    return w.wsd(security,"esg_gbo01008",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01010Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取提名委员会会议出席率时间序列
    return w.wsd(security,"esg_gbo01010",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01014Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取董事会成员受教育背景高于本科的比例时间序列
    return w.wsd(security,"esg_gbo01014",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo01015Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取女性董事占比时间序列
    return w.wsd(security,"esg_gbo01015",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo03001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取独立董事董事会会议出席率时间序列
    return w.wsd(security,"esg_gbo03001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGBo03002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取独立董事占董事会总人数的比例时间序列
    return w.wsd(security,"esg_gbo03002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGpa02001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否有股权激励计划时间序列
    return w.wsd(security,"esg_gpa02001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGpa03002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取薪酬委员会会议出席率时间序列
    return w.wsd(security,"esg_gpa03002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGpa03003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取薪酬委员会会议数时间序列
    return w.wsd(security,"esg_gpa03003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGad01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计委员会会议次数时间序列
    return w.wsd(security,"esg_gad01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGad01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计委员会会议出席率时间序列
    return w.wsd(security,"esg_gad01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGad02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否出具标准无保留意见时间序列
    return w.wsd(security,"esg_gad02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取雇员总人数时间序列
    return w.wsd(security,"esg_sem01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取员工流失率/离职率时间序列
    return w.wsd(security,"esg_sem01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem01004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取劳动合同签订率时间序列
    return w.wsd(security,"esg_sem01004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem01005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取女性员工比例时间序列
    return w.wsd(security,"esg_sem01005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem01006Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数裔员工比例时间序列
    return w.wsd(security,"esg_sem01006",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取人均培训课时时间序列
    return w.wsd(security,"esg_sem02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem03001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取工伤率时间序列
    return w.wsd(security,"esg_sem03001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem03002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取因工伤损失工作日数时间序列
    return w.wsd(security,"esg_sem03002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem03003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取职业病发生率时间序列
    return w.wsd(security,"esg_sem03003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem03004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取死亡事故数时间序列
    return w.wsd(security,"esg_sem03004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSem04001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取医保覆盖率时间序列
    return w.wsd(security,"esg_sem04001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSpc01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户投诉数量时间序列
    return w.wsd(security,"esg_spc01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSpc01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户满意度时间序列
    return w.wsd(security,"esg_spc01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSpc01003Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否有客户反馈系统时间序列
    return w.wsd(security,"esg_spc01003",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSpc02004Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取新增专利数时间序列
    return w.wsd(security,"esg_spc02004",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSch01001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取供应商数量时间序列
    return w.wsd(security,"esg_sch01001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSch02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)接受ESG评估的供应商数量时间序列
    return w.wsd(security,"esg_sch02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSch01002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取供应商本地化比例时间序列
    return w.wsd(security,"esg_sch01002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSch02001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取本地化采购支出占比时间序列
    return w.wsd(security,"esg_sch02001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSco02001Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取志愿服务时长时间序列
    return w.wsd(security,"esg_sco02001",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGSco02002Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取注册志愿者人数时间序列
    return w.wsd(security,"esg_sco02002",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNosSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取被调研总次数时间序列
    return w.wsd(security,"ir_nos",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoSfSoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取特定对象调研次数时间序列
    return w.wsd(security,"ir_nosfso",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoMiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取媒体(政府)调研家数时间序列
    return w.wsd(security,"ir_nomi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoPiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取个人调研家数时间序列
    return w.wsd(security,"ir_nopi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNosCbsCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券公司调研次数时间序列
    return w.wsd(security,"ir_noscbsc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoiIsCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券公司调研家数时间序列
    return w.wsd(security,"ir_noiisc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrTmsScSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取调研最多的证券公司时间序列
    return w.wsd(security,"ir_tmssc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoSoIamSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险资管调研次数时间序列
    return w.wsd(security,"ir_nosoiam",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoiAmiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险资管调研家数时间序列
    return w.wsd(security,"ir_noiami",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrTMriAmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取调研最多的保险资管时间序列
    return w.wsd(security,"ir_tmriam",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrTMrIiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取调研最多的投资机构时间序列
    return w.wsd(security,"ir_tmrii",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrTMrFiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取调研最多的外资机构时间序列
    return w.wsd(security,"ir_tmrfi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNosBocSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他公司调研次数时间序列
    return w.wsd(security,"ir_nosboc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrNoIfOcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他公司调研家数时间序列
    return w.wsd(security,"ir_noifoc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIrOcMrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取调研最多的其他公司时间序列
    return w.wsd(security,"ir_ocmr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerBirthYearSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取出生年份时间序列
    return w.wsd(security,"fund_manager_birthyear",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerAgeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取年龄时间序列
    return w.wsd(security,"fund_manager_age",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerEducationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取学历时间序列
    return w.wsd(security,"fund_manager_education",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerNationalitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国籍时间序列
    return w.wsd(security,"fund_manager_nationality",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerResumeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取简历时间序列
    return w.wsd(security,"fund_manager_resume",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerGenderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取性别时间序列
    return w.wsd(security,"fund_manager_gender",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职日期时间序列
    return w.wsd(security,"fund_manager_startdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerOnThePostDaysSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职天数时间序列
    return w.wsd(security,"fund_manager_onthepostdays",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerStartDateOfManagerCareerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券从业日期时间序列
    return w.wsd(security,"fund_manager_startdateofmanagercareer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerPreviousFundNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取历任基金数时间序列
    return w.wsd(security,"fund_manager_previousfundno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerFundNoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职基金数时间序列
    return w.wsd(security,"fund_manager_fundno",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerFundCodesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职基金代码时间序列
    return w.wsd(security,"fund_manager_fundcodes",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerTotalNetAssetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职基金总规模时间序列
    return w.wsd(security,"fund_manager_totalnetasset",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerTotalNetAsset2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职基金总规模(支持历史)时间序列
    return w.wsd(security,"fund_manager_totalnetasset2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取离职日期时间序列
    return w.wsd(security,"fund_manager_enddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerResignationReasonSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取离任原因时间序列
    return w.wsd(security,"fund_manager_resignationreason",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerBackgroundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资经理背景时间序列
    return w.wsd(security,"fund_manager_background",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerAwardRecordSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职基金获奖记录时间序列
    return w.wsd(security,"fund_manager_awardrecord",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerAwardRecordNumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取履任以来获奖总次数时间序列
    return w.wsd(security,"fund_manager_awardrecordnum",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerTotalReturnOverBenchmarkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取超越基准总回报时间序列
    return w.wsd(security,"fund_manager_totalreturnoverbenchmark",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavPeriodicAnnualIZedReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任职年化回报时间序列
    return w.wsd(security,"NAV_periodicannualizedreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerMaxReturnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取任期最大回报时间序列
    return w.wsd(security,"fund_manager_maxreturn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundManagerBestPerformanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现任基金最佳回报时间序列
    return w.wsd(security,"fund_manager_bestperformance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMaintenanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本项目规模维持率时间序列
    return w.wsd(security,"maintenance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossMarginTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利(TTM)时间序列
    return w.wsd(security,"grossmargin_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossMarginSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利时间序列
    return w.wsd(security,"grossmargin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossMarginTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利(TTM)_GSD时间序列
    return w.wsd(security,"grossmargin_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGrossMargin2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利_GSD时间序列
    return w.wsd(security,"wgsd_grossmargin2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaGpTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利(TTM)_PIT时间序列
    return w.wsd(security,"fa_gp_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGrossMarginTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛利(TTM,只有最新数据)时间序列
    return w.wsd(security,"grossmargin_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益(TTM)时间序列
    return w.wsd(security,"operateincome_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益时间序列
    return w.wsd(security,"operateincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益(TTM)_GSD时间序列
    return w.wsd(security,"operateincome_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOAIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益_PIT时间序列
    return w.wsd(security,"fa_oaincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOperaCtIncomeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益(TTM)_PIT时间序列
    return w.wsd(security,"fa_operactincome_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateIncomeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动净收益(TTM,只有最新数据)时间序列
    return w.wsd(security,"operateincome_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益(TTM)时间序列
    return w.wsd(security,"investincome_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益时间序列
    return w.wsd(security,"investincome",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益(TTM)_GSD时间序列
    return w.wsd(security,"investincome_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaChavAlIncomeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益(TTM)_PIT时间序列
    return w.wsd(security,"fa_chavalincome_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestIncomeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价值变动净收益(TTM,只有最新数据)时间序列
    return w.wsd(security,"investincome_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEBrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取研发支出前利润时间序列
    return w.wsd(security,"ebr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全部投入资本时间序列
    return w.wsd(security,"investcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestCapital2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取全部投入资本_GSD时间序列
    return w.wsd(security,"wgsd_investcapital2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInvestCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全部投入资本_PIT时间序列
    return w.wsd(security,"fa_investcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWorkingCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营运资本时间序列
    return w.wsd(security,"workingcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDWorkingCapital2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营运资本_GSD时间序列
    return w.wsd(security,"wgsd_workingcapital2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDWKCapChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营运资本变动_GSD时间序列
    return w.wsd(security,"wgsd_wkcap_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetworkingCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净营运资本时间序列
    return w.wsd(security,"networkingcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetworkingCapital2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净营运资本_GSD时间序列
    return w.wsd(security,"wgsd_networkingcapital2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaWKCapChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.营运资本变动_GSD时间序列
    return w.wsd(security,"wgsd_qfa_wkcap_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRetainedEarningsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取留存收益时间序列
    return w.wsd(security,"retainedearnings",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDComEqRetainEarnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取留存收益_GSD时间序列
    return w.wsd(security,"wgsd_com_eq_retain_earn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRetainEarnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取留存收益_PIT时间序列
    return w.wsd(security,"fa_retainearn",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务时间序列
    return w.wsd(security,"interestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInterestDebt2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务_GSD时间序列
    return w.wsd(security,"wgsd_interestdebt2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取带息债务_PIT时间序列
    return w.wsd(security,"fa_interestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTangibleAToInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形净值/带息债务_PIT时间序列
    return w.wsd(security,"fa_tangibleatointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDatoInterestDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA/带息债务时间序列
    return w.wsd(security,"ebitdatointerestdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净债务时间序列
    return w.wsd(security,"netdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetDebt2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净债务_GSD时间序列
    return w.wsd(security,"wgsd_netdebt2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净债务_PIT时间序列
    return w.wsd(security,"fa_netdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTangibleAssetToNetDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有形净值/净债务_PIT时间序列
    return w.wsd(security,"fa_tangibleassettonetdebt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDaPerIdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期计提折旧与摊销时间序列
    return w.wsd(security,"da_perid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDa2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取当期计提折旧与摊销_GSD时间序列
    return w.wsd(security,"wgsd_da2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTotalLoanNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款总额时间序列
    return w.wsd(security,"total_loan_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTotalLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款总额(旧)时间序列
    return w.wsd(security,"total_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9506Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取正常-占贷款总额比时间序列
    return w.wsd(security,"stmnote_bank_9506",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9507Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取关注-占贷款总额比时间序列
    return w.wsd(security,"stmnote_bank_9507",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9508Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取次级-占贷款总额比时间序列
    return w.wsd(security,"stmnote_bank_9508",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9509Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可疑-占贷款总额比时间序列
    return w.wsd(security,"stmnote_bank_9509",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9510Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取损失-占贷款总额比时间序列
    return w.wsd(security,"stmnote_bank_9510",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTotalDepositNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款总额时间序列
    return w.wsd(security,"total_deposit_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTotalDepositSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款总额(旧)时间序列
    return w.wsd(security,"total_deposit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank647Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_存款总额时间序列
    return w.wsd(security,"stmnote_bank_647",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank648Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_存款总额时间序列
    return w.wsd(security,"stmnote_bank_648",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank646Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_存款总额时间序列
    return w.wsd(security,"stmnote_bank_646",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBadDebtProvNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款减值准备时间序列
    return w.wsd(security,"baddebtprov_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBadDebtProvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款减值准备(旧)时间序列
    return w.wsd(security,"baddebtprov",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankArSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款损失准备充足率时间序列
    return w.wsd(security,"stmnote_bank_AR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank129NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取成本收入比时间序列
    return w.wsd(security,"stmnote_bank_129_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank129Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取成本收入比(旧)时间序列
    return w.wsd(security,"stmnote_bank_129",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanDePoRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存贷款比率时间序列
    return w.wsd(security,"loan_depo_ratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanDePoRatioRMbNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存贷款比率(人民币)时间序列
    return w.wsd(security,"loan_depo_ratio_rmb_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanDePoRatioNormBNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存贷款比率(外币)时间序列
    return w.wsd(security,"loan_depo_ratio_normb_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanDePoRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存贷款比率(旧)时间序列
    return w.wsd(security,"loan_depo_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanDePoRatioRMbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存贷款比率(人民币)(旧)时间序列
    return w.wsd(security,"loan_depo_ratio_rmb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanDePoRatioNormBSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存贷款比率(外币)(旧)时间序列
    return w.wsd(security,"loan_depo_ratio_normb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNPlRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款比率时间序列
    return w.wsd(security,"npl_ratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNPlRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款比率(旧)时间序列
    return w.wsd(security,"npl_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBadDebtProvCoverageNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款拨备覆盖率时间序列
    return w.wsd(security,"baddebtprovcoverage_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBadDebtProvCoverageSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款拨备覆盖率(旧)时间序列
    return w.wsd(security,"baddebtprovcoverage",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLendToBanksRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆出资金比率时间序列
    return w.wsd(security,"lend_to_banks_ratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLendToBanksRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆出资金比率(旧)时间序列
    return w.wsd(security,"lend_to_banks_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanFromBanksRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆入资金比率时间序列
    return w.wsd(security,"loan_from_banks_ratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoanFromBanksRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆入资金比率(旧)时间序列
    return w.wsd(security,"loan_from_banks_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReserveRatioRMbNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取备付金比率(人民币)时间序列
    return w.wsd(security,"reserveratio_rmb_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReserveRatioRMbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取备付金比率(人民币)(旧)时间序列
    return w.wsd(security,"reserveratio_rmb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReserveRatioFcNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取备付金比率(外币)时间序列
    return w.wsd(security,"reserveratio_fc_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getReserveRatioFcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取备付金比率(外币)(旧)时间序列
    return w.wsd(security,"reserveratio_fc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank26Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额时间序列
    return w.wsd(security,"stmnote_bank_26",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank691Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_企业贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_691",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank692Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_个人贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_692",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank693Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_票据贴现时间序列
    return w.wsd(security,"stmnote_bank_693",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank694Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_个人住房贷款时间序列
    return w.wsd(security,"stmnote_bank_694",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank695Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_个人消费贷款时间序列
    return w.wsd(security,"stmnote_bank_695",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank696Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_信用卡应收账款时间序列
    return w.wsd(security,"stmnote_bank_696",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank697Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_经营性贷款时间序列
    return w.wsd(security,"stmnote_bank_697",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank698Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_汽车贷款时间序列
    return w.wsd(security,"stmnote_bank_698",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank699Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_其他个人贷款时间序列
    return w.wsd(security,"stmnote_bank_699",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank690Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_总计时间序列
    return w.wsd(security,"stmnote_bank_690",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank751Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_信用贷款时间序列
    return w.wsd(security,"stmnote_bank_751",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank752Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_保证贷款时间序列
    return w.wsd(security,"stmnote_bank_752",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank753Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_抵押贷款时间序列
    return w.wsd(security,"stmnote_bank_753",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank754Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_质押贷款时间序列
    return w.wsd(security,"stmnote_bank_754",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank811Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_短期贷款时间序列
    return w.wsd(security,"stmnote_bank_811",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank812Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额_中长期贷款时间序列
    return w.wsd(security,"stmnote_bank_812",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank66Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款余额(按行业)时间序列
    return w.wsd(security,"stmnote_bank_66",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMedLongLoanRatioRMbNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中长期贷款比率(人民币)时间序列
    return w.wsd(security,"medlongloanratio_rmb_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMedLongLoanRatioRMbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中长期贷款比率(人民币)(旧)时间序列
    return w.wsd(security,"medlongloanratio_rmb",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMedLongLoanRatioFcNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中长期贷款比率(外币)时间序列
    return w.wsd(security,"medlongloanratio_fc_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMedLongLoanRatioFcSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取中长期贷款比率(外币)(旧)时间序列
    return w.wsd(security,"medlongloanratio_fc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntColRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息回收率时间序列
    return w.wsd(security,"intcolratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntColRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息回收率(旧)时间序列
    return w.wsd(security,"intcolratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getForCaputRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取境外资金运用比率时间序列
    return w.wsd(security,"forcaputratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getForCaputRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取境外资金运用比率(旧)时间序列
    return w.wsd(security,"forcaputratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLargestCustomerLoanNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单一最大客户贷款比例时间序列
    return w.wsd(security,"largest_customer_loan_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLargestCustomerLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单一最大客户贷款比例(旧)时间序列
    return w.wsd(security,"largest_customer_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTopTenCustomerLoanNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大十家客户贷款占资本净额比例时间序列
    return w.wsd(security,"top_ten_customer_loan_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank144NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净息差时间序列
    return w.wsd(security,"stmnote_bank_144_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank5444Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净息差(公布值)时间序列
    return w.wsd(security,"stmnote_bank_5444",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank144Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净息差(旧)时间序列
    return w.wsd(security,"stmnote_bank_144",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank147NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利差时间序列
    return w.wsd(security,"stmnote_bank_147_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank147Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净利差(旧)时间序列
    return w.wsd(security,"stmnote_bank_147",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank341Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场风险资本时间序列
    return w.wsd(security,"stmnote_bank_341",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank1778Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行理财产品余额时间序列
    return w.wsd(security,"stmnote_bank_1778",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank55Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取拨贷比时间序列
    return w.wsd(security,"stmnote_bank_55",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank5453Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取库存现金时间序列
    return w.wsd(security,"stmnote_bank_5453",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankAsFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可用的稳定资金时间序列
    return w.wsd(security,"stmnote_bank_ASF",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankRsfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所需的稳定资金时间序列
    return w.wsd(security,"stmnote_bank_RSF",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGGcbWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取绿色信贷余额时间序列
    return w.wsd(security,"esg_gcb_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTopTenCustomerLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最大十家客户贷款比例(旧)时间序列
    return w.wsd(security,"top_ten_customer_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank132NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心资本净额时间序列
    return w.wsd(security,"stmnote_bank_132_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank132Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心资本净额(旧)时间序列
    return w.wsd(security,"stmnote_bank_132",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank131NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本净额时间序列
    return w.wsd(security,"stmnote_bank_131_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankNetEquityCapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本净额(2013)时间序列
    return w.wsd(security,"stmnote_bank_NetEquityCap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank131Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本净额(旧)时间序列
    return w.wsd(security,"stmnote_bank_131",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankTier1CapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一级资本净额(2013)时间序列
    return w.wsd(security,"stmnote_bank_Tier1Cap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankCoreTier1CapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心一级资本净额(2013)时间序列
    return w.wsd(security,"stmnote_bank_CoreTier1Cap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCoreCapIADeRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心资本充足率时间序列
    return w.wsd(security,"core_capi_ade_ratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCoreCapIADeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心资本充足率(旧)时间序列
    return w.wsd(security,"core_capi_ade_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCapIADeRatioNSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本充足率时间序列
    return w.wsd(security,"capi_ade_ratio_n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankCapAdequacyRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本充足率(2013)时间序列
    return w.wsd(security,"stmnote_bank_CapAdequacyRatio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCapIADeRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本充足率(旧)时间序列
    return w.wsd(security,"capi_ade_ratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankCapAdequacyRatioT1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一级资本充足率(2013)时间序列
    return w.wsd(security,"stmnote_bank_CapAdequacyRatio_T1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBankCapAdequacyRatioCt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心一级资本充足率(2013)时间序列
    return w.wsd(security,"stmnote_bank_CapAdequacyRatio_CT1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank171Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取杠杆率时间序列
    return w.wsd(security,"stmnote_bank_171",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec34Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本杠杆率时间序列
    return w.wsd(security,"stmnote_sec_34",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank172Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率时间序列
    return w.wsd(security,"stmnote_bank_172",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec35Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率(券商)时间序列
    return w.wsd(security,"stmnote_sec_35",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212540Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率:基本情景时间序列
    return w.wsd(security,"qstmnote_insur_212540",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212541Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率:公司整体:压力情景1时间序列
    return w.wsd(security,"qstmnote_insur_212541",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212542Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率:公司整体:压力情景2时间序列
    return w.wsd(security,"qstmnote_insur_212542",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212543Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率:独立账户:压力情景1时间序列
    return w.wsd(security,"qstmnote_insur_212543",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212544Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取流动性覆盖率:独立账户:压力情景2时间序列
    return w.wsd(security,"qstmnote_insur_212544",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank31Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取正常-金额时间序列
    return w.wsd(security,"stmnote_bank_31",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9501Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取正常-迁徙率时间序列
    return w.wsd(security,"stmnote_bank_9501",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank340Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取关注-金额时间序列
    return w.wsd(security,"stmnote_bank_340",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9502Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取关注-迁徙率时间序列
    return w.wsd(security,"stmnote_bank_9502",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank37Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取次级-金额时间序列
    return w.wsd(security,"stmnote_bank_37",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9503Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取次级-迁徙率时间序列
    return w.wsd(security,"stmnote_bank_9503",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank40Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可疑-金额时间序列
    return w.wsd(security,"stmnote_bank_40",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank9504Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取可疑-迁徙率时间序列
    return w.wsd(security,"stmnote_bank_9504",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank430Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取损失-金额时间序列
    return w.wsd(security,"stmnote_bank_430",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank616Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_个人存款时间序列
    return w.wsd(security,"stmnote_bank_616",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank611Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_个人定期存款时间序列
    return w.wsd(security,"stmnote_bank_611",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank612Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_个人活期存款时间序列
    return w.wsd(security,"stmnote_bank_612",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank617Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_公司存款时间序列
    return w.wsd(security,"stmnote_bank_617",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank613Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_公司定期存款时间序列
    return w.wsd(security,"stmnote_bank_613",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank614Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_公司活期存款时间序列
    return w.wsd(security,"stmnote_bank_614",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank615Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款余额_其它存款时间序列
    return w.wsd(security,"stmnote_bank_615",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank621Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_个人定期存款时间序列
    return w.wsd(security,"stmnote_bank_621",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank622Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_个人活期存款时间序列
    return w.wsd(security,"stmnote_bank_622",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank623Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_公司定期存款时间序列
    return w.wsd(security,"stmnote_bank_623",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank624Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_公司活期存款时间序列
    return w.wsd(security,"stmnote_bank_624",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank625Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_其它存款时间序列
    return w.wsd(security,"stmnote_bank_625",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank50Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_企业存款时间序列
    return w.wsd(security,"stmnote_bank_50",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank52Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均余额_储蓄存款时间序列
    return w.wsd(security,"stmnote_bank_52",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank641Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_个人定期存款时间序列
    return w.wsd(security,"stmnote_bank_641",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank642Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_个人活期存款时间序列
    return w.wsd(security,"stmnote_bank_642",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank643Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_公司定期存款时间序列
    return w.wsd(security,"stmnote_bank_643",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank644Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_公司活期存款时间序列
    return w.wsd(security,"stmnote_bank_644",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank645Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_其它存款时间序列
    return w.wsd(security,"stmnote_bank_645",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank51Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_企业存款时间序列
    return w.wsd(security,"stmnote_bank_51",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank53Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存款平均成本率_储蓄存款时间序列
    return w.wsd(security,"stmnote_bank_53",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank680Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_总计时间序列
    return w.wsd(security,"stmnote_bank_680",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank681Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_企业贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_681",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank682Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_个人贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_682",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank683Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_票据贴现时间序列
    return w.wsd(security,"stmnote_bank_683",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank684Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_个人住房贷款时间序列
    return w.wsd(security,"stmnote_bank_684",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank685Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_个人消费贷款时间序列
    return w.wsd(security,"stmnote_bank_685",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank686Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_信用卡应收账款时间序列
    return w.wsd(security,"stmnote_bank_686",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank687Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_经营性贷款时间序列
    return w.wsd(security,"stmnote_bank_687",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank688Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_汽车贷款时间序列
    return w.wsd(security,"stmnote_bank_688",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank689Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_其他个人贷款时间序列
    return w.wsd(security,"stmnote_bank_689",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank701Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_企业贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_701",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank702Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_个人贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_702",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank703Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_票据贴现时间序列
    return w.wsd(security,"stmnote_bank_703",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank704Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_个人住房贷款时间序列
    return w.wsd(security,"stmnote_bank_704",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank705Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_个人消费贷款时间序列
    return w.wsd(security,"stmnote_bank_705",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank706Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_信用卡应收账款时间序列
    return w.wsd(security,"stmnote_bank_706",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank707Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_经营性贷款时间序列
    return w.wsd(security,"stmnote_bank_707",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank708Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_汽车贷款时间序列
    return w.wsd(security,"stmnote_bank_708",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank709Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_其他个人贷款时间序列
    return w.wsd(security,"stmnote_bank_709",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank700Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_总计时间序列
    return w.wsd(security,"stmnote_bank_700",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank711Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_企业贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_711",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank712Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_个人贷款及垫款时间序列
    return w.wsd(security,"stmnote_bank_712",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank713Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_票据贴现时间序列
    return w.wsd(security,"stmnote_bank_713",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank714Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_个人住房贷款时间序列
    return w.wsd(security,"stmnote_bank_714",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank715Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_个人消费贷款时间序列
    return w.wsd(security,"stmnote_bank_715",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank716Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_信用卡应收账款时间序列
    return w.wsd(security,"stmnote_bank_716",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank717Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_经营性贷款时间序列
    return w.wsd(security,"stmnote_bank_717",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank718Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_汽车贷款时间序列
    return w.wsd(security,"stmnote_bank_718",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank719Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_其他个人贷款时间序列
    return w.wsd(security,"stmnote_bank_719",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank741Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_信用贷款时间序列
    return w.wsd(security,"stmnote_bank_741",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank742Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_保证贷款时间序列
    return w.wsd(security,"stmnote_bank_742",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank743Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_抵押贷款时间序列
    return w.wsd(security,"stmnote_bank_743",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank744Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_质押贷款时间序列
    return w.wsd(security,"stmnote_bank_744",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank730Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_总计时间序列
    return w.wsd(security,"stmnote_bank_730",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank761Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_信用贷款时间序列
    return w.wsd(security,"stmnote_bank_761",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank762Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_保证贷款时间序列
    return w.wsd(security,"stmnote_bank_762",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank763Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_抵押贷款时间序列
    return w.wsd(security,"stmnote_bank_763",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank764Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_质押贷款时间序列
    return w.wsd(security,"stmnote_bank_764",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank771Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_信用贷款时间序列
    return w.wsd(security,"stmnote_bank_771",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank772Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_保证贷款时间序列
    return w.wsd(security,"stmnote_bank_772",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank773Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_抵押贷款时间序列
    return w.wsd(security,"stmnote_bank_773",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank774Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_质押贷款时间序列
    return w.wsd(security,"stmnote_bank_774",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank801Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_短期贷款时间序列
    return w.wsd(security,"stmnote_bank_801",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank802Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额_中长期贷款时间序列
    return w.wsd(security,"stmnote_bank_802",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank821Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_短期贷款时间序列
    return w.wsd(security,"stmnote_bank_821",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank822Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率_中长期贷款时间序列
    return w.wsd(security,"stmnote_bank_822",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank46Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_短期贷款时间序列
    return w.wsd(security,"stmnote_bank_46",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank48Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款平均余额_中长期贷款时间序列
    return w.wsd(security,"stmnote_bank_48",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank65Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款余额(按行业)时间序列
    return w.wsd(security,"stmnote_bank_65",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank67Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取不良贷款率(按行业)时间序列
    return w.wsd(security,"stmnote_bank_67",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0021Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期保证贷款_3个月以内时间序列
    return w.wsd(security,"stmnote_bank_0021",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0022Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期保证贷款_3个月至1年时间序列
    return w.wsd(security,"stmnote_bank_0022",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0023Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期保证贷款_1年以上3年以内时间序列
    return w.wsd(security,"stmnote_bank_0023",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0024Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期保证贷款_3年以上时间序列
    return w.wsd(security,"stmnote_bank_0024",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0025Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期保证贷款合计时间序列
    return w.wsd(security,"stmnote_bank_0025",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0011Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期信用贷款_3个月以内时间序列
    return w.wsd(security,"stmnote_bank_0011",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0012Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期信用贷款_3个月至1年时间序列
    return w.wsd(security,"stmnote_bank_0012",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0013Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期信用贷款_1年以上3年以内时间序列
    return w.wsd(security,"stmnote_bank_0013",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0014Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期信用贷款_3年以上时间序列
    return w.wsd(security,"stmnote_bank_0014",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0015Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期信用贷款合计时间序列
    return w.wsd(security,"stmnote_bank_0015",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0031Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期抵押贷款_3个月以内时间序列
    return w.wsd(security,"stmnote_bank_0031",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0032Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期抵押贷款_3个月至1年时间序列
    return w.wsd(security,"stmnote_bank_0032",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0033Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期抵押贷款_1年以上3年以内时间序列
    return w.wsd(security,"stmnote_bank_0033",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0034Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期抵押贷款_3年以上时间序列
    return w.wsd(security,"stmnote_bank_0034",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0035Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期抵押贷款合计时间序列
    return w.wsd(security,"stmnote_bank_0035",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0041Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期票据贴现_3个月以内时间序列
    return w.wsd(security,"stmnote_bank_0041",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0042Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期票据贴现_3个月至1年时间序列
    return w.wsd(security,"stmnote_bank_0042",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0043Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期票据贴现_1年以上3年以内时间序列
    return w.wsd(security,"stmnote_bank_0043",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0044Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期票据贴现_3年以上时间序列
    return w.wsd(security,"stmnote_bank_0044",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0045Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期票据贴现合计时间序列
    return w.wsd(security,"stmnote_bank_0045",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0051Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期质押贷款_3个月以内时间序列
    return w.wsd(security,"stmnote_bank_0051",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0052Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期质押贷款_3个月至1年时间序列
    return w.wsd(security,"stmnote_bank_0052",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0053Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期质押贷款_1年以上3年以内时间序列
    return w.wsd(security,"stmnote_bank_0053",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0054Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期质押贷款_3年以上时间序列
    return w.wsd(security,"stmnote_bank_0054",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteBank0055Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取逾期质押贷款合计时间序列
    return w.wsd(security,"stmnote_bank_0055",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资本时间序列
    return w.wsd(security,"stmnote_sec_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净资本比率时间序列
    return w.wsd(security,"stmnote_sec_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec30Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心净资本时间序列
    return w.wsd(security,"stmnote_sec_30",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec31Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取附属净资本时间序列
    return w.wsd(security,"stmnote_sec_31",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营固定收益类证券/净资本时间序列
    return w.wsd(security,"stmnote_sec_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营权益类证券及证券衍生品/净资本时间序列
    return w.wsd(security,"stmnote_sec_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec32Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取各项风险资本准备之和时间序列
    return w.wsd(security,"stmnote_sec_32",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec36Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净稳定资金率时间序列
    return w.wsd(security,"stmnote_sec_36",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取受托资金时间序列
    return w.wsd(security,"stmnote_sec_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecOp2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营股票时间序列
    return w.wsd(security,"stmnote_sec_op_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecOp3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营国债时间序列
    return w.wsd(security,"stmnote_sec_op_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecOp4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营基金时间序列
    return w.wsd(security,"stmnote_sec_op_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecOp5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营证可转债时间序列
    return w.wsd(security,"stmnote_sec_op_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSecOp1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营证券合计时间序列
    return w.wsd(security,"stmnote_sec_op_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取风险覆盖率时间序列
    return w.wsd(security,"stmnote_sec_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1540Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券投资业务收入时间序列
    return w.wsd(security,"stmnote_sec_1540",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1541Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券经纪业务收入时间序列
    return w.wsd(security,"stmnote_sec_1541",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1542Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资银行业务收入时间序列
    return w.wsd(security,"stmnote_sec_1542",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1550Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券投资业务净收入时间序列
    return w.wsd(security,"stmnote_sec_1550",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1551Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券经纪业务净收入时间序列
    return w.wsd(security,"stmnote_sec_1551",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteSec1552Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资银行业务净收入时间序列
    return w.wsd(security,"stmnote_sec_1552",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取评估利率假设:风险贴现率时间序列
    return w.wsd(security,"stmnote_insur_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取退保率时间序列
    return w.wsd(security,"stmnote_insur_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单继续率(13个月)时间序列
    return w.wsd(security,"stmnote_insur_1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单继续率(14个月)时间序列
    return w.wsd(security,"stmnote_insur_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单继续率(25个月)时间序列
    return w.wsd(security,"stmnote_insur_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单继续率(26个月)时间序列
    return w.wsd(security,"stmnote_insur_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取偿付能力充足率(产险)时间序列
    return w.wsd(security,"stmnote_insur_12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取赔付率(产险)时间序列
    return w.wsd(security,"stmnote_insur_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取费用率(产险)时间序列
    return w.wsd(security,"stmnote_insur_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur13NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际资本(产险)时间序列
    return w.wsd(security,"stmnote_insur_13n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur13Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际资本(产险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_13",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur14NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低资本(产险)时间序列
    return w.wsd(security,"stmnote_insur_14n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低资本(产险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur15Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取偿付能力充足率(寿险)时间序列
    return w.wsd(security,"stmnote_insur_15",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur16NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取内含价值(寿险)时间序列
    return w.wsd(security,"stmnote_insur_16n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur16Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取内含价值(寿险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_16",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur17NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取新业务价值(寿险)时间序列
    return w.wsd(security,"stmnote_insur_17n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur17Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取新业务价值(寿险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_17",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur18NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取有效业务价值(寿险)时间序列
    return w.wsd(security,"stmnote_insur_18n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur18Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取有效业务价值(寿险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_18",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur19NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际资本(寿险)时间序列
    return w.wsd(security,"stmnote_insur_19n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际资本(寿险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur20NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低资本(寿险)时间序列
    return w.wsd(security,"stmnote_insur_20n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低资本(寿险)(旧)时间序列
    return w.wsd(security,"stmnote_insur_20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7801Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期存款(投资)时间序列
    return w.wsd(security,"stmnote_insur_7801",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7802Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券投资时间序列
    return w.wsd(security,"stmnote_insur_7802",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs8Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券投资成本_FUND时间序列
    return w.wsd(security,"stm_bs_8",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs7Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券投资_FUND时间序列
    return w.wsd(security,"stm_bs_7",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs102Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取债券投资公允价值变动收益_FUND时间序列
    return w.wsd(security,"stm_is_102",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7803Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金投资时间序列
    return w.wsd(security,"stmnote_insur_7803",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs201Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金投资_FUND时间序列
    return w.wsd(security,"stm_bs_201",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs202Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金投资成本_FUND时间序列
    return w.wsd(security,"stm_bs_202",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs104Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金投资公允价值变动收益_FUND时间序列
    return w.wsd(security,"stm_is_104",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7804Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票投资时间序列
    return w.wsd(security,"stmnote_insur_7804",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票投资成本_FUND时间序列
    return w.wsd(security,"stm_bs_5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票投资_FUND时间序列
    return w.wsd(security,"stm_bs_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs101Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股票投资公允价值变动收益_FUND时间序列
    return w.wsd(security,"stm_is_101",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStyleTopNProportionToAllSharesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取前N大股票占全部股票投资比时间序列
    return w.wsd(security,"style_topnproportiontoallshares",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7805Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权投资时间序列
    return w.wsd(security,"stmnote_insur_7805",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongTermEqYInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期股权投资时间序列
    return w.wsd(security,"long_term_eqy_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7806Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基建投资时间序列
    return w.wsd(security,"stmnote_insur_7806",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7807Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物时间序列
    return w.wsd(security,"stmnote_insur_7807",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCCeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物_GSD时间序列
    return w.wsd(security,"wgsd_cce",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCashBegBalCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物期初余额_GSD时间序列
    return w.wsd(security,"wgsd_cash_beg_bal_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCashEndBalCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金及现金等价物期末余额_GSD时间序列
    return w.wsd(security,"wgsd_cash_end_bal_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashCashEquBegPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期初现金及现金等价物余额时间序列
    return w.wsd(security,"cash_cash_equ_beg_period",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashCashEquEndPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期末现金及现金等价物余额时间序列
    return w.wsd(security,"cash_cash_equ_end_period",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCcEpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股现金及现金等价物余额_PIT时间序列
    return w.wsd(security,"fa_cceps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCCeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期末现金及现金等价物_PIT时间序列
    return w.wsd(security,"fa_cce",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaCashBegBalCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金及现金等价物期初余额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_cash_beg_bal_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaCashEndBalCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金及现金等价物期末余额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_cash_end_bal_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashCashEquEndPeriodSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.期末现金及现金等价物余额时间序列
    return w.wsd(security,"qfa_cash_cash_equ_end_period",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur30NSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取集团内含价值时间序列
    return w.wsd(security,"stmnote_insur_30n",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7810Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取集团客户数时间序列
    return w.wsd(security,"stmnote_insur_7810",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7811Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险营销员人数时间序列
    return w.wsd(security,"stmnote_insur_7811",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7812Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险营销员每月人均首年保险业务收入时间序列
    return w.wsd(security,"stmnote_insur_7812",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInSur7813Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险营销员每月人均寿险新保单件数时间序列
    return w.wsd(security,"stmnote_insur_7813",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0005Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券买卖收益时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0005",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0006Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取公允价值变动收益时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0006",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs24Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取公允价值变动收益_FUND时间序列
    return w.wsd(security,"stm_is_24",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs103Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取权证投资公允价值变动收益_FUND时间序列
    return w.wsd(security,"stm_is_103",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmNoteInvestmentIncome0008Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取处置合营企业净收益时间序列
    return w.wsd(security,"stmnote_InvestmentIncome_0008",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212505Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心偿付能力溢额时间序列
    return w.wsd(security,"qstmnote_insur_212505",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212506Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心偿付能力充足率时间序列
    return w.wsd(security,"qstmnote_insur_212506",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212509Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险业务收入时间序列
    return w.wsd(security,"qstmnote_insur_212509",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212514Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取实际资本时间序列
    return w.wsd(security,"qstmnote_insur_212514",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212515Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心一级资本时间序列
    return w.wsd(security,"qstmnote_insur_212515",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212516Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取核心二级资本时间序列
    return w.wsd(security,"qstmnote_insur_212516",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212517Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取附属一级资本时间序列
    return w.wsd(security,"qstmnote_insur_212517",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212518Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取附属二级资本时间序列
    return w.wsd(security,"qstmnote_insur_212518",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212519Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取最低资本时间序列
    return w.wsd(security,"qstmnote_insur_212519",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212520Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取量化风险最低资本时间序列
    return w.wsd(security,"qstmnote_insur_212520",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212527Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取控制风险最低资本时间序列
    return w.wsd(security,"qstmnote_insur_212527",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212523Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场风险最低资本合计时间序列
    return w.wsd(security,"qstmnote_insur_212523",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212524Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取信用风险最低资本合计时间序列
    return w.wsd(security,"qstmnote_insur_212524",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212546Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险风险最低资本合计时间序列
    return w.wsd(security,"qstmnote_insur_212546",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212521Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取寿险业务保险风险最低资本合计时间序列
    return w.wsd(security,"qstmnote_insur_212521",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212522Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取非寿险业务保险风险最低资本合计时间序列
    return w.wsd(security,"qstmnote_insur_212522",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212528Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取附加资本时间序列
    return w.wsd(security,"qstmnote_insur_212528",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212525Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取风险分散效应的资本要求增加时间序列
    return w.wsd(security,"qstmnote_insur_212525",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212526Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取风险聚合效应的资本要求减少时间序列
    return w.wsd(security,"qstmnote_insur_212526",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212530Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流时间序列
    return w.wsd(security,"qstmnote_insur_212530",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212531Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第1年时间序列
    return w.wsd(security,"qstmnote_insur_212531",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212532Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第2年时间序列
    return w.wsd(security,"qstmnote_insur_212532",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212533Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第3年时间序列
    return w.wsd(security,"qstmnote_insur_212533",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212547Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第1年:未来1季度时间序列
    return w.wsd(security,"qstmnote_insur_212547",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212548Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第1年:未来2季度时间序列
    return w.wsd(security,"qstmnote_insur_212548",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212549Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第1年:未来3季度时间序列
    return w.wsd(security,"qstmnote_insur_212549",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQStmNoteInSur212550Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取净现金流:报告日后第1年:未来4季度时间序列
    return w.wsd(security,"qstmnote_insur_212550",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPcfOcFlyRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(经营性净现金流LYR)时间序列
    return w.wsd(security,"pcf_ocflyr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFundRestrictedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受限资金_GSD时间序列
    return w.wsd(security,"wgsd_fund_restricted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundRestrictedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取受限资金时间序列
    return w.wsd(security,"fund_restricted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNotesRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收票据时间序列
    return w.wsd(security,"notes_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRecEivNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款及票据_GSD时间序列
    return w.wsd(security,"wgsd_receiv_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccTRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收账款时间序列
    return w.wsd(security,"acct_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinancingARSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收款项融资时间序列
    return w.wsd(security,"financing_a/r",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrepaySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预付款项时间序列
    return w.wsd(security,"prepay",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDvdRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收股利时间序列
    return w.wsd(security,"dvd_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收股利_FUND时间序列
    return w.wsd(security,"stm_bs_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收利息时间序列
    return w.wsd(security,"int_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收利息_FUND时间序列
    return w.wsd(security,"stm_bs_12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他应收款时间序列
    return w.wsd(security,"oth_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInventoriesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货_GSD时间序列
    return w.wsd(security,"wgsd_inventories",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInventoriesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货时间序列
    return w.wsd(security,"inventories",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDecrInventoriesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存货的减少时间序列
    return w.wsd(security,"decr_inventories",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDecrInventoriesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.存货的减少时间序列
    return w.wsd(security,"qfa_decr_inventories",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeferredExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取待摊费用时间序列
    return w.wsd(security,"deferred_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDecrDeferredExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取待摊费用减少时间序列
    return w.wsd(security,"decr_deferred_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongTermDeferredExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期待摊费用时间序列
    return w.wsd(security,"long_term_deferred_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAMortLtDeferredExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期待摊费用摊销时间序列
    return w.wsd(security,"amort_lt_deferred_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDecrDeferredExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.待摊费用减少时间序列
    return w.wsd(security,"qfa_decr_deferred_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaAMortLtDeferredExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.长期待摊费用摊销时间序列
    return w.wsd(security,"qfa_amort_lt_deferred_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSettleRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取结算备付金时间序列
    return w.wsd(security,"settle_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取结算备付金_FUND时间序列
    return w.wsd(security,"stm_bs_2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLendIbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆出资金_GSD时间序列
    return w.wsd(security,"wgsd_lend_ib",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoansToOThBanksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆出资金时间序列
    return w.wsd(security,"loans_to_oth_banks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMarginAccTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出资金时间序列
    return w.wsd(security,"margin_acct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrLendingFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取融出资金净增加额时间序列
    return w.wsd(security,"net_incr_lending_fund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRecEivInSurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收保费_GSD时间序列
    return w.wsd(security,"wgsd_receiv_insur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPremRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收保费时间序列
    return w.wsd(security,"prem_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVFromReInsurerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收分保账款时间序列
    return w.wsd(security,"rcv_from_reinsurer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVFromCededInSurContRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收分保合同准备金时间序列
    return w.wsd(security,"rcv_from_ceded_insur_cont_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRecEivToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收款项合计_GSD时间序列
    return w.wsd(security,"wgsd_receiv_tot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTAccTRcVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收款项时间序列
    return w.wsd(security,"tot_acct_rcv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收款项类投资时间序列
    return w.wsd(security,"rcv_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取金融投资时间序列
    return w.wsd(security,"fin_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDebtInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债权投资时间序列
    return w.wsd(security,"debt_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThDebtInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他债权投资时间序列
    return w.wsd(security,"oth_debt_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThEqYInstrumentsInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他权益工具投资时间序列
    return w.wsd(security,"oth_eqy_instruments_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestHtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有至到期投资_GSD时间序列
    return w.wsd(security,"wgsd_invest_htm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHeldToMTyInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有至到期投资时间序列
    return w.wsd(security,"held_to_mty_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLongTermRecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期应收款时间序列
    return w.wsd(security,"long_term_rec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConstInProgToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取在建工程(合计)时间序列
    return w.wsd(security,"const_in_prog_tot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConstInProgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取在建工程时间序列
    return w.wsd(security,"const_in_prog",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProJMAtlSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取工程物资时间序列
    return w.wsd(security,"proj_matl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRAndDCostsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取开发支出时间序列
    return w.wsd(security,"r_and_d_costs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoansAndAdvGrantedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发放贷款及垫款时间序列
    return w.wsd(security,"loans_and_adv_granted",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAssetDepOThBanksFinInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存放同业和其它金融机构款项时间序列
    return w.wsd(security,"asset_dep_oth_banks_fin_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreciousMetalsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贵金属时间序列
    return w.wsd(security,"precious_metals",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVCededUnearnedPremRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收分保未到期责任准备金时间序列
    return w.wsd(security,"rcv_ceded_unearned_prem_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVCededClaimRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收分保未决赔款准备金时间序列
    return w.wsd(security,"rcv_ceded_claim_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVCededLifeInSurRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收分保寿险责任准备金时间序列
    return w.wsd(security,"rcv_ceded_life_insur_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRcVCededLtHealthInSurRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收分保长期健康险责任准备金时间序列
    return w.wsd(security,"rcv_ceded_lt_health_insur_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInsuredPledgeLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保户质押贷款时间序列
    return w.wsd(security,"insured_pledge_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCapMrgnPaidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存出资本保证金时间序列
    return w.wsd(security,"cap_mrgn_paid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTimeDepositsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取定期存款时间序列
    return w.wsd(security,"time_deposits",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSubRRecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收代位追偿款时间序列
    return w.wsd(security,"subr_rec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMrgnPaidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存出保证金时间序列
    return w.wsd(security,"mrgn_paid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取存出保证金_FUND时间序列
    return w.wsd(security,"stm_bs_3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSeatFeesExchangeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易席位费时间序列
    return w.wsd(security,"seat_fees_exchange",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClientsCapDepositSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户资金存款时间序列
    return w.wsd(security,"clients_cap_deposit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClientsRsRvSettleSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户备付金时间序列
    return w.wsd(security,"clients_rsrv_settle",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNotesPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付票据时间序列
    return w.wsd(security,"notes_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPayAccTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款及票据_GSD时间序列
    return w.wsd(security,"wgsd_pay_acct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccTPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付账款时间序列
    return w.wsd(security,"acct_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAdvFromCuStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预收账款时间序列
    return w.wsd(security,"adv_from_cust",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getToTAccTPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付款项时间序列
    return w.wsd(security,"tot_acct_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIntPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付利息时间序列
    return w.wsd(security,"int_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs29Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付利息_FUND时间序列
    return w.wsd(security,"stm_bs_29",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDvdPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付股利时间序列
    return w.wsd(security,"dvd_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOThPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他应付款时间序列
    return w.wsd(security,"oth_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAccExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预提费用时间序列
    return w.wsd(security,"acc_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInCrAccExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预提费用增加时间序列
    return w.wsd(security,"incr_acc_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInCrAccExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.预提费用增加时间序列
    return w.wsd(security,"qfa_incr_acc_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStBondsPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付短期债券时间序列
    return w.wsd(security,"st_bonds_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDepositReceivedIbDepositsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取吸收存款及同业存放时间序列
    return w.wsd(security,"deposit_received_ib_deposits",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDBorrowIbSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆入资金_GSD时间序列
    return w.wsd(security,"wgsd_borrow_ib",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLoansOThBanksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆入资金时间序列
    return w.wsd(security,"loans_oth_banks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrLoansOtherBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取拆入资金净增加额时间序列
    return w.wsd(security,"net_incr_loans_other_bank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrLoansOtherBankSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.拆入资金净增加额时间序列
    return w.wsd(security,"qfa_net_incr_loans_other_bank",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrFundBOrrOfISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取向其他金融机构拆入资金净增加额时间序列
    return w.wsd(security,"net_incr_fund_borr_ofi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrFundBOrrOfISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.向其他金融机构拆入资金净增加额时间序列
    return w.wsd(security,"qfa_net_incr_fund_borr_ofi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHandlingChargesComMPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付手续费及佣金时间序列
    return w.wsd(security,"handling_charges_comm_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPayableToReInsurerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付分保账款时间序列
    return w.wsd(security,"payable_to_reinsurer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRsRvInSurContSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保险合同准备金时间序列
    return w.wsd(security,"rsrv_insur_cont",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getActingTradingSecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代理买卖证券款时间序列
    return w.wsd(security,"acting_trading_sec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getActingUwSecSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代理承销证券款时间序列
    return w.wsd(security,"acting_uw_sec",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBondsPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付债券时间序列
    return w.wsd(security,"bonds_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtPayableToTSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期应付款(合计)时间序列
    return w.wsd(security,"lt_payable_tot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期应付款时间序列
    return w.wsd(security,"lt_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSpecificItemPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取专项应付款时间序列
    return w.wsd(security,"specific_item_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLiaBDepOThBanksFinInStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同业和其它金融机构存放款项时间序列
    return w.wsd(security,"liab_dep_oth_banks_fin_inst",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCuStBankDepSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取吸收存款时间序列
    return w.wsd(security,"cust_bank_dep",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getClaimsPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付赔付款时间序列
    return w.wsd(security,"claims_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDvdPayableInsuredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付保单红利时间序列
    return w.wsd(security,"dvd_payable_insured",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDepositReceivedSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存入保证金时间序列
    return w.wsd(security,"deposit_received",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInsuredDepositInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保户储金及投资款时间序列
    return w.wsd(security,"insured_deposit_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDChgRsvUnearnedPremiumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未到期责任准备金变动_GSD时间序列
    return w.wsd(security,"wgsd_chg_rsv_unearnedpremium",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnearnedPremRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未到期责任准备金时间序列
    return w.wsd(security,"unearned_prem_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaChgRsvUnearnedPremiumSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.未到期责任准备金变动_GSD时间序列
    return w.wsd(security,"wgsd_qfa_chg_rsv_unearnedpremium",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDChgRsvOutstandingLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未决赔款准备金变动_GSD时间序列
    return w.wsd(security,"wgsd_chg_rsv_outstandingloss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOutLossRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取未决赔款准备金时间序列
    return w.wsd(security,"out_loss_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaChgRsvOutstandingLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.未决赔款准备金变动_GSD时间序列
    return w.wsd(security,"wgsd_qfa_chg_rsv_outstandingloss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLifeInSurRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取寿险责任准备金时间序列
    return w.wsd(security,"life_insur_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLtHealthInSurVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期健康险责任准备金时间序列
    return w.wsd(security,"lt_health_insur_v",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPremReceivedAdvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预收保费时间序列
    return w.wsd(security,"prem_received_adv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStFinLInStPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付短期融资款时间序列
    return w.wsd(security,"st_finl_inst_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherEquityInstrumentsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他权益工具时间序列
    return w.wsd(security,"other_equity_instruments",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPerpetualDebtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他权益工具:永续债时间序列
    return w.wsd(security,"perpetual_debt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTreAsStKSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取库存股_GSD时间序列
    return w.wsd(security,"wgsd_treas_stk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTSyStKSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取库存股时间序列
    return w.wsd(security,"tsy_stk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSpecialRsRvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取专项储备时间序列
    return w.wsd(security,"special_rsrv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProvNomRisksSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一般风险准备时间序列
    return w.wsd(security,"prov_nom_risks",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCnVdDiffForeignCurRStatSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取外币报表折算差额时间序列
    return w.wsd(security,"cnvd_diff_foreign_curr_stat",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSHrhLDrEqYGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益差额(特殊报表科目)时间序列
    return w.wsd(security,"shrhldr_eqy_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSHrhLDrEqYGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他股东权益差额说明(特殊报表科目)时间序列
    return w.wsd(security,"shrhldr_eqy_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSHrhLDrEqYNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益差额(合计平衡项目)时间序列
    return w.wsd(security,"shrhldr_eqy_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEquityToTotalCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益/投入资本_GSD时间序列
    return w.wsd(security,"wgsd_equitytototalcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEqYBelongToParComShSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益时间序列
    return w.wsd(security,"eqy_belongto_parcomsh",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityMrQSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的权益(MRQ,只有最新数据)时间序列
    return w.wsd(security,"equity_mrq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDMinIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东权益_GSD时间序列
    return w.wsd(security,"wgsd_min_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getMinorityIntSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取少数股东权益时间序列
    return w.wsd(security,"minority_int",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRecpTaxRendsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收到的税费返还时间序列
    return w.wsd(security,"recp_tax_rends",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaRecpTaxRendsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收到的税费返还时间序列
    return w.wsd(security,"qfa_recp_tax_rends",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCashRecpRalOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收到其他与经营活动有关的现金时间序列
    return w.wsd(security,"other_cash_recp_ral_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCashRecpRalOperActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收到其他与经营活动有关的现金时间序列
    return w.wsd(security,"qfa_other_cash_recp_ral_oper_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrInsuredDepSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保户储金净增加额时间序列
    return w.wsd(security,"net_incr_insured_dep",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrInsuredDepSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.保户储金净增加额时间序列
    return w.wsd(security,"qfa_net_incr_insured_dep",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrDepCobSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户存款和同业存放款项净增加额时间序列
    return w.wsd(security,"net_incr_dep_cob",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrDepCobSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.客户存款和同业存放款项净增加额时间序列
    return w.wsd(security,"qfa_net_incr_dep_cob",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrIntHandlingChrGSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收取利息和手续费净增加额时间序列
    return w.wsd(security,"net_incr_int_handling_chrg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrIntHandlingChrGSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收取利息和手续费净增加额时间序列
    return w.wsd(security,"qfa_net_incr_int_handling_chrg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRecpPremOrigInCoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收到原保险合同保费取得的现金时间序列
    return w.wsd(security,"cash_recp_prem_orig_inco",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecpPremOrigInCoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收到原保险合同保费取得的现金时间序列
    return w.wsd(security,"qfa_cash_recp_prem_orig_inco",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCashReceivedReinsUBusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收到再保业务现金净额时间序列
    return w.wsd(security,"net_cash_received_reinsu_bus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashReceivedReinsUBusSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收到再保业务现金净额时间序列
    return w.wsd(security,"qfa_net_cash_received_reinsu_bus",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrRepUrchBusFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取回购业务资金净增加额时间序列
    return w.wsd(security,"net_incr_repurch_bus_fund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrRepUrchBusFundSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.回购业务资金净增加额时间序列
    return w.wsd(security,"qfa_net_incr_repurch_bus_fund",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCashFromSeUriTiesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取代理买卖证券收到的现金净额时间序列
    return w.wsd(security,"net_cash_from_seurities",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsOperActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流入差额(特殊报表科目)时间序列
    return w.wsd(security,"cash_inflows_oper_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsOperActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流入差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cash_inflows_oper_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsOperActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流入差额(合计平衡项目)时间序列
    return w.wsd(security,"cash_inflows_oper_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetFinaInstrumentsMeasuredAtFmVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取以公允价值计量且其变动计入当期损益的金融工具净额时间序列
    return w.wsd(security,"net_fina_instruments_measured_at_fmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashPayBehEMplSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付给职工以及为职工支付的现金时间序列
    return w.wsd(security,"cash_pay_beh_empl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPayBehEMplSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付给职工以及为职工支付的现金时间序列
    return w.wsd(security,"qfa_cash_pay_beh_empl",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrClientsLoanAdvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户贷款及垫款净增加额时间序列
    return w.wsd(security,"net_incr_clients_loan_adv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrClientsLoanAdvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.客户贷款及垫款净增加额时间序列
    return w.wsd(security,"qfa_net_incr_clients_loan_adv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrDepCBobSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取存放央行和同业款项净增加额时间序列
    return w.wsd(security,"net_incr_dep_cbob",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrDepCBobSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.存放央行和同业款项净增加额时间序列
    return w.wsd(security,"qfa_net_incr_dep_cbob",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashPayClaimsOrigInCoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付原保险合同赔付款项的现金时间序列
    return w.wsd(security,"cash_pay_claims_orig_inco",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPayClaimsOrigInCoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付原保险合同赔付款项的现金时间序列
    return w.wsd(security,"qfa_cash_pay_claims_orig_inco",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHandlingChrGPaidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付手续费的现金时间序列
    return w.wsd(security,"handling_chrg_paid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaHandlingChrGPaidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付手续费的现金时间序列
    return w.wsd(security,"qfa_handling_chrg_paid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getComMInSurPlcYPaidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付保单红利的现金时间序列
    return w.wsd(security,"comm_insur_plcy_paid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaComMInSurPlcYPaidSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付保单红利的现金时间序列
    return w.wsd(security,"qfa_comm_insur_plcy_paid",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsOperActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流出差额(特殊报表科目)时间序列
    return w.wsd(security,"cash_outflows_oper_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsOperActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流出差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cash_outflows_oper_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsOperActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金流出差额(合计平衡项目)时间序列
    return w.wsd(security,"cash_outflows_oper_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRecpDispWithDrWLInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收回投资收到的现金时间序列
    return w.wsd(security,"cash_recp_disp_withdrwl_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecpDispWithDrWLInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收回投资收到的现金时间序列
    return w.wsd(security,"qfa_cash_recp_disp_withdrwl_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCashRecpDispSoBuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取处置子公司及其他营业单位收到的现金净额时间序列
    return w.wsd(security,"net_cash_recp_disp_sobu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashRecpDispSoBuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.处置子公司及其他营业单位收到的现金净额时间序列
    return w.wsd(security,"qfa_net_cash_recp_disp_sobu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCashRecpRalInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收到其他与投资活动有关的现金时间序列
    return w.wsd(security,"other_cash_recp_ral_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCashRecpRalInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收到其他与投资活动有关的现金时间序列
    return w.wsd(security,"qfa_other_cash_recp_ral_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsInvActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流入差额(特殊报表科目)时间序列
    return w.wsd(security,"cash_inflows_inv_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsInvActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流入差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cash_inflows_inv_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsInvActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流入差额(合计平衡项目)时间序列
    return w.wsd(security,"cash_inflows_inv_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashPaidInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资支付的现金时间序列
    return w.wsd(security,"cash_paid_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPaidInvestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资支付的现金时间序列
    return w.wsd(security,"qfa_cash_paid_invest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetInCrPledgeLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取质押贷款净增加额时间序列
    return w.wsd(security,"net_incr_pledge_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetInCrPledgeLoanSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.质押贷款净增加额时间序列
    return w.wsd(security,"qfa_net_incr_pledge_loan",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNetCashPayAQuisSoBuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取取得子公司及其他营业单位支付的现金净额时间序列
    return w.wsd(security,"net_cash_pay_aquis_sobu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaNetCashPayAQuisSoBuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.取得子公司及其他营业单位支付的现金净额时间序列
    return w.wsd(security,"qfa_net_cash_pay_aquis_sobu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCashPayRalInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付其他与投资活动有关的现金时间序列
    return w.wsd(security,"other_cash_pay_ral_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCashPayRalInvActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付其他与投资活动有关的现金时间序列
    return w.wsd(security,"qfa_other_cash_pay_ral_inv_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsInvActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流出差额(特殊报表科目)时间序列
    return w.wsd(security,"cash_outflows_inv_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsInvActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流出差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cash_outflows_inv_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsInvActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金流出差额(合计平衡项目)时间序列
    return w.wsd(security,"cash_outflows_inv_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRecpCapContribSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取吸收投资收到的现金时间序列
    return w.wsd(security,"cash_recp_cap_contrib",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecpCapContribSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.吸收投资收到的现金时间序列
    return w.wsd(security,"qfa_cash_recp_cap_contrib",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashRecSAimsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取子公司吸收少数股东投资收到的现金时间序列
    return w.wsd(security,"cash_rec_saims",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashRecSAimsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.子公司吸收少数股东投资收到的现金时间序列
    return w.wsd(security,"qfa_cash_rec_saims",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCashRecpRalFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收到其他与筹资活动有关的现金时间序列
    return w.wsd(security,"other_cash_recp_ral_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCashRecpRalFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.收到其他与筹资活动有关的现金时间序列
    return w.wsd(security,"qfa_other_cash_recp_ral_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getProcIssueBondsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发行债券收到的现金时间序列
    return w.wsd(security,"proc_issue_bonds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaProcIssueBondsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.发行债券收到的现金时间序列
    return w.wsd(security,"qfa_proc_issue_bonds",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsFncActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流入差额(特殊报表科目)时间序列
    return w.wsd(security,"cash_inflows_fnc_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsFncActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流入差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cash_inflows_fnc_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashInFlowsFncActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流入差额(合计平衡项目)时间序列
    return w.wsd(security,"cash_inflows_fnc_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashPrepayAmtBOrrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取偿还债务支付的现金时间序列
    return w.wsd(security,"cash_prepay_amt_borr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPrepayAmtBOrrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.偿还债务支付的现金时间序列
    return w.wsd(security,"qfa_cash_prepay_amt_borr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashPayDistDpcpIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取分配股利、利润或偿付利息支付的现金时间序列
    return w.wsd(security,"cash_pay_dist_dpcp_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaCashPayDistDpcpIntExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.分配股利、利润或偿付利息支付的现金时间序列
    return w.wsd(security,"qfa_cash_pay_dist_dpcp_int_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDvdProfitPaidScMsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取子公司支付给少数股东的股利、利润时间序列
    return w.wsd(security,"dvd_profit_paid_sc_ms",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDvdProfitPaidScMsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.子公司支付给少数股东的股利、利润时间序列
    return w.wsd(security,"qfa_dvd_profit_paid_sc_ms",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOtherCashPayRalFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付其他与筹资活动有关的现金时间序列
    return w.wsd(security,"other_cash_pay_ral_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOtherCashPayRalFncActSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付其他与筹资活动有关的现金时间序列
    return w.wsd(security,"qfa_other_cash_pay_ral_fnc_act",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsFncActGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流出差额(特殊报表科目)时间序列
    return w.wsd(security,"cash_outflows_fnc_act_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsFncActGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流出差额说明(特殊报表科目)时间序列
    return w.wsd(security,"cash_outflows_fnc_act_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashOutFlowsFncActNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金流出差额(合计平衡项目)时间序列
    return w.wsd(security,"cash_outflows_fnc_act_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEffFxFluCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取汇率变动对现金的影响时间序列
    return w.wsd(security,"eff_fx_flu_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaEffFxFluCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.汇率变动对现金的影响时间序列
    return w.wsd(security,"qfa_eff_fx_flu_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getLossFvChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取公允价值变动损失时间序列
    return w.wsd(security,"loss_fv_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaLossFvChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.公允价值变动损失时间序列
    return w.wsd(security,"qfa_loss_fv_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资损失时间序列
    return w.wsd(security,"invest_loss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInvestLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资损失时间序列
    return w.wsd(security,"qfa_invest_loss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDecrOperPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营性应收项目的减少时间序列
    return w.wsd(security,"decr_oper_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaDecrOperPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营性应收项目的减少时间序列
    return w.wsd(security,"qfa_decr_oper_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInCrOperPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营性应付项目的增加时间序列
    return w.wsd(security,"incr_oper_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaInCrOperPayableSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经营性应付项目的增加时间序列
    return w.wsd(security,"qfa_incr_oper_payable",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestStOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他短期投资_GSD时间序列
    return w.wsd(security,"wgsd_invest_st_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestLtOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他长期投资_GSD时间序列
    return w.wsd(security,"wgsd_invest_lt_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他投资_GSD时间序列
    return w.wsd(security,"wgsd_invest_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRsvOtherSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他储备_GSD时间序列
    return w.wsd(security,"wgsd_rsv_other",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDToTExpOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他营业费用合计_GSD时间序列
    return w.wsd(security,"wgsd_tot_exp_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNoOperIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非经营性损益_GSD时间序列
    return w.wsd(security,"wgsd_no_oper_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDExoDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他特殊项_GSD时间序列
    return w.wsd(security,"wgsd_exod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNonCashChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他非现金调整_GSD时间序列
    return w.wsd(security,"wgsd_non_cash_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOthersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他时间序列
    return w.wsd(security,"others",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs9Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他收入_FUND时间序列
    return w.wsd(security,"stm_is_9",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs37Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取其他费用_FUND时间序列
    return w.wsd(security,"stm_is_37",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaExoDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他特殊项_GSD时间序列
    return w.wsd(security,"wgsd_qfa_exod",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaToTExpOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他营业费用合计_GSD时间序列
    return w.wsd(security,"wgsd_qfa_tot_exp_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNoOperIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他非经营性损益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_no_oper_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaNonCashChgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他非现金调整_GSD时间序列
    return w.wsd(security,"wgsd_qfa_non_cash_chg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaOthersSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.其他时间序列
    return w.wsd(security,"qfa_others",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVDebtIntoCapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债务转为资本时间序列
    return w.wsd(security,"conv_debt_into_cap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaConVDebtIntoCapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.债务转为资本时间序列
    return w.wsd(security,"qfa_conv_debt_into_cap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getConVCorpBondsDueWithin1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一年内到期的可转换公司债券时间序列
    return w.wsd(security,"conv_corp_bonds_due_within_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaConVCorpBondsDueWithin1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.一年内到期的可转换公司债券时间序列
    return w.wsd(security,"qfa_conv_corp_bonds_due_within_1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEndBalCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金的期末余额时间序列
    return w.wsd(security,"end_bal_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaEndBalCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金的期末余额时间序列
    return w.wsd(security,"qfa_end_bal_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBegBalCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金的期初余额时间序列
    return w.wsd(security,"beg_bal_cash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEndBalCashEquSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金等价物的期末余额时间序列
    return w.wsd(security,"end_bal_cash_equ",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getQfaEndBalCashEquSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.现金等价物的期末余额时间序列
    return w.wsd(security,"qfa_end_bal_cash_equ",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBegBalCashEquSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金等价物的期初余额时间序列
    return w.wsd(security,"beg_bal_cash_equ",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetInCrCashCashEquGapSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-现金净增加额差额(特殊报表科目)时间序列
    return w.wsd(security,"im_net_incr_cash_cash_equ_gap",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetInCrCashCashEquGapDetailSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-现金净增加额差额说明(特殊报表科目)时间序列
    return w.wsd(security,"im_net_incr_cash_cash_equ_gap_detail",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getImNetInCrCashCashEquNettingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取间接法-现金净增加额差额(合计平衡项目)时间序列
    return w.wsd(security,"im_net_incr_cash_cash_equ_netting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItSqFsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下QFII投资账户配售数量时间序列
    return w.wsd(security,"fund__reitsqfs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItSqFmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下QFII投资账户配售金额时间序列
    return w.wsd(security,"fund__reitsqfm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundReItSqFrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取网下QFII投资账户配售份额占比时间序列
    return w.wsd(security,"fund__reitsqfr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeltaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Delta时间序列
    return w.wsd(security,"delta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDeltaExChSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Delta(交易所)时间序列
    return w.wsd(security,"delta_exch",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGammaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Gamma时间序列
    return w.wsd(security,"gamma",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGammaExChSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Gamma(交易所)时间序列
    return w.wsd(security,"gamma_exch",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVegaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Vega时间序列
    return w.wsd(security,"vega",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getVegaExChSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Vega(交易所)时间序列
    return w.wsd(security,"vega_exch",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getThetaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Theta时间序列
    return w.wsd(security,"theta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getThetaExChSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Theta(交易所)时间序列
    return w.wsd(security,"theta_exch",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRhoSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Rho时间序列
    return w.wsd(security,"rho",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRhoExChSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Rho(交易所)时间序列
    return w.wsd(security,"rho_exch",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIoPvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取IOPV时间序列
    return w.wsd(security,"iopv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNavIoPvDiscountRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取IOPV溢折率时间序列
    return w.wsd(security,"NAV_iopv_discountratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAlpha2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha时间序列
    return w.wsd(security,"alpha2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAlphaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha_FUND时间序列
    return w.wsd(security,"risk_alpha",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnnualPhaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha(年化)时间序列
    return w.wsd(security,"risk_annualpha",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgAlphaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha同类平均时间序列
    return w.wsd(security,"risk_siml_avgalpha",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgAnnualPhaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Alpha(年化)同类平均时间序列
    return w.wsd(security,"risk_siml_avgannualpha",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBeta100WSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取BETA值(最近100周)时间序列
    return w.wsd(security,"beta_100w",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBeta24MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取BETA值(最近24个月)时间序列
    return w.wsd(security,"beta_24m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBeta60MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取BETA值(最近60个月)时间序列
    return w.wsd(security,"beta_60m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBetaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta时间序列
    return w.wsd(security,"beta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBetaDfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta(剔除财务杠杆)时间序列
    return w.wsd(security,"betadf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskBetaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta_FUND时间序列
    return w.wsd(security,"risk_beta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskBeta20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股20日的beta值_PIT时间序列
    return w.wsd(security,"risk_beta20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskBeta60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股60日的beta值_PIT时间序列
    return w.wsd(security,"risk_beta60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskBeta120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股120日的beta值_PIT时间序列
    return w.wsd(security,"risk_beta120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgBetaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Beta同类平均时间序列
    return w.wsd(security,"risk_siml_avgbeta",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getJensenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Jensen时间序列
    return w.wsd(security,"jensen",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getJensenYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Jensen(年化)时间序列
    return w.wsd(security,"jenseny",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskJensenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Jensen_FUND时间序列
    return w.wsd(security,"risk_jensen",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnNuJensenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Jensen(年化)_FUND时间序列
    return w.wsd(security,"risk_annujensen",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfIRrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取IRR时间序列
    return w.wsd(security,"tbf_IRR",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfIRr2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取IRR(支持历史)时间序列
    return w.wsd(security,"tbf_IRR2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperateProfitTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额(TTM)时间序列
    return w.wsd(security,"nonoperateprofit_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOperExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业开支_GSD时间序列
    return w.wsd(security,"wgsd_oper_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaWorkCapitalSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取运营资本_PIT时间序列
    return w.wsd(security,"fa_workcapital",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaNoOperProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额(TTM)_PIT时间序列
    return w.wsd(security,"fa_nooperprofit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getNonOperateProfitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营业外收支净额(TTM,只有最新数据)时间序列
    return w.wsd(security,"nonoperateprofit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTradeIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取自营业务收入_GSD时间序列
    return w.wsd(security,"wgsd_trade_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRetainedEarnTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取留存盈余比率(TTM)_PIT时间序列
    return w.wsd(security,"fa_retainedearn_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取BR意愿指标_PIT时间序列
    return w.wsd(security,"tech_br",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs25Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金经营业绩_FUND时间序列
    return w.wsd(security,"stm_is_25",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaTradeIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.自营业务收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_trade_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechARbrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ARBR人气意愿指标_PIT时间序列
    return w.wsd(security,"tech_arbr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFyGrowthSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY2)与一致预测每股收益(FY1)的变化率_PIT时间序列
    return w.wsd(security,"west_eps_fygrowth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsMaxMinFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)最大与一致预测每股收益(FY1)最小值的变化率_PIT时间序列
    return w.wsd(security,"west_epsmaxmin_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe(年化)时间序列
    return w.wsd(security,"sharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe时间序列
    return w.wsd(security,"risk_sharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnNuSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe(年化)_FUND时间序列
    return w.wsd(security,"risk_annusharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe同类平均时间序列
    return w.wsd(security,"risk_siml_avgsharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgAnNuSharpeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sharpe(年化)同类平均时间序列
    return w.wsd(security,"risk_siml_avgannusharpe",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTreyNorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Treynor(年化)时间序列
    return w.wsd(security,"treynor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTreyNorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Treynor时间序列
    return w.wsd(security,"risk_treynor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTreyNorRatio20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日特诺雷比率_PIT时间序列
    return w.wsd(security,"risk_treynorratio20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTreyNorRatio60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日特诺雷比率_PIT时间序列
    return w.wsd(security,"risk_treynorratio60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskTreyNorRatio120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日特诺雷比率_PIT时间序列
    return w.wsd(security,"risk_treynorratio120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnNutReyNorSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Treynor(年化)_FUND时间序列
    return w.wsd(security,"risk_annutreynor",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSortInOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sortino时间序列
    return w.wsd(security,"risk_sortino",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskAnNuSortInOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sortino(年化)时间序列
    return w.wsd(security,"risk_annuSortino",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgSortInOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sortino同类平均时间序列
    return w.wsd(security,"risk_siml_avgsortino",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSimLAvgAnNuSortInOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sortino(年化)同类平均时间序列
    return w.wsd(security,"risk_siml_avgannuSortino",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskCalmaRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Calmar时间序列
    return w.wsd(security,"risk_calmar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSterling1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sterling1时间序列
    return w.wsd(security,"risk_sterling1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskSterling2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取Sterling2时间序列
    return w.wsd(security,"risk_sterling2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfCTdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取CTD时间序列
    return w.wsd(security,"tbf_CTD",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTBfCTd2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取CTD(支持历史)时间序列
    return w.wsd(security,"tbf_CTD2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM)时间序列
    return w.wsd(security,"pe_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市销率PS(TTM)时间序列
    return w.wsd(security,"ps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEpsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股收益EPS(TTM)时间序列
    return w.wsd(security,"eps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeNonNegativeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM,剔除负值)时间序列
    return w.wsd(security,"val_pe_nonnegative",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeMedianSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM,中位数)时间序列
    return w.wsd(security,"val_pe_median",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoiCTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率ROIC(TTM)时间序列
    return w.wsd(security,"roic_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润(TTM反推法)时间序列
    return w.wsd(security,"ebit_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoiCTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率(TTM)_GSD时间序列
    return w.wsd(security,"roic_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润(TTM反推法)_GSD时间序列
    return w.wsd(security,"ebit_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润(TTM,只有最新数据)时间序列
    return w.wsd(security,"ebit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoiCTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(废弃)投入资本回报率(TTM)时间序列
    return w.wsd(security,"roic_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPetTmHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高PE(TTM)时间序列
    return w.wsd(security,"val_pettm_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPetTmLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低PE(TTM)时间序列
    return w.wsd(security,"val_pettm_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPetTmAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间平均PE(TTM)时间序列
    return w.wsd(security,"val_pettm_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPstTmHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高PS(TTM)时间序列
    return w.wsd(security,"val_psttm_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPstTmLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低PS(TTM)时间序列
    return w.wsd(security,"val_psttm_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPstTmAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间平均PS(TTM)时间序列
    return w.wsd(security,"val_psttm_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoiC2TtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率(TTM)时间序列
    return w.wsd(security,"roic2_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbIt2TtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBIT(TTM)时间序列
    return w.wsd(security,"ebit2_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRoiC2TtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率ROIC(TTM)_GSD时间序列
    return w.wsd(security,"roic2_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbIt2TtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBIT(TTM)_GSD时间序列
    return w.wsd(security,"ebit2_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeTtMwGtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM,加权)时间序列
    return w.wsd(security,"val_pe_ttmwgt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeTtMIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发布方市盈率PE(TTM)时间序列
    return w.wsd(security,"val_pe_ttm_issuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPsTtMwGtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市销率PS(TTM,加权)时间序列
    return w.wsd(security,"val_ps_ttmwgt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDaTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(TTM反推法)时间序列
    return w.wsd(security,"ebitda_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDaTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(TTM反推法)_GSD时间序列
    return w.wsd(security,"ebitda_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRocTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本报酬率(TTM)_PIT时间序列
    return w.wsd(security,"fa_roc_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益回报率(TTM)_PIT时间序列
    return w.wsd(security,"fa_roe_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPcfOCFTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(经营现金流TTM)时间序列
    return w.wsd(security,"pcf_ocf_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPcfNCfTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(现金净流量TTM)时间序列
    return w.wsd(security,"pcf_ncf_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDa2TtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(TTM)时间序列
    return w.wsd(security,"ebitda2_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDa2TtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(TTM)_GSD时间序列
    return w.wsd(security,"ebitda2_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoiCTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率(TTM)_PIT时间序列
    return w.wsd(security,"fa_roic_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbItTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBIT(TTM)_PIT时间序列
    return w.wsd(security,"fa_ebit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCashFlowTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金净流量(TTM)_PIT时间序列
    return w.wsd(security,"fa_cashflow_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashFlowTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金净流量(TTM)时间序列
    return w.wsd(security,"cashflow_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCashFlowTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金净流量(TTM)_GSD时间序列
    return w.wsd(security,"cashflow_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbItDaTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(TTM)_PIT时间序列
    return w.wsd(security,"fa_ebitda_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPcfOcFtTMwGtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(经营现金流TTM,加权)时间序列
    return w.wsd(security,"val_pcf_ocfttmwgt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValOrToMvTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取营收市值比(TTM)_PIT时间序列
    return w.wsd(security,"val_ortomv_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSalesCashInttM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金(TTM)时间序列
    return w.wsd(security,"salescashin_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDivCoverTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股利保障倍数(TTM)_PIT时间序列
    return w.wsd(security,"fa_divcover_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoiCebitTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率ROIC(TTM)_PIT时间序列
    return w.wsd(security,"fa_roicebit_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaTaxRatioTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售税金率(TTM)_PIT时间序列
    return w.wsd(security,"fa_taxratio_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getSalesCashInttMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金(TTM,只有最新数据)时间序列
    return w.wsd(security,"salescashin_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEpsDeductedTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣非后每股收益(TTM)时间序列
    return w.wsd(security,"eps_deducted_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbItUnVerTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润(TTM反推法)_PIT时间序列
    return w.wsd(security,"fa_ebitunver_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaSalesCashTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售商品提供劳务收到的现金(TTM)_PIT时间序列
    return w.wsd(security,"fa_salescash_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期间费用(TTM)_GSD时间序列
    return w.wsd(security,"periodexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaBerryRatioTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贝里比率(TTM)_PIT时间序列
    return w.wsd(security,"fa_berryratio_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaProfitToMvTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益市值比(TTM)_PIT时间序列
    return w.wsd(security,"fa_profittomv_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaPerExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期间费用(TTM)_PIT时间序列
    return w.wsd(security,"fa_perexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestCashFlowTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金净流量(TTM)时间序列
    return w.wsd(security,"investcashflow_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestCashFlowTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金净流量(TTM)_GSD时间序列
    return w.wsd(security,"investcashflow_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbItDaInverTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(TTM反推法)_PIT时间序列
    return w.wsd(security,"fa_ebitdainver_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInvestCashFlowTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金净流量(TTM,只有最新数据)时间序列
    return w.wsd(security,"investcashflow_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaOperaCtCashFlowTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金净流量(TTM)_PIT时间序列
    return w.wsd(security,"fa_operactcashflow_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeriodExpenseTTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取期间费用(TTM)时间序列
    return w.wsd(security,"periodexpense_t_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getInterestExpenseTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息费用(TTM)时间序列
    return w.wsd(security,"interestexpense_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateCashFlowTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金净流量(TTM)时间序列
    return w.wsd(security,"operatecashflow_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinanceCashFlowTtM2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金净流量(TTM)时间序列
    return w.wsd(security,"financecashflow_ttm2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getOperateCashFlowTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取经营活动现金净流量(TTM)_GSD时间序列
    return w.wsd(security,"operatecashflow_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinanceCashFlowTtM3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金净流量(TTM)_GSD时间序列
    return w.wsd(security,"financecashflow_ttm3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCashCNvCycleTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金转换周期(TTM)_PIT时间序列
    return w.wsd(security,"fa_cashcnvcycle_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFinanceCashFlowTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金净流量(TTM,只有最新数据)时间序列
    return w.wsd(security,"financecashflow_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCashRecovRatioTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资金现金回收率(TTM)_PIT时间序列
    return w.wsd(security,"fa_cashrecovratio_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaInveActCashFlowTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资活动现金净流量(TTM)_PIT时间序列
    return w.wsd(security,"fa_inveactcashflow_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaFinaActCashFlowTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取筹资活动现金净流量(TTM)_PIT时间序列
    return w.wsd(security,"fa_finaactcashflow_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDapSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股EBITDA时间序列
    return w.wsd(security,"ebitdaps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItToInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已获利息倍数(EBIT/利息费用)时间序列
    return w.wsd(security,"ebittointerest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDatoInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA/利息费用时间序列
    return w.wsd(security,"ebitdatointerest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBIT(反推法)时间序列
    return w.wsd(security,"ebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(反推法)时间序列
    return w.wsd(security,"ebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbIt2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBIT时间序列
    return w.wsd(security,"ebit2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEbItDa2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA时间序列
    return w.wsd(security,"ebitda2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIsEbItDaArdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(公布值)_GSD时间序列
    return w.wsd(security,"is_ebitda_ard",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbItToInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息保障倍数_PIT时间序列
    return w.wsd(security,"fa_ebittointerest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTlToeBitDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取全部债务/EBITDA时间序列
    return w.wsd(security,"tltoebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItToInterestSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已获利息倍数(EBIT/利息费用)_GSD时间序列
    return w.wsd(security,"wgsd_ebittointerest",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbIt3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税前利润_GSD时间序列
    return w.wsd(security,"wgsd_ebit3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItDa2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取息税折旧摊销前利润_GSD时间序列
    return w.wsd(security,"wgsd_ebitda2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBIT(反推法)_GSD时间序列
    return w.wsd(security,"wgsd_ebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取EBITDA(反推法)_GSD时间序列
    return w.wsd(security,"wgsd_ebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEv2ToEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业倍数(EV2/EBITDA)时间序列
    return w.wsd(security,"ev2_to_ebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvGebItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)平均值时间序列
    return w.wsd(security,"est_avgebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最大值时间序列
    return w.wsd(security,"est_maxebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMineBitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最小值时间序列
    return w.wsd(security,"est_minebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStDebitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)标准差时间序列
    return w.wsd(security,"est_stdebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvGebItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)平均值时间序列
    return w.wsd(security,"est_avgebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最大值时间序列
    return w.wsd(security,"est_maxebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMineBitDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最小值时间序列
    return w.wsd(security,"est_minebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStDebitDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)标准差时间序列
    return w.wsd(security,"est_stdebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvGebIt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)平均值(币种转换)时间序列
    return w.wsd(security,"est_avgebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEbIt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最大值(币种转换)时间序列
    return w.wsd(security,"est_maxebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMineBit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最小值(币种转换)时间序列
    return w.wsd(security,"est_minebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStDebit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)标准差(币种转换)时间序列
    return w.wsd(security,"est_stdebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstAvGebItDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)平均值(币种转换)时间序列
    return w.wsd(security,"est_avgebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMaxEbItDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最大值(币种转换)时间序列
    return w.wsd(security,"est_maxebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMineBitDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最小值(币种转换)时间序列
    return w.wsd(security,"est_minebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstStDebitDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)标准差(币种转换)时间序列
    return w.wsd(security,"est_stdebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValEvToeBitDa2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取企业倍数2(EV2/EBITDA)时间序列
    return w.wsd(security,"val_evtoebitda2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税前利润(FY1)时间序列
    return w.wsd(security,"west_avgebit_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税前利润(FY2)时间序列
    return w.wsd(security,"west_avgebit_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税前利润(FY3)时间序列
    return w.wsd(security,"west_avgebit_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税折旧摊销前利润(FY1)时间序列
    return w.wsd(security,"west_avgebitda_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税折旧摊销前利润(FY2)时间序列
    return w.wsd(security,"west_avgebitda_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测息税折旧摊销前利润(FY3)时间序列
    return w.wsd(security,"west_avgebitda_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)平均值(可选类型)时间序列
    return w.wsd(security,"west_avgebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMineBitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最小值(可选类型)时间序列
    return w.wsd(security,"west_minebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDebitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)标准差(可选类型)时间序列
    return w.wsd(security,"west_stdebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)平均值(可选类型)时间序列
    return w.wsd(security,"west_avgebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最大值(可选类型)时间序列
    return w.wsd(security,"west_maxebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMineBitDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最小值(可选类型)时间序列
    return w.wsd(security,"west_minebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDebitDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)标准差(可选类型)时间序列
    return w.wsd(security,"west_stdebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebIt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_avgebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEbIt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMineBit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDebit1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvGebItDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)平均值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_avgebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMaxEbItDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最大值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_maxebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMineBitDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)最小值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_minebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStDebitDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)标准差(可选类型,币种转换)时间序列
    return w.wsd(security,"west_stdebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)中值时间序列
    return w.wsd(security,"est_medianebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)中值时间序列
    return w.wsd(security,"est_medianebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEbIt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)中值(币种转换)时间序列
    return w.wsd(security,"est_medianebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEstMedianEbItDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)中值(币种转换)时间序列
    return w.wsd(security,"est_medianebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEbItSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)中值(可选类型)时间序列
    return w.wsd(security,"west_medianebit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEbItDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)中值(可选类型)时间序列
    return w.wsd(security,"west_medianebitda",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEbIt1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税前利润(EBIT)中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_medianebit1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestMedianEbItDa1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取预测息税折旧摊销前利润(EBITDA)中值(可选类型,币种转换)时间序列
    return w.wsd(security,"west_medianebitda1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMassSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取梅斯线_PIT时间序列
    return w.wsd(security,"tech_mass",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValLnMvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对数市值_PIT时间序列
    return w.wsd(security,"val_lnmv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股股利_PIT时间序列
    return w.wsd(security,"fa_dps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaBLevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取账面杠杆_PIT时间序列
    return w.wsd(security,"fa_blev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaMLevSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场杠杆_PIT时间序列
    return w.wsd(security,"fa_mlev",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaToTEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益_PIT时间序列
    return w.wsd(security,"fa_totequity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechSkewNessSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股价偏度_PIT时间序列
    return w.wsd(security,"tech_skewness",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDDnsRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下跌波动_PIT时间序列
    return w.wsd(security,"tech_ddnsr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBbiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取多空指数_PIT时间序列
    return w.wsd(security,"tech_bbi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBullPowerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取多头力道_PIT时间序列
    return w.wsd(security,"tech_bullpower",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBearPowerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取空头力道_PIT时间序列
    return w.wsd(security,"tech_bearpower",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCHaikInSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取佳庆指标_PIT时间序列
    return w.wsd(security,"tech_chaikin",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAroOnSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取阿隆指标_PIT时间序列
    return w.wsd(security,"tech_aroon",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCoppockCurveSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取估波指标_PIT时间序列
    return w.wsd(security,"tech_coppockcurve",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechUOsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取终极指标_PIT时间序列
    return w.wsd(security,"tech_uos",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取折旧和摊销_PIT时间序列
    return w.wsd(security,"fa_da",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBias5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日乖离率_PIT时间序列
    return w.wsd(security,"tech_bias5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechObVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取能量潮指标_PIT时间序列
    return w.wsd(security,"tech_obv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechPsySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取心理线指标_PIT时间序列
    return w.wsd(security,"tech_psy",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累积/派发线_PIT时间序列
    return w.wsd(security,"tech_ad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMa10CloseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取均线价格比_PIT时间序列
    return w.wsd(security,"tech_ma10close",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDHiloSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取波幅中位数_PIT时间序列
    return w.wsd(security,"tech_dhilo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbWGtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取加权市净率_PIT时间序列
    return w.wsd(security,"val_pb_wgt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValNlSizeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取对数市值立方_PIT时间序列
    return w.wsd(security,"val_nlsize",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaCTopSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金流市值比_PIT时间序列
    return w.wsd(security,"fa_ctop",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEbIAtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取息前税后利润_PIT时间序列
    return w.wsd(security,"fa_ebiat",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRoc6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日变动速率_PIT时间序列
    return w.wsd(security,"tech_roc6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBollDownSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下轨线(布林线)_PIT时间序列
    return w.wsd(security,"tech_bolldown",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBollUpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上轨线(布林线)_PIT时间序列
    return w.wsd(security,"tech_bollup",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBias10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日乖离率_PIT时间序列
    return w.wsd(security,"tech_bias10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBias20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日乖离率_PIT时间序列
    return w.wsd(security,"tech_bias20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechBias60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日乖离率_PIT时间序列
    return w.wsd(security,"tech_bias60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCci5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日顺势指标_PIT时间序列
    return w.wsd(security,"tech_cci5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRviSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对离散指数_PIT时间序列
    return w.wsd(security,"tech_rvi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRsiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取相对强弱指标_PIT时间序列
    return w.wsd(security,"tech_rsi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMfiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资金流量指标_PIT时间序列
    return w.wsd(security,"tech_mfi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechArSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取AR人气指标_PIT时间序列
    return w.wsd(security,"tech_ar",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCr20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取CR能量指标_PIT时间序列
    return w.wsd(security,"tech_cr20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCyFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场能量指标_PIT时间序列
    return w.wsd(security,"tech_cyf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCrySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场强弱指标_PIT时间序列
    return w.wsd(security,"tech_cry",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechElderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取艾达透视指标_PIT时间序列
    return w.wsd(security,"tech_elder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechATr6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日均幅指标_PIT时间序列
    return w.wsd(security,"tech_ATR6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMa5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日移动均线_PIT时间序列
    return w.wsd(security,"tech_MA5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCHaikInvolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取佳庆离散指标_PIT时间序列
    return w.wsd(security,"tech_chaikinvol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechUlcer5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取Ulcer5_PIT时间序列
    return w.wsd(security,"tech_ulcer5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechJdQs20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取阶段强势指标_PIT时间序列
    return w.wsd(security,"tech_jdqs20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAroOnUpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取阿隆向上指标_PIT时间序列
    return w.wsd(security,"tech_aroonup",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAroOnDownSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取阿隆向下指标_PIT时间序列
    return w.wsd(security,"tech_aroondown",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskVariance20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日收益方差_PIT时间序列
    return w.wsd(security,"risk_variance20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskVariance60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日收益方差_PIT时间序列
    return w.wsd(security,"risk_variance60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskLossVariance20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日损失方差_PIT时间序列
    return w.wsd(security,"risk_lossvariance20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskLossVariance60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日损失方差_PIT时间序列
    return w.wsd(security,"risk_lossvariance60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskCumReturn12MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取12月累计收益_PIT时间序列
    return w.wsd(security,"risk_cumreturn12m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRoc20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日变动速率_PIT时间序列
    return w.wsd(security,"tech_roc20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDBcdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取异同离差乖离率_PIT时间序列
    return w.wsd(security,"tech_dbcd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCci10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日顺势指标_PIT时间序列
    return w.wsd(security,"tech_cci10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCci20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日顺势指标_PIT时间序列
    return w.wsd(security,"tech_cci20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCci88Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取88日顺势指标_PIT时间序列
    return w.wsd(security,"tech_cci88",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechIlLiquiditySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取收益相对金额比_PIT时间序列
    return w.wsd(security,"tech_illiquidity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechADtmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取动态买卖气指标_PIT时间序列
    return w.wsd(security,"tech_adtm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechObV6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日能量潮指标_PIT时间序列
    return w.wsd(security,"tech_obv6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMoneyFlow20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日资金流量_PIT时间序列
    return w.wsd(security,"tech_moneyflow20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRStr12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取12月相对强势_PIT时间序列
    return w.wsd(security,"tech_rstr12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRStr24Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取24月相对强势_PIT时间序列
    return w.wsd(security,"tech_rstr24",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechATr14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取14日均幅指标_PIT时间序列
    return w.wsd(security,"tech_ATR14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMa10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日移动均线_PIT时间序列
    return w.wsd(security,"tech_MA10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMa20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日移动均线_PIT时间序列
    return w.wsd(security,"tech_MA20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMa60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日移动均线_PIT时间序列
    return w.wsd(security,"tech_MA60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechUlcer10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取Ulcer10_PIT时间序列
    return w.wsd(security,"tech_ulcer10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM)_PIT时间序列
    return w.wsd(security,"pe_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市销率PS(TTM)_PIT时间序列
    return w.wsd(security,"ps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getDividendYield2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股息率(近12个月)_PIT时间序列
    return w.wsd(security,"dividendyield2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskVariance120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日收益方差_PIT时间序列
    return w.wsd(security,"risk_variance120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGainVariance20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日正收益方差_PIT时间序列
    return w.wsd(security,"risk_gainvariance20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGainVariance60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日正收益方差_PIT时间序列
    return w.wsd(security,"risk_gainvariance60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskLossVariance120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日损失方差_PIT时间序列
    return w.wsd(security,"risk_lossvariance120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechCmOSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取钱德动量摆动指标_PIT时间序列
    return w.wsd(security,"tech_cmo",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechKDjKSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取随机指标KDJ_K_PIT时间序列
    return w.wsd(security,"tech_kdj_k",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechKDjDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取随机指标KDJ_D_PIT时间序列
    return w.wsd(security,"tech_kdj_d",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechKDjJSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取随机指标KDJ_J_PIT时间序列
    return w.wsd(security,"tech_kdj_j",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechObV20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日能量潮指标_PIT时间序列
    return w.wsd(security,"tech_obv20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMktFacIInDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市场促进指数指标_PIT时间序列
    return w.wsd(security,"tech_mktfaciind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRc12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取12日变化率指数_PIT时间序列
    return w.wsd(security,"tech_RC12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRc24Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取24日变化率指数_PIT时间序列
    return w.wsd(security,"tech_RC24",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAd6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日收集派发指标_PIT时间序列
    return w.wsd(security,"tech_ad6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEmV6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日简易波动指标_PIT时间序列
    return w.wsd(security,"tech_emv6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMa120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日移动均线_PIT时间序列
    return w.wsd(security,"tech_MA120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDDiSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取方向标准离差指数_PIT时间序列
    return w.wsd(security,"tech_DDI",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAPbMaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取绝对偏差移动平均_PIT时间序列
    return w.wsd(security,"tech_apbma",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAsISeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取累计振动升降指标_PIT时间序列
    return w.wsd(security,"tech_asi",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValMvTOfCffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市值/企业自由现金流_PIT时间序列
    return w.wsd(security,"val_mvtofcff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGainVariance120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日正收益方差_PIT时间序列
    return w.wsd(security,"risk_gainvariance120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaRoeAvg5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取5年平均权益回报率_PIT时间序列
    return w.wsd(security,"fa_roeavg5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去5日的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs250Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去1年的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs250",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs750Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去3年的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs750",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVRoc6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日量变动速率指标_PIT时间序列
    return w.wsd(security,"tech_vroc6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechAd20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日收集派发指标_PIT时间序列
    return w.wsd(security,"tech_ad20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEmV14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取14日简易波动指标_PIT时间序列
    return w.wsd(security,"tech_emv14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取12日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma26Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取26日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA26",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMacDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取平滑异同移动平均线_PIT时间序列
    return w.wsd(security,"tech_macd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取算术平均滚动市盈率_PIT时间序列
    return w.wsd(security,"val_pe_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEpsTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股收益EPS(TTM)_PIT时间序列
    return w.wsd(security,"eps_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeInDuSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE行业相对值_PIT时间序列
    return w.wsd(security,"val_peindu_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbInDuSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市净率PB行业相对值_PIT时间序列
    return w.wsd(security,"val_pbindu_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPsInDuSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市销率PS行业相对值_PIT时间序列
    return w.wsd(security,"val_psindu_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValBTopInDuSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取账面市值比行业相对值_PIT时间序列
    return w.wsd(security,"val_btopindu_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGlVarianceRatio20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日收益损失方差比_PIT时间序列
    return w.wsd(security,"risk_glvarianceratio20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGlVarianceRatio60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取60日收益损失方差比_PIT时间序列
    return w.wsd(security,"risk_glvarianceRatio60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskKurtOsIs20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股收益的20日峰度_PIT时间序列
    return w.wsd(security,"risk_kurtosis20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskKurtOsIs60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股收益的60日峰度_PIT时间序列
    return w.wsd(security,"risk_kurtosis60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去10日的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去20日的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去3个月的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去6个月的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechChAndesDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取CMO的中间因子SD_PIT时间序列
    return w.wsd(security,"tech_chandesd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechChanDesuSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取CMO的中间因子SU_PIT时间序列
    return w.wsd(security,"tech_chandesu",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTvsTd6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日成交金额的标准差_PIT时间序列
    return w.wsd(security,"tech_tvstd6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVRoc12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取12日量变动速率指标_PIT时间序列
    return w.wsd(security,"tech_vroc12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechEma120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日指数移动均线_PIT时间序列
    return w.wsd(security,"tech_EMA120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPcfInDuSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF行业相对值_PIT时间序列
    return w.wsd(security,"val_pcfindu_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskGlVarianceRatio120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取120日收益损失方差比_PIT时间序列
    return w.wsd(security,"risk_glvarianceRatio120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskKurtOsIs120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取个股收益的120日峰度_PIT时间序列
    return w.wsd(security,"risk_kurtosis120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFaEquitySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属于母公司的股东权益_PIT时间序列
    return w.wsd(security,"fa_equity",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs5InDu1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去5日收益率/行业均值_PIT时间序列
    return w.wsd(security,"tech_revs5indu1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTvsTd20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日成交金额的标准差_PIT时间序列
    return w.wsd(security,"tech_tvstd20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDizSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取DDI的中间因子DIZ_PIT时间序列
    return w.wsd(security,"tech_DIZ",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDIfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取DDI的中间因子DIF_PIT时间序列
    return w.wsd(security,"tech_DIF",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTemA5Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取5日三重指数移动平均线_PIT时间序列
    return w.wsd(security,"tech_tema5",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs20InDu1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去1个月收益率/行业均值_PIT时间序列
    return w.wsd(security,"tech_revs20indu1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechSBmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ADTM的中间因子SBM_PIT时间序列
    return w.wsd(security,"tech_sbm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechStmSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ADTM的中间因子STM_PIT时间序列
    return w.wsd(security,"tech_stm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTvMa6Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取6日成交金额的移动平均值_PIT时间序列
    return w.wsd(security,"tech_tvma6",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDeASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取MACD的中间因子DEA_PIT时间序列
    return w.wsd(security,"tech_dea",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTemA10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取10日三重指数移动平均线_PIT时间序列
    return w.wsd(security,"tech_tema10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValAvgPeSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PE均值_PIT时间序列
    return w.wsd(security,"val_avgpe_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValAvgPbSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PB均值_PIT时间序列
    return w.wsd(security,"val_avgpb_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValAvGpsSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PS均值_PIT时间序列
    return w.wsd(security,"val_avgps_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRiskRevsVarRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取30日120日回报方差比率_PIT时间序列
    return w.wsd(security,"risk_revsvarratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechTvMa20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取20日成交金额的移动平均值_PIT时间序列
    return w.wsd(security,"tech_tvma20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDiffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取MACD的中间因子DIFF_PIT时间序列
    return w.wsd(security,"tech_diff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechChgMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取与过去52 周股价最高点差距_PIT时间序列
    return w.wsd(security,"tech_chgmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEquityNewSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东的股东权益(LF)_PIT时间序列
    return w.wsd(security,"equity_new",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeToHist250Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE/过去一年PE的均值_PIT时间序列
    return w.wsd(security,"val_petohist250",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPcfOCFTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(经营现金流TTM)_PIT时间序列
    return w.wsd(security,"pcf_ocf_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPcfNCfTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(现金净流量TTM)_PIT时间序列
    return w.wsd(security,"pcf_ncf_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValAvgPcfSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PCF均值_PIT时间序列
    return w.wsd(security,"val_avgpcf_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValStdPeSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PE标准差_PIT时间序列
    return w.wsd(security,"val_stdpe_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValStdPbSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PB标准差_PIT时间序列
    return w.wsd(security,"val_stdpb_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValStDpsSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PS标准差_PIT时间序列
    return w.wsd(security,"val_stdps_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestStdEpsFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)标准差_PIT时间序列
    return w.wsd(security,"west_stdeps_fy1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs1MMaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去1个月的日收益率的最大值_PIT时间序列
    return w.wsd(security,"tech_revs1mmax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechPrice1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前股价/过去1个月股价均值-1_PIT时间序列
    return w.wsd(security,"tech_price1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechPrice3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前股价/过去3个月股价均值-1_PIT时间序列
    return w.wsd(security,"tech_price3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechPrice1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前股价/过去1年的股价均值-1_PIT时间序列
    return w.wsd(security,"tech_price1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs12M6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取12M收益率的120D变化率_PIT时间序列
    return w.wsd(security,"tech_revs12m6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVDeASeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取VMACD的中间变量VDEA_PIT时间序列
    return w.wsd(security,"tech_vdea",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechUpPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取上涨的股票占指数成份股的比例_PIT时间序列
    return w.wsd(security,"tech_uppct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechDownPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取下跌的股票占指数成份股的比例_PIT时间序列
    return w.wsd(security,"tech_downpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechLimitUpPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取涨停的股票占指数成份股的比例_PIT时间序列
    return w.wsd(security,"tech_limituppct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechLimitDownPctSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取跌停的股票占指数成份股的比例_PIT时间序列
    return w.wsd(security,"tech_limitdownpct",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeToHist20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE/过去一个月PE的均值_PIT时间序列
    return w.wsd(security,"val_petohist20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeToHist60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE/过去三个月PE的均值_PIT时间序列
    return w.wsd(security,"val_petohist60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeToHist120Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE/过去六个月PE的均值_PIT时间序列
    return w.wsd(security,"val_petohist120",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValStdPcfSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的PCF标准差_PIT时间序列
    return w.wsd(security,"val_stdpcf_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVDiffSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取VMACD的中间变量VDIFF_PIT时间序列
    return w.wsd(security,"tech_vdiff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechMawVAdSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取威廉变异离散量(WVAD)6日均值_PIT时间序列
    return w.wsd(security,"tech_mawvad",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeDeductedTtMSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(TTM,扣除非经常性损益)_PIT时间序列
    return w.wsd(security,"val_pe_deducted_ttm",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFy11MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)变化率_1M_PIT时间序列
    return w.wsd(security,"west_eps_fy1_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFy13MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)变化率_3M_PIT时间序列
    return w.wsd(security,"west_eps_fy1_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFy16MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)变化率_6M_PIT时间序列
    return w.wsd(security,"west_eps_fy1_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFy1Chg1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)的变化_1M_PIT时间序列
    return w.wsd(security,"west_eps_fy1_chg_1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFy1Chg3MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)的变化_3M_PIT时间序列
    return w.wsd(security,"west_eps_fy1_chg_3m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestEpsFy1Chg6MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股收益(FY1)的变化_6M_PIT时间序列
    return w.wsd(security,"west_eps_fy1_chg_6m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs6M20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去6个月的动量-过去1个月的动量_PIT时间序列
    return w.wsd(security,"tech_revs6m20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs12M20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去12个月的动量-过去1个月的动量_PIT时间序列
    return w.wsd(security,"tech_revs12m20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValAvgBToMvSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的账面市值比行业均值_PIT时间序列
    return w.wsd(security,"val_avgbtomv_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRank1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取1-过去一个月收益率排名/股票总数的比值_PIT时间序列
    return w.wsd(security,"tech_rank1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValStDbToMvSwSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属申万一级行业的账面市值比行业标准差_PIT时间序列
    return w.wsd(security,"val_stdbtomv_sw",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs5M20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去5日的价格动量-过去1个月的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs5m20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechRevs5M60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去5日的价格动量-过去3个月的价格动量_PIT时间序列
    return w.wsd(security,"tech_revs5m60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVolume1M60Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取过去1个月交易量/过去3个月的平均交易量_PIT时间序列
    return w.wsd(security,"tech_volume1m60",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechChgAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取与过去1 个月、3个月、6 个月、12 个月股价平均涨幅_PIT时间序列
    return w.wsd(security,"tech_chg_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getTechVolUmN1MSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取当前交易量/过去1个月日均交易量*过去一个月的收益率_PIT时间序列
    return w.wsd(security,"tech_volumn1m",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderHoldingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人持有份额时间序列
    return w.wsd(security,"fund_holder_holding",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderHoldingListingSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人持有份额(上市公告)时间序列
    return w.wsd(security,"fund_holder_holdinglisting",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderNameMmFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人类别(货币)时间序列
    return w.wsd(security,"fund_holder_namemmf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundHolderHoldingMmFSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取第N名持有人持有份额(货币)时间序列
    return w.wsd(security,"fund_holder_holdingmmf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundFOfFundOrNotSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取是否FOF基金时间序列
    return w.wsd(security,"fund_foffundornot",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundProdTypeWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind产品类型时间序列
    return w.wsd(security,"fund_prodtype_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取关联ETFWind代码时间序列
    return w.wsd(security,"fund_etfwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFFeederCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF关联联接基金代码时间序列
    return w.wsd(security,"fund_etf_feedercode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundNetworkCashBuyStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网上现金认购起始日时间序列
    return w.wsd(security,"fund_networkcashbuystartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundNetworkCashBuyEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网上现金认购截止日时间序列
    return w.wsd(security,"fund_networkcashbuyenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundNetworkCashBuyShareDownLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网上现金认购份额下限时间序列
    return w.wsd(security,"fund_networkcashbuysharedownlimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundNetworkCashBuyShareUpLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网上现金认购份额上限时间序列
    return w.wsd(security,"fund_networkcashbuyshareuplimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOffNetworkBuyStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网下现金认购起始日时间序列
    return w.wsd(security,"fund_offnetworkbuystartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOffNetworkBuyEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网下现金认购截止日时间序列
    return w.wsd(security,"fund_offnetworkbuyenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOffNetworkCashBuyShareDownLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网下现金认购份额下限时间序列
    return w.wsd(security,"fund_offnetworkcashbuysharedownlimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOffNetworkStockBuyStartDateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网下股票认购起始日时间序列
    return w.wsd(security,"fund_offnetworkstockbuystartdate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOffNetworkStockBuyEnddateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网下股票认购截止日时间序列
    return w.wsd(security,"fund_offnetworkstockbuyenddate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundOffNetworkStockBuyShareDownLimitSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网下股票认购份额下限时间序列
    return w.wsd(security,"fund_offnetworkstockbuysharedownlimit",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrCashBalanceSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申购赎回现金差额时间序列
    return w.wsd(security,"fund_etfpr_cashbalance",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrMinnaVSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申购赎回最小申购赎回单位时间序列
    return w.wsd(security,"fund_etfpr_minnav",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrEstCashSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申购赎回预估现金部分时间序列
    return w.wsd(security,"fund_etfpr_estcash",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrCashRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申购赎回现金替代比例上限(%)时间序列
    return w.wsd(security,"fund_etfpr_cashratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrMaxPurchaseSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申赎清单申购上限时间序列
    return w.wsd(security,"fund_etfpr_maxpurchase",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundEtFPrMinRedemptionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申赎清单赎回上限时间序列
    return w.wsd(security,"fund_etfpr_minredemption",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundLcRiskLevelWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取银行理财风险等级(Wind)时间序列
    return w.wsd(security,"fund_lcrisklevelwind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs127Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取未交税金_FUND时间序列
    return w.wsd(security,"stm_bs_127",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs30Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付收益_FUND时间序列
    return w.wsd(security,"stm_bs_30",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs34Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取实收基金_FUND时间序列
    return w.wsd(security,"stm_bs_34",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取收入合计_FUND时间序列
    return w.wsd(security,"stm_is_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs4Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取股利收益_FUND时间序列
    return w.wsd(security,"stm_is_4",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs77Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取汇兑收入_FUND时间序列
    return w.wsd(security,"stm_is_77",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs22Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取费用合计_FUND时间序列
    return w.wsd(security,"stm_is_22",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs73Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易费用_FUND时间序列
    return w.wsd(security,"stm_is_73",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs19Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取审计费用_FUND时间序列
    return w.wsd(security,"stm_is_19",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs14Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收申购款_FUND时间序列
    return w.wsd(security,"stm_bs_14",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs26Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付赎回款_FUND时间序列
    return w.wsd(security,"stm_bs_26",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs11Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金管理费_FUND时间序列
    return w.wsd(security,"stm_is_11",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs74Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户维护费_FUND时间序列
    return w.wsd(security,"stm_is_74",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs12Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金托管费_FUND时间序列
    return w.wsd(security,"stm_is_12",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs24Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付交易费用_FUND时间序列
    return w.wsd(security,"stm_bs_24",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs29Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取衍生工具收益_FUND时间序列
    return w.wsd(security,"stm_is_29",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs10Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收证券清算款_FUND时间序列
    return w.wsd(security,"stm_bs_10",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs28Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取卖出回购证券款_FUND时间序列
    return w.wsd(security,"stm_bs_28",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs22Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付证券清算款_FUND时间序列
    return w.wsd(security,"stm_bs_22",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs20Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付基金管理费_FUND时间序列
    return w.wsd(security,"stm_bs_20",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs21Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付基金托管费_FUND时间序列
    return w.wsd(security,"stm_bs_21",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs153Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付销售服务费_FUND时间序列
    return w.wsd(security,"stm_bs_153",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmBs38Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取持有人权益合计_FUND时间序列
    return w.wsd(security,"stm_bs_38",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStmIs16Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基金销售服务费_FUND时间序列
    return w.wsd(security,"stm_is_16",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopFundWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓基金Wind代码时间序列
    return w.wsd(security,"prt_topfundwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueFirstMarketFundCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF一级市场基金代码时间序列
    return w.wsd(security,"issue_firstmarketfundcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtQdIiCountryRegionInvestmentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取国家/地区投资市值(QDII)时间序列
    return w.wsd(security,"prt_qdii_countryregioninvestment",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueOnlineCashOfferingSymbolSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF网上现金发售代码时间序列
    return w.wsd(security,"issue_onlinecashofferingsymbol",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getFundPurchaseAndRedemptionAbbreviationSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF申购赎回简称时间序列
    return w.wsd(security,"fund_purchaseandredemptionabbreviation",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIssueEtFDealShareOnMarketSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ETF上市交易份额时间序列
    return w.wsd(security,"issue_etfdealshareonmarket",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind代码时间序列
    return w.wsd(security,"windcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWindTypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取指数分类(Wind)时间序列
    return w.wsd(security,"windtype",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWindL1TypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind债券一级分类时间序列
    return w.wsd(security,"windl1type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWindL2TypeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind债券二级分类时间序列
    return w.wsd(security,"windl2type",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCbWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司可转债Wind代码时间序列
    return w.wsd(security,"cbwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryGicSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属Wind行业名称时间序列
    return w.wsd(security,"industry_gics",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndustryGicSCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属Wind行业代码时间序列
    return w.wsd(security,"industry_gicscode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind自定义代码时间序列
    return w.wsd(security,"prewindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getGdrWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司GDRWind代码时间序列
    return w.wsd(security,"gdrwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPreCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取证券曾用Wind代码时间序列
    return w.wsd(security,"precode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getHshAreCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司港股Wind代码时间序列
    return w.wsd(security,"hsharecode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getAShareWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司A股Wind代码时间序列
    return w.wsd(security,"asharewindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getBShareWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司B股Wind代码时间序列
    return w.wsd(security,"bsharewindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUsShareWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取同公司美股Wind代码时间序列
    return w.wsd(security,"ussharewindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingWind3YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind3年评级时间序列
    return w.wsd(security,"rating_wind3y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingWind5YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind5年评级时间序列
    return w.wsd(security,"rating_wind5y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingWind1YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)Wind1年评级时间序列
    return w.wsd(security,"rating_wind1y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getRatingWind2YSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取(停止)Wind2年评级时间序列
    return w.wsd(security,"rating_wind2y",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopGicSIndustryValueSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值(Wind全球行业)时间序列
    return w.wsd(security,"prt_topgicsindustryvalue",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingWindCode2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取基础证券Wind代码时间序列
    return w.wsd(security,"underlyingwindcode2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属Wind行业指数代码时间序列
    return w.wsd(security,"indexcode_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeWindHkSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属Wind行业指数代码(港股)时间序列
    return w.wsd(security,"indexcode_wind_hk",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIndexCodeWindThematicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属Wind主题行业指数代码时间序列
    return w.wsd(security,"indexcode_windthematic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getUnderlyingWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取标的Wind代码时间序列
    return w.wsd(security,"underlyingwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGRatingWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取Wind ESG评级时间序列
    return w.wsd(security,"esg_rating_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopBondWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓债券Wind代码时间序列
    return w.wsd(security,"prt_topbondwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopStockWindCodeSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓股股票Wind代码时间序列
    return w.wsd(security,"prt_topstockwindcode",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGMGmtScoreWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ESG管理实践得分时间序列
    return w.wsd(security,"esg_mgmtscore_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getEsGEventScoreWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取ESG争议事件得分时间序列
    return w.wsd(security,"esg_eventscore_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getThematicIndustryWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取所属Wind主题行业名称时间序列
    return w.wsd(security,"thematicindustry_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPrtTopIndustryValueWindSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取重仓行业投资市值(Wind)时间序列
    return w.wsd(security,"prt_topindustryvalue_wind",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getCalcYieldSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取价格算到期收益率(BC1)时间序列
    return w.wsd(security,"calc_yield",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDOcFpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股经营现金净流量_GSD时间序列
    return w.wsd(security,"wgsd_ocfps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDpsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股派息_GSD时间序列
    return w.wsd(security,"wgsd_dps",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEpsAdjust2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股收益-最新股本摊薄_GSD时间序列
    return w.wsd(security,"wgsd_eps_adjust2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEpsDiluted3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取每股收益-期末股本摊薄_GSD时间序列
    return w.wsd(security,"wgsd_eps_diluted3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoiCSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率_GSD时间序列
    return w.wsd(security,"wgsd_roic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoiCYearlySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率(年化)_GSD时间序列
    return w.wsd(security,"wgsd_roic_yearly",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRoiC1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取投入资本回报率ROIC_GSD时间序列
    return w.wsd(security,"wgsd_roic1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestEqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益性投资_GSD时间序列
    return w.wsd(security,"wgsd_invest_eq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestAFsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售投资_GSD时间序列
    return w.wsd(security,"wgsd_invest_afs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSecCollaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取抵押担保证券_GSD时间序列
    return w.wsd(security,"wgsd_sec_colla",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLoansNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取客户贷款及垫款净额_GSD时间序列
    return w.wsd(security,"wgsd_loans_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLoansHfSSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取可供出售贷款_GSD时间序列
    return w.wsd(security,"wgsd_loans_hfs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDefPlcYAcqCostsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取递延保单获得成本_GSD时间序列
    return w.wsd(security,"wgsd_def_plcy_acq_costs",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRecEivReInSurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应收再保_GSD时间序列
    return w.wsd(security,"wgsd_receiv_reinsur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRecEivStOThSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取其它应收款_GSD时间序列
    return w.wsd(security,"wgsd_receiv_st_oth",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDLoansMtGNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取抵押贷款与票据净额_GSD时间序列
    return w.wsd(security,"wgsd_loans_mtg_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPayTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应交税金_GSD时间序列
    return w.wsd(security,"wgsd_pay_tax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDebtStSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取短期借贷及长期借贷当期到期部分_GSD时间序列
    return w.wsd(security,"wgsd_debt_st",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDebtLtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取长期借贷_GSD时间序列
    return w.wsd(security,"wgsd_debt_lt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDepositsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取总存款_GSD时间序列
    return w.wsd(security,"wgsd_deposits",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFinCollaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取抵押担保融资_GSD时间序列
    return w.wsd(security,"wgsd_fin_colla",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPayReInSurSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取应付再保_GSD时间序列
    return w.wsd(security,"wgsd_pay_reinsur",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDComEqParSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取普通股股本_GSD时间序列
    return w.wsd(security,"wgsd_com_eq_par",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRsvSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取储备_GSD时间序列
    return w.wsd(security,"wgsd_rsv",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDAPicSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股本溢价_GSD时间序列
    return w.wsd(security,"wgsd_apic",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDComEqPahOlderSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取普通股权益总额_GSD时间序列
    return w.wsd(security,"wgsd_com_eq_paholder",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDComEqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取归属母公司股东权益_GSD时间序列
    return w.wsd(security,"wgsd_com_eq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDStKhlDrSEqSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股东权益合计_GSD时间序列
    return w.wsd(security,"wgsd_stkhldrs_eq",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSalesOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取主营收入_GSD时间序列
    return w.wsd(security,"wgsd_sales_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGainJointlyControlledSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取共同发展公司损益_GSD时间序列
    return w.wsd(security,"wgsd_gain_jointlycontrolled",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEMplBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取员工薪酬_GSD时间序列
    return w.wsd(security,"wgsd_empl_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDTradeIncNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取交易账户净收入_GSD时间序列
    return w.wsd(security,"wgsd_trade_inc_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDIntInverStIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取利息及股息收入_GSD时间序列
    return w.wsd(security,"wgsd_int_inverst_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDClaimIncurredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取已发生赔款净额_GSD时间序列
    return w.wsd(security,"wgsd_claim_incurred",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPremiumGrossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取毛承保保费及保单费收入_GSD时间序列
    return w.wsd(security,"wgsd_premium_gross",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDPolicyHlDrBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单持有人利益_GSD时间序列
    return w.wsd(security,"wgsd_policyhldr_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCostPolicyAcquisitionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取保单获取成本和承保费用_GSD时间序列
    return w.wsd(security,"wgsd_cost_policyacquisition",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRevComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取扣除贷款损失准备前收入_GSD时间序列
    return w.wsd(security,"wgsd_rev_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDBrokerComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取经纪佣金收入_GSD时间序列
    return w.wsd(security,"wgsd_broker_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDUwIbIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取承销与投资银行费收入_GSD时间序列
    return w.wsd(security,"wgsd_uw_ib_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDRevRentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取租金收入_GSD时间序列
    return w.wsd(security,"wgsd_rev_rent",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGainSaleRealEstateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取房地产销售收入_GSD时间序列
    return w.wsd(security,"wgsd_gain_sale_real_estate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDMtGIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取抵押贷款相关收入_GSD时间序列
    return w.wsd(security,"wgsd_mtg_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDSgaExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取销售、行政及一般费用_GSD时间序列
    return w.wsd(security,"wgsd_sga_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDProvLoanLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取贷款损失准备_GSD时间序列
    return w.wsd(security,"wgsd_prov_loan_loss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDFeeComMExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取手续费及佣金开支_GSD时间序列
    return w.wsd(security,"wgsd_fee_comm_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestGainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取权益性投资损益_GSD时间序列
    return w.wsd(security,"wgsd_invest_gain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDExpMaterialsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取材料及相关费用_GSD时间序列
    return w.wsd(security,"wgsd_exp_materials",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDEBtExClUnusualItemsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非经常项目前利润_GSD时间序列
    return w.wsd(security,"wgsd_ebt_excl_unusual_items",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDUnusualItemsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取非经常项目损益_GSD时间序列
    return w.wsd(security,"wgsd_unusual_items",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDIncPreTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取除税前利润_GSD时间序列
    return w.wsd(security,"wgsd_inc_pretax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDNetProfitIsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取除税后利润_GSD时间序列
    return w.wsd(security,"wgsd_net_profit_is",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取折旧及摊销_GSD时间序列
    return w.wsd(security,"wgsd_da",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDGainAssociatesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取联营公司损益_GSD时间序列
    return w.wsd(security,"wgsd_gain_associates",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDepExpCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取折旧与摊销_GSD时间序列
    return w.wsd(security,"wgsd_dep_exp_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDCapeXFfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取资本性支出_GSD时间序列
    return w.wsd(security,"wgsd_capex_ff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestPUrchCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资增加_GSD时间序列
    return w.wsd(security,"wgsd_invest_purch_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDInvestSaleCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资减少_GSD时间序列
    return w.wsd(security,"wgsd_invest_sale_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDebtIsSCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债务增加_GSD时间序列
    return w.wsd(security,"wgsd_debt_iss_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDebtReDuctCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取债务减少_GSD时间序列
    return w.wsd(security,"wgsd_debt_reduct_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDStKPUrchCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股本增加_GSD时间序列
    return w.wsd(security,"wgsd_stk_purch_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDStKSaleCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股本减少_GSD时间序列
    return w.wsd(security,"wgsd_stk_sale_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDDivCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取支付的股利合计_GSD时间序列
    return w.wsd(security,"wgsd_div_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDForExChCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取汇率变动影响_GSD时间序列
    return w.wsd(security,"wgsd_for_exch_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaSalesOperSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.主营收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_sales_oper",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaGainJointlyControlledSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.共同发展公司损益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_gain_jointlycontrolled",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaEMplBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.员工薪酬_GSD时间序列
    return w.wsd(security,"wgsd_qfa_empl_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDaSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.折旧及摊销_GSD时间序列
    return w.wsd(security,"wgsd_qfa_da",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaInvestGainSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.权益性投资损益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_invest_gain",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaExpMaterialsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.材料及相关费用_GSD时间序列
    return w.wsd(security,"wgsd_qfa_exp_materials",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaGainAssociatesSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.联营公司损益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_gain_associates",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaSgaExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.销售、行政及一般费用_GSD时间序列
    return w.wsd(security,"wgsd_qfa_sga_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaIncPreTaxSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.除税前利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_inc_pretax",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaEBtExClUnusualItemsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.非经常项目前利润_GSD时间序列
    return w.wsd(security,"wgsd_qfa_ebt_excl_unusual_items",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaUnusualItemsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.非经常项目损益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_unusual_items",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaTradeIncNetSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.交易账户净收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_trade_inc_net",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaFeeComMExpSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.手续费及佣金开支_GSD时间序列
    return w.wsd(security,"wgsd_qfa_fee_comm_exp",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaRevComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.扣除贷款损失准备前收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_rev_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaPolicyHlDrBenSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.保单持有人利益_GSD时间序列
    return w.wsd(security,"wgsd_qfa_policyhldr_ben",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaCostPolicyAcquisitionSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.保单获取成本和承保费用_GSD时间序列
    return w.wsd(security,"wgsd_qfa_cost_policyacquisition",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaIntInverStIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.利息及股息收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_int_inverst_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaClaimIncurredSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.已发生赔款净额_GSD时间序列
    return w.wsd(security,"wgsd_qfa_claim_incurred",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaPremiumGrossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.毛承保保费及保单费收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_premium_gross",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaGainSaleRealEstateSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.房地产销售收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_gain_sale_real_estate",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaMtGIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.抵押贷款相关收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_mtg_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaRevRentSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.租金收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_rev_rent",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaBrokerComMIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.经纪佣金收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_broker_comm_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaUwIbIncSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.承销与投资银行费收入_GSD时间序列
    return w.wsd(security,"wgsd_qfa_uw_ib_inc",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaProvLoanLossSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.贷款损失准备_GSD时间序列
    return w.wsd(security,"wgsd_qfa_prov_loan_loss",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDepExpCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.折旧与摊销_GSD时间序列
    return w.wsd(security,"wgsd_qfa_dep_exp_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaCapeXFfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.资本性支出_GSD时间序列
    return w.wsd(security,"wgsd_qfa_capex_ff",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaInvestPUrchCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资增加_GSD时间序列
    return w.wsd(security,"wgsd_qfa_invest_purch_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaInvestSaleCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.投资减少_GSD时间序列
    return w.wsd(security,"wgsd_qfa_invest_sale_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDebtIsSCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.债务增加_GSD时间序列
    return w.wsd(security,"wgsd_qfa_debt_iss_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDebtReDuctCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.债务减少_GSD时间序列
    return w.wsd(security,"wgsd_qfa_debt_reduct_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaStKPUrchCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.股本增加_GSD时间序列
    return w.wsd(security,"wgsd_qfa_stk_purch_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaStKSaleCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.股本减少_GSD时间序列
    return w.wsd(security,"wgsd_qfa_stk_sale_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaDivCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.支付的股利合计_GSD时间序列
    return w.wsd(security,"wgsd_qfa_div_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWgsDQfaForExChCfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取单季度.汇率变动影响_GSD时间序列
    return w.wsd(security,"wgsd_qfa_for_exch_cf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArdBsPerpetualSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取永续债_合计_GSD时间序列
    return w.wsd(security,"ard_bs_perpetual",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getIsSharePaymentsSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取股权激励支出_GSD时间序列
    return w.wsd(security,"is_sharepayments",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPbMrQGsDSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市净率PB(MRQ,海外)时间序列
    return w.wsd(security,"pb_mrq_gsd",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getStDebtRatioSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取现金短债比(公告值)_GSD时间序列
    return w.wsd(security,"stdebtratio",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArdBsPerPMinSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取永续债_归属于少数股东_GSD时间序列
    return w.wsd(security,"ard_bs_perp_min",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArdBsPerPParSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取永续债_归属于母公司股东_GSD时间序列
    return w.wsd(security,"ard_bs_perp_par",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getArdIsInvestmentPropertySeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取投资物业公允价值变动(公布值)_GSD时间序列
    return w.wsd(security,"ard_is_investmentproperty",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgRoeFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测ROE(FY1)时间序列
    return w.wsd(security,"west_avgroe_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgRoeFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测ROE(FY2)时间序列
    return w.wsd(security,"west_avgroe_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgRoeFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测ROE(FY3)时间序列
    return w.wsd(security,"west_avgroe_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgRoeYoYSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测ROE同比时间序列
    return w.wsd(security,"west_avgroe_YOY",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPelYrRefSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取参考市盈率PE(LYR)时间序列
    return w.wsd(security,"pelyr_ref",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPeLyRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(LYR)时间序列
    return w.wsd(security,"pe_lyr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPbLyRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市净率PB(LYR)时间序列
    return w.wsd(security,"pb_lyr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPsLyRSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市销率PS(LYR)时间序列
    return w.wsd(security,"ps_lyr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取PER(LYR)时间序列
    return w.wsd(security,"val_per",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPeWGtSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市盈率PE(LYR,加权)时间序列
    return w.wsd(security,"val_pe_wgt",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPcfNflYrSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市现率PCF(现金净流量LYR)时间序列
    return w.wsd(security,"pcf_nflyr",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPSlyRHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高PS(LYR)时间序列
    return w.wsd(security,"val_pslyr_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPSlyRLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低PS(LYR)时间序列
    return w.wsd(security,"val_pslyr_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPSlyRAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间平均PS(LYR)时间序列
    return w.wsd(security,"val_pslyr_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getPbLfSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取市净率PB(LF,内地)时间序列
    return w.wsd(security,"pb_lf",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbHighSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最高PB(LF)时间序列
    return w.wsd(security,"val_pb_high",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbLowSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间最低PB(LF)时间序列
    return w.wsd(security,"val_pb_low",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbAvgSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取区间平均PB(LF)时间序列
    return w.wsd(security,"val_pb_avg",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getValPbLfIssuerSeries(security:list, startDate,endDate,*args,**kwargs):
    # 获取发布方市净率PB(LF)时间序列
    return w.wsd(security,"val_pb_lf_issuer",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgDpsFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股股利(FY1)时间序列
    return w.wsd(security,"west_avgdps_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgDpsFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股股利(FY2)时间序列
    return w.wsd(security,"west_avgdps_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgDpsFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股股利(FY3)时间序列
    return w.wsd(security,"west_avgdps_FY3",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgCpSFy1Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股现金流(FY1)时间序列
    return w.wsd(security,"west_avgcps_FY1",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgCpSFy2Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股现金流(FY2)时间序列
    return w.wsd(security,"west_avgcps_FY2",startDate,endDate,*args,**kwargs,usedf=True)
@convertInputSecurityType
def getWestAvgCpSFy3Series(security:list, startDate,endDate,*args,**kwargs):
    # 获取一致预测每股现金流(FY3)时间序列
    return w.wsd(security,"west_avgcps_FY3",startDate,endDate,*args,**kwargs,usedf=True)